{
 "cells": [
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "import numpy as np\n",
    "import matplotlib.pyplot as plt\n",
    "%matplotlib inline\n",
    "import matplotlib_inline\n",
    "matplotlib_inline.backend_inline.set_matplotlib_formats('svg')\n",
    "import seaborn as sns\n",
    "sns.set_context(\"paper\")\n",
    "sns.set_style(\"ticks\")\n",
    "\n",
    "import torch\n",
    "import gpytorch\n",
    "from gpytorch.kernels import RBFKernel, ScaleKernel\n",
    "\n",
    "\n",
    "class ExactGP(gpytorch.models.ExactGP):\n",
    "    def __init__(self,\n",
    "                 train_x,\n",
    "                 train_y,\n",
    "                 likelihood=gpytorch.likelihoods.GaussianLikelihood(\n",
    "                     noise_constraint=gpytorch.constraints.GreaterThan(0.0)\n",
    "                ),\n",
    "                mean_module=gpytorch.means.ConstantMean(),\n",
    "                covar_module=ScaleKernel(RBFKernel())\n",
    "        ):\n",
    "        super().__init__(train_x, train_y, likelihood)\n",
    "        self.mean_module = mean_module\n",
    "        self.covar_module = covar_module\n",
    "\n",
    "    def forward(self, x):\n",
    "        mean_x = self.mean_module(x)\n",
    "        covar_x = self.covar_module(x)\n",
    "        return gpytorch.distributions.MultivariateNormal(mean_x, covar_x)\n",
    "\n",
    "\n",
    "def plot_1d_regression(\n",
    "    x_star,\n",
    "    model,\n",
    "    ax=None,\n",
    "    f_true=None,\n",
    "    num_samples=10\n",
    "):\n",
    "    \"\"\"Plot the posterior predictive.\n",
    "    \n",
    "    Arguments\n",
    "    x_start  --  The test points on which to evaluate.\n",
    "    model    --  The trained model.\n",
    "    \n",
    "    Keyword Arguments\n",
    "    ax          --  An axes object to write on.\n",
    "    f_true      --  The true function.\n",
    "    num_samples --  The number of samples.\n",
    "    \"\"\"\n",
    "    f_star = model(x_star)\n",
    "    m_star = f_star.mean\n",
    "    v_star = f_star.variance\n",
    "    y_star = model.likelihood(f_star)\n",
    "    yv_star = y_star.variance\n",
    "\n",
    "    f_lower = (\n",
    "        m_star - 2.0 * torch.sqrt(v_star)\n",
    "    )\n",
    "    f_upper = (\n",
    "        m_star + 2.0 * torch.sqrt(v_star)\n",
    "    )\n",
    "    \n",
    "    y_lower = m_star - 2.0 * torch.sqrt(yv_star)\n",
    "    y_upper = m_star + 2.0 * torch.sqrt(yv_star)\n",
    "\n",
    "    if ax is None:\n",
    "        fig, ax = plt.subplots()\n",
    "    \n",
    "    ax.plot(model.train_inputs[0].flatten().detach(),\n",
    "            model.train_targets.detach(),\n",
    "            'kx',\n",
    "            markersize=10,\n",
    "            markeredgewidth=2,\n",
    "            label='Observations'\n",
    "    )\n",
    "\n",
    "    ax.plot(\n",
    "        x_star,\n",
    "        m_star.detach(),\n",
    "        lw=2,\n",
    "        label='$m_n(x)$',\n",
    "        color=sns.color_palette()[0]\n",
    "    )\n",
    "    \n",
    "    ax.fill_between(\n",
    "        x_star.flatten().detach(),\n",
    "        f_lower.flatten().detach(),\n",
    "        f_upper.flatten().detach(),\n",
    "        alpha=0.5,\n",
    "        label='$f(\\mathbf{x}^*)$ 95% pred.',\n",
    "        color=sns.color_palette()[0]\n",
    "    )\n",
    "\n",
    "    ax.fill_between(\n",
    "        x_star.detach().flatten(),\n",
    "        y_lower.detach().flatten(),\n",
    "        f_lower.detach().flatten(),\n",
    "        color=sns.color_palette()[1],\n",
    "        alpha=0.5,\n",
    "        label='$y^*$ 95% pred.'\n",
    "    )\n",
    "    ax.fill_between(\n",
    "        x_star.detach().flatten(),\n",
    "        f_upper.detach().flatten(),\n",
    "        y_upper.detach().flatten(),\n",
    "        color=sns.color_palette()[1],\n",
    "        alpha=0.5,\n",
    "        label=None\n",
    "    )\n",
    "\n",
    "    \n",
    "    if f_true is not None:\n",
    "        ax.plot(\n",
    "            x_star,\n",
    "            f_true(x_star),\n",
    "            'm-.',\n",
    "            label='True function'\n",
    "        )\n",
    "        \n",
    "    if num_samples > 0:\n",
    "        f_post_samples = f_star.sample(\n",
    "            sample_shape=torch.Size([10])\n",
    "        )\n",
    "        ax.plot(\n",
    "            x_star.numpy(),\n",
    "            f_post_samples.T.detach().numpy(),\n",
    "            color=\"red\",\n",
    "            lw=0.5\n",
    "        )\n",
    "        # This is just to add the legend entry\n",
    "        ax.plot(\n",
    "            [],\n",
    "            [],\n",
    "            color=\"red\",\n",
    "            lw=0.5,\n",
    "            label=\"Posterior samples\"\n",
    "        )\n",
    "        \n",
    "    ax.set_xlabel('$x$')\n",
    "    ax.set_ylabel('$y$')\n",
    "\n",
    "    plt.legend(loc='best', frameon=False)\n",
    "    sns.despine(trim=True)\n",
    "    \n",
    "    return m_star, v_star\n",
    "\n",
    "\n",
    "def train(model, train_x, train_y, n_iter=10, lr=0.1):\n",
    "    \"\"\"Train the model.\n",
    "\n",
    "    Arguments\n",
    "    model   --  The model to train.\n",
    "    train_x --  The training inputs.\n",
    "    train_y --  The training labels.\n",
    "    n_iter  --  The number of iterations.\n",
    "    \"\"\"\n",
    "    model.train()\n",
    "    optimizer = torch.optim.LBFGS(model.parameters(), line_search_fn='strong_wolfe')\n",
    "    likelihood = model.likelihood\n",
    "    mll = gpytorch.mlls.ExactMarginalLogLikelihood(likelihood, model)\n",
    "    def closure():\n",
    "        optimizer.zero_grad()\n",
    "        output = model(train_x)\n",
    "        loss = -mll(output, train_y)\n",
    "        loss.backward()\n",
    "        return loss\n",
    "    for i in range(n_iter):\n",
    "        loss = optimizer.step(closure)\n",
    "        if (i + 1) % 1 == 0:\n",
    "            print(f'Iter {i + 1:3d}/{n_iter} - Loss: {loss.item():.3f}')\n",
    "    model.eval()\n",
    "\n",
    "\n",
    "def plot_iaf(\n",
    "    x_star,\n",
    "    gpr,\n",
    "    alpha,\n",
    "    alpha_params={},\n",
    "    ax=None,\n",
    "    f_true=None\n",
    "):\n",
    "    \"\"\"Plot the information acquisition function.\n",
    "    \n",
    "    Arguments\n",
    "    x_star       -- A set of points to plot on.\n",
    "    gpr          -- A rained Gaussian process regression\n",
    "                    object.\n",
    "    alpha        -- The information acquisition function.\n",
    "                    This assumed to be a function of the\n",
    "                    posterior mean and standard deviation.\n",
    "              \n",
    "    Keyword Arguments\n",
    "    ax           -- An axes object to plot on.\n",
    "    f_true       -- The true function - if available.\n",
    "    \n",
    "    The evaluation of the information acquisition function\n",
    "    is as follows:\n",
    "    \n",
    "        af_values = alpha(mu, sigma, y_max, **alpha_params)\n",
    "\n",
    "    \"\"\"\n",
    "    if ax is None:\n",
    "        fig, ax = plt.subplots()\n",
    "    \n",
    "    ax.set_title(\n",
    "        \", \".join(\n",
    "            f\"{n}={k:.2f}\"\n",
    "            for n, k in alpha_params.items()\n",
    "            )\n",
    "    )\n",
    "    \n",
    "    m, v = plot_1d_regression(\n",
    "        x_star,\n",
    "        gpr,\n",
    "        ax=ax,\n",
    "        f_true=f_true,\n",
    "        num_samples=0\n",
    "    )\n",
    "    \n",
    "    sigma = torch.sqrt(v)\n",
    "    af_values = alpha(m, sigma, gpr.train_targets.numpy().max(), **alpha_params)\n",
    "    next_id = torch.argmax(af_values)\n",
    "    next_x = x_star[next_id]\n",
    "    af_max = af_values[next_id]\n",
    "    \n",
    "    ax2 = ax.twinx()\n",
    "    ax2.plot(x_star, af_values.detach(), color=sns.color_palette()[1])\n",
    "    ax2.set_ylabel(\n",
    "        'Maximum Upper Interval',\n",
    "        color=sns.color_palette()[1]\n",
    "    )\n",
    "    plt.setp(\n",
    "        ax2.get_yticklabels(),\n",
    "        color=sns.color_palette()[1]\n",
    "    )\n",
    "    ax2.plot(\n",
    "        next_x * np.ones(100),\n",
    "        torch.linspace(0, af_max.item(), 100),\n",
    "        color=sns.color_palette()[1],\n",
    "        linewidth=1\n",
    "    )\n",
    "\n",
    "\n",
    "def maximize(\n",
    "    f,\n",
    "    model,\n",
    "    X_design,\n",
    "    alpha,\n",
    "    alpha_params={},\n",
    "    max_it=10,\n",
    "    optimize=False,\n",
    "    plot=False,\n",
    "    **kwargs\n",
    "):\n",
    "    \"\"\"Optimize a function using a limited number of evaluations.\n",
    "    \n",
    "    Arguments\n",
    "    f            -- The function to optimize.\n",
    "    gpr          -- A Gaussian process model to use for representing\n",
    "                    our state of knowledge.\n",
    "    X_design     -- The set of candidate points for identifying the\n",
    "                    maximum.\n",
    "    alpha        -- The information acquisition function.\n",
    "                    This assumed to be a function of the\n",
    "                    posterior mean and standard deviation.\n",
    "    \n",
    "    Keyword Arguments\n",
    "    alpha_params -- Extra parameters to the information\n",
    "                    acquisition function.\n",
    "    max_it       -- The maximum number of iterations.\n",
    "    optimize     -- Whether or not to optimize the hyper-parameters.\n",
    "    plot         -- Determines how often to plot. Make it one\n",
    "                    to plot at each iteration. Make it max_it\n",
    "                    to plot at the last iteration.\n",
    "                    \n",
    "    The rest of the keyword arguments are passed to plot_iaf().\n",
    "    \"\"\"\n",
    "    af_all = []\n",
    "    for count in range(max_it):\n",
    "        # Predict\n",
    "        f_design = model(X_design)\n",
    "        m = f_design.mean\n",
    "        sigma2 = f_design.variance\n",
    "        sigma = torch.sqrt(sigma2)\n",
    "        \n",
    "        # Evaluate information acquisition function\n",
    "        y_train = model.train_targets.numpy()\n",
    "        af_values = alpha(\n",
    "            m,\n",
    "            sigma,\n",
    "            y_train.max(),\n",
    "            **alpha_params\n",
    "        )\n",
    "        \n",
    "        # Find best point to include\n",
    "        i = torch.argmax(af_values)\n",
    "        af_all.append(af_values[i])\n",
    "        \n",
    "        new_x = X_design[i:(i+1)].float()\n",
    "        new_y = f(new_x)\n",
    "        train_x = torch.cat([model.train_inputs[0], new_x[:, None]])\n",
    "        train_y = torch.cat([model.train_targets, new_y])\n",
    "        model.set_train_data(train_x, train_y, strict=False)\n",
    "        \n",
    "        if optimize:\n",
    "            train(model, train_x, train_y, n_iter=100, lr=0.1)\n",
    "        else:\n",
    "            model.train()\n",
    "            model.eval()\n",
    "        \n",
    "        # Plot if required\n",
    "        if count % plot == 0:\n",
    "            if \"ax\" in kwargs:\n",
    "                ax = kwargs[ax]\n",
    "            else:\n",
    "                fig, ax = plt.subplots()\n",
    "            plot_iaf(\n",
    "                X_design,\n",
    "                model,\n",
    "                alpha,\n",
    "                alpha_params=alpha_params,\n",
    "                f_true=f,\n",
    "                ax=ax\n",
    "            )\n",
    "            ax.set_title(\n",
    "                f\"N={count}, \" + ax.get_title()\n",
    "            )\n",
    "    return af_all"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "!pip install gpytorch"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Maximum Upper Interval\n",
    "\n",
    "We develop intuition about the maximum upper interval acquisition function.\n",
    "\n",
    "## Exploration vs Exploitation\n",
    "\n",
    "The question is this: \"Where should we evaluate the function next if our goal is to maximize it?\"\n",
    "Two possibilities for choosing a point for the subsequent evaluation are:\n",
    "+ **Exploitation:** We can select a point $\\mathbf{x}$ that *exploits* our current state of knowledge by concentrating on the region where the model thinks the maximum is. In our working example, that would be next to the leftmost observation.\n",
    "+ **Exploration:** We can *explore* the regions of maximum predictive uncertainty because there is a high chance that they may hide the maximum of the function. In our working example, this is the region between the two observations on the right.\n",
    "\n",
    "Generally speaking, focusing exclusively on exploration or exploitation is a terrible idea.\n",
    "On the one hand, if we focus on exploration, we will, in the end, recover the actual response surface (and as a consequence, we will get the correct maximum of the function). Still, we waste a lot of evaluations on regions that are unlikely to contain the maximum.\n",
    "If, on the other hand, we focus on exploitation, we will very quickly converge to a local maximum,  and a lot of the input space will remain unexplored; see the previous hands-on activity.\n",
    "\n",
    "So, what should a good *information acquisition function* $a_n(\\mathbf{x})$ for optimization do?\n",
    "It should *strike a balance between exploration and exploitation* in a way that provably reveals the global maximum of the function in the limit of infinite evaluations.\n",
    "Are there such information acquisition algorithms? Yes, there are.\n",
    "We will explore the first such acquisition function, the maximum upper interval, in this hands-on activity."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Let's reintroduce the same running example as the previous hands-on activity."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "scrolled": true,
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"414.864875pt\" height=\"309.639375pt\" viewBox=\"0 0 414.864875 309.639375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:10.100450</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 309.639375 \n",
       "L 414.864875 309.639375 \n",
       "L 414.864875 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 50.544875 273.312 \n",
       "L 407.664875 273.312 \n",
       "L 407.664875 7.2 \n",
       "L 50.544875 7.2 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m260dec6026\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m260dec6026\" x=\"73.778876\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(67.662876 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m260dec6026\" x=\"117.315919\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.3 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(111.199919 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m260dec6026\" x=\"160.852962\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(154.736962 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m260dec6026\" x=\"204.390005\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(198.274005 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m260dec6026\" x=\"247.927048\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(241.811048 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m260dec6026\" x=\"291.464091\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 0.7 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(285.348091 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-37\" d=\"M 303 3981 \n",
       "L 303 4522 \n",
       "L 3269 4522 \n",
       "L 3269 4084 \n",
       "Q 2831 3619 2401 2847 \n",
       "Q 1972 2075 1738 1259 \n",
       "Q 1569 684 1522 0 \n",
       "L 944 0 \n",
       "Q 953 541 1156 1306 \n",
       "Q 1359 2072 1739 2783 \n",
       "Q 2119 3494 2547 3981 \n",
       "L 303 3981 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-37\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_7\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m260dec6026\" x=\"335.001134\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_7\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(328.885134 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_8\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m260dec6026\" x=\"378.538177\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- 0.9 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(372.422177 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-39\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_9\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(226.224875 300.531375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <defs>\n",
       "       <path id=\"mb05e576493\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb05e576493\" x=\"50.544875\" y=\"245.1672\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −0.38 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 248.316637) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb05e576493\" x=\"50.544875\" y=\"213.255195\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −0.36 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 216.404633) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb05e576493\" x=\"50.544875\" y=\"181.343191\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- −0.34 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 184.492628) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb05e576493\" x=\"50.544875\" y=\"149.431186\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- −0.32 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 152.580624) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb05e576493\" x=\"50.544875\" y=\"117.519182\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- −0.30 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 120.668619) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb05e576493\" x=\"50.544875\" y=\"85.607177\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- −0.28 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 88.756615) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb05e576493\" x=\"50.544875\" y=\"53.695173\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_16\">\n",
       "      <!-- −0.26 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 56.84461) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_16\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb05e576493\" x=\"50.544875\" y=\"21.783168\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_17\">\n",
       "      <!-- −0.24 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 24.932606) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 143.136) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_17\">\n",
       "    <defs>\n",
       "     <path id=\"m28e713017b\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p78e5309a26)\">\n",
       "     <use xlink:href=\"#m28e713017b\" x=\"391.432148\" y=\"19.296\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m28e713017b\" x=\"124.445351\" y=\"85.049893\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m28e713017b\" x=\"66.777602\" y=\"261.216\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 50.544875 245.1672 \n",
       "L 50.544875 21.783168 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 73.778876 273.312 \n",
       "L 378.538177 273.312 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p78e5309a26\">\n",
       "   <rect x=\"50.544875\" y=\"7.2\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "def f(x):\n",
    "    \"\"\"A function to optimize.\"\"\"\n",
    "    return -4 * (1. - np.sin(6 * x + 8 * np.exp(6 * x - 7.))) \n",
    "\n",
    "np.random.seed(12345)\n",
    "\n",
    "n_init = 3\n",
    "\n",
    "X = np.random.rand(n_init)\n",
    "Y = f(X)\n",
    "\n",
    "plt.plot(X, Y, 'kx', markersize=10, markeredgewidth=2)\n",
    "plt.xlabel('$x$')\n",
    "plt.ylabel('$y$')\n",
    "sns.despine(trim=True);"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Maximum upper interval\n",
    "\n",
    "Just like in the previous hands-on activity, assume that we have made some observations and that we have used them to do Gaussian process regression resulting in the point-predictive distribution:\n",
    "\n",
    "$$\n",
    "p(y|\\mathbf{x},\\mathcal{D}_{n}) = \\mathcal{N}\\left(y|m_{n}(\\mathbf{x}), \\sigma^2_{n}(\\mathbf{x})\\right),\n",
    "$$\n",
    "\n",
    "where $m_{n}(\\mathbf{x})$ and $\\sigma^2_{n}(\\mathbf{x})$ are the predictive mean and variance respectively.\n",
    "Here is the code for this:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/Users/ibilion/.pyenv/versions/3.11.6/lib/python3.11/site-packages/linear_operator/utils/cholesky.py:40: NumericalWarning: A not p.d., added jitter of 1.0e-06 to the diagonal\n",
      "  warnings.warn(\n",
      "/Users/ibilion/.pyenv/versions/3.11.6/lib/python3.11/site-packages/linear_operator/utils/cholesky.py:40: NumericalWarning: A not p.d., added jitter of 1.0e-05 to the diagonal\n",
      "  warnings.warn(\n"
     ]
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"402.632875pt\" height=\"309.639375pt\" viewBox=\"0 0 402.632875 309.639375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:10.230644</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 309.639375 \n",
       "L 402.632875 309.639375 \n",
       "L 402.632875 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 38.312875 273.312 \n",
       "L 395.432875 273.312 \n",
       "L 395.432875 7.2 \n",
       "L 38.312875 7.2 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m35f5656bb4\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m35f5656bb4\" x=\"54.545602\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(48.429602 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m35f5656bb4\" x=\"119.476511\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(113.360511 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m35f5656bb4\" x=\"184.40742\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(178.29142 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m35f5656bb4\" x=\"249.33833\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(243.22233 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m35f5656bb4\" x=\"314.269239\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(308.153239 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m35f5656bb4\" x=\"379.200148\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(373.084148 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(213.992875 300.531375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"m82ca5cc8a2\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m82ca5cc8a2\" x=\"38.312875\" y=\"261.273565\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 264.423003) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m82ca5cc8a2\" x=\"38.312875\" y=\"220.543753\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 223.693191) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m82ca5cc8a2\" x=\"38.312875\" y=\"179.813941\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 182.963379) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m82ca5cc8a2\" x=\"38.312875\" y=\"139.084129\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 142.233567) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m82ca5cc8a2\" x=\"38.312875\" y=\"98.354317\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 101.503755) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m82ca5cc8a2\" x=\"38.312875\" y=\"57.624505\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 60.773943) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m82ca5cc8a2\" x=\"38.312875\" y=\"16.894693\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 20.044131) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-34\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_15\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 143.136) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"m1b738d7c6b\" d=\"M 54.545602 -275.586365 \n",
       "L 54.545602 -139.738011 \n",
       "L 57.824941 -141.772601 \n",
       "L 61.10428 -144.061443 \n",
       "L 64.383619 -146.609178 \n",
       "L 67.662958 -149.415772 \n",
       "L 70.942296 -152.475919 \n",
       "L 74.221636 -155.778693 \n",
       "L 77.500973 -159.307228 \n",
       "L 80.780313 -163.038474 \n",
       "L 84.059653 -166.943538 \n",
       "L 87.33899 -170.98742 \n",
       "L 90.61833 -175.129754 \n",
       "L 93.89767 -179.325104 \n",
       "L 97.177007 -183.523648 \n",
       "L 100.456344 -187.67267 \n",
       "L 103.735686 -191.716518 \n",
       "L 107.015024 -195.597713 \n",
       "L 110.294361 -199.256233 \n",
       "L 113.573703 -202.557131 \n",
       "L 116.853041 -200.890085 \n",
       "L 120.132378 -198.251434 \n",
       "L 123.41172 -196.083871 \n",
       "L 126.691057 -194.43293 \n",
       "L 129.970395 -193.328188 \n",
       "L 133.249737 -192.788402 \n",
       "L 136.529069 -192.823681 \n",
       "L 139.808412 -193.43399 \n",
       "L 143.087754 -194.609938 \n",
       "L 146.367086 -196.332605 \n",
       "L 149.646428 -198.574085 \n",
       "L 152.92577 -201.294867 \n",
       "L 156.205103 -204.407751 \n",
       "L 159.484445 -203.505617 \n",
       "L 162.763787 -200.244031 \n",
       "L 166.04312 -196.688382 \n",
       "L 169.322462 -192.906465 \n",
       "L 172.601804 -188.955634 \n",
       "L 175.881137 -184.892047 \n",
       "L 179.160479 -180.770315 \n",
       "L 182.439821 -176.642591 \n",
       "L 185.719153 -172.557849 \n",
       "L 188.998496 -168.560814 \n",
       "L 192.277838 -164.691335 \n",
       "L 195.55717 -160.9839 \n",
       "L 198.836512 -157.467212 \n",
       "L 202.115855 -154.164064 \n",
       "L 205.395187 -151.091327 \n",
       "L 208.674529 -148.260072 \n",
       "L 211.953871 -145.675965 \n",
       "L 215.233204 -143.339609 \n",
       "L 218.512556 -141.247157 \n",
       "L 221.791879 -139.390944 \n",
       "L 225.071221 -137.760126 \n",
       "L 228.350563 -136.341455 \n",
       "L 231.629886 -135.120003 \n",
       "L 234.909247 -134.079881 \n",
       "L 238.18857 -133.204957 \n",
       "L 241.467912 -132.479472 \n",
       "L 244.747254 -131.888656 \n",
       "L 248.026597 -131.419263 \n",
       "L 251.305939 -131.059975 \n",
       "L 254.585262 -130.801786 \n",
       "L 257.864623 -130.638276 \n",
       "L 261.143946 -130.565805 \n",
       "L 264.423288 -130.583605 \n",
       "L 267.70263 -130.693793 \n",
       "L 270.981953 -130.90136 \n",
       "L 274.261315 -131.213992 \n",
       "L 277.540637 -131.641872 \n",
       "L 280.81998 -132.197438 \n",
       "L 284.099322 -132.895029 \n",
       "L 287.378664 -133.750434 \n",
       "L 290.658006 -134.780554 \n",
       "L 293.937329 -136.002802 \n",
       "L 297.21669 -137.434685 \n",
       "L 300.496013 -139.093091 \n",
       "L 303.775355 -140.99395 \n",
       "L 307.054697 -143.151454 \n",
       "L 310.33402 -145.577683 \n",
       "L 313.613382 -148.281994 \n",
       "L 316.892705 -151.270611 \n",
       "L 320.172047 -154.546225 \n",
       "L 323.451389 -158.107669 \n",
       "L 326.730731 -161.949599 \n",
       "L 330.010073 -166.062502 \n",
       "L 333.289396 -170.432526 \n",
       "L 336.568738 -175.041668 \n",
       "L 339.84808 -179.867951 \n",
       "L 343.127423 -184.885221 \n",
       "L 346.406765 -190.064174 \n",
       "L 349.686088 -195.372681 \n",
       "L 352.96543 -200.772864 \n",
       "L 356.244772 -205.984662 \n",
       "L 359.524114 -201.120069 \n",
       "L 362.803456 -195.715803 \n",
       "L 366.082798 -190.400722 \n",
       "L 369.362141 -185.212487 \n",
       "L 372.641463 -180.183953 \n",
       "L 375.920806 -175.345 \n",
       "L 379.200148 -170.721316 \n",
       "L 379.200148 -243.149992 \n",
       "L 379.200148 -243.149992 \n",
       "L 375.920806 -238.267367 \n",
       "L 372.641463 -233.203513 \n",
       "L 369.362141 -227.987003 \n",
       "L 366.082798 -222.650205 \n",
       "L 362.803456 -217.227945 \n",
       "L 359.524114 -211.759313 \n",
       "L 356.244772 -206.874049 \n",
       "L 352.96543 -212.109128 \n",
       "L 349.686088 -217.576236 \n",
       "L 346.406765 -222.994386 \n",
       "L 343.127423 -228.324203 \n",
       "L 339.84808 -233.531537 \n",
       "L 336.568738 -238.584571 \n",
       "L 333.289396 -243.454164 \n",
       "L 330.010073 -248.115013 \n",
       "L 326.730731 -252.54545 \n",
       "L 323.451389 -256.727732 \n",
       "L 320.172047 -260.648299 \n",
       "L 316.892705 -264.29765 \n",
       "L 313.613382 -267.670473 \n",
       "L 310.33402 -270.76536 \n",
       "L 307.054697 -273.584544 \n",
       "L 303.775355 -276.133575 \n",
       "L 300.496013 -278.42097 \n",
       "L 297.21669 -280.457571 \n",
       "L 293.937329 -282.256297 \n",
       "L 290.658006 -283.831297 \n",
       "L 287.378664 -285.197691 \n",
       "L 284.099322 -286.370802 \n",
       "L 280.81998 -287.365745 \n",
       "L 277.540637 -288.196844 \n",
       "L 274.261315 -288.877213 \n",
       "L 270.981953 -289.41832 \n",
       "L 267.70263 -289.829589 \n",
       "L 264.423288 -290.118125 \n",
       "L 261.143946 -290.288451 \n",
       "L 257.864623 -290.342336 \n",
       "L 254.585262 -290.278721 \n",
       "L 251.305939 -290.093721 \n",
       "L 248.026597 -289.780637 \n",
       "L 244.747254 -289.3302 \n",
       "L 241.467912 -288.73077 \n",
       "L 238.18857 -287.968715 \n",
       "L 234.909247 -287.028836 \n",
       "L 231.629886 -285.894869 \n",
       "L 228.350563 -284.55013 \n",
       "L 225.071221 -282.978125 \n",
       "L 221.791879 -281.163328 \n",
       "L 218.512556 -279.091886 \n",
       "L 215.233204 -276.752383 \n",
       "L 211.953871 -274.136697 \n",
       "L 208.674529 -271.240623 \n",
       "L 205.395187 -268.064608 \n",
       "L 202.115855 -264.614356 \n",
       "L 198.836512 -260.901288 \n",
       "L 195.55717 -256.942917 \n",
       "L 192.277838 -252.763083 \n",
       "L 188.998496 -248.391913 \n",
       "L 185.719153 -243.865803 \n",
       "L 182.439821 -239.226985 \n",
       "L 179.160479 -234.523055 \n",
       "L 175.881137 -229.806383 \n",
       "L 172.601804 -225.133011 \n",
       "L 169.322462 -220.561944 \n",
       "L 166.04312 -216.154184 \n",
       "L 162.763787 -211.972351 \n",
       "L 159.484445 -208.089871 \n",
       "L 156.205103 -206.578042 \n",
       "L 152.92577 -209.098556 \n",
       "L 149.646428 -211.25052 \n",
       "L 146.367086 -212.95298 \n",
       "L 143.087754 -214.172565 \n",
       "L 139.808412 -214.887296 \n",
       "L 136.529069 -215.083864 \n",
       "L 133.249737 -214.758039 \n",
       "L 129.970395 -213.9144 \n",
       "L 126.691057 -212.567057 \n",
       "L 123.41172 -210.737999 \n",
       "L 120.132378 -208.459276 \n",
       "L 116.853041 -205.778016 \n",
       "L 113.573703 -204.137619 \n",
       "L 110.294361 -207.534213 \n",
       "L 107.015024 -211.356381 \n",
       "L 103.735686 -215.467164 \n",
       "L 100.456344 -219.803696 \n",
       "L 97.177007 -224.304869 \n",
       "L 93.89767 -228.910682 \n",
       "L 90.61833 -233.563466 \n",
       "L 87.33899 -238.207913 \n",
       "L 84.059653 -242.792695 \n",
       "L 80.780313 -247.271273 \n",
       "L 77.500973 -251.602275 \n",
       "L 74.221636 -255.750423 \n",
       "L 70.942296 -259.686289 \n",
       "L 67.662958 -263.38684 \n",
       "L 64.383619 -266.835218 \n",
       "L 61.10428 -270.020521 \n",
       "L 57.824941 -272.93759 \n",
       "L 54.545602 -275.586365 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pd2dc3bce01)\">\n",
       "     <use xlink:href=\"#m1b738d7c6b\" x=\"0\" y=\"309.639375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m8e0205bf4e\" d=\"M 54.545602 -139.738011 \n",
       "L 54.545602 -139.736792 \n",
       "L 57.824941 -141.771338 \n",
       "L 61.10428 -144.060132 \n",
       "L 64.383619 -146.607799 \n",
       "L 67.662958 -149.41432 \n",
       "L 70.942296 -152.474375 \n",
       "L 74.221636 -155.777033 \n",
       "L 77.500973 -159.305431 \n",
       "L 80.780313 -163.036503 \n",
       "L 84.059653 -166.941354 \n",
       "L 87.33899 -170.984953 \n",
       "L 90.61833 -175.126913 \n",
       "L 93.89767 -179.321758 \n",
       "L 97.177007 -183.519579 \n",
       "L 100.456344 -187.667509 \n",
       "L 103.735686 -191.709536 \n",
       "L 107.015024 -195.587192 \n",
       "L 110.294361 -199.236242 \n",
       "L 113.573703 -202.458344 \n",
       "L 116.853041 -200.856378 \n",
       "L 120.132378 -198.235209 \n",
       "L 123.41172 -196.07256 \n",
       "L 126.691057 -194.423786 \n",
       "L 129.970395 -193.320133 \n",
       "L 133.249737 -192.780852 \n",
       "L 136.529069 -192.81623 \n",
       "L 139.808412 -193.42626 \n",
       "L 143.087754 -194.601461 \n",
       "L 146.367086 -196.322629 \n",
       "L 149.646428 -198.561012 \n",
       "L 152.92577 -201.273667 \n",
       "L 156.205103 -204.333831 \n",
       "L 159.484445 -203.469711 \n",
       "L 162.763787 -200.229903 \n",
       "L 166.04312 -196.679863 \n",
       "L 169.322462 -192.900469 \n",
       "L 172.601804 -188.951051 \n",
       "L 175.881137 -184.888355 \n",
       "L 179.160479 -180.767229 \n",
       "L 182.439821 -176.63994 \n",
       "L 185.719153 -172.555523 \n",
       "L 188.998496 -168.558736 \n",
       "L 192.277838 -164.689451 \n",
       "L 195.55717 -160.982171 \n",
       "L 198.836512 -157.46561 \n",
       "L 202.115855 -154.162563 \n",
       "L 205.395187 -151.089909 \n",
       "L 208.674529 -148.258722 \n",
       "L 211.953871 -145.674674 \n",
       "L 215.233204 -143.338366 \n",
       "L 218.512556 -141.245958 \n",
       "L 221.791879 -139.389778 \n",
       "L 225.071221 -137.758985 \n",
       "L 228.350563 -136.340338 \n",
       "L 231.629886 -135.118901 \n",
       "L 234.909247 -134.078798 \n",
       "L 238.18857 -133.203889 \n",
       "L 241.467912 -132.478414 \n",
       "L 244.747254 -131.887607 \n",
       "L 248.026597 -131.418219 \n",
       "L 251.305939 -131.058931 \n",
       "L 254.585262 -130.800747 \n",
       "L 257.864623 -130.637237 \n",
       "L 261.143946 -130.564766 \n",
       "L 264.423288 -130.582566 \n",
       "L 267.70263 -130.692754 \n",
       "L 270.981953 -130.900316 \n",
       "L 274.261315 -131.212939 \n",
       "L 277.540637 -131.640814 \n",
       "L 280.81998 -132.19637 \n",
       "L 284.099322 -132.893951 \n",
       "L 287.378664 -133.749341 \n",
       "L 290.658006 -134.779443 \n",
       "L 293.937329 -136.001671 \n",
       "L 297.21669 -137.43353 \n",
       "L 300.496013 -139.091901 \n",
       "L 303.775355 -140.992721 \n",
       "L 307.054697 -143.150186 \n",
       "L 310.33402 -145.576357 \n",
       "L 313.613382 -148.280605 \n",
       "L 316.892705 -151.269145 \n",
       "L 320.172047 -154.544662 \n",
       "L 323.451389 -158.105985 \n",
       "L 326.730731 -161.947769 \n",
       "L 330.010073 -166.060477 \n",
       "L 333.289396 -170.430254 \n",
       "L 336.568738 -175.039055 \n",
       "L 339.84808 -179.864861 \n",
       "L 343.127423 -184.881402 \n",
       "L 346.406765 -190.059139 \n",
       "L 349.686088 -195.365212 \n",
       "L 352.96543 -200.75825 \n",
       "L 356.244772 -205.826327 \n",
       "L 359.524114 -201.104499 \n",
       "L 362.803456 -195.708092 \n",
       "L 366.082798 -190.395577 \n",
       "L 369.362141 -185.20861 \n",
       "L 372.641463 -180.180824 \n",
       "L 375.920806 -175.342363 \n",
       "L 379.200148 -170.719027 \n",
       "L 379.200148 -170.721316 \n",
       "L 379.200148 -170.721316 \n",
       "L 375.920806 -175.345 \n",
       "L 372.641463 -180.183953 \n",
       "L 369.362141 -185.212487 \n",
       "L 366.082798 -190.400722 \n",
       "L 362.803456 -195.715803 \n",
       "L 359.524114 -201.120069 \n",
       "L 356.244772 -205.984662 \n",
       "L 352.96543 -200.772864 \n",
       "L 349.686088 -195.372681 \n",
       "L 346.406765 -190.064174 \n",
       "L 343.127423 -184.885221 \n",
       "L 339.84808 -179.867951 \n",
       "L 336.568738 -175.041668 \n",
       "L 333.289396 -170.432526 \n",
       "L 330.010073 -166.062502 \n",
       "L 326.730731 -161.949599 \n",
       "L 323.451389 -158.107669 \n",
       "L 320.172047 -154.546225 \n",
       "L 316.892705 -151.270611 \n",
       "L 313.613382 -148.281994 \n",
       "L 310.33402 -145.577683 \n",
       "L 307.054697 -143.151454 \n",
       "L 303.775355 -140.99395 \n",
       "L 300.496013 -139.093091 \n",
       "L 297.21669 -137.434685 \n",
       "L 293.937329 -136.002802 \n",
       "L 290.658006 -134.780554 \n",
       "L 287.378664 -133.750434 \n",
       "L 284.099322 -132.895029 \n",
       "L 280.81998 -132.197438 \n",
       "L 277.540637 -131.641872 \n",
       "L 274.261315 -131.213992 \n",
       "L 270.981953 -130.90136 \n",
       "L 267.70263 -130.693793 \n",
       "L 264.423288 -130.583605 \n",
       "L 261.143946 -130.565805 \n",
       "L 257.864623 -130.638276 \n",
       "L 254.585262 -130.801786 \n",
       "L 251.305939 -131.059975 \n",
       "L 248.026597 -131.419263 \n",
       "L 244.747254 -131.888656 \n",
       "L 241.467912 -132.479472 \n",
       "L 238.18857 -133.204957 \n",
       "L 234.909247 -134.079881 \n",
       "L 231.629886 -135.120003 \n",
       "L 228.350563 -136.341455 \n",
       "L 225.071221 -137.760126 \n",
       "L 221.791879 -139.390944 \n",
       "L 218.512556 -141.247157 \n",
       "L 215.233204 -143.339609 \n",
       "L 211.953871 -145.675965 \n",
       "L 208.674529 -148.260072 \n",
       "L 205.395187 -151.091327 \n",
       "L 202.115855 -154.164064 \n",
       "L 198.836512 -157.467212 \n",
       "L 195.55717 -160.9839 \n",
       "L 192.277838 -164.691335 \n",
       "L 188.998496 -168.560814 \n",
       "L 185.719153 -172.557849 \n",
       "L 182.439821 -176.642591 \n",
       "L 179.160479 -180.770315 \n",
       "L 175.881137 -184.892047 \n",
       "L 172.601804 -188.955634 \n",
       "L 169.322462 -192.906465 \n",
       "L 166.04312 -196.688382 \n",
       "L 162.763787 -200.244031 \n",
       "L 159.484445 -203.505617 \n",
       "L 156.205103 -204.407751 \n",
       "L 152.92577 -201.294867 \n",
       "L 149.646428 -198.574085 \n",
       "L 146.367086 -196.332605 \n",
       "L 143.087754 -194.609938 \n",
       "L 139.808412 -193.43399 \n",
       "L 136.529069 -192.823681 \n",
       "L 133.249737 -192.788402 \n",
       "L 129.970395 -193.328188 \n",
       "L 126.691057 -194.43293 \n",
       "L 123.41172 -196.083871 \n",
       "L 120.132378 -198.251434 \n",
       "L 116.853041 -200.890085 \n",
       "L 113.573703 -202.557131 \n",
       "L 110.294361 -199.256233 \n",
       "L 107.015024 -195.597713 \n",
       "L 103.735686 -191.716518 \n",
       "L 100.456344 -187.67267 \n",
       "L 97.177007 -183.523648 \n",
       "L 93.89767 -179.325104 \n",
       "L 90.61833 -175.129754 \n",
       "L 87.33899 -170.98742 \n",
       "L 84.059653 -166.943538 \n",
       "L 80.780313 -163.038474 \n",
       "L 77.500973 -159.307228 \n",
       "L 74.221636 -155.778693 \n",
       "L 70.942296 -152.475919 \n",
       "L 67.662958 -149.415772 \n",
       "L 64.383619 -146.609178 \n",
       "L 61.10428 -144.061443 \n",
       "L 57.824941 -141.772601 \n",
       "L 54.545602 -139.738011 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pd2dc3bce01)\">\n",
       "     <use xlink:href=\"#m8e0205bf4e\" x=\"0\" y=\"309.639375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"m60ad6b751a\" d=\"M 54.545602 -275.587584 \n",
       "L 54.545602 -275.586365 \n",
       "L 57.824941 -272.93759 \n",
       "L 61.10428 -270.020521 \n",
       "L 64.383619 -266.835218 \n",
       "L 67.662958 -263.38684 \n",
       "L 70.942296 -259.686289 \n",
       "L 74.221636 -255.750423 \n",
       "L 77.500973 -251.602275 \n",
       "L 80.780313 -247.271273 \n",
       "L 84.059653 -242.792695 \n",
       "L 87.33899 -238.207913 \n",
       "L 90.61833 -233.563466 \n",
       "L 93.89767 -228.910682 \n",
       "L 97.177007 -224.304869 \n",
       "L 100.456344 -219.803696 \n",
       "L 103.735686 -215.467164 \n",
       "L 107.015024 -211.356381 \n",
       "L 110.294361 -207.534213 \n",
       "L 113.573703 -204.137619 \n",
       "L 116.853041 -205.778016 \n",
       "L 120.132378 -208.459276 \n",
       "L 123.41172 -210.737999 \n",
       "L 126.691057 -212.567057 \n",
       "L 129.970395 -213.9144 \n",
       "L 133.249737 -214.758039 \n",
       "L 136.529069 -215.083864 \n",
       "L 139.808412 -214.887296 \n",
       "L 143.087754 -214.172565 \n",
       "L 146.367086 -212.95298 \n",
       "L 149.646428 -211.25052 \n",
       "L 152.92577 -209.098556 \n",
       "L 156.205103 -206.578042 \n",
       "L 159.484445 -208.089871 \n",
       "L 162.763787 -211.972351 \n",
       "L 166.04312 -216.154184 \n",
       "L 169.322462 -220.561944 \n",
       "L 172.601804 -225.133011 \n",
       "L 175.881137 -229.806383 \n",
       "L 179.160479 -234.523055 \n",
       "L 182.439821 -239.226985 \n",
       "L 185.719153 -243.865803 \n",
       "L 188.998496 -248.391913 \n",
       "L 192.277838 -252.763083 \n",
       "L 195.55717 -256.942917 \n",
       "L 198.836512 -260.901288 \n",
       "L 202.115855 -264.614356 \n",
       "L 205.395187 -268.064608 \n",
       "L 208.674529 -271.240623 \n",
       "L 211.953871 -274.136697 \n",
       "L 215.233204 -276.752383 \n",
       "L 218.512556 -279.091886 \n",
       "L 221.791879 -281.163328 \n",
       "L 225.071221 -282.978125 \n",
       "L 228.350563 -284.55013 \n",
       "L 231.629886 -285.894869 \n",
       "L 234.909247 -287.028836 \n",
       "L 238.18857 -287.968715 \n",
       "L 241.467912 -288.73077 \n",
       "L 244.747254 -289.3302 \n",
       "L 248.026597 -289.780637 \n",
       "L 251.305939 -290.093721 \n",
       "L 254.585262 -290.278721 \n",
       "L 257.864623 -290.342336 \n",
       "L 261.143946 -290.288451 \n",
       "L 264.423288 -290.118125 \n",
       "L 267.70263 -289.829589 \n",
       "L 270.981953 -289.41832 \n",
       "L 274.261315 -288.877213 \n",
       "L 277.540637 -288.196844 \n",
       "L 280.81998 -287.365745 \n",
       "L 284.099322 -286.370802 \n",
       "L 287.378664 -285.197691 \n",
       "L 290.658006 -283.831297 \n",
       "L 293.937329 -282.256297 \n",
       "L 297.21669 -280.457571 \n",
       "L 300.496013 -278.42097 \n",
       "L 303.775355 -276.133575 \n",
       "L 307.054697 -273.584544 \n",
       "L 310.33402 -270.76536 \n",
       "L 313.613382 -267.670473 \n",
       "L 316.892705 -264.29765 \n",
       "L 320.172047 -260.648299 \n",
       "L 323.451389 -256.727732 \n",
       "L 326.730731 -252.54545 \n",
       "L 330.010073 -248.115013 \n",
       "L 333.289396 -243.454164 \n",
       "L 336.568738 -238.584571 \n",
       "L 339.84808 -233.531537 \n",
       "L 343.127423 -228.324203 \n",
       "L 346.406765 -222.994386 \n",
       "L 349.686088 -217.576236 \n",
       "L 352.96543 -212.109128 \n",
       "L 356.244772 -206.874049 \n",
       "L 359.524114 -211.759313 \n",
       "L 362.803456 -217.227945 \n",
       "L 366.082798 -222.650205 \n",
       "L 369.362141 -227.987003 \n",
       "L 372.641463 -233.203513 \n",
       "L 375.920806 -238.267367 \n",
       "L 379.200148 -243.149992 \n",
       "L 379.200148 -243.152282 \n",
       "L 379.200148 -243.152282 \n",
       "L 375.920806 -238.270004 \n",
       "L 372.641463 -233.206642 \n",
       "L 369.362141 -227.99088 \n",
       "L 366.082798 -222.65535 \n",
       "L 362.803456 -217.235654 \n",
       "L 359.524114 -211.774883 \n",
       "L 356.244772 -207.032385 \n",
       "L 352.96543 -212.123743 \n",
       "L 349.686088 -217.583705 \n",
       "L 346.406765 -222.999422 \n",
       "L 343.127423 -228.328021 \n",
       "L 339.84808 -233.534627 \n",
       "L 336.568738 -238.587183 \n",
       "L 333.289396 -243.456437 \n",
       "L 330.010073 -248.117038 \n",
       "L 326.730731 -252.547281 \n",
       "L 323.451389 -256.729416 \n",
       "L 320.172047 -260.649862 \n",
       "L 316.892705 -264.299116 \n",
       "L 313.613382 -267.671861 \n",
       "L 310.33402 -270.766685 \n",
       "L 307.054697 -273.585811 \n",
       "L 303.775355 -276.134804 \n",
       "L 300.496013 -278.42216 \n",
       "L 297.21669 -280.458726 \n",
       "L 293.937329 -282.257428 \n",
       "L 290.658006 -283.832409 \n",
       "L 287.378664 -285.198783 \n",
       "L 284.099322 -286.37188 \n",
       "L 280.81998 -287.366814 \n",
       "L 277.540637 -288.197903 \n",
       "L 274.261315 -288.878267 \n",
       "L 270.981953 -289.419364 \n",
       "L 267.70263 -289.830628 \n",
       "L 264.423288 -290.119164 \n",
       "L 261.143946 -290.28949 \n",
       "L 257.864623 -290.343375 \n",
       "L 254.585262 -290.27976 \n",
       "L 251.305939 -290.094765 \n",
       "L 248.026597 -289.781681 \n",
       "L 244.747254 -289.331248 \n",
       "L 241.467912 -288.731828 \n",
       "L 238.18857 -287.969783 \n",
       "L 234.909247 -287.029919 \n",
       "L 231.629886 -285.895971 \n",
       "L 228.350563 -284.551246 \n",
       "L 225.071221 -282.979266 \n",
       "L 221.791879 -281.164493 \n",
       "L 218.512556 -279.093085 \n",
       "L 215.233204 -276.753626 \n",
       "L 211.953871 -274.137988 \n",
       "L 208.674529 -271.241973 \n",
       "L 205.395187 -268.066025 \n",
       "L 202.115855 -264.615856 \n",
       "L 198.836512 -260.90289 \n",
       "L 195.55717 -256.944645 \n",
       "L 192.277838 -252.764966 \n",
       "L 188.998496 -248.393991 \n",
       "L 185.719153 -243.868129 \n",
       "L 182.439821 -239.229636 \n",
       "L 179.160479 -234.52614 \n",
       "L 175.881137 -229.810075 \n",
       "L 172.601804 -225.137597 \n",
       "L 169.322462 -220.567941 \n",
       "L 166.04312 -216.162703 \n",
       "L 162.763787 -211.986479 \n",
       "L 159.484445 -208.125777 \n",
       "L 156.205103 -206.651961 \n",
       "L 152.92577 -209.119756 \n",
       "L 149.646428 -211.263593 \n",
       "L 146.367086 -212.962955 \n",
       "L 143.087754 -214.181041 \n",
       "L 139.808412 -214.895026 \n",
       "L 136.529069 -215.091314 \n",
       "L 133.249737 -214.765588 \n",
       "L 129.970395 -213.922455 \n",
       "L 126.691057 -212.5762 \n",
       "L 123.41172 -210.749311 \n",
       "L 120.132378 -208.475502 \n",
       "L 116.853041 -205.811723 \n",
       "L 113.573703 -204.236406 \n",
       "L 110.294361 -207.554205 \n",
       "L 107.015024 -211.366901 \n",
       "L 103.735686 -215.474146 \n",
       "L 100.456344 -219.808859 \n",
       "L 97.177007 -224.308938 \n",
       "L 93.89767 -228.914027 \n",
       "L 90.61833 -233.566306 \n",
       "L 87.33899 -238.21038 \n",
       "L 84.059653 -242.794883 \n",
       "L 80.780313 -247.273245 \n",
       "L 77.500973 -251.604071 \n",
       "L 74.221636 -255.752084 \n",
       "L 70.942296 -259.687843 \n",
       "L 67.662958 -263.388292 \n",
       "L 64.383619 -266.836597 \n",
       "L 61.10428 -270.021842 \n",
       "L 57.824941 -272.938852 \n",
       "L 54.545602 -275.587584 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pd2dc3bce01)\">\n",
       "     <use xlink:href=\"#m60ad6b751a\" x=\"0\" y=\"309.639375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <defs>\n",
       "     <path id=\"m63f6a6ca9f\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pd2dc3bce01)\">\n",
       "     <use xlink:href=\"#m63f6a6ca9f\" x=\"356.349693\" y=\"103.21015\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m63f6a6ca9f\" x=\"157.258364\" y=\"104.049378\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m63f6a6ca9f\" x=\"114.255683\" y=\"106.297815\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 54.545602 101.977185 \n",
       "L 57.824941 102.284281 \n",
       "L 61.10428 102.598391 \n",
       "L 64.383619 102.917177 \n",
       "L 67.662958 103.238067 \n",
       "L 70.942296 103.558269 \n",
       "L 74.221636 103.874818 \n",
       "L 77.500973 104.184622 \n",
       "L 80.780313 104.484502 \n",
       "L 84.059653 104.771257 \n",
       "L 87.33899 105.041708 \n",
       "L 90.61833 105.292765 \n",
       "L 93.89767 105.521482 \n",
       "L 97.177007 105.725116 \n",
       "L 100.456344 105.901192 \n",
       "L 103.735686 106.047535 \n",
       "L 107.015024 106.162328 \n",
       "L 110.294361 106.244152 \n",
       "L 113.573703 106.292 \n",
       "L 116.853041 106.305324 \n",
       "L 120.132378 106.28402 \n",
       "L 123.41172 106.22844 \n",
       "L 126.691057 106.139382 \n",
       "L 129.970395 106.018081 \n",
       "L 133.249737 105.866155 \n",
       "L 136.529069 105.685603 \n",
       "L 139.808412 105.478732 \n",
       "L 143.087754 105.248124 \n",
       "L 146.367086 104.996583 \n",
       "L 149.646428 104.727072 \n",
       "L 152.92577 104.442664 \n",
       "L 156.205103 104.146479 \n",
       "L 159.484445 103.841631 \n",
       "L 162.763787 103.531184 \n",
       "L 166.04312 103.218092 \n",
       "L 169.322462 102.905171 \n",
       "L 172.601804 102.595052 \n",
       "L 175.881137 102.29016 \n",
       "L 179.160479 101.992689 \n",
       "L 182.439821 101.704587 \n",
       "L 185.719153 101.427549 \n",
       "L 188.998496 101.163012 \n",
       "L 192.277838 100.912168 \n",
       "L 195.55717 100.675966 \n",
       "L 198.836512 100.455126 \n",
       "L 202.115855 100.250164 \n",
       "L 205.395187 100.061409 \n",
       "L 208.674529 99.889026 \n",
       "L 211.953871 99.733044 \n",
       "L 215.233204 99.593378 \n",
       "L 218.512556 99.469854 \n",
       "L 221.791879 99.362237 \n",
       "L 225.071221 99.270247 \n",
       "L 228.350563 99.193582 \n",
       "L 231.629886 99.131938 \n",
       "L 234.909247 99.085015 \n",
       "L 238.18857 99.052537 \n",
       "L 241.467912 99.034254 \n",
       "L 244.747254 99.029945 \n",
       "L 248.026597 99.039424 \n",
       "L 251.305939 99.062528 \n",
       "L 254.585262 99.09912 \n",
       "L 257.864623 99.149069 \n",
       "L 261.143946 99.212248 \n",
       "L 264.423288 99.288511 \n",
       "L 267.70263 99.377683 \n",
       "L 270.981953 99.479535 \n",
       "L 274.261315 99.593775 \n",
       "L 277.540637 99.720019 \n",
       "L 280.81998 99.857782 \n",
       "L 284.099322 100.006462 \n",
       "L 287.378664 100.165312 \n",
       "L 290.658006 100.333449 \n",
       "L 293.937329 100.509826 \n",
       "L 297.21669 100.693248 \n",
       "L 300.496013 100.882345 \n",
       "L 303.775355 101.075611 \n",
       "L 307.054697 101.271378 \n",
       "L 310.33402 101.467855 \n",
       "L 313.613382 101.663142 \n",
       "L 316.892705 101.855244 \n",
       "L 320.172047 102.042114 \n",
       "L 323.451389 102.221674 \n",
       "L 326.730731 102.391851 \n",
       "L 330.010073 102.550618 \n",
       "L 333.289396 102.696029 \n",
       "L 336.568738 102.826257 \n",
       "L 339.84808 102.939631 \n",
       "L 343.127423 103.034664 \n",
       "L 346.406765 103.110095 \n",
       "L 349.686088 103.164916 \n",
       "L 352.96543 103.198379 \n",
       "L 356.244772 103.210019 \n",
       "L 359.524114 103.199684 \n",
       "L 362.803456 103.167502 \n",
       "L 366.082798 103.113912 \n",
       "L 369.362141 103.03963 \n",
       "L 372.641463 102.945642 \n",
       "L 375.920806 102.833191 \n",
       "L 379.200148 102.703721 \n",
       "\" clip-path=\"url(#pd2dc3bce01)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <path d=\"M 54.545602 179.219692 \n",
       "L 57.824941 174.249947 \n",
       "L 61.10428 169.298643 \n",
       "L 64.383619 164.384142 \n",
       "L 67.662958 159.52474 \n",
       "L 70.942296 154.738528 \n",
       "L 74.221636 150.043422 \n",
       "L 77.500973 145.457023 \n",
       "L 80.780313 140.996583 \n",
       "L 84.059653 136.678972 \n",
       "L 87.33899 132.520574 \n",
       "L 90.61833 128.537261 \n",
       "L 93.89767 124.744327 \n",
       "L 97.177007 121.15644 \n",
       "L 100.456344 117.787575 \n",
       "L 103.735686 114.651004 \n",
       "L 107.015024 111.759213 \n",
       "L 110.294361 109.123872 \n",
       "L 113.573703 106.755786 \n",
       "L 116.853041 104.664878 \n",
       "L 120.132378 102.860146 \n",
       "L 123.41172 101.349611 \n",
       "L 126.691057 100.140312 \n",
       "L 129.970395 99.238277 \n",
       "L 133.249737 98.64848 \n",
       "L 136.529069 98.374846 \n",
       "L 139.808412 98.420224 \n",
       "L 143.087754 98.786358 \n",
       "L 146.367086 99.473893 \n",
       "L 149.646428 100.482369 \n",
       "L 152.92577 101.810191 \n",
       "L 156.205103 103.454633 \n",
       "L 159.484445 105.411867 \n",
       "L 162.763787 107.676898 \n",
       "L 166.04312 110.243633 \n",
       "L 169.322462 113.104835 \n",
       "L 172.601804 116.252151 \n",
       "L 175.881137 119.676105 \n",
       "L 179.160479 123.366101 \n",
       "L 182.439821 127.310474 \n",
       "L 185.719153 131.496397 \n",
       "L 188.998496 135.910008 \n",
       "L 192.277838 140.536303 \n",
       "L 195.55717 145.359261 \n",
       "L 198.836512 150.361731 \n",
       "L 202.115855 155.525482 \n",
       "L 205.395187 160.831224 \n",
       "L 208.674529 166.258607 \n",
       "L 211.953871 171.786157 \n",
       "L 215.233204 177.391358 \n",
       "L 218.512556 183.0506 \n",
       "L 221.791879 188.739125 \n",
       "L 225.071221 194.431145 \n",
       "L 228.350563 200.099734 \n",
       "L 231.629886 205.7167 \n",
       "L 234.909247 211.25296 \n",
       "L 238.18857 216.677964 \n",
       "L 241.467912 221.96024 \n",
       "L 244.747254 227.066984 \n",
       "L 248.026597 231.964248 \n",
       "L 251.305939 236.616947 \n",
       "L 254.585262 240.988734 \n",
       "L 257.864623 245.042222 \n",
       "L 261.143946 248.738869 \n",
       "L 264.423288 252.039172 \n",
       "L 267.70263 254.902696 \n",
       "L 270.981953 257.288325 \n",
       "L 274.261315 259.154341 \n",
       "L 277.540637 260.458795 \n",
       "L 280.81998 261.159804 \n",
       "L 284.099322 261.216 \n",
       "L 287.378664 260.587074 \n",
       "L 290.658006 259.234503 \n",
       "L 293.937329 257.122349 \n",
       "L 297.21669 254.218185 \n",
       "L 300.496013 250.494698 \n",
       "L 303.775355 245.930551 \n",
       "L 307.054697 240.512636 \n",
       "L 310.33402 234.237961 \n",
       "L 313.613382 227.115713 \n",
       "L 316.892705 219.170372 \n",
       "L 320.172047 210.444327 \n",
       "L 323.451389 201.001328 \n",
       "L 326.730731 190.930102 \n",
       "L 330.010073 180.347974 \n",
       "L 333.289396 169.404699 \n",
       "L 336.568738 158.286135 \n",
       "L 339.84808 147.217169 \n",
       "L 343.127423 136.464156 \n",
       "L 346.406765 126.33584 \n",
       "L 349.686088 117.181731 \n",
       "L 352.96543 109.3878 \n",
       "L 356.244772 103.368644 \n",
       "L 359.524114 99.553303 \n",
       "L 362.803456 98.365606 \n",
       "L 366.082798 100.196309 \n",
       "L 369.362141 105.36663 \n",
       "L 372.641463 114.082809 \n",
       "L 375.920806 126.381952 \n",
       "L 379.200148 142.071712 \n",
       "\" clip-path=\"url(#pd2dc3bce01)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_17\">\n",
       "    <path d=\"M 54.545602 123.610467 \n",
       "L 57.824941 123.051718 \n",
       "L 61.10428 122.099082 \n",
       "L 64.383619 121.116908 \n",
       "L 67.662958 119.798046 \n",
       "L 70.942296 118.039267 \n",
       "L 74.221636 116.621814 \n",
       "L 77.500973 115.008818 \n",
       "L 80.780313 113.258641 \n",
       "L 84.059653 112.039739 \n",
       "L 87.33899 110.566949 \n",
       "L 90.61833 109.440149 \n",
       "L 93.89767 108.366266 \n",
       "L 97.177007 107.602447 \n",
       "L 100.456344 106.934397 \n",
       "L 103.735686 106.474334 \n",
       "L 107.015024 106.323988 \n",
       "L 110.294361 106.236557 \n",
       "L 113.573703 106.406196 \n",
       "L 116.853041 106.481559 \n",
       "L 120.132378 106.593333 \n",
       "L 123.41172 106.803473 \n",
       "L 126.691057 107.016377 \n",
       "L 129.970395 107.177004 \n",
       "L 133.249737 107.268872 \n",
       "L 136.529069 107.383235 \n",
       "L 139.808412 107.238691 \n",
       "L 143.087754 106.914097 \n",
       "L 146.367086 106.659382 \n",
       "L 149.646428 106.018857 \n",
       "L 152.92577 105.079242 \n",
       "L 156.205103 104.264769 \n",
       "L 159.484445 103.255459 \n",
       "L 162.763787 101.951649 \n",
       "L 166.04312 100.651171 \n",
       "L 169.322462 99.281302 \n",
       "L 172.601804 97.713151 \n",
       "L 175.881137 96.117064 \n",
       "L 179.160479 94.732371 \n",
       "L 182.439821 93.23659 \n",
       "L 185.719153 91.953444 \n",
       "L 188.998496 90.673295 \n",
       "L 192.277838 89.759078 \n",
       "L 195.55717 88.924882 \n",
       "L 198.836512 88.55314 \n",
       "L 202.115855 88.37964 \n",
       "L 205.395187 88.610746 \n",
       "L 208.674529 89.099886 \n",
       "L 211.953871 90.084022 \n",
       "L 215.233204 91.209883 \n",
       "L 218.512556 92.848772 \n",
       "L 221.791879 94.53788 \n",
       "L 225.071221 96.693133 \n",
       "L 228.350563 98.807985 \n",
       "L 231.629886 101.13028 \n",
       "L 234.909247 103.412083 \n",
       "L 238.18857 105.647388 \n",
       "L 241.467912 107.799345 \n",
       "L 244.747254 109.59096 \n",
       "L 248.026597 111.265131 \n",
       "L 251.305939 112.495266 \n",
       "L 254.585262 113.580095 \n",
       "L 257.864623 114.172333 \n",
       "L 261.143946 114.235136 \n",
       "L 264.423288 114.085714 \n",
       "L 267.70263 113.421826 \n",
       "L 270.981953 112.727839 \n",
       "L 274.261315 111.504998 \n",
       "L 277.540637 110.321224 \n",
       "L 280.81998 108.888921 \n",
       "L 284.099322 107.580958 \n",
       "L 287.378664 106.301628 \n",
       "L 290.658006 105.064515 \n",
       "L 293.937329 104.023204 \n",
       "L 297.21669 103.146352 \n",
       "L 300.496013 102.67051 \n",
       "L 303.775355 102.252844 \n",
       "L 307.054697 102.160421 \n",
       "L 310.33402 102.414061 \n",
       "L 313.613382 102.724698 \n",
       "L 316.892705 103.309951 \n",
       "L 320.172047 104.011967 \n",
       "L 323.451389 104.615824 \n",
       "L 326.730731 105.245863 \n",
       "L 330.010073 105.976375 \n",
       "L 333.289396 106.401329 \n",
       "L 336.568738 106.627609 \n",
       "L 339.84808 106.777219 \n",
       "L 343.127423 106.588072 \n",
       "L 346.406765 106.018672 \n",
       "L 349.686088 105.260725 \n",
       "L 352.96543 104.260437 \n",
       "L 356.244772 102.975231 \n",
       "L 359.524114 101.412696 \n",
       "L 362.803456 99.748231 \n",
       "L 366.082798 97.808412 \n",
       "L 369.362141 95.946001 \n",
       "L 372.641463 94.061365 \n",
       "L 375.920806 92.38095 \n",
       "L 379.200148 90.496553 \n",
       "\" clip-path=\"url(#pd2dc3bce01)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_18\">\n",
       "    <path d=\"M 54.545602 61.074259 \n",
       "L 57.824941 62.340176 \n",
       "L 61.10428 63.97247 \n",
       "L 64.383619 65.809669 \n",
       "L 67.662958 67.832881 \n",
       "L 70.942296 69.864194 \n",
       "L 74.221636 72.254906 \n",
       "L 77.500973 74.849335 \n",
       "L 80.780313 77.405478 \n",
       "L 84.059653 80.300709 \n",
       "L 87.33899 83.422869 \n",
       "L 90.61833 86.220583 \n",
       "L 93.89767 89.494695 \n",
       "L 97.177007 92.597692 \n",
       "L 100.456344 95.619273 \n",
       "L 103.735686 98.631878 \n",
       "L 107.015024 101.422248 \n",
       "L 110.294361 104.021591 \n",
       "L 113.573703 106.321669 \n",
       "L 116.853041 108.19639 \n",
       "L 120.132378 109.744341 \n",
       "L 123.41172 110.935161 \n",
       "L 126.691057 111.633961 \n",
       "L 129.970395 111.869141 \n",
       "L 133.249737 111.935502 \n",
       "L 136.529069 111.574926 \n",
       "L 139.808412 110.756532 \n",
       "L 143.087754 109.818488 \n",
       "L 146.367086 108.6359 \n",
       "L 149.646428 107.317289 \n",
       "L 152.92577 106.03247 \n",
       "L 156.205103 104.510349 \n",
       "L 159.484445 103.458362 \n",
       "L 162.763787 102.384341 \n",
       "L 166.04312 101.634499 \n",
       "L 169.322462 101.255398 \n",
       "L 172.601804 101.115784 \n",
       "L 175.881137 101.327244 \n",
       "L 179.160479 102.217788 \n",
       "L 182.439821 103.103305 \n",
       "L 185.719153 104.825369 \n",
       "L 188.998496 106.696567 \n",
       "L 192.277838 108.971519 \n",
       "L 195.55717 111.564949 \n",
       "L 198.836512 114.383152 \n",
       "L 202.115855 117.502642 \n",
       "L 205.395187 120.838661 \n",
       "L 208.674529 124.041264 \n",
       "L 211.953871 127.33963 \n",
       "L 215.233204 130.776753 \n",
       "L 218.512556 133.912469 \n",
       "L 221.791879 136.941427 \n",
       "L 225.071221 139.659797 \n",
       "L 228.350563 142.095897 \n",
       "L 231.629886 144.372168 \n",
       "L 234.909247 146.039498 \n",
       "L 238.18857 147.471964 \n",
       "L 241.467912 148.365853 \n",
       "L 244.747254 148.947973 \n",
       "L 248.026597 148.953843 \n",
       "L 251.305939 148.552595 \n",
       "L 254.585262 147.613246 \n",
       "L 257.864623 146.286287 \n",
       "L 261.143946 144.477729 \n",
       "L 264.423288 142.202793 \n",
       "L 267.70263 139.708137 \n",
       "L 270.981953 136.898328 \n",
       "L 274.261315 133.708487 \n",
       "L 277.540637 130.322683 \n",
       "L 280.81998 126.819865 \n",
       "L 284.099322 123.132033 \n",
       "L 287.378664 119.443786 \n",
       "L 290.658006 115.563301 \n",
       "L 293.937329 111.845843 \n",
       "L 297.21669 108.265095 \n",
       "L 300.496013 104.710536 \n",
       "L 303.775355 101.417663 \n",
       "L 307.054697 98.215644 \n",
       "L 310.33402 95.509592 \n",
       "L 313.613382 93.092876 \n",
       "L 316.892705 91.169407 \n",
       "L 320.172047 89.421361 \n",
       "L 323.451389 88.239231 \n",
       "L 326.730731 87.717452 \n",
       "L 330.010073 87.427393 \n",
       "L 333.289396 87.845865 \n",
       "L 336.568738 88.864157 \n",
       "L 339.84808 90.105294 \n",
       "L 343.127423 91.898782 \n",
       "L 346.406765 94.250562 \n",
       "L 349.686088 96.860176 \n",
       "L 352.96543 99.931772 \n",
       "L 356.244772 103.041487 \n",
       "L 359.524114 106.504611 \n",
       "L 362.803456 110.174993 \n",
       "L 366.082798 113.856715 \n",
       "L 369.362141 117.379478 \n",
       "L 372.641463 120.839205 \n",
       "L 375.920806 123.9527 \n",
       "L 379.200148 126.857715 \n",
       "\" clip-path=\"url(#pd2dc3bce01)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_19\">\n",
       "    <path d=\"M 54.545602 70.723869 \n",
       "L 57.824941 70.194789 \n",
       "L 61.10428 70.248191 \n",
       "L 64.383619 70.558454 \n",
       "L 67.662958 71.481916 \n",
       "L 70.942296 72.539584 \n",
       "L 74.221636 74.057963 \n",
       "L 77.500973 75.908341 \n",
       "L 80.780313 78.050154 \n",
       "L 84.059653 80.421637 \n",
       "L 87.33899 83.142133 \n",
       "L 90.61833 85.911269 \n",
       "L 93.89767 88.922091 \n",
       "L 97.177007 91.906231 \n",
       "L 100.456344 94.72729 \n",
       "L 103.735686 97.871344 \n",
       "L 107.015024 100.746078 \n",
       "L 110.294361 103.573473 \n",
       "L 113.573703 106.140761 \n",
       "L 116.853041 108.496099 \n",
       "L 120.132378 110.535972 \n",
       "L 123.41172 112.173233 \n",
       "L 126.691057 113.596325 \n",
       "L 129.970395 114.437305 \n",
       "L 133.249737 114.768488 \n",
       "L 136.529069 114.914991 \n",
       "L 139.808412 114.28068 \n",
       "L 143.087754 113.493039 \n",
       "L 146.367086 111.974746 \n",
       "L 149.646428 110.141556 \n",
       "L 152.92577 107.841397 \n",
       "L 156.205103 105.159515 \n",
       "L 159.484445 102.214073 \n",
       "L 162.763787 98.836937 \n",
       "L 166.04312 95.498723 \n",
       "L 169.322462 91.870039 \n",
       "L 172.601804 88.205341 \n",
       "L 175.881137 84.466014 \n",
       "L 179.160479 80.8973 \n",
       "L 182.439821 77.384842 \n",
       "L 185.719153 74.018703 \n",
       "L 188.998496 70.961476 \n",
       "L 192.277838 68.198046 \n",
       "L 195.55717 65.847694 \n",
       "L 198.836512 63.898894 \n",
       "L 202.115855 62.492555 \n",
       "L 205.395187 61.378465 \n",
       "L 208.674529 60.890442 \n",
       "L 211.953871 60.700735 \n",
       "L 215.233204 61.00643 \n",
       "L 218.512556 61.715571 \n",
       "L 221.791879 62.852551 \n",
       "L 225.071221 64.433159 \n",
       "L 228.350563 66.142986 \n",
       "L 231.629886 68.25902 \n",
       "L 234.909247 70.552348 \n",
       "L 238.18857 73.061966 \n",
       "L 241.467912 75.432551 \n",
       "L 244.747254 77.931649 \n",
       "L 248.026597 80.662576 \n",
       "L 251.305939 83.247011 \n",
       "L 254.585262 85.845671 \n",
       "L 257.864623 88.417315 \n",
       "L 261.143946 90.74977 \n",
       "L 264.423288 93.110981 \n",
       "L 267.70263 95.276283 \n",
       "L 270.981953 97.424888 \n",
       "L 274.261315 99.289662 \n",
       "L 277.540637 101.080035 \n",
       "L 280.81998 102.810635 \n",
       "L 284.099322 104.141863 \n",
       "L 287.378664 105.662722 \n",
       "L 290.658006 106.942641 \n",
       "L 293.937329 108.092557 \n",
       "L 297.21669 109.031221 \n",
       "L 300.496013 109.855701 \n",
       "L 303.775355 110.553007 \n",
       "L 307.054697 111.074359 \n",
       "L 310.33402 111.636659 \n",
       "L 313.613382 111.871952 \n",
       "L 316.892705 112.209866 \n",
       "L 320.172047 111.939894 \n",
       "L 323.451389 111.715895 \n",
       "L 326.730731 111.564352 \n",
       "L 330.010073 111.093493 \n",
       "L 333.289396 110.31342 \n",
       "L 336.568738 109.555636 \n",
       "L 339.84808 108.879665 \n",
       "L 343.127423 107.778696 \n",
       "L 346.406765 106.787411 \n",
       "L 349.686088 105.670431 \n",
       "L 352.96543 104.674337 \n",
       "L 356.244772 103.568011 \n",
       "L 359.524114 102.458002 \n",
       "L 362.803456 101.540599 \n",
       "L 366.082798 100.680925 \n",
       "L 369.362141 100.336144 \n",
       "L 372.641463 99.864321 \n",
       "L 375.920806 99.930245 \n",
       "L 379.200148 100.186698 \n",
       "\" clip-path=\"url(#pd2dc3bce01)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_20\">\n",
       "    <path d=\"M 54.545602 89.137252 \n",
       "L 57.824941 88.03864 \n",
       "L 61.10428 87.362941 \n",
       "L 64.383619 87.167654 \n",
       "L 67.662958 87.467233 \n",
       "L 70.942296 88.051133 \n",
       "L 74.221636 89.279799 \n",
       "L 77.500973 90.706012 \n",
       "L 80.780313 92.274184 \n",
       "L 84.059653 94.270965 \n",
       "L 87.33899 96.232435 \n",
       "L 90.61833 98.097242 \n",
       "L 93.89767 100.016664 \n",
       "L 97.177007 101.780017 \n",
       "L 100.456344 103.25987 \n",
       "L 103.735686 104.535726 \n",
       "L 107.015024 105.381666 \n",
       "L 110.294361 106.022288 \n",
       "L 113.573703 106.275313 \n",
       "L 116.853041 106.347751 \n",
       "L 120.132378 105.914816 \n",
       "L 123.41172 105.40714 \n",
       "L 126.691057 104.68558 \n",
       "L 129.970395 103.961693 \n",
       "L 133.249737 103.01125 \n",
       "L 136.529069 102.24105 \n",
       "L 139.808412 101.67977 \n",
       "L 143.087754 101.328208 \n",
       "L 146.367086 101.363982 \n",
       "L 149.646428 101.528583 \n",
       "L 152.92577 102.359704 \n",
       "L 156.205103 103.499985 \n",
       "L 159.484445 104.95123 \n",
       "L 162.763787 107.223461 \n",
       "L 166.04312 109.658659 \n",
       "L 169.322462 112.441412 \n",
       "L 172.601804 115.565606 \n",
       "L 175.881137 119.008392 \n",
       "L 179.160479 122.380312 \n",
       "L 182.439821 125.859812 \n",
       "L 185.719153 129.164163 \n",
       "L 188.998496 132.534145 \n",
       "L 192.277838 135.568522 \n",
       "L 195.55717 138.187243 \n",
       "L 198.836512 140.475101 \n",
       "L 202.115855 142.094003 \n",
       "L 205.395187 143.445593 \n",
       "L 208.674529 144.103836 \n",
       "L 211.953871 144.203522 \n",
       "L 215.233204 143.78059 \n",
       "L 218.512556 142.794813 \n",
       "L 221.791879 141.479915 \n",
       "L 225.071221 139.753685 \n",
       "L 228.350563 137.504029 \n",
       "L 231.629886 135.145051 \n",
       "L 234.909247 132.649596 \n",
       "L 238.18857 129.831113 \n",
       "L 241.467912 127.121928 \n",
       "L 244.747254 124.377606 \n",
       "L 248.026597 121.539495 \n",
       "L 251.305939 119.051391 \n",
       "L 254.585262 116.617366 \n",
       "L 257.864623 114.430985 \n",
       "L 261.143946 112.492835 \n",
       "L 264.423288 110.718354 \n",
       "L 267.70263 109.230899 \n",
       "L 270.981953 107.973088 \n",
       "L 274.261315 107.029574 \n",
       "L 277.540637 106.156627 \n",
       "L 280.81998 105.570377 \n",
       "L 284.099322 105.392803 \n",
       "L 287.378664 105.261324 \n",
       "L 290.658006 105.244108 \n",
       "L 293.937329 105.428554 \n",
       "L 297.21669 105.756363 \n",
       "L 300.496013 106.187588 \n",
       "L 303.775355 106.692471 \n",
       "L 307.054697 107.407073 \n",
       "L 310.33402 108.012337 \n",
       "L 313.613382 108.62311 \n",
       "L 316.892705 109.105204 \n",
       "L 320.172047 109.570171 \n",
       "L 323.451389 109.908866 \n",
       "L 326.730731 110.005377 \n",
       "L 330.010073 109.833373 \n",
       "L 333.289396 109.683692 \n",
       "L 336.568738 109.126575 \n",
       "L 339.84808 108.436196 \n",
       "L 343.127423 107.662774 \n",
       "L 346.406765 106.621946 \n",
       "L 349.686088 105.399435 \n",
       "L 352.96543 104.419794 \n",
       "L 356.244772 103.184268 \n",
       "L 359.524114 102.167429 \n",
       "L 362.803456 101.181667 \n",
       "L 366.082798 100.359617 \n",
       "L 369.362141 99.889123 \n",
       "L 372.641463 99.666696 \n",
       "L 375.920806 99.826761 \n",
       "L 379.200148 100.22995 \n",
       "\" clip-path=\"url(#pd2dc3bce01)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_21\">\n",
       "    <path d=\"M 54.545602 95.659845 \n",
       "L 57.824941 97.076766 \n",
       "L 61.10428 98.396312 \n",
       "L 64.383619 99.406019 \n",
       "L 67.662958 100.159769 \n",
       "L 70.942296 100.964657 \n",
       "L 74.221636 101.309194 \n",
       "L 77.500973 101.612758 \n",
       "L 80.780313 101.866464 \n",
       "L 84.059653 102.196971 \n",
       "L 87.33899 102.605933 \n",
       "L 90.61833 102.881196 \n",
       "L 93.89767 103.281152 \n",
       "L 97.177007 103.716003 \n",
       "L 100.456344 104.29539 \n",
       "L 103.735686 104.750586 \n",
       "L 107.015024 105.229292 \n",
       "L 110.294361 105.807725 \n",
       "L 113.573703 106.093376 \n",
       "L 116.853041 106.318561 \n",
       "L 120.132378 106.581432 \n",
       "L 123.41172 106.687846 \n",
       "L 126.691057 106.732168 \n",
       "L 129.970395 106.596604 \n",
       "L 133.249737 106.255993 \n",
       "L 136.529069 105.935873 \n",
       "L 139.808412 105.595809 \n",
       "L 143.087754 105.206421 \n",
       "L 146.367086 104.749341 \n",
       "L 149.646428 104.336298 \n",
       "L 152.92577 104.041152 \n",
       "L 156.205103 103.845825 \n",
       "L 159.484445 103.808681 \n",
       "L 162.763787 103.680802 \n",
       "L 166.04312 103.861544 \n",
       "L 169.322462 104.029783 \n",
       "L 172.601804 104.215568 \n",
       "L 175.881137 104.529986 \n",
       "L 179.160479 104.713397 \n",
       "L 182.439821 104.850752 \n",
       "L 185.719153 104.878659 \n",
       "L 188.998496 104.763954 \n",
       "L 192.277838 104.442701 \n",
       "L 195.55717 103.983941 \n",
       "L 198.836512 103.284228 \n",
       "L 202.115855 102.310117 \n",
       "L 205.395187 101.115209 \n",
       "L 208.674529 99.799912 \n",
       "L 211.953871 98.195922 \n",
       "L 215.233204 96.673622 \n",
       "L 218.512556 95.105123 \n",
       "L 221.791879 93.493901 \n",
       "L 225.071221 91.946401 \n",
       "L 228.350563 90.531582 \n",
       "L 231.629886 89.319851 \n",
       "L 234.909247 88.609028 \n",
       "L 238.18857 88.134484 \n",
       "L 241.467912 88.116227 \n",
       "L 244.747254 88.448363 \n",
       "L 248.026597 89.166153 \n",
       "L 251.305939 90.593207 \n",
       "L 254.585262 92.239461 \n",
       "L 257.864623 94.297778 \n",
       "L 261.143946 96.925312 \n",
       "L 264.423288 99.642563 \n",
       "L 267.70263 102.70927 \n",
       "L 270.981953 105.92456 \n",
       "L 274.261315 109.385231 \n",
       "L 277.540637 112.705192 \n",
       "L 280.81998 115.950125 \n",
       "L 284.099322 119.225413 \n",
       "L 287.378664 122.014375 \n",
       "L 290.658006 124.589909 \n",
       "L 293.937329 126.849303 \n",
       "L 297.21669 128.780649 \n",
       "L 300.496013 130.093947 \n",
       "L 303.775355 130.914257 \n",
       "L 307.054697 131.322074 \n",
       "L 310.33402 131.310676 \n",
       "L 313.613382 130.742955 \n",
       "L 316.892705 129.825141 \n",
       "L 320.172047 128.295796 \n",
       "L 323.451389 126.516108 \n",
       "L 326.730731 124.375987 \n",
       "L 330.010073 122.00867 \n",
       "L 333.289396 119.539143 \n",
       "L 336.568738 117.116904 \n",
       "L 339.84808 114.516106 \n",
       "L 343.127423 111.971846 \n",
       "L 346.406765 109.494235 \n",
       "L 349.686088 107.123656 \n",
       "L 352.96543 105.299441 \n",
       "L 356.244772 103.562449 \n",
       "L 359.524114 102.185545 \n",
       "L 362.803456 101.247638 \n",
       "L 366.082798 100.742151 \n",
       "L 369.362141 100.634849 \n",
       "L 372.641463 100.886203 \n",
       "L 375.920806 101.720272 \n",
       "L 379.200148 102.777368 \n",
       "\" clip-path=\"url(#pd2dc3bce01)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_22\">\n",
       "    <path d=\"M 54.545602 173.631684 \n",
       "L 57.824941 173.385764 \n",
       "L 61.10428 172.439913 \n",
       "L 64.383619 170.889204 \n",
       "L 67.662958 168.477497 \n",
       "L 70.942296 165.738101 \n",
       "L 74.221636 162.163984 \n",
       "L 77.500973 158.159007 \n",
       "L 80.780313 153.811536 \n",
       "L 84.059653 148.914131 \n",
       "L 87.33899 144.023329 \n",
       "L 90.61833 138.737805 \n",
       "L 93.89767 133.513775 \n",
       "L 97.177007 128.3379 \n",
       "L 100.456344 123.298638 \n",
       "L 103.735686 118.458781 \n",
       "L 107.015024 114.316338 \n",
       "L 110.294361 110.489096 \n",
       "L 113.573703 106.982043 \n",
       "L 116.853041 104.00561 \n",
       "L 120.132378 101.597298 \n",
       "L 123.41172 99.868957 \n",
       "L 126.691057 98.793568 \n",
       "L 129.970395 97.94309 \n",
       "L 133.249737 97.665289 \n",
       "L 136.529069 97.997806 \n",
       "L 139.808412 98.387132 \n",
       "L 143.087754 99.154166 \n",
       "L 146.367086 100.13525 \n",
       "L 149.646428 101.307812 \n",
       "L 152.92577 102.408384 \n",
       "L 156.205103 103.515502 \n",
       "L 159.484445 104.689191 \n",
       "L 162.763787 105.732176 \n",
       "L 166.04312 106.569893 \n",
       "L 169.322462 107.605594 \n",
       "L 172.601804 108.29702 \n",
       "L 175.881137 108.83388 \n",
       "L 179.160479 109.34687 \n",
       "L 182.439821 109.877324 \n",
       "L 185.719153 110.262 \n",
       "L 188.998496 110.658959 \n",
       "L 192.277838 110.969711 \n",
       "L 195.55717 111.039763 \n",
       "L 198.836512 111.321946 \n",
       "L 202.115855 111.466366 \n",
       "L 205.395187 111.593174 \n",
       "L 208.674529 111.632468 \n",
       "L 211.953871 111.574255 \n",
       "L 215.233204 111.450855 \n",
       "L 218.512556 111.036773 \n",
       "L 221.791879 110.512386 \n",
       "L 225.071221 109.929301 \n",
       "L 228.350563 108.959273 \n",
       "L 231.629886 107.947264 \n",
       "L 234.909247 106.484777 \n",
       "L 238.18857 105.077201 \n",
       "L 241.467912 103.333011 \n",
       "L 244.747254 101.281061 \n",
       "L 248.026597 99.219401 \n",
       "L 251.305939 97.074258 \n",
       "L 254.585262 94.705818 \n",
       "L 257.864623 92.15416 \n",
       "L 261.143946 89.6159 \n",
       "L 264.423288 86.930666 \n",
       "L 267.70263 84.343348 \n",
       "L 270.981953 81.678351 \n",
       "L 274.261315 79.183158 \n",
       "L 277.540637 76.63963 \n",
       "L 280.81998 74.225619 \n",
       "L 284.099322 72.00232 \n",
       "L 287.378664 70.105661 \n",
       "L 290.658006 68.406643 \n",
       "L 293.937329 66.823442 \n",
       "L 297.21669 65.661916 \n",
       "L 300.496013 64.832691 \n",
       "L 303.775355 64.251539 \n",
       "L 307.054697 64.05858 \n",
       "L 310.33402 64.374858 \n",
       "L 313.613382 65.133719 \n",
       "L 316.892705 66.218467 \n",
       "L 320.172047 67.711497 \n",
       "L 323.451389 69.703039 \n",
       "L 326.730731 71.923916 \n",
       "L 330.010073 74.610747 \n",
       "L 333.289396 77.602232 \n",
       "L 336.568738 80.799702 \n",
       "L 339.84808 84.326075 \n",
       "L 343.127423 87.95501 \n",
       "L 346.406765 91.6734 \n",
       "L 349.686088 95.520902 \n",
       "L 352.96543 99.264705 \n",
       "L 356.244772 102.973429 \n",
       "L 359.524114 106.732684 \n",
       "L 362.803456 110.394944 \n",
       "L 366.082798 113.873051 \n",
       "L 369.362141 117.107937 \n",
       "L 372.641463 120.327633 \n",
       "L 375.920806 123.365734 \n",
       "L 379.200148 126.183743 \n",
       "\" clip-path=\"url(#pd2dc3bce01)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_23\">\n",
       "    <path d=\"M 54.545602 102.93994 \n",
       "L 57.824941 104.030731 \n",
       "L 61.10428 104.699204 \n",
       "L 64.383619 105.018405 \n",
       "L 67.662958 105.295763 \n",
       "L 70.942296 105.310107 \n",
       "L 74.221636 105.026913 \n",
       "L 77.500973 104.798227 \n",
       "L 80.780313 104.369652 \n",
       "L 84.059653 104.017014 \n",
       "L 87.33899 103.685286 \n",
       "L 90.61833 103.570162 \n",
       "L 93.89767 103.361424 \n",
       "L 97.177007 103.410137 \n",
       "L 100.456344 103.688973 \n",
       "L 103.735686 104.069001 \n",
       "L 107.015024 104.5268 \n",
       "L 110.294361 105.076718 \n",
       "L 113.573703 105.988764 \n",
       "L 116.853041 106.69372 \n",
       "L 120.132378 107.639516 \n",
       "L 123.41172 108.404393 \n",
       "L 126.691057 108.990607 \n",
       "L 129.970395 109.601423 \n",
       "L 133.249737 109.872714 \n",
       "L 136.529069 110.009669 \n",
       "L 139.808412 109.831538 \n",
       "L 143.087754 109.307961 \n",
       "L 146.367086 108.649317 \n",
       "L 149.646428 107.598744 \n",
       "L 152.92577 106.318239 \n",
       "L 156.205103 104.883129 \n",
       "L 159.484445 103.15904 \n",
       "L 162.763787 101.288906 \n",
       "L 166.04312 99.333341 \n",
       "L 169.322462 97.137091 \n",
       "L 172.601804 95.232755 \n",
       "L 175.881137 93.079606 \n",
       "L 179.160479 91.201682 \n",
       "L 182.439821 89.437983 \n",
       "L 185.719153 87.657831 \n",
       "L 188.998496 86.116306 \n",
       "L 192.277838 84.789979 \n",
       "L 195.55717 83.549222 \n",
       "L 198.836512 82.725201 \n",
       "L 202.115855 82.001137 \n",
       "L 205.395187 81.323999 \n",
       "L 208.674529 81.023261 \n",
       "L 211.953871 80.717992 \n",
       "L 215.233204 80.503406 \n",
       "L 218.512556 80.32685 \n",
       "L 221.791879 80.539483 \n",
       "L 225.071221 80.419615 \n",
       "L 228.350563 80.338539 \n",
       "L 231.629886 80.238038 \n",
       "L 234.909247 80.13812 \n",
       "L 238.18857 79.866737 \n",
       "L 241.467912 79.577829 \n",
       "L 244.747254 78.948918 \n",
       "L 248.026597 78.18856 \n",
       "L 251.305939 77.206458 \n",
       "L 254.585262 75.890924 \n",
       "L 257.864623 74.50246 \n",
       "L 261.143946 72.610773 \n",
       "L 264.423288 70.868384 \n",
       "L 267.70263 68.542885 \n",
       "L 270.981953 66.251695 \n",
       "L 274.261315 63.815301 \n",
       "L 277.540637 61.289602 \n",
       "L 280.81998 58.765221 \n",
       "L 284.099322 56.3065 \n",
       "L 287.378664 53.883427 \n",
       "L 290.658006 51.73876 \n",
       "L 293.937329 49.822243 \n",
       "L 297.21669 48.239644 \n",
       "L 300.496013 47.236218 \n",
       "L 303.775355 46.598728 \n",
       "L 307.054697 46.664552 \n",
       "L 310.33402 47.09802 \n",
       "L 313.613382 48.215115 \n",
       "L 316.892705 50.018808 \n",
       "L 320.172047 52.450077 \n",
       "L 323.451389 55.444953 \n",
       "L 326.730731 58.891816 \n",
       "L 330.010073 62.947367 \n",
       "L 333.289396 67.563629 \n",
       "L 336.568738 72.161246 \n",
       "L 339.84808 77.261511 \n",
       "L 343.127423 82.488109 \n",
       "L 346.406765 87.744937 \n",
       "L 349.686088 92.899709 \n",
       "L 352.96543 97.971602 \n",
       "L 356.244772 102.595736 \n",
       "L 359.524114 106.86158 \n",
       "L 362.803456 110.615226 \n",
       "L 366.082798 113.855329 \n",
       "L 369.362141 116.545058 \n",
       "L 372.641463 118.40997 \n",
       "L 375.920806 119.437872 \n",
       "L 379.200148 119.816037 \n",
       "\" clip-path=\"url(#pd2dc3bce01)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_24\">\n",
       "    <path d=\"M 54.545602 23.131943 \n",
       "L 57.824941 28.536535 \n",
       "L 61.10428 34.177196 \n",
       "L 64.383619 40.128328 \n",
       "L 67.662958 45.910178 \n",
       "L 70.942296 51.777695 \n",
       "L 74.221636 57.506772 \n",
       "L 77.500973 63.190068 \n",
       "L 80.780313 68.720043 \n",
       "L 84.059653 73.901899 \n",
       "L 87.33899 78.996622 \n",
       "L 90.61833 83.707481 \n",
       "L 93.89767 87.998115 \n",
       "L 97.177007 91.852397 \n",
       "L 100.456344 95.536058 \n",
       "L 103.735686 98.716081 \n",
       "L 107.015024 101.659073 \n",
       "L 110.294361 103.953895 \n",
       "L 113.573703 105.985568 \n",
       "L 116.853041 107.514997 \n",
       "L 120.132378 108.71812 \n",
       "L 123.41172 109.6049 \n",
       "L 126.691057 110.129014 \n",
       "L 129.970395 110.340053 \n",
       "L 133.249737 110.175327 \n",
       "L 136.529069 109.819061 \n",
       "L 139.808412 109.362035 \n",
       "L 143.087754 108.60354 \n",
       "L 146.367086 107.688769 \n",
       "L 149.646428 106.575637 \n",
       "L 152.92577 105.563661 \n",
       "L 156.205103 104.340712 \n",
       "L 159.484445 103.097437 \n",
       "L 162.763787 101.833737 \n",
       "L 166.04312 100.434704 \n",
       "L 169.322462 99.07875 \n",
       "L 172.601804 97.777897 \n",
       "L 175.881137 96.42019 \n",
       "L 179.160479 95.118067 \n",
       "L 182.439821 93.89272 \n",
       "L 185.719153 92.672149 \n",
       "L 188.998496 91.545666 \n",
       "L 192.277838 90.379779 \n",
       "L 195.55717 89.389546 \n",
       "L 198.836512 88.561003 \n",
       "L 202.115855 87.907805 \n",
       "L 205.395187 87.214843 \n",
       "L 208.674529 86.780208 \n",
       "L 211.953871 86.409433 \n",
       "L 215.233204 86.390749 \n",
       "L 218.512556 86.472686 \n",
       "L 221.791879 86.719309 \n",
       "L 225.071221 87.230269 \n",
       "L 228.350563 87.904667 \n",
       "L 231.629886 88.839508 \n",
       "L 234.909247 90.053067 \n",
       "L 238.18857 91.386451 \n",
       "L 241.467912 92.59974 \n",
       "L 244.747254 94.280431 \n",
       "L 248.026597 96.044207 \n",
       "L 251.305939 97.823896 \n",
       "L 254.585262 99.814228 \n",
       "L 257.864623 101.587371 \n",
       "L 261.143946 103.405279 \n",
       "L 264.423288 105.37784 \n",
       "L 267.70263 106.969204 \n",
       "L 270.981953 108.600002 \n",
       "L 274.261315 110.200251 \n",
       "L 277.540637 111.441798 \n",
       "L 280.81998 112.5994 \n",
       "L 284.099322 113.491722 \n",
       "L 287.378664 114.262341 \n",
       "L 290.658006 114.637816 \n",
       "L 293.937329 114.887892 \n",
       "L 297.21669 114.923862 \n",
       "L 300.496013 114.894539 \n",
       "L 303.775355 114.47842 \n",
       "L 307.054697 114.111018 \n",
       "L 310.33402 113.352586 \n",
       "L 313.613382 112.565806 \n",
       "L 316.892705 111.73034 \n",
       "L 320.172047 110.812254 \n",
       "L 323.451389 109.86998 \n",
       "L 326.730731 108.786504 \n",
       "L 330.010073 107.985554 \n",
       "L 333.289396 106.988504 \n",
       "L 336.568738 106.287631 \n",
       "L 339.84808 105.542206 \n",
       "L 343.127423 104.968764 \n",
       "L 346.406765 104.361447 \n",
       "L 349.686088 104.015672 \n",
       "L 352.96543 103.775929 \n",
       "L 356.244772 103.279991 \n",
       "L 359.524114 103.180217 \n",
       "L 362.803456 103.083281 \n",
       "L 366.082798 103.191244 \n",
       "L 369.362141 103.228475 \n",
       "L 372.641463 103.423929 \n",
       "L 375.920806 103.542241 \n",
       "L 379.200148 103.679117 \n",
       "\" clip-path=\"url(#pd2dc3bce01)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_25\">\n",
       "    <path d=\"M 54.545602 80.804745 \n",
       "L 57.824941 83.152483 \n",
       "L 61.10428 85.249066 \n",
       "L 64.383619 87.112556 \n",
       "L 67.662958 88.993569 \n",
       "L 70.942296 90.483838 \n",
       "L 74.221636 91.89692 \n",
       "L 77.500973 93.098609 \n",
       "L 80.780313 94.205715 \n",
       "L 84.059653 95.162802 \n",
       "L 87.33899 96.168011 \n",
       "L 90.61833 97.165413 \n",
       "L 93.89767 98.213914 \n",
       "L 97.177007 99.464202 \n",
       "L 100.456344 100.596862 \n",
       "L 103.735686 101.649566 \n",
       "L 107.015024 103.036933 \n",
       "L 110.294361 104.347907 \n",
       "L 113.573703 105.737339 \n",
       "L 116.853041 106.875323 \n",
       "L 120.132378 108.267065 \n",
       "L 123.41172 109.215573 \n",
       "L 126.691057 110.01746 \n",
       "L 129.970395 110.555127 \n",
       "L 133.249737 110.85493 \n",
       "L 136.529069 110.861786 \n",
       "L 139.808412 110.404608 \n",
       "L 143.087754 109.86248 \n",
       "L 146.367086 108.707331 \n",
       "L 149.646428 107.482752 \n",
       "L 152.92577 105.971381 \n",
       "L 156.205103 104.265539 \n",
       "L 159.484445 102.472902 \n",
       "L 162.763787 100.363423 \n",
       "L 166.04312 98.407503 \n",
       "L 169.322462 96.383033 \n",
       "L 172.601804 94.611846 \n",
       "L 175.881137 92.559534 \n",
       "L 179.160479 90.86612 \n",
       "L 182.439821 89.333556 \n",
       "L 185.719153 88.071679 \n",
       "L 188.998496 86.869952 \n",
       "L 192.277838 85.757023 \n",
       "L 195.55717 84.768137 \n",
       "L 198.836512 83.728503 \n",
       "L 202.115855 82.829906 \n",
       "L 205.395187 81.816729 \n",
       "L 208.674529 80.76261 \n",
       "L 211.953871 79.489688 \n",
       "L 215.233204 78.251967 \n",
       "L 218.512556 76.591839 \n",
       "L 221.791879 74.934683 \n",
       "L 225.071221 72.896097 \n",
       "L 228.350563 70.829228 \n",
       "L 231.629886 68.526138 \n",
       "L 234.909247 66.206181 \n",
       "L 238.18857 63.772688 \n",
       "L 241.467912 61.318601 \n",
       "L 244.747254 58.933147 \n",
       "L 248.026597 56.755034 \n",
       "L 251.305939 54.56179 \n",
       "L 254.585262 52.772683 \n",
       "L 257.864623 51.277694 \n",
       "L 261.143946 50.22001 \n",
       "L 264.423288 49.340561 \n",
       "L 267.70263 49.340517 \n",
       "L 270.981953 49.293644 \n",
       "L 274.261315 49.913927 \n",
       "L 277.540637 50.886206 \n",
       "L 280.81998 52.384175 \n",
       "L 284.099322 54.055753 \n",
       "L 287.378664 56.134664 \n",
       "L 290.658006 58.550153 \n",
       "L 293.937329 61.257729 \n",
       "L 297.21669 64.073337 \n",
       "L 300.496013 67.078822 \n",
       "L 303.775355 70.039536 \n",
       "L 307.054697 73.211866 \n",
       "L 310.33402 76.314728 \n",
       "L 313.613382 79.273237 \n",
       "L 316.892705 82.067496 \n",
       "L 320.172047 85.017743 \n",
       "L 323.451389 87.665597 \n",
       "L 326.730731 90.137968 \n",
       "L 330.010073 92.384124 \n",
       "L 333.289396 94.493436 \n",
       "L 336.568738 96.362727 \n",
       "L 339.84808 98.008748 \n",
       "L 343.127423 99.538146 \n",
       "L 346.406765 100.629192 \n",
       "L 349.686088 101.582594 \n",
       "L 352.96543 102.499489 \n",
       "L 356.244772 103.061634 \n",
       "L 359.524114 103.531565 \n",
       "L 362.803456 103.808503 \n",
       "L 366.082798 104.007279 \n",
       "L 369.362141 103.995675 \n",
       "L 372.641463 103.644067 \n",
       "L 375.920806 103.284208 \n",
       "L 379.200148 102.82246 \n",
       "\" clip-path=\"url(#pd2dc3bce01)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_26\">\n",
       "    <path d=\"M 54.545602 110.905874 \n",
       "L 57.824941 112.043084 \n",
       "L 61.10428 113.266651 \n",
       "L 64.383619 114.302872 \n",
       "L 67.662958 115.347755 \n",
       "L 70.942296 116.217393 \n",
       "L 74.221636 117.039813 \n",
       "L 77.500973 117.552383 \n",
       "L 80.780313 117.950681 \n",
       "L 84.059653 118.005929 \n",
       "L 87.33899 117.761006 \n",
       "L 90.61833 117.152336 \n",
       "L 93.89767 116.425232 \n",
       "L 97.177007 115.19485 \n",
       "L 100.456344 113.748707 \n",
       "L 103.735686 112.273817 \n",
       "L 107.015024 110.49684 \n",
       "L 110.294361 108.501407 \n",
       "L 113.573703 106.576674 \n",
       "L 116.853041 104.765619 \n",
       "L 120.132378 102.878516 \n",
       "L 123.41172 101.236523 \n",
       "L 126.691057 99.807629 \n",
       "L 129.970395 98.757954 \n",
       "L 133.249737 97.937681 \n",
       "L 136.529069 97.363707 \n",
       "L 139.808412 97.475321 \n",
       "L 143.087754 97.89596 \n",
       "L 146.367086 98.704665 \n",
       "L 149.646428 99.870711 \n",
       "L 152.92577 101.513717 \n",
       "L 156.205103 103.430147 \n",
       "L 159.484445 105.784767 \n",
       "L 162.763787 108.070177 \n",
       "L 166.04312 110.853692 \n",
       "L 169.322462 113.6247 \n",
       "L 172.601804 116.516492 \n",
       "L 175.881137 119.157797 \n",
       "L 179.160479 121.830672 \n",
       "L 182.439821 124.397879 \n",
       "L 185.719153 126.691661 \n",
       "L 188.998496 128.766265 \n",
       "L 192.277838 130.529316 \n",
       "L 195.55717 131.798607 \n",
       "L 198.836512 132.851854 \n",
       "L 202.115855 133.508016 \n",
       "L 205.395187 133.653104 \n",
       "L 208.674529 133.672735 \n",
       "L 211.953871 133.175698 \n",
       "L 215.233204 132.303503 \n",
       "L 218.512556 131.423022 \n",
       "L 221.791879 129.997238 \n",
       "L 225.071221 128.49627 \n",
       "L 228.350563 126.897503 \n",
       "L 231.629886 125.206811 \n",
       "L 234.909247 123.747073 \n",
       "L 238.18857 122.181327 \n",
       "L 241.467912 120.637255 \n",
       "L 244.747254 119.528852 \n",
       "L 248.026597 118.63287 \n",
       "L 251.305939 117.96216 \n",
       "L 254.585262 117.394662 \n",
       "L 257.864623 117.276758 \n",
       "L 261.143946 117.449652 \n",
       "L 264.423288 117.71629 \n",
       "L 267.70263 118.508598 \n",
       "L 270.981953 119.137883 \n",
       "L 274.261315 120.211976 \n",
       "L 277.540637 121.267434 \n",
       "L 280.81998 122.662662 \n",
       "L 284.099322 123.738804 \n",
       "L 287.378664 125.061075 \n",
       "L 290.658006 126.116557 \n",
       "L 293.937329 127.080793 \n",
       "L 297.21669 127.844409 \n",
       "L 300.496013 128.545141 \n",
       "L 303.775355 128.926545 \n",
       "L 307.054697 129.109913 \n",
       "L 310.33402 128.955743 \n",
       "L 313.613382 128.679885 \n",
       "L 316.892705 127.982807 \n",
       "L 320.172047 126.992964 \n",
       "L 323.451389 125.942043 \n",
       "L 326.730731 124.550234 \n",
       "L 330.010073 122.857765 \n",
       "L 333.289396 120.932212 \n",
       "L 336.568738 118.890433 \n",
       "L 339.84808 116.549727 \n",
       "L 343.127423 114.133422 \n",
       "L 346.406765 111.570861 \n",
       "L 349.686088 108.852445 \n",
       "L 352.96543 106.09439 \n",
       "L 356.244772 103.305684 \n",
       "L 359.524114 100.337156 \n",
       "L 362.803456 97.397706 \n",
       "L 366.082798 94.684793 \n",
       "L 369.362141 92.130535 \n",
       "L 372.641463 89.479099 \n",
       "L 375.920806 87.355088 \n",
       "L 379.200148 85.156406 \n",
       "\" clip-path=\"url(#pd2dc3bce01)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_27\"/>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 38.312875 261.273565 \n",
       "L 38.312875 16.894693 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 54.545602 273.312 \n",
       "L 379.200148 273.312 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_28\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#m63f6a6ca9f\" x=\"55.032875\" y=\"194.65925\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_16\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 197.73925) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_29\">\n",
       "     <path d=\"M 46.232875 207.24325 \n",
       "L 55.032875 207.24325 \n",
       "L 63.832875 207.24325 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 210.32325) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 46.232875 224.48025 \n",
       "L 63.832875 224.48025 \n",
       "L 63.832875 218.32025 \n",
       "L 46.232875 218.32025 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 224.48025) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 46.232875 238.64825 \n",
       "L 63.832875 238.64825 \n",
       "L 63.832875 232.48825 \n",
       "L 46.232875 232.48825 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 238.64825) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_30\">\n",
       "     <path d=\"M 46.232875 248.115125 \n",
       "L 55.032875 248.115125 \n",
       "L 63.832875 248.115125 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 251.195125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_31\">\n",
       "     <path d=\"M 46.232875 260.563 \n",
       "L 55.032875 260.563 \n",
       "L 63.832875 260.563 \n",
       "\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- Posterior samples -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 263.643) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-50\" d=\"M 494 0 \n",
       "L 494 4581 \n",
       "L 2222 4581 \n",
       "Q 2678 4581 2919 4538 \n",
       "Q 3256 4481 3484 4323 \n",
       "Q 3713 4166 3852 3881 \n",
       "Q 3991 3597 3991 3256 \n",
       "Q 3991 2672 3619 2267 \n",
       "Q 3247 1863 2275 1863 \n",
       "L 1100 1863 \n",
       "L 1100 0 \n",
       "L 494 0 \n",
       "z\n",
       "M 1100 2403 \n",
       "L 2284 2403 \n",
       "Q 2872 2403 3119 2622 \n",
       "Q 3366 2841 3366 3238 \n",
       "Q 3366 3525 3220 3729 \n",
       "Q 3075 3934 2838 4000 \n",
       "Q 2684 4041 2272 4041 \n",
       "L 1100 4041 \n",
       "L 1100 2403 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-50\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"66.699219\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"122.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"172.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"255.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"289.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"311.230469\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"366.845703\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"400.146484\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"477.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"533.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" x=\"616.845703\"/>\n",
       "      <use xlink:href=\"#ArialMT-6c\" x=\"672.460938\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"694.677734\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"750.292969\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pd2dc3bce01\">\n",
       "   <rect x=\"38.312875\" y=\"7.2\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "train_x = torch.from_numpy(X).float()\n",
    "train_y = torch.from_numpy(Y).float()\n",
    "model = ExactGP(train_x, train_y)\n",
    "\n",
    "# It is not a good idea to train the model when we don't have enough data\n",
    "# So we fix the hyperparameters to something reasonable\n",
    "model.covar_module.base_kernel.lengthscale = 0.15\n",
    "model.covar_module.outputscale = 4.0\n",
    "model.likelihood.noise = 1e-4\n",
    "model.eval()\n",
    "\n",
    "x = torch.linspace(0, 1, 100)\n",
    "plot_1d_regression(\n",
    "    x,\n",
    "    model,\n",
    "    f_true=f\n",
    ");"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The maximum upper interval is defined to be:\n",
    "\n",
    "$$\n",
    "a_n(\\mathbf{x}) = \\mu_n(\\mathbf{x}) + \\psi \\sigma_n(\\mathbf{x}),\n",
    "$$\n",
    "\n",
    "for some $\\psi \\ge 0$.\n",
    "Note that here, we are using the predictive mean and variance.\n",
    "The parameter $\\psi$ controls your emphasis on exploitation and exploration.\n",
    "The choice $\\psi = 0$ is full-on exploitation. You are just looking at the predictive mean.\n",
    "The greater $\\psi$ is, the more emphasis you put on the predictive standard deviation, i.e., the more you try to explore.\n",
    "Okay, the information acquisition function depends only on the posterior mean, variance, and parameter $\\psi$.\n",
    "Let's implement it:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {},
   "outputs": [],
   "source": [
    "def mui(m, sigma, ymax, psi=1.96):\n",
    "    \"\"\"The maximum upper interval acquisition function.\"\"\"\n",
    "    return m + psi * sigma"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Let's write code that carries out Bayesian global optimization using the maximum upper interval as the information acquisition function."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "def plot_iaf(\n",
    "    x_star,\n",
    "    gpr,\n",
    "    alpha,\n",
    "    alpha_params={},\n",
    "    ax=None,\n",
    "    f_true=None\n",
    "):\n",
    "    \"\"\"Plot the information acquisition function.\n",
    "    \n",
    "    Arguments\n",
    "    x_star       -- A set of points to plot on.\n",
    "    gpr          -- A rained Gaussian process regression\n",
    "                    object.\n",
    "    alpha        -- The information acquisition function.\n",
    "                    This assumed to be a function of the\n",
    "                    posterior mean and standard deviation.\n",
    "              \n",
    "    Keyword Arguments\n",
    "    ax           -- An axes object to plot on.\n",
    "    f_true       -- The true function - if available.\n",
    "    \n",
    "    The evaluation of the information acquisition function\n",
    "    is as follows:\n",
    "    \n",
    "        af_values = alpha(mu, sigma, y_max, **alpha_params)\n",
    "\n",
    "    \"\"\"\n",
    "    if ax is None:\n",
    "        fig, ax = plt.subplots()\n",
    "    \n",
    "    ax.set_title(\n",
    "        \", \".join(\n",
    "            f\"{n}={k:.2f}\"\n",
    "            for n, k in alpha_params.items()\n",
    "            )\n",
    "    )\n",
    "    \n",
    "    m, v = plot_1d_regression(\n",
    "        x_star,\n",
    "        gpr,\n",
    "        ax=ax,\n",
    "        f_true=f_true,\n",
    "        num_samples=0\n",
    "    )\n",
    "    \n",
    "    sigma = torch.sqrt(v)\n",
    "    af_values = alpha(m, sigma, Y.max(), **alpha_params)\n",
    "    next_id = torch.argmax(af_values)\n",
    "    next_x = x_star[next_id]\n",
    "    af_max = af_values[next_id]\n",
    "    \n",
    "    ax2 = ax.twinx()\n",
    "    ax2.plot(x_star, af_values.detach(), color=sns.color_palette()[1])\n",
    "    ax2.set_ylabel(\n",
    "        'Maximum Upper Interval',\n",
    "        color=sns.color_palette()[1]\n",
    "    )\n",
    "    plt.setp(\n",
    "        ax2.get_yticklabels(),\n",
    "        color=sns.color_palette()[1]\n",
    "    )\n",
    "    ax2.plot(\n",
    "        next_x * np.ones(100),\n",
    "        torch.linspace(0, af_max.item(), 100),\n",
    "        color=sns.color_palette()[1],\n",
    "        linewidth=1\n",
    "    )"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Visualize this information acquisition function:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"445.97775pt\" height=\"322.539375pt\" viewBox=\"0 0 445.97775 322.539375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:10.377687</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.539375 \n",
       "L 445.97775 322.539375 \n",
       "L 445.97775 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 395.432875 286.212 \n",
       "L 395.432875 20.1 \n",
       "L 38.312875 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"mc03829a903\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc03829a903\" x=\"54.545602\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(48.429602 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc03829a903\" x=\"119.476511\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(113.360511 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc03829a903\" x=\"184.40742\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(178.29142 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc03829a903\" x=\"249.33833\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(243.22233 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc03829a903\" x=\"314.269239\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(308.153239 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc03829a903\" x=\"379.200148\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(373.084148 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(213.992875 313.431375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"m1e19b2e18f\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m1e19b2e18f\" x=\"38.312875\" y=\"275.235419\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 278.384857) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m1e19b2e18f\" x=\"38.312875\" y=\"244.401016\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −3 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 247.550454) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m1e19b2e18f\" x=\"38.312875\" y=\"213.566613\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 216.71605) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m1e19b2e18f\" x=\"38.312875\" y=\"182.73221\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 185.881647) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m1e19b2e18f\" x=\"38.312875\" y=\"151.897806\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 155.047244) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m1e19b2e18f\" x=\"38.312875\" y=\"121.063403\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 124.212841) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m1e19b2e18f\" x=\"38.312875\" y=\"90.229\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 93.378437) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m1e19b2e18f\" x=\"38.312875\" y=\"59.394597\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- 3 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 62.544034) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-33\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m1e19b2e18f\" x=\"38.312875\" y=\"28.560193\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_16\">\n",
       "      <!-- 4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 31.709631) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-34\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.036) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"m4b86843f48\" d=\"M 54.545602 -267.99986 \n",
       "L 54.545602 -62.312539 \n",
       "L 57.824941 -65.393102 \n",
       "L 61.10428 -68.858626 \n",
       "L 64.383619 -72.716139 \n",
       "L 67.662958 -76.96559 \n",
       "L 70.942296 -81.598943 \n",
       "L 74.221636 -86.599657 \n",
       "L 77.500973 -91.942194 \n",
       "L 80.780313 -97.591656 \n",
       "L 84.059653 -103.504294 \n",
       "L 87.33899 -109.627115 \n",
       "L 90.61833 -115.899002 \n",
       "L 93.89767 -122.25116 \n",
       "L 97.177007 -128.608156 \n",
       "L 100.456344 -134.89017 \n",
       "L 103.735686 -141.012939 \n",
       "L 107.015024 -146.889437 \n",
       "L 110.294361 -152.428785 \n",
       "L 113.573703 -157.426658 \n",
       "L 116.853041 -154.902592 \n",
       "L 120.132378 -150.907424 \n",
       "L 123.41172 -147.625528 \n",
       "L 126.691057 -145.125845 \n",
       "L 129.970395 -143.453161 \n",
       "L 133.249737 -142.635873 \n",
       "L 136.529069 -142.689289 \n",
       "L 139.808412 -143.613356 \n",
       "L 143.087754 -145.393853 \n",
       "L 146.367086 -148.002134 \n",
       "L 149.646428 -151.395947 \n",
       "L 152.92577 -155.51547 \n",
       "L 156.205103 -160.228673 \n",
       "L 159.484445 -158.862756 \n",
       "L 162.763787 -153.924404 \n",
       "L 166.04312 -148.540814 \n",
       "L 169.322462 -142.814632 \n",
       "L 172.601804 -136.832699 \n",
       "L 175.881137 -130.680042 \n",
       "L 179.160479 -124.439347 \n",
       "L 182.439821 -118.189581 \n",
       "L 185.719153 -112.004893 \n",
       "L 188.998496 -105.953003 \n",
       "L 192.277838 -100.094244 \n",
       "L 195.55717 -94.480834 \n",
       "L 198.836512 -89.156235 \n",
       "L 202.115855 -84.154954 \n",
       "L 205.395187 -79.502539 \n",
       "L 208.674529 -75.21575 \n",
       "L 211.953871 -71.303167 \n",
       "L 215.233204 -67.765701 \n",
       "L 218.512556 -64.597531 \n",
       "L 221.791879 -61.787047 \n",
       "L 225.071221 -59.317834 \n",
       "L 228.350563 -57.16983 \n",
       "L 231.629886 -55.320437 \n",
       "L 234.909247 -53.745592 \n",
       "L 238.18857 -52.420875 \n",
       "L 241.467912 -51.322422 \n",
       "L 244.747254 -50.42787 \n",
       "L 248.026597 -49.717165 \n",
       "L 251.305939 -49.173169 \n",
       "L 254.585262 -48.782246 \n",
       "L 257.864623 -48.534677 \n",
       "L 261.143946 -48.424948 \n",
       "L 264.423288 -48.451899 \n",
       "L 267.70263 -48.618734 \n",
       "L 270.981953 -48.93301 \n",
       "L 274.261315 -49.406365 \n",
       "L 277.540637 -50.054216 \n",
       "L 280.81998 -50.895396 \n",
       "L 284.099322 -51.951615 \n",
       "L 287.378664 -53.246779 \n",
       "L 290.658006 -54.806479 \n",
       "L 293.937329 -56.657078 \n",
       "L 297.21669 -58.825086 \n",
       "L 300.496013 -61.336069 \n",
       "L 303.775355 -64.21415 \n",
       "L 307.054697 -67.480816 \n",
       "L 310.33402 -71.154358 \n",
       "L 313.613382 -75.248942 \n",
       "L 316.892705 -79.773993 \n",
       "L 320.172047 -84.733583 \n",
       "L 323.451389 -90.125949 \n",
       "L 326.730731 -95.942995 \n",
       "L 330.010073 -102.170321 \n",
       "L 333.289396 -108.786953 \n",
       "L 336.568738 -115.765631 \n",
       "L 339.84808 -123.073083 \n",
       "L 343.127423 -130.669706 \n",
       "L 346.406765 -138.511134 \n",
       "L 349.686088 -146.548717 \n",
       "L 352.96543 -154.725109 \n",
       "L 356.244772 -162.616266 \n",
       "L 359.524114 -155.250809 \n",
       "L 362.803456 -147.068237 \n",
       "L 366.082798 -139.020699 \n",
       "L 369.362141 -131.165219 \n",
       "L 372.641463 -123.55154 \n",
       "L 375.920806 -116.224905 \n",
       "L 379.200148 -109.224209 \n",
       "L 379.200148 -218.888108 \n",
       "L 379.200148 -218.888108 \n",
       "L 375.920806 -211.49535 \n",
       "L 372.641463 -203.828193 \n",
       "L 369.362141 -195.929901 \n",
       "L 366.082798 -187.849482 \n",
       "L 362.803456 -179.639665 \n",
       "L 359.524114 -171.359636 \n",
       "L 356.244772 -163.962882 \n",
       "L 352.96543 -171.889289 \n",
       "L 349.686088 -180.16701 \n",
       "L 346.406765 -188.370604 \n",
       "L 343.127423 -196.440454 \n",
       "L 339.84808 -204.324852 \n",
       "L 336.568738 -211.975626 \n",
       "L 333.289396 -219.348654 \n",
       "L 330.010073 -226.405622 \n",
       "L 326.730731 -233.113724 \n",
       "L 323.451389 -239.446096 \n",
       "L 320.172047 -245.382207 \n",
       "L 316.892705 -250.907672 \n",
       "L 313.613382 -256.014446 \n",
       "L 310.33402 -260.700399 \n",
       "L 307.054697 -264.968912 \n",
       "L 303.775355 -268.828388 \n",
       "L 300.496013 -272.291721 \n",
       "L 297.21669 -275.375328 \n",
       "L 293.937329 -278.09877 \n",
       "L 290.658006 -280.48347 \n",
       "L 287.378664 -282.55232 \n",
       "L 284.099322 -284.328522 \n",
       "L 280.81998 -285.834961 \n",
       "L 277.540637 -287.093323 \n",
       "L 274.261315 -288.123466 \n",
       "L 270.981953 -288.942754 \n",
       "L 267.70263 -289.565455 \n",
       "L 264.423288 -290.002324 \n",
       "L 261.143946 -290.260215 \n",
       "L 257.864623 -290.341802 \n",
       "L 254.585262 -290.245482 \n",
       "L 251.305939 -289.965376 \n",
       "L 248.026597 -289.491337 \n",
       "L 244.747254 -288.809331 \n",
       "L 241.467912 -287.901738 \n",
       "L 238.18857 -286.747913 \n",
       "L 234.909247 -285.324848 \n",
       "L 231.629886 -283.607914 \n",
       "L 228.350563 -281.571851 \n",
       "L 225.071221 -279.191687 \n",
       "L 221.791879 -276.443911 \n",
       "L 218.512556 -273.307551 \n",
       "L 215.233204 -269.765321 \n",
       "L 211.953871 -265.804924 \n",
       "L 208.674529 -261.419993 \n",
       "L 205.395187 -256.611204 \n",
       "L 202.115855 -251.387195 \n",
       "L 198.836512 -245.765257 \n",
       "L 195.55717 -239.771907 \n",
       "L 192.277838 -233.44324 \n",
       "L 188.998496 -226.824874 \n",
       "L 185.719153 -219.971913 \n",
       "L 182.439821 -212.948303 \n",
       "L 179.160479 -205.826105 \n",
       "L 175.881137 -198.684615 \n",
       "L 172.601804 -191.608686 \n",
       "L 169.322462 -184.687657 \n",
       "L 166.04312 -178.013889 \n",
       "L 162.763787 -171.682197 \n",
       "L 159.484445 -165.803752 \n",
       "L 156.205103 -163.514699 \n",
       "L 152.92577 -167.330997 \n",
       "L 149.646428 -170.589275 \n",
       "L 146.367086 -173.166961 \n",
       "L 143.087754 -175.013529 \n",
       "L 139.808412 -176.095699 \n",
       "L 136.529069 -176.393322 \n",
       "L 133.249737 -175.899993 \n",
       "L 129.970395 -174.622643 \n",
       "L 126.691057 -172.582637 \n",
       "L 123.41172 -169.81327 \n",
       "L 120.132378 -166.363067 \n",
       "L 116.853041 -162.303384 \n",
       "L 113.573703 -159.819667 \n",
       "L 110.294361 -164.962433 \n",
       "L 107.015024 -170.749558 \n",
       "L 103.735686 -176.973675 \n",
       "L 100.456344 -183.539597 \n",
       "L 97.177007 -190.3548 \n",
       "L 93.89767 -197.328439 \n",
       "L 90.61833 -204.373196 \n",
       "L 87.33899 -211.405331 \n",
       "L 84.059653 -218.347126 \n",
       "L 80.780313 -225.128119 \n",
       "L 77.500973 -231.685667 \n",
       "L 74.221636 -237.966358 \n",
       "L 70.942296 -243.925634 \n",
       "L 67.662958 -249.528619 \n",
       "L 64.383619 -254.749791 \n",
       "L 61.10428 -259.572643 \n",
       "L 57.824941 -263.989362 \n",
       "L 54.545602 -267.99986 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pea610a3f59)\">\n",
       "     <use xlink:href=\"#m4b86843f48\" x=\"0\" y=\"322.539375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m5d3e7da8fe\" d=\"M 54.545602 -62.312539 \n",
       "L 54.545602 -62.310694 \n",
       "L 57.824941 -65.391191 \n",
       "L 61.10428 -68.856641 \n",
       "L 64.383619 -72.714051 \n",
       "L 67.662958 -76.963391 \n",
       "L 70.942296 -81.596605 \n",
       "L 74.221636 -86.597143 \n",
       "L 77.500973 -91.939474 \n",
       "L 80.780313 -97.588671 \n",
       "L 84.059653 -103.500986 \n",
       "L 87.33899 -109.62338 \n",
       "L 90.61833 -115.894702 \n",
       "L 93.89767 -122.246095 \n",
       "L 97.177007 -128.601995 \n",
       "L 100.456344 -134.882355 \n",
       "L 103.735686 -141.002368 \n",
       "L 107.015024 -146.873508 \n",
       "L 110.294361 -152.398517 \n",
       "L 113.573703 -157.277084 \n",
       "L 116.853041 -154.851556 \n",
       "L 120.132378 -150.882857 \n",
       "L 123.41172 -147.608401 \n",
       "L 126.691057 -145.112 \n",
       "L 129.970395 -143.440965 \n",
       "L 133.249737 -142.624442 \n",
       "L 136.529069 -142.678009 \n",
       "L 139.808412 -143.601652 \n",
       "L 143.087754 -145.381017 \n",
       "L 146.367086 -147.98703 \n",
       "L 149.646428 -151.376154 \n",
       "L 152.92577 -155.483371 \n",
       "L 156.205103 -160.116751 \n",
       "L 159.484445 -158.808391 \n",
       "L 162.763787 -153.903013 \n",
       "L 166.04312 -148.527916 \n",
       "L 169.322462 -142.805553 \n",
       "L 172.601804 -136.825759 \n",
       "L 175.881137 -130.674451 \n",
       "L 179.160479 -124.434676 \n",
       "L 182.439821 -118.185567 \n",
       "L 185.719153 -112.001372 \n",
       "L 188.998496 -105.949857 \n",
       "L 192.277838 -100.091392 \n",
       "L 195.55717 -94.478217 \n",
       "L 198.836512 -89.153809 \n",
       "L 202.115855 -84.152683 \n",
       "L 205.395187 -79.500392 \n",
       "L 208.674529 -75.213706 \n",
       "L 211.953871 -71.301212 \n",
       "L 215.233204 -67.763819 \n",
       "L 218.512556 -64.595715 \n",
       "L 221.791879 -61.785283 \n",
       "L 225.071221 -59.316107 \n",
       "L 228.350563 -57.16814 \n",
       "L 231.629886 -55.318768 \n",
       "L 234.909247 -53.743953 \n",
       "L 238.18857 -52.419258 \n",
       "L 241.467912 -51.32082 \n",
       "L 244.747254 -50.426282 \n",
       "L 248.026597 -49.715584 \n",
       "L 251.305939 -49.171588 \n",
       "L 254.585262 -48.780672 \n",
       "L 257.864623 -48.533103 \n",
       "L 261.143946 -48.423375 \n",
       "L 264.423288 -48.450326 \n",
       "L 267.70263 -48.61716 \n",
       "L 270.981953 -48.931429 \n",
       "L 274.261315 -49.40477 \n",
       "L 277.540637 -50.052613 \n",
       "L 280.81998 -50.893779 \n",
       "L 284.099322 -51.949983 \n",
       "L 287.378664 -53.245125 \n",
       "L 290.658006 -54.804796 \n",
       "L 293.937329 -56.655365 \n",
       "L 297.21669 -58.823336 \n",
       "L 300.496013 -61.334268 \n",
       "L 303.775355 -64.21229 \n",
       "L 307.054697 -67.478897 \n",
       "L 310.33402 -71.152351 \n",
       "L 313.613382 -75.24684 \n",
       "L 316.892705 -79.771773 \n",
       "L 320.172047 -84.731216 \n",
       "L 323.451389 -90.123398 \n",
       "L 326.730731 -95.940224 \n",
       "L 330.010073 -102.167256 \n",
       "L 333.289396 -108.783513 \n",
       "L 336.568738 -115.761676 \n",
       "L 339.84808 -123.068404 \n",
       "L 343.127423 -130.663924 \n",
       "L 346.406765 -138.50351 \n",
       "L 349.686088 -146.537409 \n",
       "L 352.96543 -154.702981 \n",
       "L 356.244772 -162.376531 \n",
       "L 359.524114 -155.227235 \n",
       "L 362.803456 -147.056562 \n",
       "L 366.082798 -139.01291 \n",
       "L 369.362141 -131.159349 \n",
       "L 372.641463 -123.546802 \n",
       "L 375.920806 -116.220913 \n",
       "L 379.200148 -109.220743 \n",
       "L 379.200148 -109.224209 \n",
       "L 379.200148 -109.224209 \n",
       "L 375.920806 -116.224905 \n",
       "L 372.641463 -123.55154 \n",
       "L 369.362141 -131.165219 \n",
       "L 366.082798 -139.020699 \n",
       "L 362.803456 -147.068237 \n",
       "L 359.524114 -155.250809 \n",
       "L 356.244772 -162.616266 \n",
       "L 352.96543 -154.725109 \n",
       "L 349.686088 -146.548717 \n",
       "L 346.406765 -138.511134 \n",
       "L 343.127423 -130.669706 \n",
       "L 339.84808 -123.073083 \n",
       "L 336.568738 -115.765631 \n",
       "L 333.289396 -108.786953 \n",
       "L 330.010073 -102.170321 \n",
       "L 326.730731 -95.942995 \n",
       "L 323.451389 -90.125949 \n",
       "L 320.172047 -84.733583 \n",
       "L 316.892705 -79.773993 \n",
       "L 313.613382 -75.248942 \n",
       "L 310.33402 -71.154358 \n",
       "L 307.054697 -67.480816 \n",
       "L 303.775355 -64.21415 \n",
       "L 300.496013 -61.336069 \n",
       "L 297.21669 -58.825086 \n",
       "L 293.937329 -56.657078 \n",
       "L 290.658006 -54.806479 \n",
       "L 287.378664 -53.246779 \n",
       "L 284.099322 -51.951615 \n",
       "L 280.81998 -50.895396 \n",
       "L 277.540637 -50.054216 \n",
       "L 274.261315 -49.406365 \n",
       "L 270.981953 -48.93301 \n",
       "L 267.70263 -48.618734 \n",
       "L 264.423288 -48.451899 \n",
       "L 261.143946 -48.424948 \n",
       "L 257.864623 -48.534677 \n",
       "L 254.585262 -48.782246 \n",
       "L 251.305939 -49.173169 \n",
       "L 248.026597 -49.717165 \n",
       "L 244.747254 -50.42787 \n",
       "L 241.467912 -51.322422 \n",
       "L 238.18857 -52.420875 \n",
       "L 234.909247 -53.745592 \n",
       "L 231.629886 -55.320437 \n",
       "L 228.350563 -57.16983 \n",
       "L 225.071221 -59.317834 \n",
       "L 221.791879 -61.787047 \n",
       "L 218.512556 -64.597531 \n",
       "L 215.233204 -67.765701 \n",
       "L 211.953871 -71.303167 \n",
       "L 208.674529 -75.21575 \n",
       "L 205.395187 -79.502539 \n",
       "L 202.115855 -84.154954 \n",
       "L 198.836512 -89.156235 \n",
       "L 195.55717 -94.480834 \n",
       "L 192.277838 -100.094244 \n",
       "L 188.998496 -105.953003 \n",
       "L 185.719153 -112.004893 \n",
       "L 182.439821 -118.189581 \n",
       "L 179.160479 -124.439347 \n",
       "L 175.881137 -130.680042 \n",
       "L 172.601804 -136.832699 \n",
       "L 169.322462 -142.814632 \n",
       "L 166.04312 -148.540814 \n",
       "L 162.763787 -153.924404 \n",
       "L 159.484445 -158.862756 \n",
       "L 156.205103 -160.228673 \n",
       "L 152.92577 -155.51547 \n",
       "L 149.646428 -151.395947 \n",
       "L 146.367086 -148.002134 \n",
       "L 143.087754 -145.393853 \n",
       "L 139.808412 -143.613356 \n",
       "L 136.529069 -142.689289 \n",
       "L 133.249737 -142.635873 \n",
       "L 129.970395 -143.453161 \n",
       "L 126.691057 -145.125845 \n",
       "L 123.41172 -147.625528 \n",
       "L 120.132378 -150.907424 \n",
       "L 116.853041 -154.902592 \n",
       "L 113.573703 -157.426658 \n",
       "L 110.294361 -152.428785 \n",
       "L 107.015024 -146.889437 \n",
       "L 103.735686 -141.012939 \n",
       "L 100.456344 -134.89017 \n",
       "L 97.177007 -128.608156 \n",
       "L 93.89767 -122.25116 \n",
       "L 90.61833 -115.899002 \n",
       "L 87.33899 -109.627115 \n",
       "L 84.059653 -103.504294 \n",
       "L 80.780313 -97.591656 \n",
       "L 77.500973 -91.942194 \n",
       "L 74.221636 -86.599657 \n",
       "L 70.942296 -81.598943 \n",
       "L 67.662958 -76.96559 \n",
       "L 64.383619 -72.716139 \n",
       "L 61.10428 -68.858626 \n",
       "L 57.824941 -65.393102 \n",
       "L 54.545602 -62.312539 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pea610a3f59)\">\n",
       "     <use xlink:href=\"#m5d3e7da8fe\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"m0a963b7d46\" d=\"M 54.545602 -268.001705 \n",
       "L 54.545602 -267.99986 \n",
       "L 57.824941 -263.989362 \n",
       "L 61.10428 -259.572643 \n",
       "L 64.383619 -254.749791 \n",
       "L 67.662958 -249.528619 \n",
       "L 70.942296 -243.925634 \n",
       "L 74.221636 -237.966358 \n",
       "L 77.500973 -231.685667 \n",
       "L 80.780313 -225.128119 \n",
       "L 84.059653 -218.347126 \n",
       "L 87.33899 -211.405331 \n",
       "L 90.61833 -204.373196 \n",
       "L 93.89767 -197.328439 \n",
       "L 97.177007 -190.3548 \n",
       "L 100.456344 -183.539597 \n",
       "L 103.735686 -176.973675 \n",
       "L 107.015024 -170.749558 \n",
       "L 110.294361 -164.962433 \n",
       "L 113.573703 -159.819667 \n",
       "L 116.853041 -162.303384 \n",
       "L 120.132378 -166.363067 \n",
       "L 123.41172 -169.81327 \n",
       "L 126.691057 -172.582637 \n",
       "L 129.970395 -174.622643 \n",
       "L 133.249737 -175.899993 \n",
       "L 136.529069 -176.393322 \n",
       "L 139.808412 -176.095699 \n",
       "L 143.087754 -175.013529 \n",
       "L 146.367086 -173.166961 \n",
       "L 149.646428 -170.589275 \n",
       "L 152.92577 -167.330997 \n",
       "L 156.205103 -163.514699 \n",
       "L 159.484445 -165.803752 \n",
       "L 162.763787 -171.682197 \n",
       "L 166.04312 -178.013889 \n",
       "L 169.322462 -184.687657 \n",
       "L 172.601804 -191.608686 \n",
       "L 175.881137 -198.684615 \n",
       "L 179.160479 -205.826105 \n",
       "L 182.439821 -212.948303 \n",
       "L 185.719153 -219.971913 \n",
       "L 188.998496 -226.824874 \n",
       "L 192.277838 -233.44324 \n",
       "L 195.55717 -239.771907 \n",
       "L 198.836512 -245.765257 \n",
       "L 202.115855 -251.387195 \n",
       "L 205.395187 -256.611204 \n",
       "L 208.674529 -261.419993 \n",
       "L 211.953871 -265.804924 \n",
       "L 215.233204 -269.765321 \n",
       "L 218.512556 -273.307551 \n",
       "L 221.791879 -276.443911 \n",
       "L 225.071221 -279.191687 \n",
       "L 228.350563 -281.571851 \n",
       "L 231.629886 -283.607914 \n",
       "L 234.909247 -285.324848 \n",
       "L 238.18857 -286.747913 \n",
       "L 241.467912 -287.901738 \n",
       "L 244.747254 -288.809331 \n",
       "L 248.026597 -289.491337 \n",
       "L 251.305939 -289.965376 \n",
       "L 254.585262 -290.245482 \n",
       "L 257.864623 -290.341802 \n",
       "L 261.143946 -290.260215 \n",
       "L 264.423288 -290.002324 \n",
       "L 267.70263 -289.565455 \n",
       "L 270.981953 -288.942754 \n",
       "L 274.261315 -288.123466 \n",
       "L 277.540637 -287.093323 \n",
       "L 280.81998 -285.834961 \n",
       "L 284.099322 -284.328522 \n",
       "L 287.378664 -282.55232 \n",
       "L 290.658006 -280.48347 \n",
       "L 293.937329 -278.09877 \n",
       "L 297.21669 -275.375328 \n",
       "L 300.496013 -272.291721 \n",
       "L 303.775355 -268.828388 \n",
       "L 307.054697 -264.968912 \n",
       "L 310.33402 -260.700399 \n",
       "L 313.613382 -256.014446 \n",
       "L 316.892705 -250.907672 \n",
       "L 320.172047 -245.382207 \n",
       "L 323.451389 -239.446096 \n",
       "L 326.730731 -233.113724 \n",
       "L 330.010073 -226.405622 \n",
       "L 333.289396 -219.348654 \n",
       "L 336.568738 -211.975626 \n",
       "L 339.84808 -204.324852 \n",
       "L 343.127423 -196.440454 \n",
       "L 346.406765 -188.370604 \n",
       "L 349.686088 -180.16701 \n",
       "L 352.96543 -171.889289 \n",
       "L 356.244772 -163.962882 \n",
       "L 359.524114 -171.359636 \n",
       "L 362.803456 -179.639665 \n",
       "L 366.082798 -187.849482 \n",
       "L 369.362141 -195.929901 \n",
       "L 372.641463 -203.828193 \n",
       "L 375.920806 -211.49535 \n",
       "L 379.200148 -218.888108 \n",
       "L 379.200148 -218.891574 \n",
       "L 379.200148 -218.891574 \n",
       "L 375.920806 -211.499341 \n",
       "L 372.641463 -203.832931 \n",
       "L 369.362141 -195.935772 \n",
       "L 366.082798 -187.857271 \n",
       "L 362.803456 -179.651337 \n",
       "L 359.524114 -171.38321 \n",
       "L 356.244772 -164.202618 \n",
       "L 352.96543 -171.911418 \n",
       "L 349.686088 -180.178319 \n",
       "L 346.406765 -188.378229 \n",
       "L 343.127423 -196.446235 \n",
       "L 339.84808 -204.329532 \n",
       "L 336.568738 -211.979582 \n",
       "L 333.289396 -219.352094 \n",
       "L 330.010073 -226.408687 \n",
       "L 326.730731 -233.116496 \n",
       "L 323.451389 -239.448647 \n",
       "L 320.172047 -245.384575 \n",
       "L 316.892705 -250.909892 \n",
       "L 313.613382 -256.016549 \n",
       "L 310.33402 -260.702406 \n",
       "L 307.054697 -264.970831 \n",
       "L 303.775355 -268.830248 \n",
       "L 300.496013 -272.293522 \n",
       "L 297.21669 -275.377077 \n",
       "L 293.937329 -278.100483 \n",
       "L 290.658006 -280.485153 \n",
       "L 287.378664 -282.553974 \n",
       "L 284.099322 -284.330154 \n",
       "L 280.81998 -285.836578 \n",
       "L 277.540637 -287.094926 \n",
       "L 274.261315 -288.125062 \n",
       "L 270.981953 -288.944334 \n",
       "L 267.70263 -289.567028 \n",
       "L 264.423288 -290.003898 \n",
       "L 261.143946 -290.261788 \n",
       "L 257.864623 -290.343375 \n",
       "L 254.585262 -290.247056 \n",
       "L 251.305939 -289.966956 \n",
       "L 248.026597 -289.492917 \n",
       "L 244.747254 -288.810919 \n",
       "L 241.467912 -287.90334 \n",
       "L 238.18857 -286.749531 \n",
       "L 234.909247 -285.326487 \n",
       "L 231.629886 -283.609582 \n",
       "L 228.350563 -281.573542 \n",
       "L 225.071221 -279.193415 \n",
       "L 221.791879 -276.445676 \n",
       "L 218.512556 -273.309367 \n",
       "L 215.233204 -269.767203 \n",
       "L 211.953871 -265.80688 \n",
       "L 208.674529 -261.422036 \n",
       "L 205.395187 -256.61335 \n",
       "L 202.115855 -251.389466 \n",
       "L 198.836512 -245.767683 \n",
       "L 195.55717 -239.774524 \n",
       "L 192.277838 -233.446093 \n",
       "L 188.998496 -226.82802 \n",
       "L 185.719153 -219.975435 \n",
       "L 182.439821 -212.952317 \n",
       "L 179.160479 -205.830777 \n",
       "L 175.881137 -198.690206 \n",
       "L 172.601804 -191.615629 \n",
       "L 169.322462 -184.696736 \n",
       "L 166.04312 -178.026787 \n",
       "L 162.763787 -171.703587 \n",
       "L 159.484445 -165.858117 \n",
       "L 156.205103 -163.62662 \n",
       "L 152.92577 -167.363097 \n",
       "L 149.646428 -170.609069 \n",
       "L 146.367086 -173.182065 \n",
       "L 143.087754 -175.026363 \n",
       "L 139.808412 -176.107403 \n",
       "L 136.529069 -176.404603 \n",
       "L 133.249737 -175.911422 \n",
       "L 129.970395 -174.634839 \n",
       "L 126.691057 -172.596481 \n",
       "L 123.41172 -169.830397 \n",
       "L 120.132378 -166.387634 \n",
       "L 116.853041 -162.35442 \n",
       "L 113.573703 -159.96924 \n",
       "L 110.294361 -164.992703 \n",
       "L 107.015024 -170.765487 \n",
       "L 103.735686 -176.984246 \n",
       "L 100.456344 -183.547413 \n",
       "L 97.177007 -190.36096 \n",
       "L 93.89767 -197.333504 \n",
       "L 90.61833 -204.377497 \n",
       "L 87.33899 -211.409065 \n",
       "L 84.059653 -218.350438 \n",
       "L 80.780313 -225.131104 \n",
       "L 77.500973 -231.688387 \n",
       "L 74.221636 -237.968872 \n",
       "L 70.942296 -243.927986 \n",
       "L 67.662958 -249.530818 \n",
       "L 64.383619 -254.751878 \n",
       "L 61.10428 -259.574643 \n",
       "L 57.824941 -263.991274 \n",
       "L 54.545602 -268.001705 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pea610a3f59)\">\n",
       "     <use xlink:href=\"#m0a963b7d46\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <defs>\n",
       "     <path id=\"m536c951c68\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pea610a3f59)\">\n",
       "     <use xlink:href=\"#m536c951c68\" x=\"356.349693\" y=\"159.249999\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m536c951c68\" x=\"157.258364\" y=\"160.52067\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m536c951c68\" x=\"114.255683\" y=\"163.925017\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_17\">\n",
       "    <path d=\"M 54.545602 157.383172 \n",
       "L 57.824941 157.848146 \n",
       "L 61.10428 158.323737 \n",
       "L 64.383619 158.80641 \n",
       "L 67.662958 159.292268 \n",
       "L 70.942296 159.777083 \n",
       "L 74.221636 160.256369 \n",
       "L 77.500973 160.725443 \n",
       "L 80.780313 161.179488 \n",
       "L 84.059653 161.613663 \n",
       "L 87.33899 162.023151 \n",
       "L 90.61833 162.403275 \n",
       "L 93.89767 162.749575 \n",
       "L 97.177007 163.057896 \n",
       "L 100.456344 163.324492 \n",
       "L 103.735686 163.546069 \n",
       "L 107.015024 163.719877 \n",
       "L 110.294361 163.843766 \n",
       "L 113.573703 163.916213 \n",
       "L 116.853041 163.936387 \n",
       "L 120.132378 163.90413 \n",
       "L 123.41172 163.819976 \n",
       "L 126.691057 163.685134 \n",
       "L 129.970395 163.501473 \n",
       "L 133.249737 163.271442 \n",
       "L 136.529069 162.99807 \n",
       "L 139.808412 162.684847 \n",
       "L 143.087754 162.335685 \n",
       "L 146.367086 161.954827 \n",
       "L 149.646428 161.546763 \n",
       "L 152.92577 161.116141 \n",
       "L 156.205103 160.667689 \n",
       "L 159.484445 160.206121 \n",
       "L 162.763787 159.736075 \n",
       "L 166.04312 159.262024 \n",
       "L 169.322462 158.788231 \n",
       "L 172.601804 158.318682 \n",
       "L 175.881137 157.857047 \n",
       "L 179.160479 157.406648 \n",
       "L 182.439821 156.970433 \n",
       "L 185.719153 156.550971 \n",
       "L 188.998496 156.150438 \n",
       "L 192.277838 155.770636 \n",
       "L 195.55717 155.413003 \n",
       "L 198.836512 155.078631 \n",
       "L 202.115855 154.768299 \n",
       "L 205.395187 154.482506 \n",
       "L 208.674529 154.221502 \n",
       "L 211.953871 153.985329 \n",
       "L 215.233204 153.773862 \n",
       "L 218.512556 153.586835 \n",
       "L 221.791879 153.423893 \n",
       "L 225.071221 153.284611 \n",
       "L 228.350563 153.168534 \n",
       "L 231.629886 153.075198 \n",
       "L 234.909247 153.004152 \n",
       "L 238.18857 152.954978 \n",
       "L 241.467912 152.927295 \n",
       "L 244.747254 152.920772 \n",
       "L 248.026597 152.935123 \n",
       "L 251.305939 152.970105 \n",
       "L 254.585262 153.025508 \n",
       "L 257.864623 153.101136 \n",
       "L 261.143946 153.196795 \n",
       "L 264.423288 153.312265 \n",
       "L 267.70263 153.447279 \n",
       "L 270.981953 153.601493 \n",
       "L 274.261315 153.774463 \n",
       "L 277.540637 153.965608 \n",
       "L 280.81998 154.174196 \n",
       "L 284.099322 154.39931 \n",
       "L 287.378664 154.639825 \n",
       "L 290.658006 154.894399 \n",
       "L 293.937329 155.161451 \n",
       "L 297.21669 155.43917 \n",
       "L 300.496013 155.725481 \n",
       "L 303.775355 156.018103 \n",
       "L 307.054697 156.314513 \n",
       "L 310.33402 156.611999 \n",
       "L 313.613382 156.907681 \n",
       "L 316.892705 157.198543 \n",
       "L 320.172047 157.481481 \n",
       "L 323.451389 157.753352 \n",
       "L 326.730731 158.011016 \n",
       "L 330.010073 158.251405 \n",
       "L 333.289396 158.471571 \n",
       "L 336.568738 158.668748 \n",
       "L 339.84808 158.840408 \n",
       "L 343.127423 158.984296 \n",
       "L 346.406765 159.098505 \n",
       "L 349.686088 159.181511 \n",
       "L 352.96543 159.232176 \n",
       "L 356.244772 159.2498 \n",
       "L 359.524114 159.234152 \n",
       "L 362.803456 159.185425 \n",
       "L 366.082798 159.104285 \n",
       "L 369.362141 158.991816 \n",
       "L 372.641463 158.849509 \n",
       "L 375.920806 158.679246 \n",
       "L 379.200148 158.483217 \n",
       "\" clip-path=\"url(#pea610a3f59)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 38.312875 275.235419 \n",
       "L 38.312875 28.560193 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 54.545602 286.212 \n",
       "L 379.200148 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_18\">\n",
       "    <!-- psi=0.00 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(198.592375 14.1) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-70\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"55.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"105.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"127.832031\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"241.845703\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"269.628906\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"325.244141\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_18\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#m536c951c68\" x=\"307.608875\" y=\"31.238875\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(323.448875 34.318875) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_19\">\n",
       "     <path d=\"M 298.808875 43.822875 \n",
       "L 307.608875 43.822875 \n",
       "L 316.408875 43.822875 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(323.448875 46.902875) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 298.808875 61.059875 \n",
       "L 316.408875 61.059875 \n",
       "L 316.408875 54.899875 \n",
       "L 298.808875 54.899875 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(323.448875 61.059875) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 298.808875 75.227875 \n",
       "L 316.408875 75.227875 \n",
       "L 316.408875 69.067875 \n",
       "L 298.808875 69.067875 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_22\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(323.448875 75.227875) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <defs>\n",
       "       <path id=\"mfbd7e0d493\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mfbd7e0d493\" x=\"395.432875\" y=\"280.047772\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- −0.40 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 283.19721) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mfbd7e0d493\" x=\"395.432875\" y=\"249.066301\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- −0.35 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 252.215738) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mfbd7e0d493\" x=\"395.432875\" y=\"218.084829\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- −0.30 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 221.234267) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mfbd7e0d493\" x=\"395.432875\" y=\"187.103358\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- −0.25 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 190.252795) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_14\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mfbd7e0d493\" x=\"395.432875\" y=\"156.121886\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- −0.20 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 159.271324) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_15\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mfbd7e0d493\" x=\"395.432875\" y=\"125.140415\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_28\">\n",
       "      <!-- −0.15 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 128.289852) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_16\">\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mfbd7e0d493\" x=\"395.432875\" y=\"94.158943\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_29\">\n",
       "      <!-- −0.10 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 97.308381) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_17\">\n",
       "     <g id=\"line2d_27\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mfbd7e0d493\" x=\"395.432875\" y=\"63.177472\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_30\">\n",
       "      <!-- −0.05 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 66.326909) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_18\">\n",
       "     <g id=\"line2d_28\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mfbd7e0d493\" x=\"395.432875\" y=\"32.196\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_31\">\n",
       "      <!-- 0.00 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 35.345437) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_32\">\n",
       "     <!-- Maximum Upper Interval -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(436.86975 205.43475) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4d\" d=\"M 475 0 \n",
       "L 475 4581 \n",
       "L 1388 4581 \n",
       "L 2472 1338 \n",
       "Q 2622 884 2691 659 \n",
       "Q 2769 909 2934 1394 \n",
       "L 4031 4581 \n",
       "L 4847 4581 \n",
       "L 4847 0 \n",
       "L 4263 0 \n",
       "L 4263 3834 \n",
       "L 2931 0 \n",
       "L 2384 0 \n",
       "L 1059 3900 \n",
       "L 1059 0 \n",
       "L 475 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-78\" d=\"M 47 0 \n",
       "L 1259 1725 \n",
       "L 138 3319 \n",
       "L 841 3319 \n",
       "L 1350 2541 \n",
       "Q 1494 2319 1581 2169 \n",
       "Q 1719 2375 1834 2534 \n",
       "L 2394 3319 \n",
       "L 3066 3319 \n",
       "L 1919 1756 \n",
       "L 3153 0 \n",
       "L 2463 0 \n",
       "L 1781 1031 \n",
       "L 1600 1309 \n",
       "L 728 0 \n",
       "L 47 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-55\" d=\"M 3500 4581 \n",
       "L 4106 4581 \n",
       "L 4106 1934 \n",
       "Q 4106 1244 3950 837 \n",
       "Q 3794 431 3386 176 \n",
       "Q 2978 -78 2316 -78 \n",
       "Q 1672 -78 1262 144 \n",
       "Q 853 366 678 786 \n",
       "Q 503 1206 503 1934 \n",
       "L 503 4581 \n",
       "L 1109 4581 \n",
       "L 1109 1938 \n",
       "Q 1109 1341 1220 1058 \n",
       "Q 1331 775 1601 622 \n",
       "Q 1872 469 2263 469 \n",
       "Q 2931 469 3215 772 \n",
       "Q 3500 1075 3500 1938 \n",
       "L 3500 4581 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4d\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "      <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"188.916016\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"211.132812\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"294.433594\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"350.048828\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"433.349609\"/>\n",
       "      <use xlink:href=\"#ArialMT-55\" x=\"461.132812\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" x=\"533.349609\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" x=\"588.964844\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"644.580078\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"700.195312\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"733.496094\"/>\n",
       "      <use xlink:href=\"#ArialMT-49\" x=\"761.279297\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"789.0625\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.677734\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"872.460938\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"928.076172\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"961.376953\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"1011.376953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6c\" x=\"1066.992188\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_29\">\n",
       "    <path d=\"M 54.545602 142.426581 \n",
       "L 57.824941 151.770402 \n",
       "L 61.10428 161.327593 \n",
       "L 64.383619 171.027104 \n",
       "L 67.662958 180.790602 \n",
       "L 70.942296 190.533158 \n",
       "L 74.221636 200.164603 \n",
       "L 77.500973 209.590811 \n",
       "L 80.780313 218.715039 \n",
       "L 84.059653 227.43995 \n",
       "L 87.33899 235.668779 \n",
       "L 90.61833 243.307514 \n",
       "L 93.89767 250.266557 \n",
       "L 97.177007 256.462384 \n",
       "L 100.456344 261.819725 \n",
       "L 103.735686 266.272398 \n",
       "L 107.015024 269.765151 \n",
       "L 110.294361 272.254735 \n",
       "L 113.573703 273.710589 \n",
       "L 116.853041 274.116 \n",
       "L 120.132378 273.467774 \n",
       "L 123.41172 271.776677 \n",
       "L 126.691057 269.066973 \n",
       "L 129.970395 265.376224 \n",
       "L 133.249737 260.753679 \n",
       "L 136.529069 255.260148 \n",
       "L 139.808412 248.965821 \n",
       "L 143.087754 241.949255 \n",
       "L 146.367086 234.295784 \n",
       "L 149.646428 226.095577 \n",
       "L 152.92577 217.442058 \n",
       "L 156.205103 208.430235 \n",
       "L 159.484445 199.154842 \n",
       "L 162.763787 189.709077 \n",
       "L 166.04312 180.182836 \n",
       "L 169.322462 170.661783 \n",
       "L 172.601804 161.226009 \n",
       "L 175.881137 151.949276 \n",
       "L 179.160479 142.898323 \n",
       "L 182.439821 134.132427 \n",
       "L 185.719153 125.703163 \n",
       "L 188.998496 117.654298 \n",
       "L 192.277838 110.022035 \n",
       "L 195.55717 102.835265 \n",
       "L 198.836512 96.115911 \n",
       "L 202.115855 89.879666 \n",
       "L 205.395187 84.136548 \n",
       "L 208.674529 78.891569 \n",
       "L 211.953871 74.145595 \n",
       "L 215.233204 69.896075 \n",
       "L 218.512556 66.137691 \n",
       "L 221.791879 62.863315 \n",
       "L 225.071221 60.064384 \n",
       "L 228.350563 57.731764 \n",
       "L 231.629886 55.856139 \n",
       "L 234.909247 54.428447 \n",
       "L 238.18857 53.440268 \n",
       "L 241.467912 52.88397 \n",
       "L 244.747254 52.752887 \n",
       "L 248.026597 53.041286 \n",
       "L 251.305939 53.744269 \n",
       "L 254.585262 54.857603 \n",
       "L 257.864623 56.377388 \n",
       "L 261.143946 58.29968 \n",
       "L 264.423288 60.620091 \n",
       "L 267.70263 63.333257 \n",
       "L 270.981953 66.432241 \n",
       "L 274.261315 69.908146 \n",
       "L 277.540637 73.749287 \n",
       "L 280.81998 77.940933 \n",
       "L 284.099322 82.464702 \n",
       "L 287.378664 87.297939 \n",
       "L 290.658006 92.413713 \n",
       "L 293.937329 97.780218 \n",
       "L 297.21669 103.361081 \n",
       "L 300.496013 109.114629 \n",
       "L 303.775355 114.99498 \n",
       "L 307.054697 120.951455 \n",
       "L 310.33402 126.929544 \n",
       "L 313.613382 132.871393 \n",
       "L 316.892705 138.716377 \n",
       "L 320.172047 144.402134 \n",
       "L 323.451389 149.865482 \n",
       "L 326.730731 155.043349 \n",
       "L 330.010073 159.874056 \n",
       "L 333.289396 164.298383 \n",
       "L 336.568738 168.260727 \n",
       "L 339.84808 171.710296 \n",
       "L 343.127423 174.601783 \n",
       "L 346.406765 176.89687 \n",
       "L 349.686088 178.564893 \n",
       "L 352.96543 179.583038 \n",
       "L 356.244772 179.937205 \n",
       "L 359.524114 179.62275 \n",
       "L 362.803456 178.643551 \n",
       "L 366.082798 177.013014 \n",
       "L 369.362141 174.752903 \n",
       "L 372.641463 171.893187 \n",
       "L 375.920806 168.471696 \n",
       "L 379.200148 164.532408 \n",
       "\" clip-path=\"url(#pea610a3f59)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_30\">\n",
       "    <path d=\"M 244.747254 32.196 \n",
       "L 244.747254 32.403645 \n",
       "L 244.747254 32.611291 \n",
       "L 244.747254 32.818936 \n",
       "L 244.747254 33.026581 \n",
       "L 244.747254 33.234227 \n",
       "L 244.747254 33.441872 \n",
       "L 244.747254 33.649517 \n",
       "L 244.747254 33.857163 \n",
       "L 244.747254 34.064808 \n",
       "L 244.747254 34.272453 \n",
       "L 244.747254 34.480098 \n",
       "L 244.747254 34.687744 \n",
       "L 244.747254 34.895389 \n",
       "L 244.747254 35.103034 \n",
       "L 244.747254 35.31068 \n",
       "L 244.747254 35.518325 \n",
       "L 244.747254 35.72597 \n",
       "L 244.747254 35.933616 \n",
       "L 244.747254 36.141261 \n",
       "L 244.747254 36.348906 \n",
       "L 244.747254 36.556552 \n",
       "L 244.747254 36.764197 \n",
       "L 244.747254 36.971842 \n",
       "L 244.747254 37.179488 \n",
       "L 244.747254 37.387133 \n",
       "L 244.747254 37.594778 \n",
       "L 244.747254 37.802424 \n",
       "L 244.747254 38.010069 \n",
       "L 244.747254 38.217714 \n",
       "L 244.747254 38.425359 \n",
       "L 244.747254 38.633005 \n",
       "L 244.747254 38.84065 \n",
       "L 244.747254 39.048296 \n",
       "L 244.747254 39.255941 \n",
       "L 244.747254 39.463586 \n",
       "L 244.747254 39.671232 \n",
       "L 244.747254 39.878877 \n",
       "L 244.747254 40.086522 \n",
       "L 244.747254 40.294167 \n",
       "L 244.747254 40.501813 \n",
       "L 244.747254 40.709458 \n",
       "L 244.747254 40.917104 \n",
       "L 244.747254 41.124749 \n",
       "L 244.747254 41.332394 \n",
       "L 244.747254 41.540039 \n",
       "L 244.747254 41.747684 \n",
       "L 244.747254 41.95533 \n",
       "L 244.747254 42.162975 \n",
       "L 244.747254 42.370621 \n",
       "L 244.747254 42.578266 \n",
       "L 244.747254 42.785911 \n",
       "L 244.747254 42.993557 \n",
       "L 244.747254 43.201202 \n",
       "L 244.747254 43.408848 \n",
       "L 244.747254 43.616493 \n",
       "L 244.747254 43.824137 \n",
       "L 244.747254 44.031783 \n",
       "L 244.747254 44.239428 \n",
       "L 244.747254 44.447073 \n",
       "L 244.747254 44.654719 \n",
       "L 244.747254 44.862364 \n",
       "L 244.747254 45.07001 \n",
       "L 244.747254 45.277655 \n",
       "L 244.747254 45.4853 \n",
       "L 244.747254 45.692946 \n",
       "L 244.747254 45.900591 \n",
       "L 244.747254 46.108237 \n",
       "L 244.747254 46.315882 \n",
       "L 244.747254 46.523527 \n",
       "L 244.747254 46.731173 \n",
       "L 244.747254 46.938818 \n",
       "L 244.747254 47.146463 \n",
       "L 244.747254 47.354109 \n",
       "L 244.747254 47.561754 \n",
       "L 244.747254 47.7694 \n",
       "L 244.747254 47.977045 \n",
       "L 244.747254 48.18469 \n",
       "L 244.747254 48.392335 \n",
       "L 244.747254 48.59998 \n",
       "L 244.747254 48.807625 \n",
       "L 244.747254 49.015271 \n",
       "L 244.747254 49.222916 \n",
       "L 244.747254 49.430562 \n",
       "L 244.747254 49.638207 \n",
       "L 244.747254 49.845852 \n",
       "L 244.747254 50.053498 \n",
       "L 244.747254 50.261143 \n",
       "L 244.747254 50.468789 \n",
       "L 244.747254 50.676434 \n",
       "L 244.747254 50.884078 \n",
       "L 244.747254 51.091724 \n",
       "L 244.747254 51.299369 \n",
       "L 244.747254 51.507014 \n",
       "L 244.747254 51.71466 \n",
       "L 244.747254 51.922305 \n",
       "L 244.747254 52.129951 \n",
       "L 244.747254 52.337596 \n",
       "L 244.747254 52.545241 \n",
       "L 244.747254 52.752887 \n",
       "\" clip-path=\"url(#pea610a3f59)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 38.312875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 395.432875 286.212 \n",
       "L 395.432875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 395.432875 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 38.312875 20.1 \n",
       "L 395.432875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pea610a3f59\">\n",
       "   <rect x=\"38.312875\" y=\"20.1\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "plot_iaf(\n",
    "    x,\n",
    "    model,\n",
    "    mui,\n",
    "    alpha_params=dict(psi=0.0)\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Questions\n",
    "+ Experiment with different values of $\\psi$.\n",
    "+ When do you get exploration?\n",
    "+ When do you get exploitation?"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Bayesian global optimization with the maximum upper interval\n",
    "\n",
    "Let's now run the Bayesian global optimization algorithm using the maximum upper interval as the information acquisition function.\n",
    "For convenience, I have written the following generic code for you:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {},
   "outputs": [],
   "source": [
    "def maximize(\n",
    "    f,\n",
    "    model,\n",
    "    X_design,\n",
    "    alpha,\n",
    "    alpha_params={},\n",
    "    max_it=10,\n",
    "    optimize=False,\n",
    "    plot=False,\n",
    "    **kwargs\n",
    "):\n",
    "    \"\"\"Optimize a function using a limited number of evaluations.\n",
    "    \n",
    "    Arguments\n",
    "    f            -- The function to optimize.\n",
    "    gpr          -- A Gaussian process model to use for representing\n",
    "                    our state of knowledge.\n",
    "    X_design     -- The set of candidate points for identifying the\n",
    "                    maximum.\n",
    "    alpha        -- The information acquisition function.\n",
    "                    This assumed to be a function of the\n",
    "                    posterior mean and standard deviation.\n",
    "    \n",
    "    Keyword Arguments\n",
    "    alpha_params -- Extra parameters to the information\n",
    "                    acquisition function.\n",
    "    max_it       -- The maximum number of iterations.\n",
    "    optimize     -- Whether or not to optimize the hyper-parameters.\n",
    "    plot         -- Determines how often to plot. Make it one\n",
    "                    to plot at each iteration. Make it max_it\n",
    "                    to plot at the last iteration.\n",
    "                    \n",
    "    The rest of the keyword arguments are passed to plot_iaf().\n",
    "    \"\"\"\n",
    "    af_all = []\n",
    "    for count in range(max_it):\n",
    "        # Predict\n",
    "        f_design = model(X_design)\n",
    "        m = f_design.mean\n",
    "        sigma2 = f_design.variance\n",
    "        sigma = torch.sqrt(sigma2)\n",
    "        \n",
    "        # Evaluate information acquisition function\n",
    "        y_train = model.train_targets.numpy()\n",
    "        af_values = alpha(\n",
    "            m,\n",
    "            sigma,\n",
    "            y_train.max(),\n",
    "            **alpha_params\n",
    "        )\n",
    "        \n",
    "        # Find best point to include\n",
    "        i = torch.argmax(af_values)\n",
    "        af_all.append(af_values[i])\n",
    "        \n",
    "        new_x = X_design[i:(i+1)].float()\n",
    "        new_y = f(new_x)\n",
    "        train_x = torch.cat([model.train_inputs[0], new_x[:, None]])\n",
    "        train_y = torch.cat([model.train_targets, new_y])\n",
    "        model.set_train_data(train_x, train_y, strict=False)\n",
    "\n",
    "        if optimize:\n",
    "            train(model, train_x, train_y, n_iter=100, lr=0.1)\n",
    "        else:\n",
    "            model.train()\n",
    "            model.eval()\n",
    "        \n",
    "        # Plot if required\n",
    "        if count % plot == 0:\n",
    "            if \"ax\" in kwargs:\n",
    "                ax = kwargs[ax]\n",
    "            else:\n",
    "                fig, ax = plt.subplots()\n",
    "            plot_iaf(\n",
    "                X_design,\n",
    "                model,\n",
    "                alpha,\n",
    "                alpha_params=alpha_params,\n",
    "                f_true=f,\n",
    "                ax=ax\n",
    "            )\n",
    "            ax.set_title(\n",
    "                f\"N={count}, \" + ax.get_title()\n",
    "            )\n",
    "    return af_all"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The code accepts the information acquisition function as an input.\n",
    "Here is how you can use it:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {
    "tags": [
     "hide-output"
    ]
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"433.74575pt\" height=\"322.539375pt\" viewBox=\"0 0 433.74575 322.539375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:10.720386</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.539375 \n",
       "L 433.74575 322.539375 \n",
       "L 433.74575 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 395.432875 286.212 \n",
       "L 395.432875 20.1 \n",
       "L 38.312875 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m97cac16c00\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m97cac16c00\" x=\"54.545602\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(48.429602 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m97cac16c00\" x=\"119.476511\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(113.360511 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m97cac16c00\" x=\"184.40742\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(178.29142 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m97cac16c00\" x=\"249.33833\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(243.22233 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m97cac16c00\" x=\"314.269239\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(308.153239 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m97cac16c00\" x=\"379.200148\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(373.084148 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(213.992875 313.431375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"m84996aa1a3\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m84996aa1a3\" x=\"38.312875\" y=\"273.970638\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 277.120076) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m84996aa1a3\" x=\"38.312875\" y=\"229.526022\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 232.67546) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m84996aa1a3\" x=\"38.312875\" y=\"185.081407\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 188.230844) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m84996aa1a3\" x=\"38.312875\" y=\"140.636791\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 143.786228) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m84996aa1a3\" x=\"38.312875\" y=\"96.192175\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 99.341612) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m84996aa1a3\" x=\"38.312875\" y=\"51.747559\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 54.896997) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_14\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.036) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"md732572d7f\" d=\"M 54.545602 -290.34204 \n",
       "L 54.545602 -142.253787 \n",
       "L 57.824941 -144.208345 \n",
       "L 61.10428 -146.481648 \n",
       "L 64.383619 -149.087118 \n",
       "L 67.662958 -152.033019 \n",
       "L 70.942296 -155.321512 \n",
       "L 74.221636 -158.948042 \n",
       "L 77.500973 -162.900699 \n",
       "L 80.780313 -167.159729 \n",
       "L 84.059653 -171.697456 \n",
       "L 87.33899 -176.477868 \n",
       "L 90.61833 -181.457026 \n",
       "L 93.89767 -186.583236 \n",
       "L 97.177007 -191.797476 \n",
       "L 100.456344 -197.034784 \n",
       "L 103.735686 -202.224265 \n",
       "L 107.015024 -207.290012 \n",
       "L 110.294361 -212.150355 \n",
       "L 113.573703 -216.637607 \n",
       "L 116.853041 -215.763576 \n",
       "L 120.132378 -213.822 \n",
       "L 123.41172 -212.34358 \n",
       "L 126.691057 -211.345956 \n",
       "L 129.970395 -210.826558 \n",
       "L 133.249737 -210.769038 \n",
       "L 136.529069 -211.145487 \n",
       "L 139.808412 -211.915794 \n",
       "L 143.087754 -213.028692 \n",
       "L 146.367086 -214.422377 \n",
       "L 149.646428 -216.02533 \n",
       "L 152.92577 -217.75451 \n",
       "L 156.205103 -219.47432 \n",
       "L 159.484445 -216.586852 \n",
       "L 162.763787 -210.838797 \n",
       "L 166.04312 -204.37925 \n",
       "L 169.322462 -197.282205 \n",
       "L 172.601804 -189.616064 \n",
       "L 175.881137 -181.455436 \n",
       "L 179.160479 -172.880631 \n",
       "L 182.439821 -163.977327 \n",
       "L 185.719153 -154.835719 \n",
       "L 188.998496 -145.549211 \n",
       "L 192.277838 -136.213673 \n",
       "L 195.55717 -126.926365 \n",
       "L 198.836512 -117.784874 \n",
       "L 202.115855 -108.886263 \n",
       "L 205.395187 -100.326092 \n",
       "L 208.674529 -92.197258 \n",
       "L 211.953871 -84.589197 \n",
       "L 215.233204 -77.58688 \n",
       "L 218.512556 -71.2696 \n",
       "L 221.791879 -65.710378 \n",
       "L 225.071221 -60.974551 \n",
       "L 228.350563 -57.11917 \n",
       "L 231.629886 -54.191887 \n",
       "L 234.909247 -52.230214 \n",
       "L 238.18857 -51.260821 \n",
       "L 241.467912 -51.298693 \n",
       "L 244.747254 -52.346891 \n",
       "L 248.026597 -54.395921 \n",
       "L 251.305939 -57.423277 \n",
       "L 254.585262 -61.390492 \n",
       "L 257.864623 -65.838849 \n",
       "L 261.143946 -61.005726 \n",
       "L 264.423288 -56.618203 \n",
       "L 267.70263 -53.135127 \n",
       "L 270.981953 -50.595514 \n",
       "L 274.261315 -49.022401 \n",
       "L 277.540637 -48.426554 \n",
       "L 280.81998 -48.80687 \n",
       "L 284.099322 -50.151217 \n",
       "L 287.378664 -52.43712 \n",
       "L 290.658006 -55.632799 \n",
       "L 293.937329 -59.697894 \n",
       "L 297.21669 -64.584922 \n",
       "L 300.496013 -70.239766 \n",
       "L 303.775355 -76.603595 \n",
       "L 307.054697 -83.613097 \n",
       "L 310.33402 -91.20217 \n",
       "L 313.613382 -99.302605 \n",
       "L 316.892705 -107.8449 \n",
       "L 320.172047 -116.75932 \n",
       "L 323.451389 -125.976512 \n",
       "L 326.730731 -135.427789 \n",
       "L 330.010073 -145.046257 \n",
       "L 333.289396 -154.766726 \n",
       "L 336.568738 -164.526439 \n",
       "L 339.84808 -174.265414 \n",
       "L 343.127423 -183.925937 \n",
       "L 346.406765 -193.453861 \n",
       "L 349.686088 -202.798427 \n",
       "L 352.96543 -211.908732 \n",
       "L 356.244772 -220.471597 \n",
       "L 359.524114 -218.077322 \n",
       "L 362.803456 -214.67202 \n",
       "L 366.082798 -210.95927 \n",
       "L 369.362141 -207.008968 \n",
       "L 372.641463 -202.886639 \n",
       "L 375.920806 -198.655038 \n",
       "L 379.200148 -194.372337 \n",
       "L 379.200148 -272.351328 \n",
       "L 379.200148 -272.351328 \n",
       "L 375.920806 -266.253281 \n",
       "L 372.641463 -259.705471 \n",
       "L 369.362141 -252.718887 \n",
       "L 366.082798 -245.310272 \n",
       "L 362.803456 -237.501367 \n",
       "L 359.524114 -229.321463 \n",
       "L 356.244772 -221.437534 \n",
       "L 352.96543 -223.764532 \n",
       "L 349.686088 -225.867658 \n",
       "L 346.406765 -227.416383 \n",
       "L 343.127423 -228.350644 \n",
       "L 339.84808 -228.620337 \n",
       "L 336.568738 -228.182368 \n",
       "L 333.289396 -227.001749 \n",
       "L 330.010073 -225.053104 \n",
       "L 326.730731 -222.321087 \n",
       "L 323.451389 -218.801218 \n",
       "L 320.172047 -214.500119 \n",
       "L 316.892705 -209.436222 \n",
       "L 313.613382 -203.639597 \n",
       "L 310.33402 -197.151805 \n",
       "L 307.054697 -190.025997 \n",
       "L 303.775355 -182.325901 \n",
       "L 300.496013 -174.125245 \n",
       "L 297.21669 -165.507175 \n",
       "L 293.937329 -156.562396 \n",
       "L 290.658006 -147.388888 \n",
       "L 287.378664 -138.08942 \n",
       "L 284.099322 -128.770968 \n",
       "L 280.81998 -119.542311 \n",
       "L 277.540637 -110.513132 \n",
       "L 274.261315 -101.791566 \n",
       "L 270.981953 -93.482986 \n",
       "L 267.70263 -85.688777 \n",
       "L 264.423288 -78.504117 \n",
       "L 261.143946 -72.021088 \n",
       "L 257.864623 -66.730453 \n",
       "L 254.585262 -72.36989 \n",
       "L 251.305939 -79.165333 \n",
       "L 248.026597 -86.62496 \n",
       "L 244.747254 -94.655925 \n",
       "L 241.467912 -103.161143 \n",
       "L 238.18857 -112.03766 \n",
       "L 234.909247 -121.177933 \n",
       "L 231.629886 -130.471482 \n",
       "L 228.350563 -139.80657 \n",
       "L 225.071221 -149.072272 \n",
       "L 221.791879 -158.160262 \n",
       "L 218.512556 -166.966652 \n",
       "L 215.233204 -175.394124 \n",
       "L 211.953871 -183.353128 \n",
       "L 208.674529 -190.764028 \n",
       "L 205.395187 -197.558173 \n",
       "L 202.115855 -203.679164 \n",
       "L 198.836512 -209.083954 \n",
       "L 195.55717 -213.743447 \n",
       "L 192.277838 -217.64292 \n",
       "L 188.998496 -220.782319 \n",
       "L 185.719153 -223.175887 \n",
       "L 182.439821 -224.851873 \n",
       "L 179.160479 -225.851677 \n",
       "L 175.881137 -226.229095 \n",
       "L 172.601804 -226.048505 \n",
       "L 169.322462 -225.383894 \n",
       "L 166.04312 -224.317367 \n",
       "L 162.763787 -222.93802 \n",
       "L 159.484445 -221.352507 \n",
       "L 156.205103 -221.753369 \n",
       "L 152.92577 -225.940148 \n",
       "L 149.646428 -229.375841 \n",
       "L 146.367086 -231.992252 \n",
       "L 143.087754 -233.778784 \n",
       "L 139.808412 -234.739854 \n",
       "L 136.529069 -234.891653 \n",
       "L 133.249737 -234.261462 \n",
       "L 129.970395 -232.886908 \n",
       "L 126.691057 -230.815812 \n",
       "L 123.41172 -228.10424 \n",
       "L 120.132378 -224.81778 \n",
       "L 116.853041 -221.037091 \n",
       "L 113.573703 -218.349909 \n",
       "L 110.294361 -221.100533 \n",
       "L 107.015024 -224.344495 \n",
       "L 103.735686 -227.950596 \n",
       "L 100.456344 -231.866454 \n",
       "L 97.177007 -236.038304 \n",
       "L 93.89767 -240.410413 \n",
       "L 90.61833 -244.926507 \n",
       "L 87.33899 -249.530021 \n",
       "L 84.059653 -254.166199 \n",
       "L 80.780313 -258.783126 \n",
       "L 77.500973 -263.332539 \n",
       "L 74.221636 -267.771083 \n",
       "L 70.942296 -272.060441 \n",
       "L 67.662958 -276.168154 \n",
       "L 64.383619 -280.067691 \n",
       "L 61.10428 -283.738567 \n",
       "L 57.824941 -287.166319 \n",
       "L 54.545602 -290.34204 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p7b3201c021)\">\n",
       "     <use xlink:href=\"#md732572d7f\" x=\"0\" y=\"322.539375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m68ab6d5965\" d=\"M 54.545602 -142.253787 \n",
       "L 54.545602 -142.252452 \n",
       "L 57.824941 -144.206967 \n",
       "L 61.10428 -146.480213 \n",
       "L 64.383619 -149.085608 \n",
       "L 67.662958 -152.031424 \n",
       "L 70.942296 -155.319817 \n",
       "L 74.221636 -158.946225 \n",
       "L 77.500973 -162.898733 \n",
       "L 80.780313 -167.157578 \n",
       "L 84.059653 -171.695061 \n",
       "L 87.33899 -176.475166 \n",
       "L 90.61833 -181.453916 \n",
       "L 93.89767 -186.579569 \n",
       "L 97.177007 -191.793012 \n",
       "L 100.456344 -197.029115 \n",
       "L 103.735686 -202.216588 \n",
       "L 107.015024 -207.278435 \n",
       "L 110.294361 -212.128338 \n",
       "L 113.573703 -216.529119 \n",
       "L 116.853041 -215.726381 \n",
       "L 120.132378 -213.804064 \n",
       "L 123.41172 -212.331058 \n",
       "L 126.691057 -211.335816 \n",
       "L 129.970395 -210.817608 \n",
       "L 133.249737 -210.760634 \n",
       "L 136.529069 -211.137171 \n",
       "L 139.808412 -211.907143 \n",
       "L 143.087754 -213.019177 \n",
       "L 146.367086 -214.411141 \n",
       "L 149.646428 -216.01055 \n",
       "L 152.92577 -217.730448 \n",
       "L 156.205103 -219.390714 \n",
       "L 159.484445 -216.545757 \n",
       "L 162.763787 -210.822493 \n",
       "L 166.04312 -204.369348 \n",
       "L 169.322462 -197.275177 \n",
       "L 172.601804 -189.610644 \n",
       "L 175.881137 -181.451023 \n",
       "L 179.160479 -172.876907 \n",
       "L 182.439821 -163.974084 \n",
       "L 185.719153 -154.832826 \n",
       "L 188.998496 -145.546588 \n",
       "L 192.277838 -136.211246 \n",
       "L 195.55717 -126.924086 \n",
       "L 198.836512 -117.782701 \n",
       "L 202.115855 -108.884186 \n",
       "L 205.395187 -100.324057 \n",
       "L 208.674529 -92.195245 \n",
       "L 211.953871 -84.587205 \n",
       "L 215.233204 -77.584856 \n",
       "L 218.512556 -71.267534 \n",
       "L 221.791879 -65.708238 \n",
       "L 225.071221 -60.972304 \n",
       "L 228.350563 -57.116786 \n",
       "L 231.629886 -54.189291 \n",
       "L 234.909247 -52.227353 \n",
       "L 238.18857 -51.257579 \n",
       "L 241.467912 -51.294889 \n",
       "L 244.747254 -52.342229 \n",
       "L 248.026597 -54.389796 \n",
       "L 251.305939 -57.414195 \n",
       "L 254.585262 -61.372531 \n",
       "L 257.864623 -65.65515 \n",
       "L 261.143946 -60.987818 \n",
       "L 264.423288 -56.609175 \n",
       "L 267.70263 -53.129055 \n",
       "L 270.981953 -50.590905 \n",
       "L 274.261315 -49.018661 \n",
       "L 277.540637 -48.423375 \n",
       "L 280.81998 -48.804073 \n",
       "L 284.099322 -50.148706 \n",
       "L 287.378664 -52.43482 \n",
       "L 290.658006 -55.630659 \n",
       "L 293.937329 -59.695849 \n",
       "L 297.21669 -64.582961 \n",
       "L 300.496013 -70.237869 \n",
       "L 303.775355 -76.60172 \n",
       "L 307.054697 -83.611232 \n",
       "L 310.33402 -91.200305 \n",
       "L 313.613382 -99.300708 \n",
       "L 316.892705 -107.84295 \n",
       "L 320.172047 -116.757307 \n",
       "L 323.451389 -125.974371 \n",
       "L 326.730731 -135.425522 \n",
       "L 330.010073 -145.043788 \n",
       "L 333.289396 -154.763992 \n",
       "L 336.568738 -164.523334 \n",
       "L 339.84808 -174.26178 \n",
       "L 343.127423 -183.921491 \n",
       "L 346.406765 -193.448048 \n",
       "L 349.686088 -202.789865 \n",
       "L 352.96543 -211.892093 \n",
       "L 356.244772 -220.298219 \n",
       "L 359.524114 -218.059783 \n",
       "L 362.803456 -214.66337 \n",
       "L 366.082798 -210.953522 \n",
       "L 369.362141 -207.00465 \n",
       "L 372.641463 -202.883164 \n",
       "L 375.920806 -198.652116 \n",
       "L 379.200148 -194.369802 \n",
       "L 379.200148 -194.372337 \n",
       "L 379.200148 -194.372337 \n",
       "L 375.920806 -198.655038 \n",
       "L 372.641463 -202.886639 \n",
       "L 369.362141 -207.008968 \n",
       "L 366.082798 -210.95927 \n",
       "L 362.803456 -214.67202 \n",
       "L 359.524114 -218.077322 \n",
       "L 356.244772 -220.471597 \n",
       "L 352.96543 -211.908732 \n",
       "L 349.686088 -202.798427 \n",
       "L 346.406765 -193.453861 \n",
       "L 343.127423 -183.925937 \n",
       "L 339.84808 -174.265414 \n",
       "L 336.568738 -164.526439 \n",
       "L 333.289396 -154.766726 \n",
       "L 330.010073 -145.046257 \n",
       "L 326.730731 -135.427789 \n",
       "L 323.451389 -125.976512 \n",
       "L 320.172047 -116.75932 \n",
       "L 316.892705 -107.8449 \n",
       "L 313.613382 -99.302605 \n",
       "L 310.33402 -91.20217 \n",
       "L 307.054697 -83.613097 \n",
       "L 303.775355 -76.603595 \n",
       "L 300.496013 -70.239766 \n",
       "L 297.21669 -64.584922 \n",
       "L 293.937329 -59.697894 \n",
       "L 290.658006 -55.632799 \n",
       "L 287.378664 -52.43712 \n",
       "L 284.099322 -50.151217 \n",
       "L 280.81998 -48.80687 \n",
       "L 277.540637 -48.426554 \n",
       "L 274.261315 -49.022401 \n",
       "L 270.981953 -50.595514 \n",
       "L 267.70263 -53.135127 \n",
       "L 264.423288 -56.618203 \n",
       "L 261.143946 -61.005726 \n",
       "L 257.864623 -65.838849 \n",
       "L 254.585262 -61.390492 \n",
       "L 251.305939 -57.423277 \n",
       "L 248.026597 -54.395921 \n",
       "L 244.747254 -52.346891 \n",
       "L 241.467912 -51.298693 \n",
       "L 238.18857 -51.260821 \n",
       "L 234.909247 -52.230214 \n",
       "L 231.629886 -54.191887 \n",
       "L 228.350563 -57.11917 \n",
       "L 225.071221 -60.974551 \n",
       "L 221.791879 -65.710378 \n",
       "L 218.512556 -71.2696 \n",
       "L 215.233204 -77.58688 \n",
       "L 211.953871 -84.589197 \n",
       "L 208.674529 -92.197258 \n",
       "L 205.395187 -100.326092 \n",
       "L 202.115855 -108.886263 \n",
       "L 198.836512 -117.784874 \n",
       "L 195.55717 -126.926365 \n",
       "L 192.277838 -136.213673 \n",
       "L 188.998496 -145.549211 \n",
       "L 185.719153 -154.835719 \n",
       "L 182.439821 -163.977327 \n",
       "L 179.160479 -172.880631 \n",
       "L 175.881137 -181.455436 \n",
       "L 172.601804 -189.616064 \n",
       "L 169.322462 -197.282205 \n",
       "L 166.04312 -204.37925 \n",
       "L 162.763787 -210.838797 \n",
       "L 159.484445 -216.586852 \n",
       "L 156.205103 -219.47432 \n",
       "L 152.92577 -217.75451 \n",
       "L 149.646428 -216.02533 \n",
       "L 146.367086 -214.422377 \n",
       "L 143.087754 -213.028692 \n",
       "L 139.808412 -211.915794 \n",
       "L 136.529069 -211.145487 \n",
       "L 133.249737 -210.769038 \n",
       "L 129.970395 -210.826558 \n",
       "L 126.691057 -211.345956 \n",
       "L 123.41172 -212.34358 \n",
       "L 120.132378 -213.822 \n",
       "L 116.853041 -215.763576 \n",
       "L 113.573703 -216.637607 \n",
       "L 110.294361 -212.150355 \n",
       "L 107.015024 -207.290012 \n",
       "L 103.735686 -202.224265 \n",
       "L 100.456344 -197.034784 \n",
       "L 97.177007 -191.797476 \n",
       "L 93.89767 -186.583236 \n",
       "L 90.61833 -181.457026 \n",
       "L 87.33899 -176.477868 \n",
       "L 84.059653 -171.697456 \n",
       "L 80.780313 -167.159729 \n",
       "L 77.500973 -162.900699 \n",
       "L 74.221636 -158.948042 \n",
       "L 70.942296 -155.321512 \n",
       "L 67.662958 -152.033019 \n",
       "L 64.383619 -149.087118 \n",
       "L 61.10428 -146.481648 \n",
       "L 57.824941 -144.208345 \n",
       "L 54.545602 -142.253787 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p7b3201c021)\">\n",
       "     <use xlink:href=\"#m68ab6d5965\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"m9c9cca7eec\" d=\"M 54.545602 -290.343375 \n",
       "L 54.545602 -290.34204 \n",
       "L 57.824941 -287.166319 \n",
       "L 61.10428 -283.738567 \n",
       "L 64.383619 -280.067691 \n",
       "L 67.662958 -276.168154 \n",
       "L 70.942296 -272.060441 \n",
       "L 74.221636 -267.771083 \n",
       "L 77.500973 -263.332539 \n",
       "L 80.780313 -258.783126 \n",
       "L 84.059653 -254.166199 \n",
       "L 87.33899 -249.530021 \n",
       "L 90.61833 -244.926507 \n",
       "L 93.89767 -240.410413 \n",
       "L 97.177007 -236.038304 \n",
       "L 100.456344 -231.866454 \n",
       "L 103.735686 -227.950596 \n",
       "L 107.015024 -224.344495 \n",
       "L 110.294361 -221.100533 \n",
       "L 113.573703 -218.349909 \n",
       "L 116.853041 -221.037091 \n",
       "L 120.132378 -224.81778 \n",
       "L 123.41172 -228.10424 \n",
       "L 126.691057 -230.815812 \n",
       "L 129.970395 -232.886908 \n",
       "L 133.249737 -234.261462 \n",
       "L 136.529069 -234.891653 \n",
       "L 139.808412 -234.739854 \n",
       "L 143.087754 -233.778784 \n",
       "L 146.367086 -231.992252 \n",
       "L 149.646428 -229.375841 \n",
       "L 152.92577 -225.940148 \n",
       "L 156.205103 -221.753369 \n",
       "L 159.484445 -221.352507 \n",
       "L 162.763787 -222.93802 \n",
       "L 166.04312 -224.317367 \n",
       "L 169.322462 -225.383894 \n",
       "L 172.601804 -226.048505 \n",
       "L 175.881137 -226.229095 \n",
       "L 179.160479 -225.851677 \n",
       "L 182.439821 -224.851873 \n",
       "L 185.719153 -223.175887 \n",
       "L 188.998496 -220.782319 \n",
       "L 192.277838 -217.64292 \n",
       "L 195.55717 -213.743447 \n",
       "L 198.836512 -209.083954 \n",
       "L 202.115855 -203.679164 \n",
       "L 205.395187 -197.558173 \n",
       "L 208.674529 -190.764028 \n",
       "L 211.953871 -183.353128 \n",
       "L 215.233204 -175.394124 \n",
       "L 218.512556 -166.966652 \n",
       "L 221.791879 -158.160262 \n",
       "L 225.071221 -149.072272 \n",
       "L 228.350563 -139.80657 \n",
       "L 231.629886 -130.471482 \n",
       "L 234.909247 -121.177933 \n",
       "L 238.18857 -112.03766 \n",
       "L 241.467912 -103.161143 \n",
       "L 244.747254 -94.655925 \n",
       "L 248.026597 -86.62496 \n",
       "L 251.305939 -79.165333 \n",
       "L 254.585262 -72.36989 \n",
       "L 257.864623 -66.730453 \n",
       "L 261.143946 -72.021088 \n",
       "L 264.423288 -78.504117 \n",
       "L 267.70263 -85.688777 \n",
       "L 270.981953 -93.482986 \n",
       "L 274.261315 -101.791566 \n",
       "L 277.540637 -110.513132 \n",
       "L 280.81998 -119.542311 \n",
       "L 284.099322 -128.770968 \n",
       "L 287.378664 -138.08942 \n",
       "L 290.658006 -147.388888 \n",
       "L 293.937329 -156.562396 \n",
       "L 297.21669 -165.507175 \n",
       "L 300.496013 -174.125245 \n",
       "L 303.775355 -182.325901 \n",
       "L 307.054697 -190.025997 \n",
       "L 310.33402 -197.151805 \n",
       "L 313.613382 -203.639597 \n",
       "L 316.892705 -209.436222 \n",
       "L 320.172047 -214.500119 \n",
       "L 323.451389 -218.801218 \n",
       "L 326.730731 -222.321087 \n",
       "L 330.010073 -225.053104 \n",
       "L 333.289396 -227.001749 \n",
       "L 336.568738 -228.182368 \n",
       "L 339.84808 -228.620337 \n",
       "L 343.127423 -228.350644 \n",
       "L 346.406765 -227.416383 \n",
       "L 349.686088 -225.867658 \n",
       "L 352.96543 -223.764532 \n",
       "L 356.244772 -221.437534 \n",
       "L 359.524114 -229.321463 \n",
       "L 362.803456 -237.501367 \n",
       "L 366.082798 -245.310272 \n",
       "L 369.362141 -252.718887 \n",
       "L 372.641463 -259.705471 \n",
       "L 375.920806 -266.253281 \n",
       "L 379.200148 -272.351328 \n",
       "L 379.200148 -272.353861 \n",
       "L 379.200148 -272.353861 \n",
       "L 375.920806 -266.256203 \n",
       "L 372.641463 -259.708946 \n",
       "L 369.362141 -252.723205 \n",
       "L 366.082798 -245.316021 \n",
       "L 362.803456 -237.510017 \n",
       "L 359.524114 -229.339002 \n",
       "L 356.244772 -221.610912 \n",
       "L 352.96543 -223.78117 \n",
       "L 349.686088 -225.876218 \n",
       "L 346.406765 -227.422198 \n",
       "L 343.127423 -228.35509 \n",
       "L 339.84808 -228.623971 \n",
       "L 336.568738 -228.185473 \n",
       "L 333.289396 -227.004483 \n",
       "L 330.010073 -225.055573 \n",
       "L 326.730731 -222.32336 \n",
       "L 323.451389 -218.803347 \n",
       "L 320.172047 -214.502138 \n",
       "L 316.892705 -209.438171 \n",
       "L 313.613382 -203.641494 \n",
       "L 310.33402 -197.15367 \n",
       "L 307.054697 -190.027852 \n",
       "L 303.775355 -182.327771 \n",
       "L 300.496013 -174.127147 \n",
       "L 297.21669 -165.50913 \n",
       "L 293.937329 -156.564435 \n",
       "L 290.658006 -147.391039 \n",
       "L 287.378664 -138.091724 \n",
       "L 284.099322 -128.77348 \n",
       "L 280.81998 -119.545109 \n",
       "L 277.540637 -110.516321 \n",
       "L 274.261315 -101.795307 \n",
       "L 270.981953 -93.487595 \n",
       "L 267.70263 -85.694849 \n",
       "L 264.423288 -78.513145 \n",
       "L 261.143946 -72.038996 \n",
       "L 257.864623 -66.914153 \n",
       "L 254.585262 -72.387851 \n",
       "L 251.305939 -79.174415 \n",
       "L 248.026597 -86.631085 \n",
       "L 244.747254 -94.660588 \n",
       "L 241.467912 -103.164947 \n",
       "L 238.18857 -112.040903 \n",
       "L 234.909247 -121.180794 \n",
       "L 231.629886 -130.474078 \n",
       "L 228.350563 -139.808959 \n",
       "L 225.071221 -149.074519 \n",
       "L 221.791879 -158.162397 \n",
       "L 218.512556 -166.968718 \n",
       "L 215.233204 -175.396148 \n",
       "L 211.953871 -183.355126 \n",
       "L 208.674529 -190.766036 \n",
       "L 205.395187 -197.560207 \n",
       "L 202.115855 -203.681246 \n",
       "L 198.836512 -209.086121 \n",
       "L 195.55717 -213.745723 \n",
       "L 192.277838 -217.645347 \n",
       "L 188.998496 -220.784945 \n",
       "L 185.719153 -223.178777 \n",
       "L 182.439821 -224.855115 \n",
       "L 179.160479 -225.855404 \n",
       "L 175.881137 -226.233506 \n",
       "L 172.601804 -226.053927 \n",
       "L 169.322462 -225.390921 \n",
       "L 166.04312 -224.327269 \n",
       "L 162.763787 -222.954324 \n",
       "L 159.484445 -221.393602 \n",
       "L 156.205103 -221.836975 \n",
       "L 152.92577 -225.964209 \n",
       "L 149.646428 -229.390621 \n",
       "L 146.367086 -232.003487 \n",
       "L 143.087754 -233.7883 \n",
       "L 139.808412 -234.748504 \n",
       "L 136.529069 -234.899968 \n",
       "L 133.249737 -234.269867 \n",
       "L 129.970395 -232.895858 \n",
       "L 126.691057 -230.825952 \n",
       "L 123.41172 -228.116763 \n",
       "L 120.132378 -224.835715 \n",
       "L 116.853041 -221.074287 \n",
       "L 113.573703 -218.458397 \n",
       "L 110.294361 -221.122549 \n",
       "L 107.015024 -224.356071 \n",
       "L 103.735686 -227.958272 \n",
       "L 100.456344 -231.872124 \n",
       "L 97.177007 -236.042767 \n",
       "L 93.89767 -240.414082 \n",
       "L 90.61833 -244.92962 \n",
       "L 87.33899 -249.532728 \n",
       "L 84.059653 -254.168594 \n",
       "L 80.780313 -258.785283 \n",
       "L 77.500973 -263.334504 \n",
       "L 74.221636 -267.7729 \n",
       "L 70.942296 -272.062136 \n",
       "L 67.662958 -276.169749 \n",
       "L 64.383619 -280.069201 \n",
       "L 61.10428 -283.740003 \n",
       "L 57.824941 -287.167696 \n",
       "L 54.545602 -290.343375 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p7b3201c021)\">\n",
       "     <use xlink:href=\"#m9c9cca7eec\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_13\">\n",
       "    <defs>\n",
       "     <path id=\"m1ad7c1bca5\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p7b3201c021)\">\n",
       "     <use xlink:href=\"#m1ad7c1bca5\" x=\"356.349693\" y=\"101.490889\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m1ad7c1bca5\" x=\"157.258364\" y=\"102.40666\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m1ad7c1bca5\" x=\"114.255683\" y=\"104.860168\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m1ad7c1bca5\" x=\"257.864623\" y=\"256.258899\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <path d=\"M 54.545602 106.24146 \n",
       "L 57.824941 106.852046 \n",
       "L 61.10428 107.429267 \n",
       "L 64.383619 107.961971 \n",
       "L 67.662958 108.43879 \n",
       "L 70.942296 108.848396 \n",
       "L 74.221636 109.179812 \n",
       "L 77.500973 109.422755 \n",
       "L 80.780313 109.567946 \n",
       "L 84.059653 109.607547 \n",
       "L 87.33899 109.53543 \n",
       "L 90.61833 109.347608 \n",
       "L 93.89767 109.04255 \n",
       "L 97.177007 108.621485 \n",
       "L 100.456344 108.088756 \n",
       "L 103.735686 107.451945 \n",
       "L 107.015024 106.722122 \n",
       "L 110.294361 105.913931 \n",
       "L 113.573703 105.045617 \n",
       "L 116.853041 104.139041 \n",
       "L 120.132378 103.219485 \n",
       "L 123.41172 102.315465 \n",
       "L 126.691057 101.458491 \n",
       "L 129.970395 100.682642 \n",
       "L 133.249737 100.024125 \n",
       "L 136.529069 99.520805 \n",
       "L 139.808412 99.211551 \n",
       "L 143.087754 99.135637 \n",
       "L 146.367086 99.33206 \n",
       "L 149.646428 99.838789 \n",
       "L 152.92577 100.692046 \n",
       "L 156.205103 101.925531 \n",
       "L 159.484445 103.569696 \n",
       "L 162.763787 105.650967 \n",
       "L 166.04312 108.191067 \n",
       "L 169.322462 111.206326 \n",
       "L 172.601804 114.70709 \n",
       "L 175.881137 118.697111 \n",
       "L 179.160479 123.17322 \n",
       "L 182.439821 128.124777 \n",
       "L 185.719153 133.533572 \n",
       "L 188.998496 139.37361 \n",
       "L 192.277838 145.61108 \n",
       "L 195.55717 152.20447 \n",
       "L 198.836512 159.104961 \n",
       "L 202.115855 166.256661 \n",
       "L 205.395187 173.597243 \n",
       "L 208.674529 181.058735 \n",
       "L 211.953871 188.568212 \n",
       "L 215.233204 196.048873 \n",
       "L 218.512556 203.421249 \n",
       "L 221.791879 210.604055 \n",
       "L 225.071221 217.515963 \n",
       "L 228.350563 224.076505 \n",
       "L 231.629886 230.20769 \n",
       "L 234.909247 235.835302 \n",
       "L 238.18857 240.890134 \n",
       "L 241.467912 245.309457 \n",
       "L 244.747254 249.037967 \n",
       "L 248.026597 252.028934 \n",
       "L 251.305939 254.24507 \n",
       "L 254.585262 255.659184 \n",
       "L 257.864623 256.254724 \n",
       "L 261.143946 256.025968 \n",
       "L 264.423288 254.978215 \n",
       "L 267.70263 253.127423 \n",
       "L 270.981953 250.500125 \n",
       "L 274.261315 247.132391 \n",
       "L 277.540637 243.069532 \n",
       "L 280.81998 238.364784 \n",
       "L 284.099322 233.078282 \n",
       "L 287.378664 227.276105 \n",
       "L 290.658006 221.028529 \n",
       "L 293.937329 214.40923 \n",
       "L 297.21669 207.493327 \n",
       "L 300.496013 200.35687 \n",
       "L 303.775355 193.074627 \n",
       "L 307.054697 185.71983 \n",
       "L 310.33402 178.36239 \n",
       "L 313.613382 171.068274 \n",
       "L 316.892705 163.898814 \n",
       "L 320.172047 156.909653 \n",
       "L 323.451389 150.150513 \n",
       "L 326.730731 143.664936 \n",
       "L 330.010073 137.489696 \n",
       "L 333.289396 131.655139 \n",
       "L 336.568738 126.184972 \n",
       "L 339.84808 121.096498 \n",
       "L 343.127423 116.401085 \n",
       "L 346.406765 112.104253 \n",
       "L 349.686088 108.206334 \n",
       "L 352.96543 104.702743 \n",
       "L 356.244772 101.584809 \n",
       "L 359.524114 98.839982 \n",
       "L 362.803456 96.452681 \n",
       "L 366.082798 94.404604 \n",
       "L 369.362141 92.675448 \n",
       "L 372.641463 91.243321 \n",
       "L 375.920806 90.085215 \n",
       "L 379.200148 89.177543 \n",
       "\" clip-path=\"url(#p7b3201c021)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 54.545602 184.432959 \n",
       "L 57.824941 179.009943 \n",
       "L 61.10428 173.60705 \n",
       "L 64.383619 168.244317 \n",
       "L 67.662958 162.941708 \n",
       "L 70.942296 157.718965 \n",
       "L 74.221636 152.595637 \n",
       "L 77.500973 147.590931 \n",
       "L 80.780313 142.723671 \n",
       "L 84.059653 138.012269 \n",
       "L 87.33899 133.4746 \n",
       "L 90.61833 129.127985 \n",
       "L 93.89767 124.989113 \n",
       "L 97.177007 121.073989 \n",
       "L 100.456344 117.397862 \n",
       "L 103.735686 113.975218 \n",
       "L 107.015024 110.819677 \n",
       "L 110.294361 107.943978 \n",
       "L 113.573703 105.359908 \n",
       "L 116.853041 103.078297 \n",
       "L 120.132378 101.108963 \n",
       "L 123.41172 99.460657 \n",
       "L 126.691057 98.141064 \n",
       "L 129.970395 97.156757 \n",
       "L 133.249737 96.513167 \n",
       "L 136.529069 96.214576 \n",
       "L 139.808412 96.264093 \n",
       "L 143.087754 96.66362 \n",
       "L 146.367086 97.413863 \n",
       "L 149.646428 98.514317 \n",
       "L 152.92577 99.963246 \n",
       "L 156.205103 101.75767 \n",
       "L 159.484445 103.893416 \n",
       "L 162.763787 106.365032 \n",
       "L 166.04312 109.165867 \n",
       "L 169.322462 112.288029 \n",
       "L 172.601804 115.722398 \n",
       "L 175.881137 119.458638 \n",
       "L 179.160479 123.485184 \n",
       "L 182.439821 127.789307 \n",
       "L 185.719153 132.357011 \n",
       "L 188.998496 137.17317 \n",
       "L 192.277838 142.221412 \n",
       "L 195.55717 147.484252 \n",
       "L 198.836512 152.942977 \n",
       "L 202.115855 158.577694 \n",
       "L 205.395187 164.367351 \n",
       "L 208.674529 170.289744 \n",
       "L 211.953871 176.32144 \n",
       "L 215.233204 182.43787 \n",
       "L 218.512556 188.613268 \n",
       "L 221.791879 194.820621 \n",
       "L 225.071221 201.031788 \n",
       "L 228.350563 207.217385 \n",
       "L 231.629886 213.346653 \n",
       "L 234.909247 219.387853 \n",
       "L 238.18857 225.30765 \n",
       "L 241.467912 231.071701 \n",
       "L 244.747254 236.644211 \n",
       "L 248.026597 241.988135 \n",
       "L 251.305939 247.065189 \n",
       "L 254.585262 251.835708 \n",
       "L 257.864623 256.258899 \n",
       "L 261.143946 260.292702 \n",
       "L 264.423288 263.894013 \n",
       "L 267.70263 267.018707 \n",
       "L 270.981953 269.62192 \n",
       "L 274.261315 271.658128 \n",
       "L 277.540637 273.081556 \n",
       "L 280.81998 273.846501 \n",
       "L 284.099322 273.907823 \n",
       "L 287.378664 273.221535 \n",
       "L 290.658006 271.745602 \n",
       "L 293.937329 269.440806 \n",
       "L 297.21669 266.271765 \n",
       "L 300.496013 262.208673 \n",
       "L 303.775355 257.228249 \n",
       "L 307.054697 251.316187 \n",
       "L 310.33402 244.469224 \n",
       "L 313.613382 236.697384 \n",
       "L 316.892705 228.027381 \n",
       "L 320.172047 218.505468 \n",
       "L 323.451389 208.20121 \n",
       "L 326.730731 197.211428 \n",
       "L 330.010073 185.664146 \n",
       "L 333.289396 173.722779 \n",
       "L 336.568738 161.590135 \n",
       "L 339.84808 149.511612 \n",
       "L 343.127423 137.77786 \n",
       "L 346.406765 126.725781 \n",
       "L 349.686088 116.736762 \n",
       "L 352.96543 108.231978 \n",
       "L 356.244772 101.663839 \n",
       "L 359.524114 97.500515 \n",
       "L 362.803456 96.204493 \n",
       "L 366.082798 98.202168 \n",
       "L 369.362141 103.844053 \n",
       "L 372.641463 113.3552 \n",
       "L 375.920806 126.776098 \n",
       "L 379.200148 143.89686 \n",
       "\" clip-path=\"url(#p7b3201c021)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 38.312875 273.970638 \n",
       "L 38.312875 51.747559 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 54.545602 286.212 \n",
       "L 379.200148 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_15\">\n",
       "    <!-- N=0, psi=1.96 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(186.986125 14.1) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2c\" d=\"M 569 0 \n",
       "L 569 641 \n",
       "L 1209 641 \n",
       "L 1209 0 \n",
       "Q 1209 -353 1084 -570 \n",
       "Q 959 -788 688 -906 \n",
       "L 531 -666 \n",
       "Q 709 -588 793 -436 \n",
       "Q 878 -284 888 0 \n",
       "L 569 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-2c\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"214.013672\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"241.796875\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"297.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"347.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"369.628906\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"428.027344\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"483.642578\"/>\n",
       "     <use xlink:href=\"#ArialMT-39\" x=\"511.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-36\" x=\"567.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_16\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#m1ad7c1bca5\" x=\"55.032875\" y=\"31.238875\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_16\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 34.318875) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_17\">\n",
       "     <path d=\"M 46.232875 43.822875 \n",
       "L 55.032875 43.822875 \n",
       "L 63.832875 43.822875 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 46.902875) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 46.232875 61.059875 \n",
       "L 63.832875 61.059875 \n",
       "L 63.832875 54.899875 \n",
       "L 46.232875 54.899875 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 61.059875) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 46.232875 75.227875 \n",
       "L 63.832875 75.227875 \n",
       "L 63.832875 69.067875 \n",
       "L 46.232875 69.067875 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 75.227875) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_18\">\n",
       "     <path d=\"M 46.232875 84.69475 \n",
       "L 55.032875 84.69475 \n",
       "L 63.832875 84.69475 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 87.77475) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <defs>\n",
       "       <path id=\"mbdf46fa10c\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbdf46fa10c\" x=\"395.432875\" y=\"245.483039\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_21\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 248.632477) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbdf46fa10c\" x=\"395.432875\" y=\"197.08086\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 200.230298) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbdf46fa10c\" x=\"395.432875\" y=\"148.678682\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 151.828119) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbdf46fa10c\" x=\"395.432875\" y=\"100.276503\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 103.42594) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbdf46fa10c\" x=\"395.432875\" y=\"51.874324\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 55.023761) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_26\">\n",
       "     <!-- Maximum Upper Interval -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(424.63775 205.43475) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4d\" d=\"M 475 0 \n",
       "L 475 4581 \n",
       "L 1388 4581 \n",
       "L 2472 1338 \n",
       "Q 2622 884 2691 659 \n",
       "Q 2769 909 2934 1394 \n",
       "L 4031 4581 \n",
       "L 4847 4581 \n",
       "L 4847 0 \n",
       "L 4263 0 \n",
       "L 4263 3834 \n",
       "L 2931 0 \n",
       "L 2384 0 \n",
       "L 1059 3900 \n",
       "L 1059 0 \n",
       "L 475 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-78\" d=\"M 47 0 \n",
       "L 1259 1725 \n",
       "L 138 3319 \n",
       "L 841 3319 \n",
       "L 1350 2541 \n",
       "Q 1494 2319 1581 2169 \n",
       "Q 1719 2375 1834 2534 \n",
       "L 2394 3319 \n",
       "L 3066 3319 \n",
       "L 1919 1756 \n",
       "L 3153 0 \n",
       "L 2463 0 \n",
       "L 1781 1031 \n",
       "L 1600 1309 \n",
       "L 728 0 \n",
       "L 47 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-55\" d=\"M 3500 4581 \n",
       "L 4106 4581 \n",
       "L 4106 1934 \n",
       "Q 4106 1244 3950 837 \n",
       "Q 3794 431 3386 176 \n",
       "Q 2978 -78 2316 -78 \n",
       "Q 1672 -78 1262 144 \n",
       "Q 853 366 678 786 \n",
       "Q 503 1206 503 1934 \n",
       "L 503 4581 \n",
       "L 1109 4581 \n",
       "L 1109 1938 \n",
       "Q 1109 1341 1220 1058 \n",
       "Q 1331 775 1601 622 \n",
       "Q 1872 469 2263 469 \n",
       "Q 2931 469 3215 772 \n",
       "Q 3500 1075 3500 1938 \n",
       "L 3500 4581 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4d\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "      <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"188.916016\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"211.132812\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"294.433594\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"350.048828\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"433.349609\"/>\n",
       "      <use xlink:href=\"#ArialMT-55\" x=\"461.132812\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" x=\"533.349609\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" x=\"588.964844\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"644.580078\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"700.195312\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"733.496094\"/>\n",
       "      <use xlink:href=\"#ArialMT-49\" x=\"761.279297\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"789.0625\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.677734\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"872.460938\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"928.076172\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"961.376953\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"1011.376953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6c\" x=\"1066.992188\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_24\">\n",
       "    <path d=\"M 54.545602 32.196 \n",
       "L 57.824941 35.598638 \n",
       "L 61.10428 39.269522 \n",
       "L 64.383619 43.198914 \n",
       "L 67.662958 47.371135 \n",
       "L 70.942296 51.764071 \n",
       "L 74.221636 56.34917 \n",
       "L 77.500973 61.091559 \n",
       "L 80.780313 65.950146 \n",
       "L 84.059653 70.878488 \n",
       "L 87.33899 75.824938 \n",
       "L 90.61833 80.734015 \n",
       "L 93.89767 85.547236 \n",
       "L 97.177007 90.204258 \n",
       "L 100.456344 94.64512 \n",
       "L 103.735686 98.810503 \n",
       "L 107.015024 102.643269 \n",
       "L 110.294361 106.087829 \n",
       "L 113.573703 109.004559 \n",
       "L 116.853041 106.11688 \n",
       "L 120.132378 102.061858 \n",
       "L 123.41172 98.534648 \n",
       "L 126.691057 95.62202 \n",
       "L 129.970395 93.394715 \n",
       "L 133.249737 91.913359 \n",
       "L 136.529069 91.229817 \n",
       "L 139.808412 91.38509 \n",
       "L 143.087754 92.409152 \n",
       "L 146.367086 94.320132 \n",
       "L 149.646428 97.12357 \n",
       "L 152.92577 100.808946 \n",
       "L 156.205103 105.304211 \n",
       "L 159.484445 105.767848 \n",
       "L 162.763787 104.121018 \n",
       "L 166.04312 102.704217 \n",
       "L 169.322462 101.631626 \n",
       "L 172.601804 100.998559 \n",
       "L 175.881137 100.892729 \n",
       "L 179.160479 101.393027 \n",
       "L 182.439821 102.567933 \n",
       "L 185.719153 104.474458 \n",
       "L 188.998496 107.156228 \n",
       "L 192.277838 110.642655 \n",
       "L 195.55717 114.948031 \n",
       "L 198.836512 120.071236 \n",
       "L 202.115855 125.995347 \n",
       "L 205.395187 132.687947 \n",
       "L 208.674529 140.10161 \n",
       "L 211.953871 148.174558 \n",
       "L 215.233204 156.83185 \n",
       "L 218.512556 165.986763 \n",
       "L 221.791879 175.541952 \n",
       "L 225.071221 185.391785 \n",
       "L 228.350563 195.423627 \n",
       "L 231.629886 205.520174 \n",
       "L 234.909247 215.561421 \n",
       "L 238.18857 225.426603 \n",
       "L 241.467912 234.996453 \n",
       "L 244.747254 244.154972 \n",
       "L 248.026597 252.791285 \n",
       "L 251.305939 260.80093 \n",
       "L 254.585262 268.084272 \n",
       "L 257.864623 274.116 \n",
       "L 261.143946 268.464515 \n",
       "L 264.423288 261.522594 \n",
       "L 267.70263 253.81435 \n",
       "L 270.981953 245.438645 \n",
       "L 274.261315 236.49785 \n",
       "L 277.540637 227.101146 \n",
       "L 280.81998 217.362154 \n",
       "L 284.099322 207.397601 \n",
       "L 287.378664 197.32597 \n",
       "L 290.658006 187.264908 \n",
       "L 293.937329 177.330181 \n",
       "L 297.21669 167.633102 \n",
       "L 300.496013 158.279909 \n",
       "L 303.775355 149.369032 \n",
       "L 307.054697 140.990805 \n",
       "L 310.33402 133.225433 \n",
       "L 313.613382 126.142378 \n",
       "L 316.892705 119.799689 \n",
       "L 320.172047 114.242947 \n",
       "L 323.451389 109.505318 \n",
       "L 326.730731 105.607428 \n",
       "L 330.010073 102.55714 \n",
       "L 333.289396 100.350341 \n",
       "L 336.568738 98.971164 \n",
       "L 339.84808 98.392904 \n",
       "L 343.127423 98.578467 \n",
       "L 346.406765 99.481981 \n",
       "L 349.686088 101.04998 \n",
       "L 352.96543 103.218259 \n",
       "L 356.244772 105.633869 \n",
       "L 359.524114 97.159851 \n",
       "L 362.803456 88.377736 \n",
       "L 366.082798 79.998964 \n",
       "L 369.362141 72.054354 \n",
       "L 372.641463 64.566633 \n",
       "L 375.920806 57.553167 \n",
       "L 379.200148 51.025172 \n",
       "\" clip-path=\"url(#p7b3201c021)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_25\">\n",
       "    <path d=\"M 54.545602 100.276503 \n",
       "L 54.545602 99.588821 \n",
       "L 54.545602 98.901139 \n",
       "L 54.545602 98.213457 \n",
       "L 54.545602 97.525775 \n",
       "L 54.545602 96.838093 \n",
       "L 54.545602 96.150411 \n",
       "L 54.545602 95.46273 \n",
       "L 54.545602 94.775048 \n",
       "L 54.545602 94.087366 \n",
       "L 54.545602 93.399684 \n",
       "L 54.545602 92.712003 \n",
       "L 54.545602 92.02432 \n",
       "L 54.545602 91.336638 \n",
       "L 54.545602 90.648957 \n",
       "L 54.545602 89.961275 \n",
       "L 54.545602 89.273593 \n",
       "L 54.545602 88.585911 \n",
       "L 54.545602 87.89823 \n",
       "L 54.545602 87.210548 \n",
       "L 54.545602 86.522866 \n",
       "L 54.545602 85.835184 \n",
       "L 54.545602 85.147503 \n",
       "L 54.545602 84.459821 \n",
       "L 54.545602 83.772138 \n",
       "L 54.545602 83.084456 \n",
       "L 54.545602 82.396774 \n",
       "L 54.545602 81.709092 \n",
       "L 54.545602 81.021411 \n",
       "L 54.545602 80.333729 \n",
       "L 54.545602 79.646047 \n",
       "L 54.545602 78.958365 \n",
       "L 54.545602 78.270684 \n",
       "L 54.545602 77.583002 \n",
       "L 54.545602 76.89532 \n",
       "L 54.545602 76.207638 \n",
       "L 54.545602 75.519956 \n",
       "L 54.545602 74.832275 \n",
       "L 54.545602 74.144593 \n",
       "L 54.545602 73.456911 \n",
       "L 54.545602 72.769229 \n",
       "L 54.545602 72.081548 \n",
       "L 54.545602 71.393866 \n",
       "L 54.545602 70.706184 \n",
       "L 54.545602 70.018502 \n",
       "L 54.545602 69.330821 \n",
       "L 54.545602 68.643139 \n",
       "L 54.545602 67.955457 \n",
       "L 54.545602 67.267773 \n",
       "L 54.545602 66.580091 \n",
       "L 54.545602 65.892412 \n",
       "L 54.545602 65.20473 \n",
       "L 54.545602 64.517045 \n",
       "L 54.545602 63.829364 \n",
       "L 54.545602 63.141682 \n",
       "L 54.545602 62.454 \n",
       "L 54.545602 61.766318 \n",
       "L 54.545602 61.078637 \n",
       "L 54.545602 60.390955 \n",
       "L 54.545602 59.703273 \n",
       "L 54.545602 59.015591 \n",
       "L 54.545602 58.32791 \n",
       "L 54.545602 57.640228 \n",
       "L 54.545602 56.952546 \n",
       "L 54.545602 56.264864 \n",
       "L 54.545602 55.577183 \n",
       "L 54.545602 54.889501 \n",
       "L 54.545602 54.201819 \n",
       "L 54.545602 53.514137 \n",
       "L 54.545602 52.826456 \n",
       "L 54.545602 52.138774 \n",
       "L 54.545602 51.451095 \n",
       "L 54.545602 50.76341 \n",
       "L 54.545602 50.075726 \n",
       "L 54.545602 49.388047 \n",
       "L 54.545602 48.700368 \n",
       "L 54.545602 48.012683 \n",
       "L 54.545602 47.324999 \n",
       "L 54.545602 46.63732 \n",
       "L 54.545602 45.949635 \n",
       "L 54.545602 45.261956 \n",
       "L 54.545602 44.574272 \n",
       "L 54.545602 43.886593 \n",
       "L 54.545602 43.198908 \n",
       "L 54.545602 42.511229 \n",
       "L 54.545602 41.823545 \n",
       "L 54.545602 41.135866 \n",
       "L 54.545602 40.448181 \n",
       "L 54.545602 39.760502 \n",
       "L 54.545602 39.072818 \n",
       "L 54.545602 38.385139 \n",
       "L 54.545602 37.697454 \n",
       "L 54.545602 37.009775 \n",
       "L 54.545602 36.322091 \n",
       "L 54.545602 35.634412 \n",
       "L 54.545602 34.946727 \n",
       "L 54.545602 34.259048 \n",
       "L 54.545602 33.571364 \n",
       "L 54.545602 32.883685 \n",
       "L 54.545602 32.196 \n",
       "\" clip-path=\"url(#p7b3201c021)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 38.312875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 395.432875 286.212 \n",
       "L 395.432875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 395.432875 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 38.312875 20.1 \n",
       "L 395.432875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p7b3201c021\">\n",
       "   <rect x=\"38.312875\" y=\"20.1\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"433.74575pt\" height=\"322.539375pt\" viewBox=\"0 0 433.74575 322.539375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:10.786778</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.539375 \n",
       "L 433.74575 322.539375 \n",
       "L 433.74575 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 395.432875 286.212 \n",
       "L 395.432875 20.1 \n",
       "L 38.312875 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"mc064353a3b\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc064353a3b\" x=\"54.545602\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(48.429602 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc064353a3b\" x=\"119.476511\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(113.360511 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc064353a3b\" x=\"184.40742\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(178.29142 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc064353a3b\" x=\"249.33833\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(243.22233 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc064353a3b\" x=\"314.269239\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(308.153239 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc064353a3b\" x=\"379.200148\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(373.084148 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(213.992875 313.431375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"m38039b8134\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m38039b8134\" x=\"38.312875\" y=\"272.831305\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 275.980742) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m38039b8134\" x=\"38.312875\" y=\"224.97608\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 228.125518) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m38039b8134\" x=\"38.312875\" y=\"177.120856\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 180.270293) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m38039b8134\" x=\"38.312875\" y=\"129.265632\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 132.415069) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m38039b8134\" x=\"38.312875\" y=\"81.410407\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 84.559845) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m38039b8134\" x=\"38.312875\" y=\"33.555183\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 36.70462) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_14\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.036) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"m3579289de9\" d=\"M 54.545602 -146.599199 \n",
       "L 54.545602 -145.640304 \n",
       "L 57.824941 -144.333663 \n",
       "L 61.10428 -143.579558 \n",
       "L 64.383619 -143.82807 \n",
       "L 67.662958 -145.087824 \n",
       "L 70.942296 -147.343925 \n",
       "L 74.221636 -150.562309 \n",
       "L 77.500973 -154.690213 \n",
       "L 80.780313 -159.657372 \n",
       "L 84.059653 -165.37702 \n",
       "L 87.33899 -171.746615 \n",
       "L 90.61833 -178.650212 \n",
       "L 93.89767 -185.960434 \n",
       "L 97.177007 -193.540351 \n",
       "L 100.456344 -201.247621 \n",
       "L 103.735686 -208.935165 \n",
       "L 107.015024 -216.454248 \n",
       "L 110.294361 -223.653878 \n",
       "L 113.573703 -230.272407 \n",
       "L 116.853041 -232.553121 \n",
       "L 120.132378 -233.355785 \n",
       "L 123.41172 -233.900094 \n",
       "L 126.691057 -234.252833 \n",
       "L 129.970395 -234.464213 \n",
       "L 133.249737 -234.576375 \n",
       "L 136.529069 -234.625935 \n",
       "L 139.808412 -234.640095 \n",
       "L 143.087754 -234.637143 \n",
       "L 146.367086 -234.625014 \n",
       "L 149.646428 -234.600391 \n",
       "L 152.92577 -234.545285 \n",
       "L 156.205103 -234.377073 \n",
       "L 159.484445 -229.715825 \n",
       "L 162.763787 -222.176427 \n",
       "L 166.04312 -213.868208 \n",
       "L 169.322462 -204.907776 \n",
       "L 172.601804 -195.400808 \n",
       "L 175.881137 -185.456057 \n",
       "L 179.160479 -175.183937 \n",
       "L 182.439821 -164.696068 \n",
       "L 185.719153 -154.104052 \n",
       "L 188.998496 -143.518186 \n",
       "L 192.277838 -133.046855 \n",
       "L 195.55717 -122.795375 \n",
       "L 198.836512 -112.865474 \n",
       "L 202.115855 -103.354635 \n",
       "L 205.395187 -94.355607 \n",
       "L 208.674529 -85.955673 \n",
       "L 211.953871 -78.236388 \n",
       "L 215.233204 -71.273033 \n",
       "L 218.512556 -65.133861 \n",
       "L 221.791879 -59.879934 \n",
       "L 225.071221 -55.56408 \n",
       "L 228.350563 -52.230716 \n",
       "L 231.629886 -49.914937 \n",
       "L 234.909247 -48.642028 \n",
       "L 238.18857 -48.426912 \n",
       "L 241.467912 -49.273525 \n",
       "L 244.747254 -51.174577 \n",
       "L 248.026597 -54.110808 \n",
       "L 251.305939 -58.050877 \n",
       "L 254.585262 -62.947706 \n",
       "L 257.864623 -68.303349 \n",
       "L 261.143946 -63.645288 \n",
       "L 264.423288 -59.394035 \n",
       "L 267.70263 -56.044925 \n",
       "L 270.981953 -53.642468 \n",
       "L 274.261315 -52.214788 \n",
       "L 277.540637 -51.777436 \n",
       "L 280.81998 -52.33371 \n",
       "L 284.099322 -53.875372 \n",
       "L 287.378664 -56.383333 \n",
       "L 290.658006 -59.828523 \n",
       "L 293.937329 -64.172684 \n",
       "L 297.21669 -69.369871 \n",
       "L 300.496013 -75.36672 \n",
       "L 303.775355 -82.104702 \n",
       "L 307.054697 -89.520115 \n",
       "L 310.33402 -97.545975 \n",
       "L 313.613382 -106.112717 \n",
       "L 316.892705 -115.149032 \n",
       "L 320.172047 -124.582981 \n",
       "L 323.451389 -134.342675 \n",
       "L 326.730731 -144.356653 \n",
       "L 330.010073 -154.554896 \n",
       "L 333.289396 -164.869037 \n",
       "L 336.568738 -175.232878 \n",
       "L 339.84808 -185.583046 \n",
       "L 343.127423 -195.858186 \n",
       "L 346.406765 -206.000645 \n",
       "L 349.686088 -215.95612 \n",
       "L 352.96543 -225.669964 \n",
       "L 356.244772 -234.805827 \n",
       "L 359.524114 -232.153258 \n",
       "L 362.803456 -228.422929 \n",
       "L 366.082798 -224.371127 \n",
       "L 369.362141 -220.072625 \n",
       "L 372.641463 -215.597412 \n",
       "L 375.920806 -211.012517 \n",
       "L 379.200148 -206.379871 \n",
       "L 379.200148 -290.340648 \n",
       "L 379.200148 -290.340648 \n",
       "L 375.920806 -283.795894 \n",
       "L 372.641463 -276.774267 \n",
       "L 369.362141 -269.288209 \n",
       "L 366.082798 -261.356424 \n",
       "L 362.803456 -253.002884 \n",
       "L 359.524114 -244.259612 \n",
       "L 356.244772 -235.84428 \n",
       "L 352.96543 -238.434553 \n",
       "L 349.686088 -240.793251 \n",
       "L 346.406765 -242.565338 \n",
       "L 343.127423 -243.685876 \n",
       "L 339.84808 -244.1005 \n",
       "L 336.568738 -243.762181 \n",
       "L 333.289396 -242.632265 \n",
       "L 330.010073 -240.682306 \n",
       "L 326.730731 -237.894268 \n",
       "L 323.451389 -234.261562 \n",
       "L 320.172047 -229.789208 \n",
       "L 316.892705 -224.494573 \n",
       "L 313.613382 -218.407291 \n",
       "L 310.33402 -211.568991 \n",
       "L 307.054697 -204.03344 \n",
       "L 303.775355 -195.865531 \n",
       "L 300.496013 -187.140612 \n",
       "L 297.21669 -177.943976 \n",
       "L 293.937329 -168.368753 \n",
       "L 290.658006 -158.515963 \n",
       "L 287.378664 -148.491477 \n",
       "L 284.099322 -138.405921 \n",
       "L 280.81998 -128.371884 \n",
       "L 277.540637 -118.503184 \n",
       "L 274.261315 -108.91225 \n",
       "L 270.981953 -99.709196 \n",
       "L 267.70263 -91.000279 \n",
       "L 264.423288 -82.885961 \n",
       "L 261.143946 -75.464261 \n",
       "L 257.864623 -69.263374 \n",
       "L 254.585262 -74.716044 \n",
       "L 251.305939 -81.341082 \n",
       "L 248.026597 -88.611445 \n",
       "L 244.747254 -96.431362 \n",
       "L 241.467912 -104.702539 \n",
       "L 238.18857 -113.322051 \n",
       "L 234.909247 -122.184175 \n",
       "L 231.629886 -131.18212 \n",
       "L 228.350563 -140.209786 \n",
       "L 225.071221 -149.163934 \n",
       "L 221.791879 -157.946004 \n",
       "L 218.512556 -166.463913 \n",
       "L 215.233204 -174.63399 \n",
       "L 211.953871 -182.382089 \n",
       "L 208.674529 -189.645208 \n",
       "L 205.395187 -196.372316 \n",
       "L 202.115855 -202.525072 \n",
       "L 198.836512 -208.078303 \n",
       "L 195.55717 -213.019961 \n",
       "L 192.277838 -217.35083 \n",
       "L 188.998496 -221.084062 \n",
       "L 185.719153 -224.243944 \n",
       "L 182.439821 -226.864937 \n",
       "L 179.160479 -228.989945 \n",
       "L 175.881137 -230.66878 \n",
       "L 172.601804 -231.956034 \n",
       "L 169.322462 -232.909222 \n",
       "L 166.04312 -233.587434 \n",
       "L 162.763787 -234.049566 \n",
       "L 159.484445 -234.367754 \n",
       "L 156.205103 -236.609202 \n",
       "L 152.92577 -242.34893 \n",
       "L 149.646428 -247.169933 \n",
       "L 146.367086 -250.955744 \n",
       "L 143.087754 -253.658569 \n",
       "L 139.808412 -255.250442 \n",
       "L 136.529069 -255.720813 \n",
       "L 133.249737 -255.077053 \n",
       "L 129.970395 -253.344287 \n",
       "L 126.691057 -250.567031 \n",
       "L 123.41172 -246.806727 \n",
       "L 120.132378 -242.145269 \n",
       "L 116.853041 -236.694227 \n",
       "L 113.573703 -231.731875 \n",
       "L 110.294361 -230.190714 \n",
       "L 107.015024 -228.400541 \n",
       "L 103.735686 -226.199619 \n",
       "L 100.456344 -223.549791 \n",
       "L 97.177007 -220.426091 \n",
       "L 93.89767 -216.815344 \n",
       "L 90.61833 -212.716514 \n",
       "L 87.33899 -208.139757 \n",
       "L 84.059653 -203.107856 \n",
       "L 80.780313 -197.655089 \n",
       "L 77.500973 -191.827055 \n",
       "L 74.221636 -185.679976 \n",
       "L 70.942296 -179.278959 \n",
       "L 67.662958 -172.695771 \n",
       "L 64.383619 -166.008648 \n",
       "L 61.10428 -159.299927 \n",
       "L 57.824941 -152.659109 \n",
       "L 54.545602 -146.599199 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pf21ddddc07)\">\n",
       "     <use xlink:href=\"#m3579289de9\" x=\"0\" y=\"322.539375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"mbeb74ea76a\" d=\"M 54.545602 -145.640304 \n",
       "L 54.545602 -145.442342 \n",
       "L 57.824941 -144.306245 \n",
       "L 61.10428 -143.564999 \n",
       "L 64.383619 -143.817744 \n",
       "L 67.662958 -145.079541 \n",
       "L 70.942296 -147.336754 \n",
       "L 74.221636 -150.555794 \n",
       "L 77.500973 -154.684052 \n",
       "L 80.780313 -159.651347 \n",
       "L 84.059653 -165.37095 \n",
       "L 87.33899 -171.740322 \n",
       "L 90.61833 -178.643491 \n",
       "L 93.89767 -185.953018 \n",
       "L 97.177007 -193.531834 \n",
       "L 100.456344 -201.237358 \n",
       "L 103.735686 -208.921909 \n",
       "L 107.015024 -216.435109 \n",
       "L 110.294361 -223.61903 \n",
       "L 113.573703 -230.129487 \n",
       "L 116.853041 -232.498538 \n",
       "L 120.132378 -233.329806 \n",
       "L 123.41172 -233.882374 \n",
       "L 126.691057 -234.238807 \n",
       "L 129.970395 -234.45209 \n",
       "L 133.249737 -234.56521 \n",
       "L 136.529069 -234.615084 \n",
       "L 139.808412 -234.628989 \n",
       "L 143.087754 -234.625111 \n",
       "L 146.367086 -234.611002 \n",
       "L 149.646428 -234.582198 \n",
       "L 152.92577 -234.516048 \n",
       "L 156.205103 -234.278801 \n",
       "L 159.484445 -229.667106 \n",
       "L 162.763787 -222.15717 \n",
       "L 166.04312 -213.856599 \n",
       "L 169.322462 -204.899598 \n",
       "L 172.601804 -195.394544 \n",
       "L 175.881137 -185.450991 \n",
       "L 179.160479 -175.179681 \n",
       "L 182.439821 -164.692383 \n",
       "L 185.719153 -154.100789 \n",
       "L 188.998496 -143.515242 \n",
       "L 192.277838 -133.044139 \n",
       "L 195.55717 -122.792842 \n",
       "L 198.836512 -112.863066 \n",
       "L 202.115855 -103.35233 \n",
       "L 205.395187 -94.353348 \n",
       "L 208.674529 -85.953459 \n",
       "L 211.953871 -78.234197 \n",
       "L 215.233204 -71.27082 \n",
       "L 218.512556 -65.131602 \n",
       "L 221.791879 -59.877595 \n",
       "L 225.071221 -55.561638 \n",
       "L 228.350563 -52.228114 \n",
       "L 231.629886 -49.912119 \n",
       "L 234.909247 -48.638925 \n",
       "L 238.18857 -48.423375 \n",
       "L 241.467912 -49.269395 \n",
       "L 244.747254 -51.169511 \n",
       "L 248.026597 -54.104168 \n",
       "L 251.305939 -58.041053 \n",
       "L 254.585262 -62.928276 \n",
       "L 257.864623 -68.105553 \n",
       "L 261.143946 -63.625937 \n",
       "L 264.423288 -59.384291 \n",
       "L 267.70263 -56.038376 \n",
       "L 270.981953 -53.637494 \n",
       "L 274.261315 -52.210749 \n",
       "L 277.540637 -51.774002 \n",
       "L 280.81998 -52.330698 \n",
       "L 284.099322 -53.872656 \n",
       "L 287.378664 -56.380846 \n",
       "L 290.658006 -59.826195 \n",
       "L 293.937329 -64.170482 \n",
       "L 297.21669 -69.36776 \n",
       "L 300.496013 -75.364678 \n",
       "L 303.775355 -82.102682 \n",
       "L 307.054697 -89.518107 \n",
       "L 310.33402 -97.543967 \n",
       "L 313.613382 -106.110686 \n",
       "L 316.892705 -115.146932 \n",
       "L 320.172047 -124.580802 \n",
       "L 323.451389 -134.340393 \n",
       "L 326.730731 -144.3542 \n",
       "L 330.010073 -154.552237 \n",
       "L 333.289396 -164.866093 \n",
       "L 336.568738 -175.229535 \n",
       "L 339.84808 -185.579132 \n",
       "L 343.127423 -195.853397 \n",
       "L 346.406765 -205.994384 \n",
       "L 349.686088 -215.946904 \n",
       "L 352.96543 -225.652048 \n",
       "L 356.244772 -234.618932 \n",
       "L 359.524114 -232.134371 \n",
       "L 362.803456 -228.413616 \n",
       "L 366.082798 -224.364936 \n",
       "L 369.362141 -220.067973 \n",
       "L 372.641463 -215.593667 \n",
       "L 375.920806 -211.009368 \n",
       "L 379.200148 -206.377144 \n",
       "L 379.200148 -206.379871 \n",
       "L 379.200148 -206.379871 \n",
       "L 375.920806 -211.012517 \n",
       "L 372.641463 -215.597412 \n",
       "L 369.362141 -220.072625 \n",
       "L 366.082798 -224.371127 \n",
       "L 362.803456 -228.422929 \n",
       "L 359.524114 -232.153258 \n",
       "L 356.244772 -234.805827 \n",
       "L 352.96543 -225.669964 \n",
       "L 349.686088 -215.95612 \n",
       "L 346.406765 -206.000645 \n",
       "L 343.127423 -195.858186 \n",
       "L 339.84808 -185.583046 \n",
       "L 336.568738 -175.232878 \n",
       "L 333.289396 -164.869037 \n",
       "L 330.010073 -154.554896 \n",
       "L 326.730731 -144.356653 \n",
       "L 323.451389 -134.342675 \n",
       "L 320.172047 -124.582981 \n",
       "L 316.892705 -115.149032 \n",
       "L 313.613382 -106.112717 \n",
       "L 310.33402 -97.545975 \n",
       "L 307.054697 -89.520115 \n",
       "L 303.775355 -82.104702 \n",
       "L 300.496013 -75.36672 \n",
       "L 297.21669 -69.369871 \n",
       "L 293.937329 -64.172684 \n",
       "L 290.658006 -59.828523 \n",
       "L 287.378664 -56.383333 \n",
       "L 284.099322 -53.875372 \n",
       "L 280.81998 -52.33371 \n",
       "L 277.540637 -51.777436 \n",
       "L 274.261315 -52.214788 \n",
       "L 270.981953 -53.642468 \n",
       "L 267.70263 -56.044925 \n",
       "L 264.423288 -59.394035 \n",
       "L 261.143946 -63.645288 \n",
       "L 257.864623 -68.303349 \n",
       "L 254.585262 -62.947706 \n",
       "L 251.305939 -58.050877 \n",
       "L 248.026597 -54.110808 \n",
       "L 244.747254 -51.174577 \n",
       "L 241.467912 -49.273525 \n",
       "L 238.18857 -48.426912 \n",
       "L 234.909247 -48.642028 \n",
       "L 231.629886 -49.914937 \n",
       "L 228.350563 -52.230716 \n",
       "L 225.071221 -55.56408 \n",
       "L 221.791879 -59.879934 \n",
       "L 218.512556 -65.133861 \n",
       "L 215.233204 -71.273033 \n",
       "L 211.953871 -78.236388 \n",
       "L 208.674529 -85.955673 \n",
       "L 205.395187 -94.355607 \n",
       "L 202.115855 -103.354635 \n",
       "L 198.836512 -112.865474 \n",
       "L 195.55717 -122.795375 \n",
       "L 192.277838 -133.046855 \n",
       "L 188.998496 -143.518186 \n",
       "L 185.719153 -154.104052 \n",
       "L 182.439821 -164.696068 \n",
       "L 179.160479 -175.183937 \n",
       "L 175.881137 -185.456057 \n",
       "L 172.601804 -195.400808 \n",
       "L 169.322462 -204.907776 \n",
       "L 166.04312 -213.868208 \n",
       "L 162.763787 -222.176427 \n",
       "L 159.484445 -229.715825 \n",
       "L 156.205103 -234.377073 \n",
       "L 152.92577 -234.545285 \n",
       "L 149.646428 -234.600391 \n",
       "L 146.367086 -234.625014 \n",
       "L 143.087754 -234.637143 \n",
       "L 139.808412 -234.640095 \n",
       "L 136.529069 -234.625935 \n",
       "L 133.249737 -234.576375 \n",
       "L 129.970395 -234.464213 \n",
       "L 126.691057 -234.252833 \n",
       "L 123.41172 -233.900094 \n",
       "L 120.132378 -233.355785 \n",
       "L 116.853041 -232.553121 \n",
       "L 113.573703 -230.272407 \n",
       "L 110.294361 -223.653878 \n",
       "L 107.015024 -216.454248 \n",
       "L 103.735686 -208.935165 \n",
       "L 100.456344 -201.247621 \n",
       "L 97.177007 -193.540351 \n",
       "L 93.89767 -185.960434 \n",
       "L 90.61833 -178.650212 \n",
       "L 87.33899 -171.746615 \n",
       "L 84.059653 -165.37702 \n",
       "L 80.780313 -159.657372 \n",
       "L 77.500973 -154.690213 \n",
       "L 74.221636 -150.562309 \n",
       "L 70.942296 -147.343925 \n",
       "L 67.662958 -145.087824 \n",
       "L 64.383619 -143.82807 \n",
       "L 61.10428 -143.579558 \n",
       "L 57.824941 -144.333663 \n",
       "L 54.545602 -145.640304 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pf21ddddc07)\">\n",
       "     <use xlink:href=\"#mbeb74ea76a\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"m299463b3d4\" d=\"M 54.545602 -146.797161 \n",
       "L 54.545602 -146.599199 \n",
       "L 57.824941 -152.659109 \n",
       "L 61.10428 -159.299927 \n",
       "L 64.383619 -166.008648 \n",
       "L 67.662958 -172.695771 \n",
       "L 70.942296 -179.278959 \n",
       "L 74.221636 -185.679976 \n",
       "L 77.500973 -191.827055 \n",
       "L 80.780313 -197.655089 \n",
       "L 84.059653 -203.107856 \n",
       "L 87.33899 -208.139757 \n",
       "L 90.61833 -212.716514 \n",
       "L 93.89767 -216.815344 \n",
       "L 97.177007 -220.426091 \n",
       "L 100.456344 -223.549791 \n",
       "L 103.735686 -226.199619 \n",
       "L 107.015024 -228.400541 \n",
       "L 110.294361 -230.190714 \n",
       "L 113.573703 -231.731875 \n",
       "L 116.853041 -236.694227 \n",
       "L 120.132378 -242.145269 \n",
       "L 123.41172 -246.806727 \n",
       "L 126.691057 -250.567031 \n",
       "L 129.970395 -253.344287 \n",
       "L 133.249737 -255.077053 \n",
       "L 136.529069 -255.720813 \n",
       "L 139.808412 -255.250442 \n",
       "L 143.087754 -253.658569 \n",
       "L 146.367086 -250.955744 \n",
       "L 149.646428 -247.169933 \n",
       "L 152.92577 -242.34893 \n",
       "L 156.205103 -236.609202 \n",
       "L 159.484445 -234.367754 \n",
       "L 162.763787 -234.049566 \n",
       "L 166.04312 -233.587434 \n",
       "L 169.322462 -232.909222 \n",
       "L 172.601804 -231.956034 \n",
       "L 175.881137 -230.66878 \n",
       "L 179.160479 -228.989945 \n",
       "L 182.439821 -226.864937 \n",
       "L 185.719153 -224.243944 \n",
       "L 188.998496 -221.084062 \n",
       "L 192.277838 -217.35083 \n",
       "L 195.55717 -213.019961 \n",
       "L 198.836512 -208.078303 \n",
       "L 202.115855 -202.525072 \n",
       "L 205.395187 -196.372316 \n",
       "L 208.674529 -189.645208 \n",
       "L 211.953871 -182.382089 \n",
       "L 215.233204 -174.63399 \n",
       "L 218.512556 -166.463913 \n",
       "L 221.791879 -157.946004 \n",
       "L 225.071221 -149.163934 \n",
       "L 228.350563 -140.209786 \n",
       "L 231.629886 -131.18212 \n",
       "L 234.909247 -122.184175 \n",
       "L 238.18857 -113.322051 \n",
       "L 241.467912 -104.702539 \n",
       "L 244.747254 -96.431362 \n",
       "L 248.026597 -88.611445 \n",
       "L 251.305939 -81.341082 \n",
       "L 254.585262 -74.716044 \n",
       "L 257.864623 -69.263374 \n",
       "L 261.143946 -75.464261 \n",
       "L 264.423288 -82.885961 \n",
       "L 267.70263 -91.000279 \n",
       "L 270.981953 -99.709196 \n",
       "L 274.261315 -108.91225 \n",
       "L 277.540637 -118.503184 \n",
       "L 280.81998 -128.371884 \n",
       "L 284.099322 -138.405921 \n",
       "L 287.378664 -148.491477 \n",
       "L 290.658006 -158.515963 \n",
       "L 293.937329 -168.368753 \n",
       "L 297.21669 -177.943976 \n",
       "L 300.496013 -187.140612 \n",
       "L 303.775355 -195.865531 \n",
       "L 307.054697 -204.03344 \n",
       "L 310.33402 -211.568991 \n",
       "L 313.613382 -218.407291 \n",
       "L 316.892705 -224.494573 \n",
       "L 320.172047 -229.789208 \n",
       "L 323.451389 -234.261562 \n",
       "L 326.730731 -237.894268 \n",
       "L 330.010073 -240.682306 \n",
       "L 333.289396 -242.632265 \n",
       "L 336.568738 -243.762181 \n",
       "L 339.84808 -244.1005 \n",
       "L 343.127423 -243.685876 \n",
       "L 346.406765 -242.565338 \n",
       "L 349.686088 -240.793251 \n",
       "L 352.96543 -238.434553 \n",
       "L 356.244772 -235.84428 \n",
       "L 359.524114 -244.259612 \n",
       "L 362.803456 -253.002884 \n",
       "L 366.082798 -261.356424 \n",
       "L 369.362141 -269.288209 \n",
       "L 372.641463 -276.774267 \n",
       "L 375.920806 -283.795894 \n",
       "L 379.200148 -290.340648 \n",
       "L 379.200148 -290.343375 \n",
       "L 379.200148 -290.343375 \n",
       "L 375.920806 -283.799037 \n",
       "L 372.641463 -276.778013 \n",
       "L 369.362141 -269.292861 \n",
       "L 366.082798 -261.362615 \n",
       "L 362.803456 -253.012197 \n",
       "L 359.524114 -244.278499 \n",
       "L 356.244772 -236.031176 \n",
       "L 352.96543 -238.452469 \n",
       "L 349.686088 -240.802469 \n",
       "L 346.406765 -242.5716 \n",
       "L 343.127423 -243.690664 \n",
       "L 339.84808 -244.104414 \n",
       "L 336.568738 -243.765524 \n",
       "L 333.289396 -242.635209 \n",
       "L 330.010073 -240.684964 \n",
       "L 326.730731 -237.896715 \n",
       "L 323.451389 -234.263855 \n",
       "L 320.172047 -229.791382 \n",
       "L 316.892705 -224.496666 \n",
       "L 313.613382 -218.409327 \n",
       "L 310.33402 -211.570999 \n",
       "L 307.054697 -204.035443 \n",
       "L 303.775355 -195.867545 \n",
       "L 300.496013 -187.14266 \n",
       "L 297.21669 -177.946087 \n",
       "L 293.937329 -168.370949 \n",
       "L 290.658006 -158.51828 \n",
       "L 287.378664 -148.493964 \n",
       "L 284.099322 -138.408636 \n",
       "L 280.81998 -128.374897 \n",
       "L 277.540637 -118.506619 \n",
       "L 274.261315 -108.916289 \n",
       "L 270.981953 -99.714171 \n",
       "L 267.70263 -91.006828 \n",
       "L 264.423288 -82.895705 \n",
       "L 261.143946 -75.483611 \n",
       "L 257.864623 -69.46117 \n",
       "L 254.585262 -74.735474 \n",
       "L 251.305939 -81.350905 \n",
       "L 248.026597 -88.618086 \n",
       "L 244.747254 -96.436428 \n",
       "L 241.467912 -104.70667 \n",
       "L 238.18857 -113.325576 \n",
       "L 234.909247 -122.18729 \n",
       "L 231.629886 -131.184938 \n",
       "L 228.350563 -140.212387 \n",
       "L 225.071221 -149.166382 \n",
       "L 221.791879 -157.948343 \n",
       "L 218.512556 -166.466172 \n",
       "L 215.233204 -174.636209 \n",
       "L 211.953871 -182.384291 \n",
       "L 208.674529 -189.647421 \n",
       "L 205.395187 -196.374564 \n",
       "L 202.115855 -202.527376 \n",
       "L 198.836512 -208.08071 \n",
       "L 195.55717 -213.022499 \n",
       "L 192.277838 -217.353548 \n",
       "L 188.998496 -221.087015 \n",
       "L 185.719153 -224.247207 \n",
       "L 182.439821 -226.868623 \n",
       "L 179.160479 -228.994201 \n",
       "L 175.881137 -230.673844 \n",
       "L 172.601804 -231.962297 \n",
       "L 169.322462 -232.917399 \n",
       "L 166.04312 -233.599042 \n",
       "L 162.763787 -234.068824 \n",
       "L 159.484445 -234.416473 \n",
       "L 156.205103 -236.707474 \n",
       "L 152.92577 -242.378167 \n",
       "L 149.646428 -247.188127 \n",
       "L 146.367086 -250.969755 \n",
       "L 143.087754 -253.670601 \n",
       "L 139.808412 -255.261547 \n",
       "L 136.529069 -255.731663 \n",
       "L 133.249737 -255.088217 \n",
       "L 129.970395 -253.356409 \n",
       "L 126.691057 -250.581057 \n",
       "L 123.41172 -246.824447 \n",
       "L 120.132378 -242.171248 \n",
       "L 116.853041 -236.74881 \n",
       "L 113.573703 -231.874795 \n",
       "L 110.294361 -230.225562 \n",
       "L 107.015024 -228.41968 \n",
       "L 103.735686 -226.212874 \n",
       "L 100.456344 -223.560054 \n",
       "L 97.177007 -220.434605 \n",
       "L 93.89767 -216.822763 \n",
       "L 90.61833 -212.723235 \n",
       "L 87.33899 -208.14605 \n",
       "L 84.059653 -203.113925 \n",
       "L 80.780313 -197.661116 \n",
       "L 77.500973 -191.833216 \n",
       "L 74.221636 -185.68649 \n",
       "L 70.942296 -179.28613 \n",
       "L 67.662958 -172.70406 \n",
       "L 64.383619 -166.018968 \n",
       "L 61.10428 -159.31448 \n",
       "L 57.824941 -152.686527 \n",
       "L 54.545602 -146.797161 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pf21ddddc07)\">\n",
       "     <use xlink:href=\"#m299463b3d4\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_13\">\n",
       "    <defs>\n",
       "     <path id=\"m7be35fa189\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pf21ddddc07)\">\n",
       "     <use xlink:href=\"#m7be35fa189\" x=\"356.349693\" y=\"87.115736\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m7be35fa189\" x=\"157.258364\" y=\"88.101782\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m7be35fa189\" x=\"114.255683\" y=\"90.743567\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m7be35fa189\" x=\"257.864623\" y=\"253.760395\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m7be35fa189\" x=\"54.545602\" y=\"176.422647\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <path d=\"M 54.545602 176.419623 \n",
       "L 57.824941 174.042992 \n",
       "L 61.10428 171.099635 \n",
       "L 64.383619 167.621016 \n",
       "L 67.662958 163.647574 \n",
       "L 70.942296 159.227933 \n",
       "L 74.221636 154.418233 \n",
       "L 77.500973 149.280741 \n",
       "L 80.780313 143.883145 \n",
       "L 84.059653 138.296937 \n",
       "L 87.33899 132.596189 \n",
       "L 90.61833 126.856012 \n",
       "L 93.89767 121.151484 \n",
       "L 97.177007 115.556155 \n",
       "L 100.456344 110.140669 \n",
       "L 103.735686 104.971983 \n",
       "L 107.015024 100.111981 \n",
       "L 110.294361 95.617079 \n",
       "L 113.573703 91.537234 \n",
       "L 116.853041 87.915701 \n",
       "L 120.132378 84.788848 \n",
       "L 123.41172 82.185964 \n",
       "L 126.691057 80.129443 \n",
       "L 129.970395 78.635125 \n",
       "L 133.249737 77.712661 \n",
       "L 136.529069 77.366001 \n",
       "L 139.808412 77.594107 \n",
       "L 143.087754 78.391519 \n",
       "L 146.367086 79.748996 \n",
       "L 149.646428 81.654213 \n",
       "L 152.92577 84.092268 \n",
       "L 156.205103 87.046238 \n",
       "L 159.484445 90.497586 \n",
       "L 162.763787 94.426378 \n",
       "L 166.04312 98.811554 \n",
       "L 169.322462 103.630876 \n",
       "L 172.601804 108.860954 \n",
       "L 175.881137 114.476957 \n",
       "L 179.160479 120.452434 \n",
       "L 182.439821 126.758871 \n",
       "L 185.719153 133.365377 \n",
       "L 188.998496 140.238248 \n",
       "L 192.277838 147.340531 \n",
       "L 195.55717 154.631706 \n",
       "L 198.836512 162.067485 \n",
       "L 202.115855 169.599522 \n",
       "L 205.395187 177.175416 \n",
       "L 208.674529 184.738938 \n",
       "L 211.953871 192.230133 \n",
       "L 215.233204 199.585863 \n",
       "L 218.512556 206.740488 \n",
       "L 221.791879 213.626406 \n",
       "L 225.071221 220.175365 \n",
       "L 228.350563 226.319124 \n",
       "L 231.629886 231.990847 \n",
       "L 234.909247 237.126273 \n",
       "L 238.18857 241.664899 \n",
       "L 241.467912 245.551343 \n",
       "L 244.747254 248.736405 \n",
       "L 248.026597 251.178248 \n",
       "L 251.305939 252.843396 \n",
       "L 254.585262 253.7075 \n",
       "L 257.864623 253.756013 \n",
       "L 261.143946 252.984601 \n",
       "L 264.423288 251.399377 \n",
       "L 267.70263 249.016773 \n",
       "L 270.981953 245.863543 \n",
       "L 274.261315 241.975856 \n",
       "L 277.540637 237.399065 \n",
       "L 280.81998 232.186578 \n",
       "L 284.099322 226.398729 \n",
       "L 287.378664 220.101967 \n",
       "L 290.658006 213.367135 \n",
       "L 293.937329 206.268657 \n",
       "L 297.21669 198.882452 \n",
       "L 300.496013 191.285706 \n",
       "L 303.775355 183.554259 \n",
       "L 307.054697 175.762597 \n",
       "L 310.33402 167.981889 \n",
       "L 313.613382 160.279371 \n",
       "L 316.892705 152.717573 \n",
       "L 320.172047 145.35328 \n",
       "L 323.451389 138.237254 \n",
       "L 326.730731 131.413917 \n",
       "L 330.010073 124.920774 \n",
       "L 333.289396 118.788724 \n",
       "L 336.568738 113.041844 \n",
       "L 339.84808 107.697602 \n",
       "L 343.127423 102.767344 \n",
       "L 346.406765 98.256383 \n",
       "L 349.686088 94.164688 \n",
       "L 352.96543 90.487117 \n",
       "L 356.244772 87.214321 \n",
       "L 359.524114 84.33294 \n",
       "L 362.803456 81.826469 \n",
       "L 366.082798 79.675599 \n",
       "L 369.362141 77.858958 \n",
       "L 372.641463 76.353534 \n",
       "L 375.920806 75.135171 \n",
       "L 379.200148 74.179117 \n",
       "\" clip-path=\"url(#pf21ddddc07)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 54.545602 176.422647 \n",
       "L 57.824941 170.583478 \n",
       "L 61.10428 164.765975 \n",
       "L 64.383619 158.991715 \n",
       "L 67.662958 153.282193 \n",
       "L 70.942296 147.658664 \n",
       "L 74.221636 142.142181 \n",
       "L 77.500973 136.753422 \n",
       "L 80.780313 131.512656 \n",
       "L 84.059653 126.439708 \n",
       "L 87.33899 121.553826 \n",
       "L 90.61833 116.873658 \n",
       "L 93.89767 112.417175 \n",
       "L 97.177007 108.201611 \n",
       "L 100.456344 104.243385 \n",
       "L 103.735686 100.558092 \n",
       "L 107.015024 97.160401 \n",
       "L 110.294361 94.064025 \n",
       "L 113.573703 91.281657 \n",
       "L 116.853041 88.824959 \n",
       "L 120.132378 86.704501 \n",
       "L 123.41172 84.929707 \n",
       "L 126.691057 83.50885 \n",
       "L 129.970395 82.449009 \n",
       "L 133.249737 81.756032 \n",
       "L 136.529069 81.434527 \n",
       "L 139.808412 81.487844 \n",
       "L 143.087754 81.91803 \n",
       "L 146.367086 82.725845 \n",
       "L 149.646428 83.910747 \n",
       "L 152.92577 85.470864 \n",
       "L 156.205103 87.40299 \n",
       "L 159.484445 89.702629 \n",
       "L 162.763787 92.363912 \n",
       "L 166.04312 95.37968 \n",
       "L 169.322462 98.741431 \n",
       "L 172.601804 102.439348 \n",
       "L 175.881137 106.462302 \n",
       "L 179.160479 110.797837 \n",
       "L 182.439821 115.432253 \n",
       "L 185.719153 120.350475 \n",
       "L 188.998496 125.536218 \n",
       "L 192.277838 130.971854 \n",
       "L 195.55717 136.638556 \n",
       "L 198.836512 142.516175 \n",
       "L 202.115855 148.583291 \n",
       "L 205.395187 154.817237 \n",
       "L 208.674529 161.194105 \n",
       "L 211.953871 167.688663 \n",
       "L 215.233204 174.274458 \n",
       "L 218.512556 180.923747 \n",
       "L 221.791879 187.607442 \n",
       "L 225.071221 194.295244 \n",
       "L 228.350563 200.955514 \n",
       "L 231.629886 207.555132 \n",
       "L 234.909247 214.059924 \n",
       "L 238.18857 220.433997 \n",
       "L 241.467912 226.640372 \n",
       "L 244.747254 232.640508 \n",
       "L 248.026597 238.394516 \n",
       "L 251.305939 243.861174 \n",
       "L 254.585262 248.997776 \n",
       "L 257.864623 253.760395 \n",
       "L 261.143946 258.103746 \n",
       "L 264.423288 261.981415 \n",
       "L 267.70263 265.345894 \n",
       "L 270.981953 268.148872 \n",
       "L 274.261315 270.341336 \n",
       "L 277.540637 271.873996 \n",
       "L 280.81998 272.697642 \n",
       "L 284.099322 272.763669 \n",
       "L 287.378664 272.024716 \n",
       "L 290.658006 270.435522 \n",
       "L 293.937329 267.95386 \n",
       "L 297.21669 264.541633 \n",
       "L 300.496013 260.166745 \n",
       "L 303.775355 254.804131 \n",
       "L 307.054697 248.438387 \n",
       "L 310.33402 241.065999 \n",
       "L 313.613382 232.697761 \n",
       "L 316.892705 223.362436 \n",
       "L 320.172047 213.109826 \n",
       "L 323.451389 202.014836 \n",
       "L 326.730731 190.181715 \n",
       "L 330.010073 177.748314 \n",
       "L 333.289396 164.890585 \n",
       "L 336.568738 151.826902 \n",
       "L 339.84808 138.821493 \n",
       "L 343.127423 126.187311 \n",
       "L 346.406765 114.287113 \n",
       "L 349.686088 103.531553 \n",
       "L 352.96543 94.374125 \n",
       "L 356.244772 87.301958 \n",
       "L 359.524114 82.819147 \n",
       "L 362.803456 81.423671 \n",
       "L 366.082798 83.574644 \n",
       "L 369.362141 89.649478 \n",
       "L 372.641463 99.890495 \n",
       "L 375.920806 114.341292 \n",
       "L 379.200148 132.775873 \n",
       "\" clip-path=\"url(#pf21ddddc07)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 38.312875 272.831305 \n",
       "L 38.312875 33.555183 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 54.545602 286.212 \n",
       "L 379.200148 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_15\">\n",
       "    <!-- N=1, psi=1.96 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(186.986125 14.1) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2c\" d=\"M 569 0 \n",
       "L 569 641 \n",
       "L 1209 641 \n",
       "L 1209 0 \n",
       "Q 1209 -353 1084 -570 \n",
       "Q 959 -788 688 -906 \n",
       "L 531 -666 \n",
       "Q 709 -588 793 -436 \n",
       "Q 878 -284 888 0 \n",
       "L 569 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-2c\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"214.013672\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"241.796875\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"297.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"347.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"369.628906\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"428.027344\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"483.642578\"/>\n",
       "     <use xlink:href=\"#ArialMT-39\" x=\"511.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-36\" x=\"567.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_16\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#m7be35fa189\" x=\"55.032875\" y=\"220.007125\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_16\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 223.087125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_17\">\n",
       "     <path d=\"M 46.232875 232.591125 \n",
       "L 55.032875 232.591125 \n",
       "L 63.832875 232.591125 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 235.671125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 46.232875 249.828125 \n",
       "L 63.832875 249.828125 \n",
       "L 63.832875 243.668125 \n",
       "L 46.232875 243.668125 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 249.828125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 46.232875 263.996125 \n",
       "L 63.832875 263.996125 \n",
       "L 63.832875 257.836125 \n",
       "L 46.232875 257.836125 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 263.996125) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_18\">\n",
       "     <path d=\"M 46.232875 273.463 \n",
       "L 55.032875 273.463 \n",
       "L 63.832875 273.463 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 276.543) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <defs>\n",
       "       <path id=\"m2c145b603d\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2c145b603d\" x=\"395.432875\" y=\"243.020775\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_21\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 246.170212) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2c145b603d\" x=\"395.432875\" y=\"190.456508\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 193.605945) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2c145b603d\" x=\"395.432875\" y=\"137.892241\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 141.041678) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2c145b603d\" x=\"395.432875\" y=\"85.327974\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 88.477411) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2c145b603d\" x=\"395.432875\" y=\"32.763707\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 35.913144) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_26\">\n",
       "     <!-- Maximum Upper Interval -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(424.63775 205.43475) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4d\" d=\"M 475 0 \n",
       "L 475 4581 \n",
       "L 1388 4581 \n",
       "L 2472 1338 \n",
       "Q 2622 884 2691 659 \n",
       "Q 2769 909 2934 1394 \n",
       "L 4031 4581 \n",
       "L 4847 4581 \n",
       "L 4847 0 \n",
       "L 4263 0 \n",
       "L 4263 3834 \n",
       "L 2931 0 \n",
       "L 2384 0 \n",
       "L 1059 3900 \n",
       "L 1059 0 \n",
       "L 475 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-78\" d=\"M 47 0 \n",
       "L 1259 1725 \n",
       "L 138 3319 \n",
       "L 841 3319 \n",
       "L 1350 2541 \n",
       "Q 1494 2319 1581 2169 \n",
       "Q 1719 2375 1834 2534 \n",
       "L 2394 3319 \n",
       "L 3066 3319 \n",
       "L 1919 1756 \n",
       "L 3153 0 \n",
       "L 2463 0 \n",
       "L 1781 1031 \n",
       "L 1600 1309 \n",
       "L 728 0 \n",
       "L 47 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-55\" d=\"M 3500 4581 \n",
       "L 4106 4581 \n",
       "L 4106 1934 \n",
       "Q 4106 1244 3950 837 \n",
       "Q 3794 431 3386 176 \n",
       "Q 2978 -78 2316 -78 \n",
       "Q 1672 -78 1262 144 \n",
       "Q 853 366 678 786 \n",
       "Q 503 1206 503 1934 \n",
       "L 503 4581 \n",
       "L 1109 4581 \n",
       "L 1109 1938 \n",
       "Q 1109 1341 1220 1058 \n",
       "Q 1331 775 1601 622 \n",
       "Q 1872 469 2263 469 \n",
       "Q 2931 469 3215 772 \n",
       "Q 3500 1075 3500 1938 \n",
       "L 3500 4581 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4d\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "      <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"188.916016\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"211.132812\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"294.433594\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"350.048828\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"433.349609\"/>\n",
       "      <use xlink:href=\"#ArialMT-55\" x=\"461.132812\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" x=\"533.349609\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" x=\"588.964844\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"644.580078\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"700.195312\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"733.496094\"/>\n",
       "      <use xlink:href=\"#ArialMT-49\" x=\"761.279297\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"789.0625\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.677734\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"872.460938\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"928.076172\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"961.376953\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"1011.376953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6c\" x=\"1066.992188\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_24\">\n",
       "    <path d=\"M 54.545602 189.17018 \n",
       "L 57.824941 182.594878 \n",
       "L 61.10428 175.38182 \n",
       "L 64.383619 168.0839 \n",
       "L 67.662958 160.798368 \n",
       "L 70.942296 153.614911 \n",
       "L 74.221636 146.618987 \n",
       "L 77.500973 139.8892 \n",
       "L 80.780313 133.497133 \n",
       "L 84.059653 127.504868 \n",
       "L 87.33899 121.963126 \n",
       "L 90.61833 116.910452 \n",
       "L 93.89767 112.373014 \n",
       "L 97.177007 108.363365 \n",
       "L 100.456344 104.881943 \n",
       "L 103.735686 101.916032 \n",
       "L 107.015024 99.44012 \n",
       "L 110.294361 97.414373 \n",
       "L 113.573703 95.665788 \n",
       "L 116.853041 90.244587 \n",
       "L 120.132378 84.30821 \n",
       "L 123.41172 79.233279 \n",
       "L 126.691057 75.140383 \n",
       "L 129.970395 72.118023 \n",
       "L 133.249737 70.232552 \n",
       "L 136.529069 69.531971 \n",
       "L 139.808412 70.043305 \n",
       "L 143.087754 71.774369 \n",
       "L 146.367086 74.713602 \n",
       "L 149.646428 78.83063 \n",
       "L 152.92577 84.07368 \n",
       "L 156.205103 90.317011 \n",
       "L 159.484445 92.805601 \n",
       "L 162.763787 93.234416 \n",
       "L 166.04312 93.828205 \n",
       "L 169.322462 94.664125 \n",
       "L 172.601804 95.805064 \n",
       "L 175.881137 97.314081 \n",
       "L 179.160479 99.252503 \n",
       "L 182.439821 101.678474 \n",
       "L 185.719153 104.644932 \n",
       "L 188.998496 108.197318 \n",
       "L 192.277838 112.371921 \n",
       "L 195.55717 117.193989 \n",
       "L 198.836512 122.676703 \n",
       "L 202.115855 128.819854 \n",
       "L 205.395187 135.609314 \n",
       "L 208.674529 143.01676 \n",
       "L 211.953871 150.999589 \n",
       "L 215.233204 159.5015 \n",
       "L 218.512556 168.45322 \n",
       "L 221.791879 177.773453 \n",
       "L 225.071221 187.370643 \n",
       "L 228.350563 197.144156 \n",
       "L 231.629886 206.986433 \n",
       "L 234.909247 216.784936 \n",
       "L 238.18857 226.42414 \n",
       "L 241.467912 235.787859 \n",
       "L 244.747254 244.761185 \n",
       "L 248.026597 253.232455 \n",
       "L 251.305939 261.095105 \n",
       "L 254.585262 268.245496 \n",
       "L 257.864623 274.116 \n",
       "L 261.143946 267.424204 \n",
       "L 264.423288 259.400413 \n",
       "L 267.70263 250.613555 \n",
       "L 270.981953 241.169704 \n",
       "L 274.261315 231.177829 \n",
       "L 277.540637 220.753275 \n",
       "L 280.81998 210.015765 \n",
       "L 284.099322 199.087639 \n",
       "L 287.378664 188.092879 \n",
       "L 290.658006 177.154232 \n",
       "L 293.937329 166.392422 \n",
       "L 297.21669 155.923066 \n",
       "L 300.496013 145.85661 \n",
       "L 303.775355 136.294968 \n",
       "L 307.054697 127.331587 \n",
       "L 310.33402 119.049135 \n",
       "L 313.613382 111.518954 \n",
       "L 316.892705 104.800276 \n",
       "L 320.172047 98.939171 \n",
       "L 323.451389 93.968655 \n",
       "L 326.730731 89.908391 \n",
       "L 330.010073 86.764614 \n",
       "L 333.289396 84.530901 \n",
       "L 336.568738 83.188375 \n",
       "L 339.84808 82.706794 \n",
       "L 343.127423 83.044801 \n",
       "L 346.406765 84.15189 \n",
       "L 349.686088 85.969537 \n",
       "L 352.96543 88.427731 \n",
       "L 356.244772 91.144091 \n",
       "L 359.524114 82.022245 \n",
       "L 362.803456 72.555629 \n",
       "L 366.082798 63.516346 \n",
       "L 369.362141 54.938395 \n",
       "L 372.641463 46.847077 \n",
       "L 375.920806 39.261998 \n",
       "L 379.200148 32.196 \n",
       "\" clip-path=\"url(#pf21ddddc07)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_25\">\n",
       "    <path d=\"M 379.200148 85.327974 \n",
       "L 379.200148 84.791287 \n",
       "L 379.200148 84.254601 \n",
       "L 379.200148 83.717914 \n",
       "L 379.200148 83.181227 \n",
       "L 379.200148 82.644541 \n",
       "L 379.200148 82.107854 \n",
       "L 379.200148 81.571168 \n",
       "L 379.200148 81.034481 \n",
       "L 379.200148 80.497794 \n",
       "L 379.200148 79.961108 \n",
       "L 379.200148 79.424421 \n",
       "L 379.200148 78.887735 \n",
       "L 379.200148 78.351048 \n",
       "L 379.200148 77.814362 \n",
       "L 379.200148 77.277675 \n",
       "L 379.200148 76.740988 \n",
       "L 379.200148 76.204302 \n",
       "L 379.200148 75.667615 \n",
       "L 379.200148 75.130929 \n",
       "L 379.200148 74.594242 \n",
       "L 379.200148 74.057555 \n",
       "L 379.200148 73.520868 \n",
       "L 379.200148 72.984182 \n",
       "L 379.200148 72.447496 \n",
       "L 379.200148 71.91081 \n",
       "L 379.200148 71.374122 \n",
       "L 379.200148 70.837436 \n",
       "L 379.200148 70.300749 \n",
       "L 379.200148 69.764063 \n",
       "L 379.200148 69.227375 \n",
       "L 379.200148 68.690689 \n",
       "L 379.200148 68.154003 \n",
       "L 379.200148 67.617316 \n",
       "L 379.200148 67.08063 \n",
       "L 379.200148 66.543942 \n",
       "L 379.200148 66.007256 \n",
       "L 379.200148 65.47057 \n",
       "L 379.200148 64.933884 \n",
       "L 379.200148 64.397196 \n",
       "L 379.200148 63.860509 \n",
       "L 379.200148 63.323823 \n",
       "L 379.200148 62.787137 \n",
       "L 379.200148 62.250451 \n",
       "L 379.200148 61.713763 \n",
       "L 379.200148 61.177077 \n",
       "L 379.200148 60.64039 \n",
       "L 379.200148 60.103704 \n",
       "L 379.200148 59.567018 \n",
       "L 379.200148 59.030332 \n",
       "L 379.200148 58.493642 \n",
       "L 379.200148 57.956956 \n",
       "L 379.200148 57.42027 \n",
       "L 379.200148 56.883583 \n",
       "L 379.200148 56.346897 \n",
       "L 379.200148 55.810211 \n",
       "L 379.200148 55.273525 \n",
       "L 379.200148 54.736835 \n",
       "L 379.200148 54.200152 \n",
       "L 379.200148 53.663463 \n",
       "L 379.200148 53.12678 \n",
       "L 379.200148 52.59009 \n",
       "L 379.200148 52.053404 \n",
       "L 379.200148 51.516718 \n",
       "L 379.200148 50.980032 \n",
       "L 379.200148 50.443345 \n",
       "L 379.200148 49.906656 \n",
       "L 379.200148 49.369973 \n",
       "L 379.200148 48.833283 \n",
       "L 379.200148 48.2966 \n",
       "L 379.200148 47.759911 \n",
       "L 379.200148 47.223225 \n",
       "L 379.200148 46.686538 \n",
       "L 379.200148 46.149852 \n",
       "L 379.200148 45.613166 \n",
       "L 379.200148 45.076476 \n",
       "L 379.200148 44.539793 \n",
       "L 379.200148 44.003104 \n",
       "L 379.200148 43.466418 \n",
       "L 379.200148 42.929731 \n",
       "L 379.200148 42.393045 \n",
       "L 379.200148 41.856359 \n",
       "L 379.200148 41.319673 \n",
       "L 379.200148 40.782986 \n",
       "L 379.200148 40.2463 \n",
       "L 379.200148 39.709614 \n",
       "L 379.200148 39.172924 \n",
       "L 379.200148 38.636238 \n",
       "L 379.200148 38.099552 \n",
       "L 379.200148 37.562866 \n",
       "L 379.200148 37.026179 \n",
       "L 379.200148 36.489493 \n",
       "L 379.200148 35.952807 \n",
       "L 379.200148 35.416121 \n",
       "L 379.200148 34.879434 \n",
       "L 379.200148 34.342745 \n",
       "L 379.200148 33.806059 \n",
       "L 379.200148 33.269373 \n",
       "L 379.200148 32.732689 \n",
       "L 379.200148 32.196 \n",
       "\" clip-path=\"url(#pf21ddddc07)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 38.312875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 395.432875 286.212 \n",
       "L 395.432875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 395.432875 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 38.312875 20.1 \n",
       "L 395.432875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pf21ddddc07\">\n",
       "   <rect x=\"38.312875\" y=\"20.1\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"433.74575pt\" height=\"322.539375pt\" viewBox=\"0 0 433.74575 322.539375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:10.856145</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.539375 \n",
       "L 433.74575 322.539375 \n",
       "L 433.74575 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 395.432875 286.212 \n",
       "L 395.432875 20.1 \n",
       "L 38.312875 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m40ae4131b0\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m40ae4131b0\" x=\"54.545602\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(48.429602 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m40ae4131b0\" x=\"119.476511\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(113.360511 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m40ae4131b0\" x=\"184.40742\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(178.29142 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m40ae4131b0\" x=\"249.33833\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(243.22233 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m40ae4131b0\" x=\"314.269239\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(308.153239 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m40ae4131b0\" x=\"379.200148\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(373.084148 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(213.992875 313.431375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"mc7e930518d\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc7e930518d\" x=\"38.312875\" y=\"262.950083\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 266.09952) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc7e930518d\" x=\"38.312875\" y=\"213.168254\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 216.317692) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc7e930518d\" x=\"38.312875\" y=\"163.386426\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 166.535863) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc7e930518d\" x=\"38.312875\" y=\"113.604597\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 116.754035) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc7e930518d\" x=\"38.312875\" y=\"63.822769\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 66.972206) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_13\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.036) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"mbc6658480a\" d=\"M 54.545602 -160.379952 \n",
       "L 54.545602 -159.384826 \n",
       "L 57.824941 -157.956682 \n",
       "L 61.10428 -157.104577 \n",
       "L 64.383619 -157.297684 \n",
       "L 67.662958 -158.546448 \n",
       "L 70.942296 -160.837071 \n",
       "L 74.221636 -164.135887 \n",
       "L 77.500973 -168.389675 \n",
       "L 80.780313 -173.526879 \n",
       "L 84.059653 -179.458683 \n",
       "L 87.33899 -186.079483 \n",
       "L 90.61833 -193.269593 \n",
       "L 93.89767 -200.896877 \n",
       "L 97.177007 -208.819192 \n",
       "L 100.456344 -216.888018 \n",
       "L 103.735686 -224.949543 \n",
       "L 107.015024 -232.847801 \n",
       "L 110.294361 -240.423466 \n",
       "L 113.573703 -247.402351 \n",
       "L 116.853041 -249.87583 \n",
       "L 120.132378 -250.8132 \n",
       "L 123.41172 -251.479675 \n",
       "L 126.691057 -251.940122 \n",
       "L 129.970395 -252.242095 \n",
       "L 133.249737 -252.424427 \n",
       "L 136.529069 -252.51981 \n",
       "L 139.808412 -252.551249 \n",
       "L 143.087754 -252.532269 \n",
       "L 146.367086 -252.465656 \n",
       "L 149.646428 -252.34296 \n",
       "L 152.92577 -252.140468 \n",
       "L 156.205103 -251.767025 \n",
       "L 159.484445 -246.67166 \n",
       "L 162.763787 -238.528768 \n",
       "L 166.04312 -229.528368 \n",
       "L 169.322462 -219.791261 \n",
       "L 172.601804 -209.428412 \n",
       "L 175.881137 -198.554612 \n",
       "L 179.160479 -187.288041 \n",
       "L 182.439821 -175.749671 \n",
       "L 185.719153 -164.061908 \n",
       "L 188.998496 -152.347528 \n",
       "L 192.277838 -140.728907 \n",
       "L 195.55717 -129.326965 \n",
       "L 198.836512 -118.260485 \n",
       "L 202.115855 -107.645535 \n",
       "L 205.395187 -97.59469 \n",
       "L 208.674529 -88.216303 \n",
       "L 211.953871 -79.613964 \n",
       "L 215.233204 -71.885664 \n",
       "L 218.512556 -65.122888 \n",
       "L 221.791879 -59.409977 \n",
       "L 225.071221 -54.822689 \n",
       "L 228.350563 -51.427634 \n",
       "L 231.629886 -49.280833 \n",
       "L 234.909247 -48.426675 \n",
       "L 238.18857 -48.896684 \n",
       "L 241.467912 -50.708473 \n",
       "L 244.747254 -53.864654 \n",
       "L 248.026597 -58.351721 \n",
       "L 251.305939 -64.139121 \n",
       "L 254.585262 -71.174514 \n",
       "L 257.864623 -78.933044 \n",
       "L 261.143946 -77.151271 \n",
       "L 264.423288 -76.151268 \n",
       "L 267.70263 -76.433368 \n",
       "L 270.981953 -78.02226 \n",
       "L 274.261315 -80.916803 \n",
       "L 277.540637 -85.093188 \n",
       "L 280.81998 -90.505496 \n",
       "L 284.099322 -97.086309 \n",
       "L 287.378664 -104.747052 \n",
       "L 290.658006 -113.379466 \n",
       "L 293.937329 -122.85741 \n",
       "L 297.21669 -133.038706 \n",
       "L 300.496013 -143.76666 \n",
       "L 303.775355 -154.874372 \n",
       "L 307.054697 -166.185826 \n",
       "L 310.33402 -177.520222 \n",
       "L 313.613382 -188.694733 \n",
       "L 316.892705 -199.528166 \n",
       "L 320.172047 -209.844135 \n",
       "L 323.451389 -219.474865 \n",
       "L 326.730731 -228.263477 \n",
       "L 330.010073 -236.068486 \n",
       "L 333.289396 -242.765644 \n",
       "L 336.568738 -248.250918 \n",
       "L 339.84808 -252.442629 \n",
       "L 343.127423 -255.280917 \n",
       "L 346.406765 -256.732301 \n",
       "L 349.686088 -256.789097 \n",
       "L 352.96543 -255.455117 \n",
       "L 356.244772 -252.44109 \n",
       "L 359.524114 -245.464022 \n",
       "L 362.803456 -237.942927 \n",
       "L 366.082798 -230.526636 \n",
       "L 369.362141 -223.395066 \n",
       "L 372.641463 -216.708702 \n",
       "L 375.920806 -210.600405 \n",
       "L 379.200148 -204.792367 \n",
       "L 379.200148 -205.789866 \n",
       "L 379.200148 -205.789866 \n",
       "L 375.920806 -214.342501 \n",
       "L 372.641463 -222.83439 \n",
       "L 369.362141 -230.701735 \n",
       "L 366.082798 -237.779248 \n",
       "L 362.803456 -243.928364 \n",
       "L 359.524114 -249.031378 \n",
       "L 356.244772 -253.449747 \n",
       "L 352.96543 -260.331877 \n",
       "L 349.686088 -267.146001 \n",
       "L 346.406765 -273.38389 \n",
       "L 343.127423 -278.863961 \n",
       "L 339.84808 -283.429984 \n",
       "L 336.568738 -286.9417 \n",
       "L 333.289396 -289.277538 \n",
       "L 330.010073 -290.338811 \n",
       "L 326.730731 -290.050741 \n",
       "L 323.451389 -288.363898 \n",
       "L 320.172047 -285.255012 \n",
       "L 316.892705 -280.727766 \n",
       "L 313.613382 -274.812072 \n",
       "L 310.33402 -267.563347 \n",
       "L 307.054697 -259.061324 \n",
       "L 303.775355 -249.407768 \n",
       "L 300.496013 -238.72439 \n",
       "L 297.21669 -227.150372 \n",
       "L 293.937329 -214.838684 \n",
       "L 290.658006 -201.954314 \n",
       "L 287.378664 -188.669357 \n",
       "L 284.099322 -175.161062 \n",
       "L 280.81998 -161.607903 \n",
       "L 277.540637 -148.187095 \n",
       "L 274.261315 -135.070664 \n",
       "L 270.981953 -122.42372 \n",
       "L 267.70263 -110.402102 \n",
       "L 264.423288 -99.149613 \n",
       "L 261.143946 -88.801725 \n",
       "L 257.864623 -79.933238 \n",
       "L 254.585262 -82.905605 \n",
       "L 251.305939 -87.460158 \n",
       "L 248.026597 -93.043603 \n",
       "L 244.747254 -99.54448 \n",
       "L 241.467912 -106.844728 \n",
       "L 238.18857 -114.81805 \n",
       "L 234.909247 -123.33238 \n",
       "L 231.629886 -132.252533 \n",
       "L 228.350563 -141.442656 \n",
       "L 225.071221 -150.76907 \n",
       "L 221.791879 -160.102688 \n",
       "L 218.512556 -169.321314 \n",
       "L 215.233204 -178.312211 \n",
       "L 211.953871 -186.973337 \n",
       "L 208.674529 -195.215591 \n",
       "L 205.395187 -202.963735 \n",
       "L 202.115855 -210.157359 \n",
       "L 198.836512 -216.751549 \n",
       "L 195.55717 -222.716891 \n",
       "L 192.277838 -228.039161 \n",
       "L 188.998496 -232.719005 \n",
       "L 185.719153 -236.770488 \n",
       "L 182.439821 -240.220122 \n",
       "L 179.160479 -243.105037 \n",
       "L 175.881137 -245.47125 \n",
       "L 172.601804 -247.371403 \n",
       "L 169.322462 -248.862713 \n",
       "L 166.04312 -250.005162 \n",
       "L 162.763787 -250.860429 \n",
       "L 159.484445 -251.5048 \n",
       "L 156.205103 -254.088253 \n",
       "L 152.92577 -260.249241 \n",
       "L 149.646428 -265.405343 \n",
       "L 146.367086 -269.438479 \n",
       "L 143.087754 -272.303243 \n",
       "L 139.808412 -273.975545 \n",
       "L 136.529069 -274.449389 \n",
       "L 133.249737 -273.737567 \n",
       "L 129.970395 -271.87158 \n",
       "L 126.691057 -268.902703 \n",
       "L 123.41172 -264.899881 \n",
       "L 120.132378 -259.952951 \n",
       "L 116.853041 -254.182036 \n",
       "L 113.573703 -248.921058 \n",
       "L 110.294361 -247.221788 \n",
       "L 107.015024 -245.271449 \n",
       "L 103.735686 -242.90452 \n",
       "L 100.456344 -240.082765 \n",
       "L 97.177007 -236.78155 \n",
       "L 93.89767 -232.988002 \n",
       "L 90.61833 -228.701247 \n",
       "L 87.33899 -223.931867 \n",
       "L 84.059653 -218.702935 \n",
       "L 80.780313 -213.049252 \n",
       "L 77.500973 -207.017029 \n",
       "L 74.221636 -200.663392 \n",
       "L 70.942296 -194.05449 \n",
       "L 67.662958 -187.263265 \n",
       "L 64.383619 -180.369379 \n",
       "L 61.10428 -173.456728 \n",
       "L 57.824941 -166.61646 \n",
       "L 54.545602 -160.379952 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pd199a93c5a)\">\n",
       "     <use xlink:href=\"#mbc6658480a\" x=\"0\" y=\"322.539375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m75ee91bd76\" d=\"M 54.545602 -159.384826 \n",
       "L 54.545602 -159.178551 \n",
       "L 57.824941 -157.928149 \n",
       "L 61.10428 -157.089432 \n",
       "L 64.383619 -157.286954 \n",
       "L 67.662958 -158.537819 \n",
       "L 70.942296 -160.829611 \n",
       "L 74.221636 -164.129104 \n",
       "L 77.500973 -168.38326 \n",
       "L 80.780313 -173.520612 \n",
       "L 84.059653 -179.452369 \n",
       "L 87.33899 -186.072937 \n",
       "L 90.61833 -193.262597 \n",
       "L 93.89767 -200.889156 \n",
       "L 97.177007 -208.810332 \n",
       "L 100.456344 -216.877336 \n",
       "L 103.735686 -224.935752 \n",
       "L 107.015024 -232.827884 \n",
       "L 110.294361 -240.387205 \n",
       "L 113.573703 -247.253717 \n",
       "L 116.853041 -249.819029 \n",
       "L 120.132378 -250.786165 \n",
       "L 123.41172 -251.461233 \n",
       "L 126.691057 -251.925525 \n",
       "L 129.970395 -252.229478 \n",
       "L 133.249737 -252.412806 \n",
       "L 136.529069 -252.508514 \n",
       "L 139.808412 -252.539688 \n",
       "L 143.087754 -252.519742 \n",
       "L 146.367086 -252.451067 \n",
       "L 149.646428 -252.324016 \n",
       "L 152.92577 -252.110019 \n",
       "L 156.205103 -251.664766 \n",
       "L 159.484445 -246.620917 \n",
       "L 162.763787 -238.508705 \n",
       "L 166.04312 -229.516274 \n",
       "L 169.322462 -219.782739 \n",
       "L 172.601804 -209.421881 \n",
       "L 175.881137 -198.549331 \n",
       "L 179.160479 -187.283602 \n",
       "L 182.439821 -175.745832 \n",
       "L 185.719153 -164.058501 \n",
       "L 188.998496 -152.344442 \n",
       "L 192.277838 -140.72607 \n",
       "L 195.55717 -129.324306 \n",
       "L 198.836512 -118.257969 \n",
       "L 202.115855 -107.643126 \n",
       "L 205.395187 -97.59234 \n",
       "L 208.674529 -88.214 \n",
       "L 211.953871 -79.61165 \n",
       "L 215.233204 -71.883326 \n",
       "L 218.512556 -65.120514 \n",
       "L 221.791879 -59.407508 \n",
       "L 225.071221 -54.820126 \n",
       "L 228.350563 -51.424881 \n",
       "L 231.629886 -49.277842 \n",
       "L 234.909247 -48.423375 \n",
       "L 238.18857 -48.892933 \n",
       "L 241.467912 -50.704058 \n",
       "L 244.747254 -53.859242 \n",
       "L 248.026597 -58.344575 \n",
       "L 251.305939 -64.128498 \n",
       "L 254.585262 -71.153435 \n",
       "L 257.864623 -78.727499 \n",
       "L 261.143946 -77.130038 \n",
       "L 264.423288 -76.140491 \n",
       "L 267.70263 -76.426081 \n",
       "L 270.981953 -78.016681 \n",
       "L 274.261315 -80.912233 \n",
       "L 277.540637 -85.08926 \n",
       "L 280.81998 -90.502018 \n",
       "L 284.099322 -97.08314 \n",
       "L 287.378664 -104.744096 \n",
       "L 290.658006 -113.376665 \n",
       "L 293.937329 -122.854716 \n",
       "L 297.21669 -133.036071 \n",
       "L 300.496013 -143.764049 \n",
       "L 303.775355 -154.871761 \n",
       "L 307.054697 -166.183156 \n",
       "L 310.33402 -177.517469 \n",
       "L 313.613382 -188.69186 \n",
       "L 316.892705 -199.525116 \n",
       "L 320.172047 -209.840848 \n",
       "L 323.451389 -219.471269 \n",
       "L 326.730731 -228.259466 \n",
       "L 330.010073 -236.063923 \n",
       "L 333.289396 -242.760316 \n",
       "L 336.568738 -248.244513 \n",
       "L 339.84808 -252.434633 \n",
       "L 343.127423 -255.270413 \n",
       "L 346.406765 -256.717431 \n",
       "L 349.686088 -256.765224 \n",
       "L 352.96543 -255.404819 \n",
       "L 356.244772 -252.236779 \n",
       "L 359.524114 -245.395854 \n",
       "L 362.803456 -237.901805 \n",
       "L 366.082798 -230.492625 \n",
       "L 369.362141 -223.361305 \n",
       "L 372.641463 -216.668508 \n",
       "L 375.920806 -210.53531 \n",
       "L 379.200148 -204.586435 \n",
       "L 379.200148 -204.792367 \n",
       "L 379.200148 -204.792367 \n",
       "L 375.920806 -210.600405 \n",
       "L 372.641463 -216.708702 \n",
       "L 369.362141 -223.395066 \n",
       "L 366.082798 -230.526636 \n",
       "L 362.803456 -237.942927 \n",
       "L 359.524114 -245.464022 \n",
       "L 356.244772 -252.44109 \n",
       "L 352.96543 -255.455117 \n",
       "L 349.686088 -256.789097 \n",
       "L 346.406765 -256.732301 \n",
       "L 343.127423 -255.280917 \n",
       "L 339.84808 -252.442629 \n",
       "L 336.568738 -248.250918 \n",
       "L 333.289396 -242.765644 \n",
       "L 330.010073 -236.068486 \n",
       "L 326.730731 -228.263477 \n",
       "L 323.451389 -219.474865 \n",
       "L 320.172047 -209.844135 \n",
       "L 316.892705 -199.528166 \n",
       "L 313.613382 -188.694733 \n",
       "L 310.33402 -177.520222 \n",
       "L 307.054697 -166.185826 \n",
       "L 303.775355 -154.874372 \n",
       "L 300.496013 -143.76666 \n",
       "L 297.21669 -133.038706 \n",
       "L 293.937329 -122.85741 \n",
       "L 290.658006 -113.379466 \n",
       "L 287.378664 -104.747052 \n",
       "L 284.099322 -97.086309 \n",
       "L 280.81998 -90.505496 \n",
       "L 277.540637 -85.093188 \n",
       "L 274.261315 -80.916803 \n",
       "L 270.981953 -78.02226 \n",
       "L 267.70263 -76.433368 \n",
       "L 264.423288 -76.151268 \n",
       "L 261.143946 -77.151271 \n",
       "L 257.864623 -78.933044 \n",
       "L 254.585262 -71.174514 \n",
       "L 251.305939 -64.139121 \n",
       "L 248.026597 -58.351721 \n",
       "L 244.747254 -53.864654 \n",
       "L 241.467912 -50.708473 \n",
       "L 238.18857 -48.896684 \n",
       "L 234.909247 -48.426675 \n",
       "L 231.629886 -49.280833 \n",
       "L 228.350563 -51.427634 \n",
       "L 225.071221 -54.822689 \n",
       "L 221.791879 -59.409977 \n",
       "L 218.512556 -65.122888 \n",
       "L 215.233204 -71.885664 \n",
       "L 211.953871 -79.613964 \n",
       "L 208.674529 -88.216303 \n",
       "L 205.395187 -97.59469 \n",
       "L 202.115855 -107.645535 \n",
       "L 198.836512 -118.260485 \n",
       "L 195.55717 -129.326965 \n",
       "L 192.277838 -140.728907 \n",
       "L 188.998496 -152.347528 \n",
       "L 185.719153 -164.061908 \n",
       "L 182.439821 -175.749671 \n",
       "L 179.160479 -187.288041 \n",
       "L 175.881137 -198.554612 \n",
       "L 172.601804 -209.428412 \n",
       "L 169.322462 -219.791261 \n",
       "L 166.04312 -229.528368 \n",
       "L 162.763787 -238.528768 \n",
       "L 159.484445 -246.67166 \n",
       "L 156.205103 -251.767025 \n",
       "L 152.92577 -252.140468 \n",
       "L 149.646428 -252.34296 \n",
       "L 146.367086 -252.465656 \n",
       "L 143.087754 -252.532269 \n",
       "L 139.808412 -252.551249 \n",
       "L 136.529069 -252.51981 \n",
       "L 133.249737 -252.424427 \n",
       "L 129.970395 -252.242095 \n",
       "L 126.691057 -251.940122 \n",
       "L 123.41172 -251.479675 \n",
       "L 120.132378 -250.8132 \n",
       "L 116.853041 -249.87583 \n",
       "L 113.573703 -247.402351 \n",
       "L 110.294361 -240.423466 \n",
       "L 107.015024 -232.847801 \n",
       "L 103.735686 -224.949543 \n",
       "L 100.456344 -216.888018 \n",
       "L 97.177007 -208.819192 \n",
       "L 93.89767 -200.896877 \n",
       "L 90.61833 -193.269593 \n",
       "L 87.33899 -186.079483 \n",
       "L 84.059653 -179.458683 \n",
       "L 80.780313 -173.526879 \n",
       "L 77.500973 -168.389675 \n",
       "L 74.221636 -164.135887 \n",
       "L 70.942296 -160.837071 \n",
       "L 67.662958 -158.546448 \n",
       "L 64.383619 -157.297684 \n",
       "L 61.10428 -157.104577 \n",
       "L 57.824941 -157.956682 \n",
       "L 54.545602 -159.384826 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pd199a93c5a)\">\n",
       "     <use xlink:href=\"#m75ee91bd76\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"m8c2313e60f\" d=\"M 54.545602 -160.586227 \n",
       "L 54.545602 -160.379952 \n",
       "L 57.824941 -166.61646 \n",
       "L 61.10428 -173.456728 \n",
       "L 64.383619 -180.369379 \n",
       "L 67.662958 -187.263265 \n",
       "L 70.942296 -194.05449 \n",
       "L 74.221636 -200.663392 \n",
       "L 77.500973 -207.017029 \n",
       "L 80.780313 -213.049252 \n",
       "L 84.059653 -218.702935 \n",
       "L 87.33899 -223.931867 \n",
       "L 90.61833 -228.701247 \n",
       "L 93.89767 -232.988002 \n",
       "L 97.177007 -236.78155 \n",
       "L 100.456344 -240.082765 \n",
       "L 103.735686 -242.90452 \n",
       "L 107.015024 -245.271449 \n",
       "L 110.294361 -247.221788 \n",
       "L 113.573703 -248.921058 \n",
       "L 116.853041 -254.182036 \n",
       "L 120.132378 -259.952951 \n",
       "L 123.41172 -264.899881 \n",
       "L 126.691057 -268.902703 \n",
       "L 129.970395 -271.87158 \n",
       "L 133.249737 -273.737567 \n",
       "L 136.529069 -274.449389 \n",
       "L 139.808412 -273.975545 \n",
       "L 143.087754 -272.303243 \n",
       "L 146.367086 -269.438479 \n",
       "L 149.646428 -265.405343 \n",
       "L 152.92577 -260.249241 \n",
       "L 156.205103 -254.088253 \n",
       "L 159.484445 -251.5048 \n",
       "L 162.763787 -250.860429 \n",
       "L 166.04312 -250.005162 \n",
       "L 169.322462 -248.862713 \n",
       "L 172.601804 -247.371403 \n",
       "L 175.881137 -245.47125 \n",
       "L 179.160479 -243.105037 \n",
       "L 182.439821 -240.220122 \n",
       "L 185.719153 -236.770488 \n",
       "L 188.998496 -232.719005 \n",
       "L 192.277838 -228.039161 \n",
       "L 195.55717 -222.716891 \n",
       "L 198.836512 -216.751549 \n",
       "L 202.115855 -210.157359 \n",
       "L 205.395187 -202.963735 \n",
       "L 208.674529 -195.215591 \n",
       "L 211.953871 -186.973337 \n",
       "L 215.233204 -178.312211 \n",
       "L 218.512556 -169.321314 \n",
       "L 221.791879 -160.102688 \n",
       "L 225.071221 -150.76907 \n",
       "L 228.350563 -141.442656 \n",
       "L 231.629886 -132.252533 \n",
       "L 234.909247 -123.33238 \n",
       "L 238.18857 -114.81805 \n",
       "L 241.467912 -106.844728 \n",
       "L 244.747254 -99.54448 \n",
       "L 248.026597 -93.043603 \n",
       "L 251.305939 -87.460158 \n",
       "L 254.585262 -82.905605 \n",
       "L 257.864623 -79.933238 \n",
       "L 261.143946 -88.801725 \n",
       "L 264.423288 -99.149613 \n",
       "L 267.70263 -110.402102 \n",
       "L 270.981953 -122.42372 \n",
       "L 274.261315 -135.070664 \n",
       "L 277.540637 -148.187095 \n",
       "L 280.81998 -161.607903 \n",
       "L 284.099322 -175.161062 \n",
       "L 287.378664 -188.669357 \n",
       "L 290.658006 -201.954314 \n",
       "L 293.937329 -214.838684 \n",
       "L 297.21669 -227.150372 \n",
       "L 300.496013 -238.72439 \n",
       "L 303.775355 -249.407768 \n",
       "L 307.054697 -259.061324 \n",
       "L 310.33402 -267.563347 \n",
       "L 313.613382 -274.812072 \n",
       "L 316.892705 -280.727766 \n",
       "L 320.172047 -285.255012 \n",
       "L 323.451389 -288.363898 \n",
       "L 326.730731 -290.050741 \n",
       "L 330.010073 -290.338811 \n",
       "L 333.289396 -289.277538 \n",
       "L 336.568738 -286.9417 \n",
       "L 339.84808 -283.429984 \n",
       "L 343.127423 -278.863961 \n",
       "L 346.406765 -273.38389 \n",
       "L 349.686088 -267.146001 \n",
       "L 352.96543 -260.331877 \n",
       "L 356.244772 -253.449747 \n",
       "L 359.524114 -249.031378 \n",
       "L 362.803456 -243.928364 \n",
       "L 366.082798 -237.779248 \n",
       "L 369.362141 -230.701735 \n",
       "L 372.641463 -222.83439 \n",
       "L 375.920806 -214.342501 \n",
       "L 379.200148 -205.789866 \n",
       "L 379.200148 -205.995798 \n",
       "L 379.200148 -205.995798 \n",
       "L 375.920806 -214.407596 \n",
       "L 372.641463 -222.874585 \n",
       "L 369.362141 -230.735496 \n",
       "L 366.082798 -237.813258 \n",
       "L 362.803456 -243.969487 \n",
       "L 359.524114 -249.099545 \n",
       "L 356.244772 -253.654058 \n",
       "L 352.96543 -260.382176 \n",
       "L 349.686088 -267.169875 \n",
       "L 346.406765 -273.39876 \n",
       "L 343.127423 -278.874465 \n",
       "L 339.84808 -283.437981 \n",
       "L 336.568738 -286.948106 \n",
       "L 333.289396 -289.282864 \n",
       "L 330.010073 -290.343375 \n",
       "L 326.730731 -290.054753 \n",
       "L 323.451389 -288.367495 \n",
       "L 320.172047 -285.2583 \n",
       "L 316.892705 -280.730817 \n",
       "L 313.613382 -274.81495 \n",
       "L 310.33402 -267.5661 \n",
       "L 307.054697 -259.063995 \n",
       "L 303.775355 -249.410388 \n",
       "L 300.496013 -238.727001 \n",
       "L 297.21669 -227.153007 \n",
       "L 293.937329 -214.841378 \n",
       "L 290.658006 -201.957115 \n",
       "L 287.378664 -188.672312 \n",
       "L 284.099322 -175.164231 \n",
       "L 280.81998 -161.611387 \n",
       "L 277.540637 -148.191023 \n",
       "L 274.261315 -135.075234 \n",
       "L 270.981953 -122.429299 \n",
       "L 267.70263 -110.409389 \n",
       "L 264.423288 -99.16039 \n",
       "L 261.143946 -88.822959 \n",
       "L 257.864623 -80.138784 \n",
       "L 254.585262 -82.926684 \n",
       "L 251.305939 -87.470781 \n",
       "L 248.026597 -93.050736 \n",
       "L 244.747254 -99.549904 \n",
       "L 241.467912 -106.849143 \n",
       "L 238.18857 -114.8218 \n",
       "L 234.909247 -123.335692 \n",
       "L 231.629886 -132.255512 \n",
       "L 228.350563 -141.44541 \n",
       "L 225.071221 -150.771657 \n",
       "L 221.791879 -160.105151 \n",
       "L 218.512556 -169.323688 \n",
       "L 215.233204 -178.314543 \n",
       "L 211.953871 -186.975645 \n",
       "L 208.674529 -195.217905 \n",
       "L 205.395187 -202.966086 \n",
       "L 202.115855 -210.159774 \n",
       "L 198.836512 -216.754068 \n",
       "L 195.55717 -222.719544 \n",
       "L 192.277838 -228.041998 \n",
       "L 188.998496 -232.722091 \n",
       "L 185.719153 -236.773897 \n",
       "L 182.439821 -240.223965 \n",
       "L 179.160479 -243.109476 \n",
       "L 175.881137 -245.476531 \n",
       "L 172.601804 -247.377934 \n",
       "L 169.322462 -248.871235 \n",
       "L 166.04312 -250.017257 \n",
       "L 162.763787 -250.880493 \n",
       "L 159.484445 -251.555542 \n",
       "L 156.205103 -254.190512 \n",
       "L 152.92577 -260.279689 \n",
       "L 149.646428 -265.424287 \n",
       "L 146.367086 -269.453067 \n",
       "L 143.087754 -272.315769 \n",
       "L 139.808412 -273.987105 \n",
       "L 136.529069 -274.460684 \n",
       "L 133.249737 -273.749188 \n",
       "L 129.970395 -271.884198 \n",
       "L 126.691057 -268.917301 \n",
       "L 123.41172 -264.918323 \n",
       "L 120.132378 -259.979985 \n",
       "L 116.853041 -254.238837 \n",
       "L 113.573703 -249.069692 \n",
       "L 110.294361 -247.258048 \n",
       "L 107.015024 -245.291365 \n",
       "L 103.735686 -242.918312 \n",
       "L 100.456344 -240.093445 \n",
       "L 97.177007 -236.79041 \n",
       "L 93.89767 -232.995723 \n",
       "L 90.61833 -228.708244 \n",
       "L 87.33899 -223.938413 \n",
       "L 84.059653 -218.709249 \n",
       "L 80.780313 -213.055522 \n",
       "L 77.500973 -207.023444 \n",
       "L 74.221636 -200.670175 \n",
       "L 70.942296 -194.06195 \n",
       "L 67.662958 -187.271893 \n",
       "L 64.383619 -180.380114 \n",
       "L 61.10428 -173.471867 \n",
       "L 57.824941 -166.644981 \n",
       "L 54.545602 -160.586227 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pd199a93c5a)\">\n",
       "     <use xlink:href=\"#m8c2313e60f\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_12\">\n",
       "    <defs>\n",
       "     <path id=\"m0430a0303d\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pd199a93c5a)\">\n",
       "     <use xlink:href=\"#m0430a0303d\" x=\"356.349693\" y=\"69.757789\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m0430a0303d\" x=\"157.258364\" y=\"70.783531\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m0430a0303d\" x=\"114.255683\" y=\"73.531673\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m0430a0303d\" x=\"257.864623\" y=\"243.111397\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m0430a0303d\" x=\"54.545602\" y=\"162.660108\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m0430a0303d\" x=\"379.200148\" y=\"117.256157\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_13\">\n",
       "    <path d=\"M 54.545602 162.656986 \n",
       "L 57.824941 160.252807 \n",
       "L 61.10428 157.258726 \n",
       "L 64.383619 153.705844 \n",
       "L 67.662958 149.634522 \n",
       "L 70.942296 145.093594 \n",
       "L 74.221636 140.139736 \n",
       "L 77.500973 134.836023 \n",
       "L 80.780313 129.251308 \n",
       "L 84.059653 123.458566 \n",
       "L 87.33899 117.5337 \n",
       "L 90.61833 111.553955 \n",
       "L 93.89767 105.596935 \n",
       "L 97.177007 99.739004 \n",
       "L 100.456344 94.053984 \n",
       "L 103.735686 88.612343 \n",
       "L 107.015024 83.47975 \n",
       "L 110.294361 78.716748 \n",
       "L 113.573703 74.37767 \n",
       "L 116.853041 70.510442 \n",
       "L 120.132378 67.1563 \n",
       "L 123.41172 64.349597 \n",
       "L 126.691057 62.117962 \n",
       "L 129.970395 60.482538 \n",
       "L 133.249737 59.458378 \n",
       "L 136.529069 59.054776 \n",
       "L 139.808412 59.275978 \n",
       "L 143.087754 60.121619 \n",
       "L 146.367086 61.587308 \n",
       "L 149.646428 63.665224 \n",
       "L 152.92577 66.344521 \n",
       "L 156.205103 69.611736 \n",
       "L 159.484445 73.451145 \n",
       "L 162.763787 77.844776 \n",
       "L 166.04312 82.77261 \n",
       "L 169.322462 88.212387 \n",
       "L 172.601804 94.139467 \n",
       "L 175.881137 100.526444 \n",
       "L 179.160479 107.342838 \n",
       "L 182.439821 114.554478 \n",
       "L 185.719153 122.123177 \n",
       "L 188.998496 130.006105 \n",
       "L 192.277838 138.155342 \n",
       "L 195.55717 146.517449 \n",
       "L 198.836512 155.033358 \n",
       "L 202.115855 163.637928 \n",
       "L 205.395187 172.260159 \n",
       "L 208.674529 180.823425 \n",
       "L 211.953871 189.245725 \n",
       "L 215.233204 197.440437 \n",
       "L 218.512556 205.317277 \n",
       "L 221.791879 212.783049 \n",
       "L 225.071221 219.74349 \n",
       "L 228.350563 226.10423 \n",
       "L 231.629886 231.772692 \n",
       "L 234.909247 236.659848 \n",
       "L 238.18857 240.682008 \n",
       "L 241.467912 243.762775 \n",
       "L 244.747254 245.834802 \n",
       "L 248.026597 246.841713 \n",
       "L 251.305939 246.739735 \n",
       "L 254.585262 245.499315 \n",
       "L 257.864623 243.106234 \n",
       "L 261.143946 239.562877 \n",
       "L 264.423288 234.888934 \n",
       "L 267.70263 229.12164 \n",
       "L 270.981953 222.316385 \n",
       "L 274.261315 214.545642 \n",
       "L 277.540637 205.899234 \n",
       "L 280.81998 196.482676 \n",
       "L 284.099322 186.415689 \n",
       "L 287.378664 175.831171 \n",
       "L 290.658006 164.872485 \n",
       "L 293.937329 153.691328 \n",
       "L 297.21669 142.444833 \n",
       "L 300.496013 131.293847 \n",
       "L 303.775355 120.398304 \n",
       "L 307.054697 109.915798 \n",
       "L 310.33402 99.997589 \n",
       "L 313.613382 90.785971 \n",
       "L 316.892705 82.411409 \n",
       "L 320.172047 74.989801 \n",
       "L 323.451389 68.619993 \n",
       "L 326.730731 63.382266 \n",
       "L 330.010073 59.335726 \n",
       "L 333.289396 56.517785 \n",
       "L 336.568738 54.943065 \n",
       "L 339.84808 54.603068 \n",
       "L 343.127423 55.466935 \n",
       "L 346.406765 57.48128 \n",
       "L 349.686088 60.571826 \n",
       "L 352.96543 64.645878 \n",
       "L 356.244772 69.593956 \n",
       "L 359.524114 75.291675 \n",
       "L 362.803456 81.603729 \n",
       "L 366.082798 88.386433 \n",
       "L 369.362141 95.490975 \n",
       "L 372.641463 102.767829 \n",
       "L 375.920806 110.067922 \n",
       "L 379.200148 117.248258 \n",
       "\" clip-path=\"url(#pd199a93c5a)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <path d=\"M 54.545602 162.660108 \n",
       "L 57.824941 156.585859 \n",
       "L 61.10428 150.53415 \n",
       "L 64.383619 144.527424 \n",
       "L 67.662958 138.588041 \n",
       "L 70.942296 132.738115 \n",
       "L 74.221636 126.999544 \n",
       "L 77.500973 121.393838 \n",
       "L 80.780313 115.942085 \n",
       "L 84.059653 110.664905 \n",
       "L 87.33899 105.582322 \n",
       "L 90.61833 100.713735 \n",
       "L 93.89767 96.077839 \n",
       "L 97.177007 91.69256 \n",
       "L 100.456344 87.574979 \n",
       "L 103.735686 83.741321 \n",
       "L 107.015024 80.206841 \n",
       "L 110.294361 76.985808 \n",
       "L 113.573703 74.091426 \n",
       "L 116.853041 71.535823 \n",
       "L 120.132378 69.329998 \n",
       "L 123.41172 67.483753 \n",
       "L 126.691057 66.005693 \n",
       "L 129.970395 64.903184 \n",
       "L 133.249737 64.182308 \n",
       "L 136.529069 63.847859 \n",
       "L 139.808412 63.903323 \n",
       "L 143.087754 64.350828 \n",
       "L 146.367086 65.191165 \n",
       "L 149.646428 66.42377 \n",
       "L 152.92577 68.046695 \n",
       "L 156.205103 70.056606 \n",
       "L 159.484445 72.448827 \n",
       "L 162.763787 75.217251 \n",
       "L 166.04312 78.35443 \n",
       "L 169.322462 81.851523 \n",
       "L 172.601804 85.698314 \n",
       "L 175.881137 89.883228 \n",
       "L 179.160479 94.393308 \n",
       "L 182.439821 99.2143 \n",
       "L 185.719153 104.330525 \n",
       "L 188.998496 109.725041 \n",
       "L 192.277838 115.37951 \n",
       "L 195.55717 121.274348 \n",
       "L 198.836512 127.388595 \n",
       "L 202.115855 133.699966 \n",
       "L 205.395187 140.184885 \n",
       "L 208.674529 146.81848 \n",
       "L 211.953871 153.574502 \n",
       "L 215.233204 160.425435 \n",
       "L 218.512556 167.342417 \n",
       "L 221.791879 174.295191 \n",
       "L 225.071221 181.252237 \n",
       "L 228.350563 188.180644 \n",
       "L 231.629886 195.045955 \n",
       "L 234.909247 201.812624 \n",
       "L 238.18857 208.443311 \n",
       "L 241.467912 214.899549 \n",
       "L 244.747254 221.141244 \n",
       "L 248.026597 227.126903 \n",
       "L 251.305939 232.813643 \n",
       "L 254.585262 238.15704 \n",
       "L 257.864623 243.111397 \n",
       "L 261.143946 247.629607 \n",
       "L 264.423288 251.663388 \n",
       "L 267.70263 255.163316 \n",
       "L 270.981953 258.07914 \n",
       "L 274.261315 260.359871 \n",
       "L 277.540637 261.954234 \n",
       "L 280.81998 262.811039 \n",
       "L 284.099322 262.879724 \n",
       "L 287.378664 262.111022 \n",
       "L 290.658006 260.457849 \n",
       "L 293.937329 257.876277 \n",
       "L 297.21669 254.326677 \n",
       "L 300.496013 249.775661 \n",
       "L 303.775355 244.197153 \n",
       "L 307.054697 237.575131 \n",
       "L 310.33402 229.905938 \n",
       "L 313.613382 221.200802 \n",
       "L 316.892705 211.489646 \n",
       "L 320.172047 200.824276 \n",
       "L 323.451389 189.282613 \n",
       "L 326.730731 176.973103 \n",
       "L 330.010073 164.039145 \n",
       "L 333.289396 150.663776 \n",
       "L 336.568738 137.074162 \n",
       "L 339.84808 123.545168 \n",
       "L 343.127423 110.402347 \n",
       "L 346.406765 98.023059 \n",
       "L 349.686088 86.83449 \n",
       "L 352.96543 77.308394 \n",
       "L 356.244772 69.951507 \n",
       "L 359.524114 65.288223 \n",
       "L 362.803456 63.836566 \n",
       "L 366.082798 66.074135 \n",
       "L 369.362141 72.393536 \n",
       "L 372.641463 83.046847 \n",
       "L 375.920806 98.079418 \n",
       "L 379.200148 117.256157 \n",
       "\" clip-path=\"url(#pd199a93c5a)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 38.312875 262.950083 \n",
       "L 38.312875 63.822769 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 54.545602 286.212 \n",
       "L 379.200148 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_14\">\n",
       "    <!-- N=2, psi=1.96 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(186.986125 14.1) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2c\" d=\"M 569 0 \n",
       "L 569 641 \n",
       "L 1209 641 \n",
       "L 1209 0 \n",
       "Q 1209 -353 1084 -570 \n",
       "Q 959 -788 688 -906 \n",
       "L 531 -666 \n",
       "Q 709 -588 793 -436 \n",
       "Q 878 -284 888 0 \n",
       "L 569 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-2c\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"214.013672\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"241.796875\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"297.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"347.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"369.628906\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"428.027344\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"483.642578\"/>\n",
       "     <use xlink:href=\"#ArialMT-39\" x=\"511.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-36\" x=\"567.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_15\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#m0430a0303d\" x=\"55.032875\" y=\"220.007125\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_15\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 223.087125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_16\">\n",
       "     <path d=\"M 46.232875 232.591125 \n",
       "L 55.032875 232.591125 \n",
       "L 63.832875 232.591125 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_16\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 235.671125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 46.232875 249.828125 \n",
       "L 63.832875 249.828125 \n",
       "L 63.832875 243.668125 \n",
       "L 46.232875 243.668125 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 249.828125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 46.232875 263.996125 \n",
       "L 63.832875 263.996125 \n",
       "L 63.832875 257.836125 \n",
       "L 46.232875 257.836125 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 263.996125) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_17\">\n",
       "     <path d=\"M 46.232875 273.463 \n",
       "L 55.032875 273.463 \n",
       "L 63.832875 273.463 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 276.543) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_18\">\n",
       "      <defs>\n",
       "       <path id=\"mf47db8571b\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf47db8571b\" x=\"395.432875\" y=\"240.171496\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_20\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 243.320933) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf47db8571b\" x=\"395.432875\" y=\"182.788089\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_21\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 185.937526) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf47db8571b\" x=\"395.432875\" y=\"125.404682\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 128.55412) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf47db8571b\" x=\"395.432875\" y=\"68.021275\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 71.170713) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_24\">\n",
       "     <!-- Maximum Upper Interval -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(424.63775 205.43475) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4d\" d=\"M 475 0 \n",
       "L 475 4581 \n",
       "L 1388 4581 \n",
       "L 2472 1338 \n",
       "Q 2622 884 2691 659 \n",
       "Q 2769 909 2934 1394 \n",
       "L 4031 4581 \n",
       "L 4847 4581 \n",
       "L 4847 0 \n",
       "L 4263 0 \n",
       "L 4263 3834 \n",
       "L 2931 0 \n",
       "L 2384 0 \n",
       "L 1059 3900 \n",
       "L 1059 0 \n",
       "L 475 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-78\" d=\"M 47 0 \n",
       "L 1259 1725 \n",
       "L 138 3319 \n",
       "L 841 3319 \n",
       "L 1350 2541 \n",
       "Q 1494 2319 1581 2169 \n",
       "Q 1719 2375 1834 2534 \n",
       "L 2394 3319 \n",
       "L 3066 3319 \n",
       "L 1919 1756 \n",
       "L 3153 0 \n",
       "L 2463 0 \n",
       "L 1781 1031 \n",
       "L 1600 1309 \n",
       "L 728 0 \n",
       "L 47 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-55\" d=\"M 3500 4581 \n",
       "L 4106 4581 \n",
       "L 4106 1934 \n",
       "Q 4106 1244 3950 837 \n",
       "Q 3794 431 3386 176 \n",
       "Q 2978 -78 2316 -78 \n",
       "Q 1672 -78 1262 144 \n",
       "Q 853 366 678 786 \n",
       "Q 503 1206 503 1934 \n",
       "L 503 4581 \n",
       "L 1109 4581 \n",
       "L 1109 1938 \n",
       "Q 1109 1341 1220 1058 \n",
       "Q 1331 775 1601 622 \n",
       "Q 1872 469 2263 469 \n",
       "Q 2931 469 3215 772 \n",
       "Q 3500 1075 3500 1938 \n",
       "L 3500 4581 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4d\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "      <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"188.916016\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"211.132812\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"294.433594\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"350.048828\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"433.349609\"/>\n",
       "      <use xlink:href=\"#ArialMT-55\" x=\"461.132812\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" x=\"533.349609\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" x=\"588.964844\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"644.580078\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"700.195312\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"733.496094\"/>\n",
       "      <use xlink:href=\"#ArialMT-49\" x=\"761.279297\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"789.0625\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.677734\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"872.460938\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"928.076172\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"961.376953\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"1011.376953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6c\" x=\"1066.992188\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_22\">\n",
       "    <path d=\"M 54.545602 181.385198 \n",
       "L 57.824941 174.284742 \n",
       "L 61.10428 166.488648 \n",
       "L 64.383619 158.597907 \n",
       "L 67.662958 150.716407 \n",
       "L 70.942296 142.940055 \n",
       "L 74.221636 135.360146 \n",
       "L 77.500973 128.060524 \n",
       "L 80.780313 121.117509 \n",
       "L 84.059653 114.597313 \n",
       "L 87.33899 108.553892 \n",
       "L 90.61833 103.028335 \n",
       "L 93.89767 98.048496 \n",
       "L 97.177007 93.628088 \n",
       "L 100.456344 89.767829 \n",
       "L 103.735686 86.4548 \n",
       "L 107.015024 83.662687 \n",
       "L 110.294361 81.349692 \n",
       "L 113.573703 79.330088 \n",
       "L 116.853041 73.297902 \n",
       "L 120.132378 66.701497 \n",
       "L 123.41172 61.048522 \n",
       "L 126.691057 56.47531 \n",
       "L 129.970395 53.083835 \n",
       "L 133.249737 50.952322 \n",
       "L 136.529069 50.138911 \n",
       "L 139.808412 50.679287 \n",
       "L 143.087754 52.587887 \n",
       "L 146.367086 55.857842 \n",
       "L 149.646428 60.461753 \n",
       "L 152.92577 66.348081 \n",
       "L 156.205103 73.383125 \n",
       "L 159.484445 76.390021 \n",
       "L 162.763787 77.219221 \n",
       "L 166.04312 78.298974 \n",
       "L 169.322462 79.714943 \n",
       "L 172.601804 81.536234 \n",
       "L 175.881137 83.829976 \n",
       "L 179.160479 86.660097 \n",
       "L 182.439821 90.085282 \n",
       "L 185.719153 94.156626 \n",
       "L 188.998496 98.915095 \n",
       "L 192.277838 104.389522 \n",
       "L 195.55717 110.594574 \n",
       "L 198.836512 117.529609 \n",
       "L 202.115855 125.177067 \n",
       "L 205.395187 133.502072 \n",
       "L 208.674529 142.45214 \n",
       "L 211.953871 151.957114 \n",
       "L 215.233204 161.930021 \n",
       "L 218.512556 172.268129 \n",
       "L 221.791879 182.854005 \n",
       "L 225.071221 193.558136 \n",
       "L 228.350563 204.240294 \n",
       "L 231.629886 214.752558 \n",
       "L 234.909247 224.94182 \n",
       "L 238.18857 234.652718 \n",
       "L 241.467912 243.730733 \n",
       "L 244.747254 252.025195 \n",
       "L 248.026597 259.392094 \n",
       "L 251.305939 265.697039 \n",
       "L 254.585262 270.813464 \n",
       "L 257.864623 274.116 \n",
       "L 261.143946 264.016076 \n",
       "L 264.423288 252.218908 \n",
       "L 267.70263 239.374644 \n",
       "L 270.981953 225.637609 \n",
       "L 274.261315 211.171923 \n",
       "L 277.540637 196.155675 \n",
       "L 280.81998 180.777866 \n",
       "L 284.099322 165.235539 \n",
       "L 287.378664 149.731965 \n",
       "L 290.658006 134.472047 \n",
       "L 293.937329 119.659527 \n",
       "L 297.21669 105.492428 \n",
       "L 300.496013 92.160833 \n",
       "L 303.775355 79.841236 \n",
       "L 307.054697 68.694493 \n",
       "L 310.33402 58.861579 \n",
       "L 313.613382 50.460739 \n",
       "L 316.892705 43.585042 \n",
       "L 320.172047 38.299772 \n",
       "L 323.451389 34.640987 \n",
       "L 326.730731 32.614705 \n",
       "L 330.010073 32.196 \n",
       "L 333.289396 33.329897 \n",
       "L 336.568738 35.932256 \n",
       "L 339.84808 39.891408 \n",
       "L 343.127423 45.069302 \n",
       "L 346.406765 51.306272 \n",
       "L 349.686088 58.424114 \n",
       "L 352.96543 66.21557 \n",
       "L 356.244772 74.103999 \n",
       "L 359.524114 79.226538 \n",
       "L 362.803456 85.136644 \n",
       "L 366.082798 92.239323 \n",
       "L 369.362141 100.398183 \n",
       "L 372.641463 109.453238 \n",
       "L 375.920806 119.214345 \n",
       "L 379.200148 129.041314 \n",
       "\" clip-path=\"url(#pd199a93c5a)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_23\">\n",
       "    <path d=\"M 330.010073 68.021275 \n",
       "L 330.010073 67.659404 \n",
       "L 330.010073 67.297532 \n",
       "L 330.010073 66.935661 \n",
       "L 330.010073 66.573789 \n",
       "L 330.010073 66.211918 \n",
       "L 330.010073 65.850046 \n",
       "L 330.010073 65.488175 \n",
       "L 330.010073 65.126303 \n",
       "L 330.010073 64.764432 \n",
       "L 330.010073 64.40256 \n",
       "L 330.010073 64.040689 \n",
       "L 330.010073 63.678818 \n",
       "L 330.010073 63.316946 \n",
       "L 330.010073 62.955075 \n",
       "L 330.010073 62.593203 \n",
       "L 330.010073 62.231332 \n",
       "L 330.010073 61.86946 \n",
       "L 330.010073 61.507589 \n",
       "L 330.010073 61.145717 \n",
       "L 330.010073 60.783846 \n",
       "L 330.010073 60.421974 \n",
       "L 330.010073 60.060103 \n",
       "L 330.010073 59.698232 \n",
       "L 330.010073 59.33636 \n",
       "L 330.010073 58.974488 \n",
       "L 330.010073 58.612617 \n",
       "L 330.010073 58.250745 \n",
       "L 330.010073 57.888874 \n",
       "L 330.010073 57.527003 \n",
       "L 330.010073 57.165131 \n",
       "L 330.010073 56.803259 \n",
       "L 330.010073 56.441388 \n",
       "L 330.010073 56.079517 \n",
       "L 330.010073 55.717645 \n",
       "L 330.010073 55.355773 \n",
       "L 330.010073 54.993902 \n",
       "L 330.010073 54.632031 \n",
       "L 330.010073 54.270159 \n",
       "L 330.010073 53.908288 \n",
       "L 330.010073 53.546416 \n",
       "L 330.010073 53.184545 \n",
       "L 330.010073 52.822673 \n",
       "L 330.010073 52.460802 \n",
       "L 330.010073 52.098931 \n",
       "L 330.010073 51.737059 \n",
       "L 330.010073 51.375188 \n",
       "L 330.010073 51.013317 \n",
       "L 330.010073 50.651445 \n",
       "L 330.010073 50.289572 \n",
       "L 330.010073 49.927703 \n",
       "L 330.010073 49.56583 \n",
       "L 330.010073 49.203958 \n",
       "L 330.010073 48.842087 \n",
       "L 330.010073 48.480216 \n",
       "L 330.010073 48.118345 \n",
       "L 330.010073 47.756473 \n",
       "L 330.010073 47.394602 \n",
       "L 330.010073 47.032731 \n",
       "L 330.010073 46.670859 \n",
       "L 330.010073 46.308986 \n",
       "L 330.010073 45.947117 \n",
       "L 330.010073 45.585244 \n",
       "L 330.010073 45.223374 \n",
       "L 330.010073 44.861501 \n",
       "L 330.010073 44.49963 \n",
       "L 330.010073 44.137758 \n",
       "L 330.010073 43.775887 \n",
       "L 330.010073 43.414016 \n",
       "L 330.010073 43.052144 \n",
       "L 330.010073 42.690273 \n",
       "L 330.010073 42.3284 \n",
       "L 330.010073 41.966531 \n",
       "L 330.010073 41.604657 \n",
       "L 330.010073 41.242788 \n",
       "L 330.010073 40.880915 \n",
       "L 330.010073 40.519044 \n",
       "L 330.010073 40.157172 \n",
       "L 330.010073 39.795301 \n",
       "L 330.010073 39.43343 \n",
       "L 330.010073 39.071557 \n",
       "L 330.010073 38.709687 \n",
       "L 330.010073 38.347814 \n",
       "L 330.010073 37.985944 \n",
       "L 330.010073 37.624071 \n",
       "L 330.010073 37.262202 \n",
       "L 330.010073 36.900329 \n",
       "L 330.010073 36.538456 \n",
       "L 330.010073 36.176586 \n",
       "L 330.010073 35.814717 \n",
       "L 330.010073 35.452844 \n",
       "L 330.010073 35.09097 \n",
       "L 330.010073 34.729101 \n",
       "L 330.010073 34.367228 \n",
       "L 330.010073 34.005358 \n",
       "L 330.010073 33.643485 \n",
       "L 330.010073 33.281616 \n",
       "L 330.010073 32.919743 \n",
       "L 330.010073 32.557873 \n",
       "L 330.010073 32.196 \n",
       "\" clip-path=\"url(#pd199a93c5a)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 38.312875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 395.432875 286.212 \n",
       "L 395.432875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 38.312875 286.212 \n",
       "L 395.432875 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 38.312875 20.1 \n",
       "L 395.432875 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pd199a93c5a\">\n",
       "   <rect x=\"38.312875\" y=\"20.1\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"438.639375pt\" height=\"322.539375pt\" viewBox=\"0 0 438.639375 322.539375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:10.924714</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.539375 \n",
       "L 438.639375 322.539375 \n",
       "L 438.639375 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 400.3265 286.212 \n",
       "L 400.3265 20.1 \n",
       "L 43.2065 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m723535ff5a\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m723535ff5a\" x=\"59.439227\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(53.323227 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m723535ff5a\" x=\"124.370136\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(118.254136 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m723535ff5a\" x=\"189.301045\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(183.185045 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m723535ff5a\" x=\"254.231955\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(248.115955 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m723535ff5a\" x=\"319.162864\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(313.046864 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m723535ff5a\" x=\"384.093773\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.977773 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(218.8865 313.431375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"mc3dde596d7\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc3dde596d7\" x=\"43.2065\" y=\"252.704936\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 255.854374) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc3dde596d7\" x=\"43.2065\" y=\"211.525961\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 214.675399) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc3dde596d7\" x=\"43.2065\" y=\"170.346986\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 173.496423) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc3dde596d7\" x=\"43.2065\" y=\"129.168011\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 132.317448) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc3dde596d7\" x=\"43.2065\" y=\"87.989035\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 91.138473) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc3dde596d7\" x=\"43.2065\" y=\"46.81006\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(30.012875 49.959498) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_14\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.036) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"mbd92f534f3\" d=\"M 59.439227 -194.3856 \n",
       "L 59.439227 -193.564407 \n",
       "L 62.718566 -192.924339 \n",
       "L 65.997905 -192.758663 \n",
       "L 69.277244 -193.441812 \n",
       "L 72.556583 -194.968834 \n",
       "L 75.835921 -197.314329 \n",
       "L 79.115261 -200.436689 \n",
       "L 82.394598 -204.278383 \n",
       "L 85.673938 -208.767744 \n",
       "L 88.953278 -213.820241 \n",
       "L 92.232615 -219.339306 \n",
       "L 95.511955 -225.21899 \n",
       "L 98.791295 -231.345981 \n",
       "L 102.070632 -237.601634 \n",
       "L 105.349969 -243.865887 \n",
       "L 108.629311 -250.017955 \n",
       "L 111.908649 -255.939311 \n",
       "L 115.187986 -261.513185 \n",
       "L 118.467328 -266.531107 \n",
       "L 121.746666 -267.800549 \n",
       "L 125.026003 -267.79322 \n",
       "L 128.305345 -267.583511 \n",
       "L 131.584682 -267.25837 \n",
       "L 134.86402 -266.893383 \n",
       "L 138.143362 -266.558482 \n",
       "L 141.422694 -266.32001 \n",
       "L 144.702037 -266.236284 \n",
       "L 147.981379 -266.357221 \n",
       "L 151.260711 -266.722336 \n",
       "L 154.540053 -267.358972 \n",
       "L 157.819395 -268.277931 \n",
       "L 161.098728 -269.428626 \n",
       "L 164.37807 -267.130446 \n",
       "L 167.657412 -262.771554 \n",
       "L 170.936745 -258.147756 \n",
       "L 174.216087 -253.358853 \n",
       "L 177.495429 -248.485909 \n",
       "L 180.774762 -243.602411 \n",
       "L 184.054104 -238.772855 \n",
       "L 187.333446 -234.051535 \n",
       "L 190.612778 -229.481334 \n",
       "L 193.892121 -225.092507 \n",
       "L 197.171463 -220.902089 \n",
       "L 200.450795 -216.913722 \n",
       "L 203.730137 -213.117638 \n",
       "L 207.00948 -209.491293 \n",
       "L 210.288812 -206.000406 \n",
       "L 213.568154 -202.600176 \n",
       "L 216.847496 -199.237205 \n",
       "L 220.126829 -195.851452 \n",
       "L 223.406181 -192.378703 \n",
       "L 226.685504 -188.753341 \n",
       "L 229.964846 -184.911083 \n",
       "L 233.244188 -180.792207 \n",
       "L 236.523511 -176.344503 \n",
       "L 239.802872 -171.526274 \n",
       "L 243.082195 -166.309863 \n",
       "L 246.361537 -160.683538 \n",
       "L 249.640879 -154.654486 \n",
       "L 252.920222 -148.250107 \n",
       "L 256.199564 -141.519806 \n",
       "L 259.478887 -134.530049 \n",
       "L 262.758248 -127.01008 \n",
       "L 266.037571 -113.607099 \n",
       "L 269.316913 -100.522235 \n",
       "L 272.596255 -88.379186 \n",
       "L 275.875578 -77.436386 \n",
       "L 279.15494 -67.936514 \n",
       "L 282.434262 -60.10314 \n",
       "L 285.713605 -54.135272 \n",
       "L 288.992947 -50.20054 \n",
       "L 292.272289 -48.428618 \n",
       "L 295.551631 -48.905254 \n",
       "L 298.830954 -51.669249 \n",
       "L 302.110315 -56.706818 \n",
       "L 305.389638 -63.950454 \n",
       "L 308.66898 -73.278848 \n",
       "L 311.948322 -84.516693 \n",
       "L 315.227645 -97.438728 \n",
       "L 318.507007 -111.772597 \n",
       "L 321.78633 -127.207045 \n",
       "L 325.065672 -143.396092 \n",
       "L 328.345014 -159.968662 \n",
       "L 331.624356 -176.524778 \n",
       "L 334.903698 -192.448292 \n",
       "L 338.183021 -206.819002 \n",
       "L 341.462363 -220.287635 \n",
       "L 344.741705 -232.773386 \n",
       "L 348.021048 -243.967742 \n",
       "L 351.30039 -253.578613 \n",
       "L 354.579713 -261.348136 \n",
       "L 357.859055 -267.029202 \n",
       "L 361.138397 -270.295608 \n",
       "L 364.417739 -270.818397 \n",
       "L 367.697081 -268.877053 \n",
       "L 370.976423 -264.78322 \n",
       "L 374.255766 -258.73959 \n",
       "L 377.535088 -250.982466 \n",
       "L 380.814431 -241.775857 \n",
       "L 384.093773 -231.14768 \n",
       "L 384.093773 -231.971818 \n",
       "L 384.093773 -231.971818 \n",
       "L 380.814431 -243.382398 \n",
       "L 377.535088 -253.343812 \n",
       "L 374.255766 -261.352871 \n",
       "L 370.976423 -267.208139 \n",
       "L 367.697081 -270.787453 \n",
       "L 364.417739 -272.035727 \n",
       "L 361.138397 -271.122128 \n",
       "L 357.859055 -268.310589 \n",
       "L 354.579713 -263.372058 \n",
       "L 351.30039 -256.210934 \n",
       "L 348.021048 -246.923499 \n",
       "L 344.741705 -235.692509 \n",
       "L 341.462363 -222.757301 \n",
       "L 338.183021 -208.421989 \n",
       "L 334.903698 -193.27244 \n",
       "L 331.624356 -178.654482 \n",
       "L 328.345014 -164.365952 \n",
       "L 325.065672 -150.496643 \n",
       "L 321.78633 -137.32927 \n",
       "L 318.507007 -125.131624 \n",
       "L 315.227645 -114.133747 \n",
       "L 311.948322 -104.523473 \n",
       "L 308.66898 -96.445792 \n",
       "L 305.389638 -89.997165 \n",
       "L 302.110315 -85.225816 \n",
       "L 298.830954 -82.134062 \n",
       "L 295.551631 -80.682044 \n",
       "L 292.272289 -80.791101 \n",
       "L 288.992947 -82.348209 \n",
       "L 285.713605 -85.214407 \n",
       "L 282.434262 -89.229076 \n",
       "L 279.15494 -94.216771 \n",
       "L 275.875578 -99.99541 \n",
       "L 272.596255 -106.381949 \n",
       "L 269.316913 -113.197175 \n",
       "L 266.037571 -120.277943 \n",
       "L 262.758248 -127.835878 \n",
       "L 259.478887 -141.67967 \n",
       "L 256.199564 -156.092081 \n",
       "L 252.920222 -170.472713 \n",
       "L 249.640879 -184.598483 \n",
       "L 246.361537 -198.271798 \n",
       "L 243.082195 -211.318971 \n",
       "L 239.802872 -223.591223 \n",
       "L 236.523511 -234.966056 \n",
       "L 233.244188 -245.346927 \n",
       "L 229.964846 -254.663753 \n",
       "L 226.685504 -262.871675 \n",
       "L 223.406181 -269.949873 \n",
       "L 220.126829 -275.900229 \n",
       "L 216.847496 -280.745022 \n",
       "L 213.568154 -284.525315 \n",
       "L 210.288812 -287.298328 \n",
       "L 207.00948 -289.135254 \n",
       "L 203.730137 -290.118883 \n",
       "L 200.450795 -290.341065 \n",
       "L 197.171463 -289.900382 \n",
       "L 193.892121 -288.899744 \n",
       "L 190.612778 -287.444196 \n",
       "L 187.333446 -285.638512 \n",
       "L 184.054104 -283.585179 \n",
       "L 180.774762 -281.382502 \n",
       "L 177.495429 -279.122467 \n",
       "L 174.216087 -276.889222 \n",
       "L 170.936745 -274.758155 \n",
       "L 167.657412 -272.794891 \n",
       "L 164.37807 -271.067728 \n",
       "L 161.098728 -271.326357 \n",
       "L 157.819395 -274.900034 \n",
       "L 154.540053 -278.038884 \n",
       "L 151.260711 -280.614974 \n",
       "L 147.981379 -282.556519 \n",
       "L 144.702037 -283.806084 \n",
       "L 141.422694 -284.31889 \n",
       "L 138.143362 -284.064375 \n",
       "L 134.86402 -283.027038 \n",
       "L 131.584682 -281.20854 \n",
       "L 128.305345 -278.626378 \n",
       "L 125.026003 -275.317856 \n",
       "L 121.746666 -271.347628 \n",
       "L 118.467328 -267.785459 \n",
       "L 115.187986 -267.117108 \n",
       "L 111.908649 -266.182918 \n",
       "L 108.629311 -264.826207 \n",
       "L 105.349969 -263.000707 \n",
       "L 102.070632 -260.67518 \n",
       "L 98.791295 -257.832235 \n",
       "L 95.511955 -254.46829 \n",
       "L 92.232615 -250.592629 \n",
       "L 88.953278 -246.228188 \n",
       "L 85.673938 -241.41029 \n",
       "L 82.394598 -236.186133 \n",
       "L 79.115261 -230.613693 \n",
       "L 75.835921 -224.759972 \n",
       "L 72.556583 -218.698329 \n",
       "L 69.277244 -212.508426 \n",
       "L 65.997905 -206.273347 \n",
       "L 62.718566 -200.081858 \n",
       "L 59.439227 -194.3856 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p4719db0ad1)\">\n",
       "     <use xlink:href=\"#mbd92f534f3\" x=\"0\" y=\"322.539375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"mde3b40e6b4\" d=\"M 59.439227 -193.564407 \n",
       "L 59.439227 -193.393489 \n",
       "L 62.718566 -192.900717 \n",
       "L 65.997905 -192.746125 \n",
       "L 69.277244 -193.432922 \n",
       "L 72.556583 -194.961691 \n",
       "L 75.835921 -197.308148 \n",
       "L 79.115261 -200.431068 \n",
       "L 82.394598 -204.273066 \n",
       "L 85.673938 -208.76255 \n",
       "L 88.953278 -213.815013 \n",
       "L 92.232615 -219.333882 \n",
       "L 95.511955 -225.213188 \n",
       "L 98.791295 -231.339579 \n",
       "L 102.070632 -237.594288 \n",
       "L 105.349969 -243.857029 \n",
       "L 108.629311 -250.006512 \n",
       "L 111.908649 -255.922783 \n",
       "L 115.187986 -261.483087 \n",
       "L 118.467328 -266.408003 \n",
       "L 121.746666 -267.75337 \n",
       "L 125.026003 -267.770752 \n",
       "L 128.305345 -267.568177 \n",
       "L 131.584682 -267.246226 \n",
       "L 134.86402 -266.882879 \n",
       "L 138.143362 -266.548801 \n",
       "L 141.422694 -266.310594 \n",
       "L 144.702037 -266.226638 \n",
       "L 147.981379 -266.346759 \n",
       "L 151.260711 -266.710141 \n",
       "L 154.540053 -267.343118 \n",
       "L 157.819395 -268.252423 \n",
       "L 161.098728 -269.343123 \n",
       "L 164.37807 -267.087839 \n",
       "L 167.657412 -262.754665 \n",
       "L 170.936745 -258.137553 \n",
       "L 174.216087 -253.351651 \n",
       "L 177.495429 -248.480374 \n",
       "L 180.774762 -243.597924 \n",
       "L 184.054104 -238.769072 \n",
       "L 187.333446 -234.048246 \n",
       "L 190.612778 -229.478413 \n",
       "L 193.892121 -225.089851 \n",
       "L 197.171463 -220.899635 \n",
       "L 200.450795 -216.911415 \n",
       "L 203.730137 -213.115434 \n",
       "L 207.00948 -209.489163 \n",
       "L 210.288812 -205.998315 \n",
       "L 213.568154 -202.598105 \n",
       "L 216.847496 -199.235124 \n",
       "L 220.126829 -195.849336 \n",
       "L 223.406181 -192.376514 \n",
       "L 226.685504 -188.751053 \n",
       "L 229.964846 -184.908648 \n",
       "L 233.244188 -180.789586 \n",
       "L 236.523511 -176.341607 \n",
       "L 239.802872 -171.523024 \n",
       "L 243.082195 -166.306093 \n",
       "L 246.361537 -160.679032 \n",
       "L 249.640879 -154.648821 \n",
       "L 252.920222 -148.242479 \n",
       "L 256.199564 -141.508172 \n",
       "L 259.478887 -134.506408 \n",
       "L 262.758248 -126.839839 \n",
       "L 266.037571 -113.581778 \n",
       "L 269.316913 -100.508883 \n",
       "L 272.596255 -88.36978 \n",
       "L 275.875578 -77.428866 \n",
       "L 279.15494 -67.930054 \n",
       "L 282.434262 -60.097328 \n",
       "L 285.713605 -54.129814 \n",
       "L 288.992947 -50.195278 \n",
       "L 292.272289 -48.423375 \n",
       "L 295.551631 -48.899913 \n",
       "L 298.830954 -51.663672 \n",
       "L 302.110315 -56.700868 \n",
       "L 305.389638 -63.943935 \n",
       "L 308.66898 -73.271544 \n",
       "L 311.948322 -84.508211 \n",
       "L 315.227645 -97.428596 \n",
       "L 318.507007 -111.759913 \n",
       "L 321.78633 -127.190316 \n",
       "L 325.065672 -143.372284 \n",
       "L 328.345014 -159.930432 \n",
       "L 331.624356 -176.447924 \n",
       "L 334.903698 -192.277805 \n",
       "L 338.183021 -206.719405 \n",
       "L 341.462363 -220.220781 \n",
       "L 344.741705 -232.716408 \n",
       "L 348.021048 -243.911444 \n",
       "L 351.30039 -253.515698 \n",
       "L 354.579713 -261.267561 \n",
       "L 357.859055 -266.908279 \n",
       "L 361.138397 -270.125468 \n",
       "L 364.417739 -270.692185 \n",
       "L 367.697081 -268.792072 \n",
       "L 370.976423 -264.7152 \n",
       "L 374.255766 -258.676238 \n",
       "L 377.535088 -250.912715 \n",
       "L 380.814431 -241.676456 \n",
       "L 384.093773 -230.977193 \n",
       "L 384.093773 -231.14768 \n",
       "L 384.093773 -231.14768 \n",
       "L 380.814431 -241.775857 \n",
       "L 377.535088 -250.982466 \n",
       "L 374.255766 -258.73959 \n",
       "L 370.976423 -264.78322 \n",
       "L 367.697081 -268.877053 \n",
       "L 364.417739 -270.818397 \n",
       "L 361.138397 -270.295608 \n",
       "L 357.859055 -267.029202 \n",
       "L 354.579713 -261.348136 \n",
       "L 351.30039 -253.578613 \n",
       "L 348.021048 -243.967742 \n",
       "L 344.741705 -232.773386 \n",
       "L 341.462363 -220.287635 \n",
       "L 338.183021 -206.819002 \n",
       "L 334.903698 -192.448292 \n",
       "L 331.624356 -176.524778 \n",
       "L 328.345014 -159.968662 \n",
       "L 325.065672 -143.396092 \n",
       "L 321.78633 -127.207045 \n",
       "L 318.507007 -111.772597 \n",
       "L 315.227645 -97.438728 \n",
       "L 311.948322 -84.516693 \n",
       "L 308.66898 -73.278848 \n",
       "L 305.389638 -63.950454 \n",
       "L 302.110315 -56.706818 \n",
       "L 298.830954 -51.669249 \n",
       "L 295.551631 -48.905254 \n",
       "L 292.272289 -48.428618 \n",
       "L 288.992947 -50.20054 \n",
       "L 285.713605 -54.135272 \n",
       "L 282.434262 -60.10314 \n",
       "L 279.15494 -67.936514 \n",
       "L 275.875578 -77.436386 \n",
       "L 272.596255 -88.379186 \n",
       "L 269.316913 -100.522235 \n",
       "L 266.037571 -113.607099 \n",
       "L 262.758248 -127.01008 \n",
       "L 259.478887 -134.530049 \n",
       "L 256.199564 -141.519806 \n",
       "L 252.920222 -148.250107 \n",
       "L 249.640879 -154.654486 \n",
       "L 246.361537 -160.683538 \n",
       "L 243.082195 -166.309863 \n",
       "L 239.802872 -171.526274 \n",
       "L 236.523511 -176.344503 \n",
       "L 233.244188 -180.792207 \n",
       "L 229.964846 -184.911083 \n",
       "L 226.685504 -188.753341 \n",
       "L 223.406181 -192.378703 \n",
       "L 220.126829 -195.851452 \n",
       "L 216.847496 -199.237205 \n",
       "L 213.568154 -202.600176 \n",
       "L 210.288812 -206.000406 \n",
       "L 207.00948 -209.491293 \n",
       "L 203.730137 -213.117638 \n",
       "L 200.450795 -216.913722 \n",
       "L 197.171463 -220.902089 \n",
       "L 193.892121 -225.092507 \n",
       "L 190.612778 -229.481334 \n",
       "L 187.333446 -234.051535 \n",
       "L 184.054104 -238.772855 \n",
       "L 180.774762 -243.602411 \n",
       "L 177.495429 -248.485909 \n",
       "L 174.216087 -253.358853 \n",
       "L 170.936745 -258.147756 \n",
       "L 167.657412 -262.771554 \n",
       "L 164.37807 -267.130446 \n",
       "L 161.098728 -269.428626 \n",
       "L 157.819395 -268.277931 \n",
       "L 154.540053 -267.358972 \n",
       "L 151.260711 -266.722336 \n",
       "L 147.981379 -266.357221 \n",
       "L 144.702037 -266.236284 \n",
       "L 141.422694 -266.32001 \n",
       "L 138.143362 -266.558482 \n",
       "L 134.86402 -266.893383 \n",
       "L 131.584682 -267.25837 \n",
       "L 128.305345 -267.583511 \n",
       "L 125.026003 -267.79322 \n",
       "L 121.746666 -267.800549 \n",
       "L 118.467328 -266.531107 \n",
       "L 115.187986 -261.513185 \n",
       "L 111.908649 -255.939311 \n",
       "L 108.629311 -250.017955 \n",
       "L 105.349969 -243.865887 \n",
       "L 102.070632 -237.601634 \n",
       "L 98.791295 -231.345981 \n",
       "L 95.511955 -225.21899 \n",
       "L 92.232615 -219.339306 \n",
       "L 88.953278 -213.820241 \n",
       "L 85.673938 -208.767744 \n",
       "L 82.394598 -204.278383 \n",
       "L 79.115261 -200.436689 \n",
       "L 75.835921 -197.314329 \n",
       "L 72.556583 -194.968834 \n",
       "L 69.277244 -193.441812 \n",
       "L 65.997905 -192.758663 \n",
       "L 62.718566 -192.924339 \n",
       "L 59.439227 -193.564407 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p4719db0ad1)\">\n",
       "     <use xlink:href=\"#mde3b40e6b4\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"m1de3979466\" d=\"M 59.439227 -194.556519 \n",
       "L 59.439227 -194.3856 \n",
       "L 62.718566 -200.081858 \n",
       "L 65.997905 -206.273347 \n",
       "L 69.277244 -212.508426 \n",
       "L 72.556583 -218.698329 \n",
       "L 75.835921 -224.759972 \n",
       "L 79.115261 -230.613693 \n",
       "L 82.394598 -236.186133 \n",
       "L 85.673938 -241.41029 \n",
       "L 88.953278 -246.228188 \n",
       "L 92.232615 -250.592629 \n",
       "L 95.511955 -254.46829 \n",
       "L 98.791295 -257.832235 \n",
       "L 102.070632 -260.67518 \n",
       "L 105.349969 -263.000707 \n",
       "L 108.629311 -264.826207 \n",
       "L 111.908649 -266.182918 \n",
       "L 115.187986 -267.117108 \n",
       "L 118.467328 -267.785459 \n",
       "L 121.746666 -271.347628 \n",
       "L 125.026003 -275.317856 \n",
       "L 128.305345 -278.626378 \n",
       "L 131.584682 -281.20854 \n",
       "L 134.86402 -283.027038 \n",
       "L 138.143362 -284.064375 \n",
       "L 141.422694 -284.31889 \n",
       "L 144.702037 -283.806084 \n",
       "L 147.981379 -282.556519 \n",
       "L 151.260711 -280.614974 \n",
       "L 154.540053 -278.038884 \n",
       "L 157.819395 -274.900034 \n",
       "L 161.098728 -271.326357 \n",
       "L 164.37807 -271.067728 \n",
       "L 167.657412 -272.794891 \n",
       "L 170.936745 -274.758155 \n",
       "L 174.216087 -276.889222 \n",
       "L 177.495429 -279.122467 \n",
       "L 180.774762 -281.382502 \n",
       "L 184.054104 -283.585179 \n",
       "L 187.333446 -285.638512 \n",
       "L 190.612778 -287.444196 \n",
       "L 193.892121 -288.899744 \n",
       "L 197.171463 -289.900382 \n",
       "L 200.450795 -290.341065 \n",
       "L 203.730137 -290.118883 \n",
       "L 207.00948 -289.135254 \n",
       "L 210.288812 -287.298328 \n",
       "L 213.568154 -284.525315 \n",
       "L 216.847496 -280.745022 \n",
       "L 220.126829 -275.900229 \n",
       "L 223.406181 -269.949873 \n",
       "L 226.685504 -262.871675 \n",
       "L 229.964846 -254.663753 \n",
       "L 233.244188 -245.346927 \n",
       "L 236.523511 -234.966056 \n",
       "L 239.802872 -223.591223 \n",
       "L 243.082195 -211.318971 \n",
       "L 246.361537 -198.271798 \n",
       "L 249.640879 -184.598483 \n",
       "L 252.920222 -170.472713 \n",
       "L 256.199564 -156.092081 \n",
       "L 259.478887 -141.67967 \n",
       "L 262.758248 -127.835878 \n",
       "L 266.037571 -120.277943 \n",
       "L 269.316913 -113.197175 \n",
       "L 272.596255 -106.381949 \n",
       "L 275.875578 -99.99541 \n",
       "L 279.15494 -94.216771 \n",
       "L 282.434262 -89.229076 \n",
       "L 285.713605 -85.214407 \n",
       "L 288.992947 -82.348209 \n",
       "L 292.272289 -80.791101 \n",
       "L 295.551631 -80.682044 \n",
       "L 298.830954 -82.134062 \n",
       "L 302.110315 -85.225816 \n",
       "L 305.389638 -89.997165 \n",
       "L 308.66898 -96.445792 \n",
       "L 311.948322 -104.523473 \n",
       "L 315.227645 -114.133747 \n",
       "L 318.507007 -125.131624 \n",
       "L 321.78633 -137.32927 \n",
       "L 325.065672 -150.496643 \n",
       "L 328.345014 -164.365952 \n",
       "L 331.624356 -178.654482 \n",
       "L 334.903698 -193.27244 \n",
       "L 338.183021 -208.421989 \n",
       "L 341.462363 -222.757301 \n",
       "L 344.741705 -235.692509 \n",
       "L 348.021048 -246.923499 \n",
       "L 351.30039 -256.210934 \n",
       "L 354.579713 -263.372058 \n",
       "L 357.859055 -268.310589 \n",
       "L 361.138397 -271.122128 \n",
       "L 364.417739 -272.035727 \n",
       "L 367.697081 -270.787453 \n",
       "L 370.976423 -267.208139 \n",
       "L 374.255766 -261.352871 \n",
       "L 377.535088 -253.343812 \n",
       "L 380.814431 -243.382398 \n",
       "L 384.093773 -231.971818 \n",
       "L 384.093773 -232.142305 \n",
       "L 384.093773 -232.142305 \n",
       "L 380.814431 -243.481799 \n",
       "L 377.535088 -253.413563 \n",
       "L 374.255766 -261.416223 \n",
       "L 370.976423 -267.276159 \n",
       "L 367.697081 -270.872435 \n",
       "L 364.417739 -272.161939 \n",
       "L 361.138397 -271.292268 \n",
       "L 357.859055 -268.431511 \n",
       "L 354.579713 -263.452633 \n",
       "L 351.30039 -256.27385 \n",
       "L 348.021048 -246.979797 \n",
       "L 344.741705 -235.749487 \n",
       "L 341.462363 -222.824156 \n",
       "L 338.183021 -208.521586 \n",
       "L 334.903698 -193.442922 \n",
       "L 331.624356 -178.731336 \n",
       "L 328.345014 -164.404183 \n",
       "L 325.065672 -150.520451 \n",
       "L 321.78633 -137.346 \n",
       "L 318.507007 -125.144309 \n",
       "L 315.227645 -114.143899 \n",
       "L 311.948322 -104.531956 \n",
       "L 308.66898 -96.453097 \n",
       "L 305.389638 -90.003684 \n",
       "L 302.110315 -85.231765 \n",
       "L 298.830954 -82.139639 \n",
       "L 295.551631 -80.687385 \n",
       "L 292.272289 -80.796343 \n",
       "L 288.992947 -82.353471 \n",
       "L 285.713605 -85.219866 \n",
       "L 282.434262 -89.234888 \n",
       "L 279.15494 -94.223231 \n",
       "L 275.875578 -100.00293 \n",
       "L 272.596255 -106.391355 \n",
       "L 269.316913 -113.210537 \n",
       "L 266.037571 -120.303263 \n",
       "L 262.758248 -128.006119 \n",
       "L 259.478887 -141.703311 \n",
       "L 256.199564 -156.103715 \n",
       "L 252.920222 -170.480341 \n",
       "L 249.640879 -184.604148 \n",
       "L 246.361537 -198.276309 \n",
       "L 243.082195 -211.322737 \n",
       "L 239.802872 -223.594473 \n",
       "L 236.523511 -234.96895 \n",
       "L 233.244188 -245.349553 \n",
       "L 229.964846 -254.666186 \n",
       "L 226.685504 -262.873963 \n",
       "L 223.406181 -269.95206 \n",
       "L 220.126829 -275.902347 \n",
       "L 216.847496 -280.747104 \n",
       "L 213.568154 -284.527387 \n",
       "L 210.288812 -287.300414 \n",
       "L 207.00948 -289.137384 \n",
       "L 203.730137 -290.121085 \n",
       "L 200.450795 -290.343375 \n",
       "L 197.171463 -289.902841 \n",
       "L 193.892121 -288.902402 \n",
       "L 190.612778 -287.447119 \n",
       "L 187.333446 -285.641799 \n",
       "L 184.054104 -283.588961 \n",
       "L 180.774762 -281.38699 \n",
       "L 177.495429 -279.128001 \n",
       "L 174.216087 -276.896426 \n",
       "L 170.936745 -274.768358 \n",
       "L 167.657412 -272.81178 \n",
       "L 164.37807 -271.110335 \n",
       "L 161.098728 -271.41186 \n",
       "L 157.819395 -274.925542 \n",
       "L 154.540053 -278.054738 \n",
       "L 151.260711 -280.627169 \n",
       "L 147.981379 -282.56698 \n",
       "L 144.702037 -283.81573 \n",
       "L 141.422694 -284.328306 \n",
       "L 138.143362 -284.074057 \n",
       "L 134.86402 -283.037542 \n",
       "L 131.584682 -281.220685 \n",
       "L 128.305345 -278.641712 \n",
       "L 125.026003 -275.340324 \n",
       "L 121.746666 -271.394807 \n",
       "L 118.467328 -267.908563 \n",
       "L 115.187986 -267.147206 \n",
       "L 111.908649 -266.199445 \n",
       "L 108.629311 -264.837649 \n",
       "L 105.349969 -263.009564 \n",
       "L 102.070632 -260.682527 \n",
       "L 98.791295 -257.838637 \n",
       "L 95.511955 -254.474087 \n",
       "L 92.232615 -250.598054 \n",
       "L 88.953278 -246.233418 \n",
       "L 85.673938 -241.415484 \n",
       "L 82.394598 -236.191447 \n",
       "L 79.115261 -230.619314 \n",
       "L 75.835921 -224.766153 \n",
       "L 72.556583 -218.705472 \n",
       "L 69.277244 -212.517316 \n",
       "L 65.997905 -206.285879 \n",
       "L 62.718566 -200.10547 \n",
       "L 59.439227 -194.556519 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p4719db0ad1)\">\n",
       "     <use xlink:href=\"#m1de3979466\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_13\">\n",
       "    <defs>\n",
       "     <path id=\"mb0e9a39cdf\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p4719db0ad1)\">\n",
       "     <use xlink:href=\"#mb0e9a39cdf\" x=\"361.243318\" y=\"51.719443\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb0e9a39cdf\" x=\"162.151989\" y=\"52.567926\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb0e9a39cdf\" x=\"119.149308\" y=\"54.841158\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb0e9a39cdf\" x=\"262.758248\" y=\"195.115621\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb0e9a39cdf\" x=\"59.439227\" y=\"128.567208\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb0e9a39cdf\" x=\"384.093773\" y=\"91.009565\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb0e9a39cdf\" x=\"334.903698\" y=\"129.707933\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <path d=\"M 59.439227 128.564371 \n",
       "L 62.718566 126.036279 \n",
       "L 65.997905 123.023373 \n",
       "L 69.277244 119.564256 \n",
       "L 72.556583 115.705793 \n",
       "L 75.835921 111.502225 \n",
       "L 79.115261 107.014184 \n",
       "L 82.394598 102.307117 \n",
       "L 85.673938 97.450358 \n",
       "L 88.953278 92.515159 \n",
       "L 92.232615 87.573407 \n",
       "L 95.511955 82.695736 \n",
       "L 98.791295 77.950267 \n",
       "L 102.070632 73.400968 \n",
       "L 105.349969 69.106079 \n",
       "L 108.629311 65.117294 \n",
       "L 111.908649 61.478261 \n",
       "L 115.187986 58.224228 \n",
       "L 118.467328 55.381092 \n",
       "L 121.746666 52.965287 \n",
       "L 125.026003 50.983837 \n",
       "L 128.305345 49.434431 \n",
       "L 131.584682 48.30592 \n",
       "L 134.86402 47.579165 \n",
       "L 138.143362 47.227946 \n",
       "L 141.422694 47.219925 \n",
       "L 144.702037 47.518191 \n",
       "L 147.981379 48.082505 \n",
       "L 151.260711 48.87072 \n",
       "L 154.540053 49.840447 \n",
       "L 157.819395 50.950392 \n",
       "L 161.098728 52.161883 \n",
       "L 164.37807 53.440288 \n",
       "L 167.657412 54.756152 \n",
       "L 170.936745 56.08642 \n",
       "L 174.216087 57.415337 \n",
       "L 177.495429 58.735188 \n",
       "L 180.774762 60.046919 \n",
       "L 184.054104 61.360358 \n",
       "L 187.333446 62.694351 \n",
       "L 190.612778 64.076609 \n",
       "L 193.892121 65.543248 \n",
       "L 197.171463 67.138138 \n",
       "L 200.450795 68.91198 \n",
       "L 203.730137 70.921116 \n",
       "L 207.00948 73.226103 \n",
       "L 210.288812 75.89001 \n",
       "L 213.568154 78.976628 \n",
       "L 216.847496 82.548262 \n",
       "L 220.126829 86.663535 \n",
       "L 223.406181 91.375088 \n",
       "L 226.685504 96.726867 \n",
       "L 229.964846 102.751958 \n",
       "L 233.244188 109.469805 \n",
       "L 236.523511 116.884095 \n",
       "L 239.802872 124.980626 \n",
       "L 243.082195 133.724958 \n",
       "L 246.361537 143.061707 \n",
       "L 249.640879 152.912891 \n",
       "L 252.920222 163.177965 \n",
       "L 256.199564 173.733431 \n",
       "L 259.478887 184.434516 \n",
       "L 262.758248 195.116396 \n",
       "L 266.037571 205.596854 \n",
       "L 269.316913 215.67967 \n",
       "L 272.596255 225.158807 \n",
       "L 275.875578 233.823477 \n",
       "L 279.15494 241.462733 \n",
       "L 282.434262 247.873267 \n",
       "L 285.713605 252.864535 \n",
       "L 288.992947 256.265 \n",
       "L 292.272289 257.929516 \n",
       "L 295.551631 257.745726 \n",
       "L 298.830954 255.637719 \n",
       "L 302.110315 251.573058 \n",
       "L 305.389638 245.565566 \n",
       "L 308.66898 237.677055 \n",
       "L 311.948322 228.019292 \n",
       "L 315.227645 216.753132 \n",
       "L 318.507007 204.087264 \n",
       "L 321.78633 190.271217 \n",
       "L 325.065672 175.593007 \n",
       "L 328.345014 160.372068 \n",
       "L 331.624356 144.949745 \n",
       "L 334.903698 129.679009 \n",
       "L 338.183021 114.918879 \n",
       "L 341.462363 101.016907 \n",
       "L 344.741705 88.306426 \n",
       "L 348.021048 77.093754 \n",
       "L 351.30039 67.644601 \n",
       "L 354.579713 60.179278 \n",
       "L 357.859055 54.86948 \n",
       "L 361.138397 51.830507 \n",
       "L 364.417739 51.112313 \n",
       "L 367.697081 52.707122 \n",
       "L 370.976423 56.543695 \n",
       "L 374.255766 62.493145 \n",
       "L 377.535088 70.376236 \n",
       "L 380.814431 79.960247 \n",
       "L 384.093773 90.979626 \n",
       "\" clip-path=\"url(#p4719db0ad1)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 59.439227 128.567208 \n",
       "L 62.718566 123.542658 \n",
       "L 65.997905 118.536751 \n",
       "L 69.277244 113.568054 \n",
       "L 72.556583 108.655063 \n",
       "L 75.835921 103.816069 \n",
       "L 79.115261 99.069186 \n",
       "L 82.394598 94.432209 \n",
       "L 85.673938 89.922579 \n",
       "L 88.953278 85.557355 \n",
       "L 92.232615 81.353098 \n",
       "L 95.511955 77.325858 \n",
       "L 98.791295 73.491096 \n",
       "L 102.070632 69.863642 \n",
       "L 105.349969 66.457625 \n",
       "L 108.629311 63.286465 \n",
       "L 111.908649 60.362783 \n",
       "L 115.187986 57.69838 \n",
       "L 118.467328 55.304179 \n",
       "L 121.746666 53.190213 \n",
       "L 125.026003 51.365579 \n",
       "L 128.305345 49.838385 \n",
       "L 131.584682 48.615751 \n",
       "L 134.86402 47.703768 \n",
       "L 138.143362 47.107467 \n",
       "L 141.422694 46.830815 \n",
       "L 144.702037 46.876694 \n",
       "L 147.981379 47.246865 \n",
       "L 151.260711 47.941983 \n",
       "L 154.540053 48.961579 \n",
       "L 157.819395 50.304045 \n",
       "L 161.098728 51.966621 \n",
       "L 164.37807 53.94544 \n",
       "L 167.657412 56.23545 \n",
       "L 170.936745 58.830489 \n",
       "L 174.216087 61.723245 \n",
       "L 177.495429 64.905268 \n",
       "L 180.774762 68.366982 \n",
       "L 184.054104 72.09767 \n",
       "L 187.333446 76.085541 \n",
       "L 190.612778 80.317626 \n",
       "L 193.892121 84.77991 \n",
       "L 197.171463 89.457224 \n",
       "L 200.450795 94.333368 \n",
       "L 203.730137 99.391005 \n",
       "L 207.00948 104.611701 \n",
       "L 210.288812 109.975954 \n",
       "L 213.568154 115.46319 \n",
       "L 216.847496 121.051697 \n",
       "L 220.126829 126.718712 \n",
       "L 223.406181 132.440363 \n",
       "L 226.685504 138.19162 \n",
       "L 229.964846 143.946411 \n",
       "L 233.244188 149.677512 \n",
       "L 236.523511 155.356422 \n",
       "L 239.802872 160.953735 \n",
       "L 243.082195 166.438566 \n",
       "L 246.361537 171.779094 \n",
       "L 249.640879 176.942154 \n",
       "L 252.920222 181.893425 \n",
       "L 256.199564 186.597433 \n",
       "L 259.478887 191.017431 \n",
       "L 262.758248 195.115621 \n",
       "L 266.037571 198.853034 \n",
       "L 269.316913 202.189732 \n",
       "L 272.596255 205.084835 \n",
       "L 275.875578 207.496772 \n",
       "L 279.15494 209.383366 \n",
       "L 282.434262 210.702206 \n",
       "L 285.713605 211.410945 \n",
       "L 288.992947 211.467761 \n",
       "L 292.272289 210.831899 \n",
       "L 295.551631 209.464413 \n",
       "L 298.830954 207.328965 \n",
       "L 302.110315 204.392776 \n",
       "L 305.389638 200.628226 \n",
       "L 308.66898 196.013746 \n",
       "L 311.948322 190.536083 \n",
       "L 315.227645 184.192212 \n",
       "L 318.507007 176.99142 \n",
       "L 321.78633 168.95846 \n",
       "L 325.065672 160.136185 \n",
       "L 328.345014 150.589049 \n",
       "L 331.624356 140.406759 \n",
       "L 334.903698 129.707933 \n",
       "L 338.183021 118.643976 \n",
       "L 341.462363 107.402798 \n",
       "L 344.741705 96.211765 \n",
       "L 348.021048 85.340169 \n",
       "L 351.30039 75.10016 \n",
       "L 354.579713 65.8451 \n",
       "L 357.859055 57.965219 \n",
       "L 361.138397 51.879685 \n",
       "L 364.417739 48.022268 \n",
       "L 367.697081 46.821473 \n",
       "L 370.976423 48.672366 \n",
       "L 374.255766 53.899704 \n",
       "L 377.535088 62.712004 \n",
       "L 380.814431 75.14678 \n",
       "L 384.093773 91.009565 \n",
       "\" clip-path=\"url(#p4719db0ad1)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 43.2065 252.704936 \n",
       "L 43.2065 46.81006 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 59.439227 286.212 \n",
       "L 384.093773 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_15\">\n",
       "    <!-- N=3, psi=1.96 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(191.87975 14.1) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2c\" d=\"M 569 0 \n",
       "L 569 641 \n",
       "L 1209 641 \n",
       "L 1209 0 \n",
       "Q 1209 -353 1084 -570 \n",
       "Q 959 -788 688 -906 \n",
       "L 531 -666 \n",
       "Q 709 -588 793 -436 \n",
       "Q 878 -284 888 0 \n",
       "L 569 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-33\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-2c\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"214.013672\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"241.796875\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"297.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"347.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"369.628906\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"428.027344\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"483.642578\"/>\n",
       "     <use xlink:href=\"#ArialMT-39\" x=\"511.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-36\" x=\"567.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_16\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#mb0e9a39cdf\" x=\"59.9265\" y=\"220.007125\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_16\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 223.087125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_17\">\n",
       "     <path d=\"M 51.1265 232.591125 \n",
       "L 59.9265 232.591125 \n",
       "L 68.7265 232.591125 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 235.671125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 51.1265 249.828125 \n",
       "L 68.7265 249.828125 \n",
       "L 68.7265 243.668125 \n",
       "L 51.1265 243.668125 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 249.828125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 51.1265 263.996125 \n",
       "L 68.7265 263.996125 \n",
       "L 68.7265 257.836125 \n",
       "L 51.1265 257.836125 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 263.996125) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_18\">\n",
       "     <path d=\"M 51.1265 273.463 \n",
       "L 59.9265 273.463 \n",
       "L 68.7265 273.463 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 276.543) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <defs>\n",
       "       <path id=\"m5f86e3dbd9\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m5f86e3dbd9\" x=\"400.3265\" y=\"238.680379\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_21\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 241.829816) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m5f86e3dbd9\" x=\"400.3265\" y=\"191.070466\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 194.219904) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m5f86e3dbd9\" x=\"400.3265\" y=\"143.460554\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 146.609991) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m5f86e3dbd9\" x=\"400.3265\" y=\"95.850641\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 99.000078) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m5f86e3dbd9\" x=\"400.3265\" y=\"48.240728\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 51.390166) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_26\">\n",
       "     <!-- Maximum Upper Interval -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(429.531375 205.43475) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4d\" d=\"M 475 0 \n",
       "L 475 4581 \n",
       "L 1388 4581 \n",
       "L 2472 1338 \n",
       "Q 2622 884 2691 659 \n",
       "Q 2769 909 2934 1394 \n",
       "L 4031 4581 \n",
       "L 4847 4581 \n",
       "L 4847 0 \n",
       "L 4263 0 \n",
       "L 4263 3834 \n",
       "L 2931 0 \n",
       "L 2384 0 \n",
       "L 1059 3900 \n",
       "L 1059 0 \n",
       "L 475 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-78\" d=\"M 47 0 \n",
       "L 1259 1725 \n",
       "L 138 3319 \n",
       "L 841 3319 \n",
       "L 1350 2541 \n",
       "Q 1494 2319 1581 2169 \n",
       "Q 1719 2375 1834 2534 \n",
       "L 2394 3319 \n",
       "L 3066 3319 \n",
       "L 1919 1756 \n",
       "L 3153 0 \n",
       "L 2463 0 \n",
       "L 1781 1031 \n",
       "L 1600 1309 \n",
       "L 728 0 \n",
       "L 47 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-55\" d=\"M 3500 4581 \n",
       "L 4106 4581 \n",
       "L 4106 1934 \n",
       "Q 4106 1244 3950 837 \n",
       "Q 3794 431 3386 176 \n",
       "Q 2978 -78 2316 -78 \n",
       "Q 1672 -78 1262 144 \n",
       "Q 853 366 678 786 \n",
       "Q 503 1206 503 1934 \n",
       "L 503 4581 \n",
       "L 1109 4581 \n",
       "L 1109 1938 \n",
       "Q 1109 1341 1220 1058 \n",
       "Q 1331 775 1601 622 \n",
       "Q 1872 469 2263 469 \n",
       "Q 2931 469 3215 772 \n",
       "Q 3500 1075 3500 1938 \n",
       "L 3500 4581 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4d\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "      <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"188.916016\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"211.132812\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"294.433594\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"350.048828\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"433.349609\"/>\n",
       "      <use xlink:href=\"#ArialMT-55\" x=\"461.132812\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" x=\"533.349609\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" x=\"588.964844\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"644.580078\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"700.195312\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"733.496094\"/>\n",
       "      <use xlink:href=\"#ArialMT-49\" x=\"761.279297\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"789.0625\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.677734\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"872.460938\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"928.076172\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"961.376953\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"1011.376953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6c\" x=\"1066.992188\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_24\">\n",
       "    <path d=\"M 59.439227 142.297419 \n",
       "L 62.718566 135.784835 \n",
       "L 65.997905 128.699917 \n",
       "L 69.277244 121.555293 \n",
       "L 72.556583 114.452622 \n",
       "L 75.835921 107.487288 \n",
       "L 79.115261 100.750968 \n",
       "L 82.394598 94.328293 \n",
       "L 85.673938 88.29677 \n",
       "L 88.953278 82.723749 \n",
       "L 92.232615 77.664362 \n",
       "L 95.511955 73.160268 \n",
       "L 98.791295 69.239028 \n",
       "L 102.070632 65.912642 \n",
       "L 105.349969 63.178399 \n",
       "L 108.629311 61.017788 \n",
       "L 111.908649 59.396423 \n",
       "L 115.187986 58.262697 \n",
       "L 118.467328 57.439682 \n",
       "L 121.746666 53.347715 \n",
       "L 125.026003 48.803442 \n",
       "L 128.305345 45.018905 \n",
       "L 131.584682 42.067098 \n",
       "L 134.86402 39.989849 \n",
       "L 138.143362 38.806376 \n",
       "L 141.422694 38.517814 \n",
       "L 144.702037 39.105744 \n",
       "L 147.981379 40.534609 \n",
       "L 151.260711 42.752696 \n",
       "L 154.540053 45.693951 \n",
       "L 157.819395 49.276081 \n",
       "L 161.098728 53.353239 \n",
       "L 164.37807 53.675839 \n",
       "L 167.657412 51.749309 \n",
       "L 170.936745 49.555599 \n",
       "L 174.216087 47.17173 \n",
       "L 177.495429 44.671877 \n",
       "L 180.774762 42.141483 \n",
       "L 184.054104 39.676117 \n",
       "L 187.333446 37.380439 \n",
       "L 190.612778 35.366478 \n",
       "L 193.892121 33.751187 \n",
       "L 197.171463 32.654297 \n",
       "L 200.450795 32.196 \n",
       "L 203.730137 32.494202 \n",
       "L 207.00948 33.661999 \n",
       "L 210.288812 35.804919 \n",
       "L 213.568154 39.018248 \n",
       "L 216.847496 43.384083 \n",
       "L 220.126829 48.968623 \n",
       "L 223.406181 55.819603 \n",
       "L 226.685504 63.963285 \n",
       "L 229.964846 73.402565 \n",
       "L 233.244188 84.114309 \n",
       "L 236.523511 96.047764 \n",
       "L 239.802872 109.123207 \n",
       "L 243.082195 123.230446 \n",
       "L 246.361537 138.229399 \n",
       "L 249.640879 153.949696 \n",
       "L 252.920222 170.192229 \n",
       "L 256.199564 186.73023 \n",
       "L 259.478887 203.30762 \n",
       "L 262.758248 219.24029 \n",
       "L 266.037571 228.046124 \n",
       "L 269.316913 236.302122 \n",
       "L 272.596255 244.243274 \n",
       "L 275.875578 251.679894 \n",
       "L 279.15494 258.404006 \n",
       "L 282.434262 264.203526 \n",
       "L 285.713605 268.867756 \n",
       "L 288.992947 272.19392 \n",
       "L 292.272289 273.9967 \n",
       "L 295.551631 274.116 \n",
       "L 298.830954 272.422054 \n",
       "L 302.110315 268.824963 \n",
       "L 305.389638 263.279888 \n",
       "L 308.66898 255.790895 \n",
       "L 311.948322 246.415169 \n",
       "L 315.227645 235.265767 \n",
       "L 318.507007 222.511776 \n",
       "L 321.78633 208.371794 \n",
       "L 325.065672 193.113128 \n",
       "L 328.345014 177.046595 \n",
       "L 331.624356 160.500398 \n",
       "L 334.903698 143.584462 \n",
       "L 338.183021 126.078003 \n",
       "L 341.462363 109.513957 \n",
       "L 344.741705 94.563848 \n",
       "L 348.021048 81.579333 \n",
       "L 351.30039 70.837736 \n",
       "L 354.579713 62.551223 \n",
       "L 357.859055 56.832855 \n",
       "L 361.138397 53.576977 \n",
       "L 364.417739 52.52522 \n",
       "L 367.697081 53.97645 \n",
       "L 370.976423 58.120696 \n",
       "L 374.255766 64.892561 \n",
       "L 377.535088 74.149487 \n",
       "L 380.814431 85.657849 \n",
       "L 384.093773 98.84138 \n",
       "\" clip-path=\"url(#p4719db0ad1)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_25\">\n",
       "    <path d=\"M 200.450795 48.240728 \n",
       "L 200.450795 48.07866 \n",
       "L 200.450795 47.916593 \n",
       "L 200.450795 47.754525 \n",
       "L 200.450795 47.592457 \n",
       "L 200.450795 47.430389 \n",
       "L 200.450795 47.268321 \n",
       "L 200.450795 47.106253 \n",
       "L 200.450795 46.944185 \n",
       "L 200.450795 46.782117 \n",
       "L 200.450795 46.620049 \n",
       "L 200.450795 46.457981 \n",
       "L 200.450795 46.295913 \n",
       "L 200.450795 46.133845 \n",
       "L 200.450795 45.971777 \n",
       "L 200.450795 45.809709 \n",
       "L 200.450795 45.647641 \n",
       "L 200.450795 45.485573 \n",
       "L 200.450795 45.323505 \n",
       "L 200.450795 45.161437 \n",
       "L 200.450795 44.999369 \n",
       "L 200.450795 44.837301 \n",
       "L 200.450795 44.675233 \n",
       "L 200.450795 44.513165 \n",
       "L 200.450795 44.351097 \n",
       "L 200.450795 44.189029 \n",
       "L 200.450795 44.026961 \n",
       "L 200.450795 43.864894 \n",
       "L 200.450795 43.702826 \n",
       "L 200.450795 43.540758 \n",
       "L 200.450795 43.37869 \n",
       "L 200.450795 43.216622 \n",
       "L 200.450795 43.054554 \n",
       "L 200.450795 42.892486 \n",
       "L 200.450795 42.730418 \n",
       "L 200.450795 42.56835 \n",
       "L 200.450795 42.406282 \n",
       "L 200.450795 42.244214 \n",
       "L 200.450795 42.082146 \n",
       "L 200.450795 41.920078 \n",
       "L 200.450795 41.75801 \n",
       "L 200.450795 41.595942 \n",
       "L 200.450795 41.433874 \n",
       "L 200.450795 41.271806 \n",
       "L 200.450795 41.109738 \n",
       "L 200.450795 40.94767 \n",
       "L 200.450795 40.785602 \n",
       "L 200.450795 40.623534 \n",
       "L 200.450795 40.461466 \n",
       "L 200.450795 40.299398 \n",
       "L 200.450795 40.13733 \n",
       "L 200.450795 39.975262 \n",
       "L 200.450795 39.813194 \n",
       "L 200.450795 39.651126 \n",
       "L 200.450795 39.489058 \n",
       "L 200.450795 39.32699 \n",
       "L 200.450795 39.164922 \n",
       "L 200.450795 39.002854 \n",
       "L 200.450795 38.840786 \n",
       "L 200.450795 38.678718 \n",
       "L 200.450795 38.51665 \n",
       "L 200.450795 38.354582 \n",
       "L 200.450795 38.192514 \n",
       "L 200.450795 38.030446 \n",
       "L 200.450795 37.868378 \n",
       "L 200.450795 37.70631 \n",
       "L 200.450795 37.544242 \n",
       "L 200.450795 37.382174 \n",
       "L 200.450795 37.220106 \n",
       "L 200.450795 37.058038 \n",
       "L 200.450795 36.89597 \n",
       "L 200.450795 36.733902 \n",
       "L 200.450795 36.571834 \n",
       "L 200.450795 36.409767 \n",
       "L 200.450795 36.2477 \n",
       "L 200.450795 36.085632 \n",
       "L 200.450795 35.923564 \n",
       "L 200.450795 35.761496 \n",
       "L 200.450795 35.599428 \n",
       "L 200.450795 35.43736 \n",
       "L 200.450795 35.275292 \n",
       "L 200.450795 35.113224 \n",
       "L 200.450795 34.951156 \n",
       "L 200.450795 34.789088 \n",
       "L 200.450795 34.62702 \n",
       "L 200.450795 34.464952 \n",
       "L 200.450795 34.302884 \n",
       "L 200.450795 34.140816 \n",
       "L 200.450795 33.978748 \n",
       "L 200.450795 33.81668 \n",
       "L 200.450795 33.654612 \n",
       "L 200.450795 33.492544 \n",
       "L 200.450795 33.330476 \n",
       "L 200.450795 33.168408 \n",
       "L 200.450795 33.00634 \n",
       "L 200.450795 32.844272 \n",
       "L 200.450795 32.682204 \n",
       "L 200.450795 32.520136 \n",
       "L 200.450795 32.358068 \n",
       "L 200.450795 32.196 \n",
       "\" clip-path=\"url(#p4719db0ad1)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 43.2065 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 400.3265 286.212 \n",
       "L 400.3265 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 400.3265 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 43.2065 20.1 \n",
       "L 400.3265 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p4719db0ad1\">\n",
       "   <rect x=\"43.2065\" y=\"20.1\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"438.639375pt\" height=\"322.539375pt\" viewBox=\"0 0 438.639375 322.539375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:10.994247</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.539375 \n",
       "L 438.639375 322.539375 \n",
       "L 438.639375 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 400.3265 286.212 \n",
       "L 400.3265 20.1 \n",
       "L 43.2065 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m3898a69726\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3898a69726\" x=\"59.439227\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(53.323227 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3898a69726\" x=\"124.370136\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(118.254136 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3898a69726\" x=\"189.301045\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(183.185045 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3898a69726\" x=\"254.231955\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(248.115955 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3898a69726\" x=\"319.162864\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(313.046864 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3898a69726\" x=\"384.093773\" y=\"286.212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.977773 300.810875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(218.8865 313.431375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"m381f525915\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m381f525915\" x=\"43.2065\" y=\"262.316916\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 265.466353) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m381f525915\" x=\"43.2065\" y=\"218.403094\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 221.552531) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m381f525915\" x=\"43.2065\" y=\"174.489272\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 177.638709) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m381f525915\" x=\"43.2065\" y=\"130.57545\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 133.724887) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m381f525915\" x=\"43.2065\" y=\"86.661628\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 89.811065) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m381f525915\" x=\"43.2065\" y=\"42.747806\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(30.012875 45.897243) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_14\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.036) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"mbcad2f0d86\" d=\"M 59.439227 -193.045248 \n",
       "L 59.439227 -192.169014 \n",
       "L 62.718566 -190.767889 \n",
       "L 65.997905 -189.917704 \n",
       "L 69.277244 -190.031972 \n",
       "L 72.556583 -191.121718 \n",
       "L 75.835921 -193.174169 \n",
       "L 79.115261 -196.156721 \n",
       "L 82.394598 -200.016905 \n",
       "L 85.673938 -204.683583 \n",
       "L 88.953278 -210.068253 \n",
       "L 92.232615 -216.065359 \n",
       "L 95.511955 -222.555192 \n",
       "L 98.791295 -229.406231 \n",
       "L 102.070632 -236.477372 \n",
       "L 105.349969 -243.622766 \n",
       "L 108.629311 -250.692952 \n",
       "L 111.908649 -257.538583 \n",
       "L 115.187986 -264.009854 \n",
       "L 118.467328 -269.840602 \n",
       "L 121.746666 -272.762746 \n",
       "L 125.026003 -274.575562 \n",
       "L 128.305345 -276.083678 \n",
       "L 131.584682 -277.305643 \n",
       "L 134.86402 -278.241573 \n",
       "L 138.143362 -278.883956 \n",
       "L 141.422694 -279.224325 \n",
       "L 144.702037 -279.250581 \n",
       "L 147.981379 -278.949557 \n",
       "L 151.260711 -278.307306 \n",
       "L 154.540053 -277.309531 \n",
       "L 157.819395 -275.934378 \n",
       "L 161.098728 -274.075064 \n",
       "L 164.37807 -270.509875 \n",
       "L 167.657412 -265.947222 \n",
       "L 170.936745 -261.244826 \n",
       "L 174.216087 -256.559253 \n",
       "L 177.495429 -252.004034 \n",
       "L 180.774762 -247.674421 \n",
       "L 184.054104 -243.646305 \n",
       "L 187.333446 -239.973223 \n",
       "L 190.612778 -236.685385 \n",
       "L 193.892121 -233.78538 \n",
       "L 197.171463 -231.238322 \n",
       "L 200.450795 -228.677078 \n",
       "L 203.730137 -224.084909 \n",
       "L 207.00948 -219.120713 \n",
       "L 210.288812 -214.121549 \n",
       "L 213.568154 -209.112647 \n",
       "L 216.847496 -204.09827 \n",
       "L 220.126829 -199.071774 \n",
       "L 223.406181 -194.016779 \n",
       "L 226.685504 -188.909414 \n",
       "L 229.964846 -183.718954 \n",
       "L 233.244188 -178.410928 \n",
       "L 236.523511 -172.949561 \n",
       "L 239.802872 -167.300657 \n",
       "L 243.082195 -161.43575 \n",
       "L 246.361537 -155.334244 \n",
       "L 249.640879 -148.988361 \n",
       "L 252.920222 -142.405042 \n",
       "L 256.199564 -135.608745 \n",
       "L 259.478887 -128.635957 \n",
       "L 262.758248 -121.193282 \n",
       "L 266.037571 -110.055768 \n",
       "L 269.316913 -98.762704 \n",
       "L 272.596255 -87.948248 \n",
       "L 275.875578 -77.902888 \n",
       "L 279.15494 -68.90952 \n",
       "L 282.434262 -61.240277 \n",
       "L 285.713605 -55.149471 \n",
       "L 288.992947 -50.863986 \n",
       "L 292.272289 -48.575209 \n",
       "L 295.551631 -48.430495 \n",
       "L 298.830954 -50.52694 \n",
       "L 302.110315 -54.905858 \n",
       "L 305.389638 -61.547882 \n",
       "L 308.66898 -70.373083 \n",
       "L 311.948322 -81.238547 \n",
       "L 315.227645 -93.94181 \n",
       "L 318.507007 -108.224577 \n",
       "L 321.78633 -123.779434 \n",
       "L 325.065672 -140.254583 \n",
       "L 328.345014 -157.266197 \n",
       "L 331.624356 -174.389744 \n",
       "L 334.903698 -190.982019 \n",
       "L 338.183021 -206.150993 \n",
       "L 341.462363 -220.423966 \n",
       "L 344.741705 -233.698554 \n",
       "L 348.021048 -245.638816 \n",
       "L 351.30039 -255.926448 \n",
       "L 354.579713 -264.277174 \n",
       "L 357.859055 -270.415959 \n",
       "L 361.138397 -273.992045 \n",
       "L 364.417739 -274.6718 \n",
       "L 367.697081 -272.705935 \n",
       "L 370.976423 -268.404074 \n",
       "L 374.255766 -261.973033 \n",
       "L 377.535088 -253.658748 \n",
       "L 380.814431 -243.739317 \n",
       "L 384.093773 -232.249775 \n",
       "L 384.093773 -233.128647 \n",
       "L 384.093773 -233.128647 \n",
       "L 380.814431 -245.409062 \n",
       "L 377.535088 -256.097521 \n",
       "L 374.255766 -264.66385 \n",
       "L 370.976423 -270.89683 \n",
       "L 367.697081 -274.671679 \n",
       "L 364.417739 -275.937571 \n",
       "L 361.138397 -274.872793 \n",
       "L 357.859055 -271.73543 \n",
       "L 354.579713 -266.327036 \n",
       "L 351.30039 -258.571917 \n",
       "L 348.021048 -248.590383 \n",
       "L 344.741705 -236.598025 \n",
       "L 341.462363 -222.870733 \n",
       "L 338.183021 -207.749167 \n",
       "L 334.903698 -191.859645 \n",
       "L 331.624356 -176.484975 \n",
       "L 328.345014 -161.501532 \n",
       "L 325.065672 -147.016339 \n",
       "L 321.78633 -133.320754 \n",
       "L 318.507007 -120.689294 \n",
       "L 315.227645 -109.353114 \n",
       "L 311.948322 -99.497165 \n",
       "L 308.66898 -91.259052 \n",
       "L 305.389638 -84.723528 \n",
       "L 302.110315 -79.924453 \n",
       "L 298.830954 -76.847525 \n",
       "L 295.551631 -75.435642 \n",
       "L 292.272289 -75.592795 \n",
       "L 288.992947 -77.190937 \n",
       "L 285.713605 -80.077146 \n",
       "L 282.434262 -84.081808 \n",
       "L 279.15494 -89.024111 \n",
       "L 275.875578 -94.721899 \n",
       "L 272.596255 -100.997435 \n",
       "L 269.316913 -107.682311 \n",
       "L 266.037571 -114.63284 \n",
       "L 262.758248 -122.075243 \n",
       "L 259.478887 -133.178646 \n",
       "L 256.199564 -144.393679 \n",
       "L 252.920222 -155.154623 \n",
       "L 249.640879 -165.281134 \n",
       "L 246.361537 -174.637733 \n",
       "L 243.082195 -183.128171 \n",
       "L 239.802872 -190.695019 \n",
       "L 236.523511 -197.318332 \n",
       "L 233.244188 -203.013393 \n",
       "L 229.964846 -207.827696 \n",
       "L 226.685504 -211.837154 \n",
       "L 223.406181 -215.140477 \n",
       "L 220.126829 -217.85466 \n",
       "L 216.847496 -220.109258 \n",
       "L 213.568154 -222.040488 \n",
       "L 210.288812 -223.786025 \n",
       "L 207.00948 -225.480605 \n",
       "L 203.730137 -227.261289 \n",
       "L 200.450795 -229.553856 \n",
       "L 197.171463 -234.080756 \n",
       "L 193.892121 -238.861378 \n",
       "L 190.612778 -243.53722 \n",
       "L 187.333446 -248.054671 \n",
       "L 184.054104 -252.371885 \n",
       "L 180.774762 -256.451172 \n",
       "L 177.495429 -260.257621 \n",
       "L 174.216087 -263.761699 \n",
       "L 170.936745 -266.940156 \n",
       "L 167.657412 -269.779269 \n",
       "L 164.37807 -272.303682 \n",
       "L 161.098728 -275.239131 \n",
       "L 157.819395 -279.165742 \n",
       "L 154.540053 -282.741448 \n",
       "L 151.260711 -285.750218 \n",
       "L 147.981379 -288.075491 \n",
       "L 144.702037 -289.625023 \n",
       "L 141.422694 -290.326032 \n",
       "L 138.143362 -290.126859 \n",
       "L 134.86402 -288.998512 \n",
       "L 131.584682 -286.937331 \n",
       "L 128.305345 -283.962349 \n",
       "L 125.026003 -280.121261 \n",
       "L 121.746666 -275.500269 \n",
       "L 118.467328 -270.990013 \n",
       "L 115.187986 -268.492681 \n",
       "L 111.908649 -265.857592 \n",
       "L 108.629311 -262.948183 \n",
       "L 105.349969 -259.754199 \n",
       "L 102.070632 -256.272564 \n",
       "L 98.791295 -252.50484 \n",
       "L 95.511955 -248.457729 \n",
       "L 92.232615 -244.141658 \n",
       "L 88.953278 -239.57323 \n",
       "L 85.673938 -234.774474 \n",
       "L 82.394598 -229.773629 \n",
       "L 79.115261 -224.605455 \n",
       "L 75.835921 -219.310108 \n",
       "L 72.556583 -213.932269 \n",
       "L 69.277244 -208.521806 \n",
       "L 65.997905 -203.13233 \n",
       "L 62.718566 -197.824713 \n",
       "L 59.439227 -193.045248 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pc18e2bc6c3)\">\n",
       "     <use xlink:href=\"#mbcad2f0d86\" x=\"0\" y=\"322.539375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m32592da4ce\" d=\"M 59.439227 -192.169014 \n",
       "L 59.439227 -191.986818 \n",
       "L 62.718566 -190.740667 \n",
       "L 65.997905 -189.90313 \n",
       "L 69.277244 -190.021544 \n",
       "L 72.556583 -191.113269 \n",
       "L 75.835921 -193.166798 \n",
       "L 79.115261 -196.149942 \n",
       "L 82.394598 -200.010424 \n",
       "L 85.673938 -204.677176 \n",
       "L 88.953278 -210.06172 \n",
       "L 92.232615 -216.058491 \n",
       "L 95.511955 -222.547748 \n",
       "L 98.791295 -229.397886 \n",
       "L 102.070632 -236.467636 \n",
       "L 105.349969 -243.61082 \n",
       "L 108.629311 -250.677237 \n",
       "L 111.908649 -257.515466 \n",
       "L 115.187986 -263.96724 \n",
       "L 118.467328 -269.692031 \n",
       "L 121.746666 -272.694027 \n",
       "L 125.026003 -274.541004 \n",
       "L 128.305345 -276.059278 \n",
       "L 131.584682 -277.285663 \n",
       "L 134.86402 -278.223676 \n",
       "L 138.143362 -278.86683 \n",
       "L 141.422694 -279.206981 \n",
       "L 144.702037 -279.232026 \n",
       "L 147.981379 -278.928475 \n",
       "L 151.260711 -278.281486 \n",
       "L 154.540053 -277.274258 \n",
       "L 157.819395 -275.875763 \n",
       "L 161.098728 -273.927984 \n",
       "L 164.37807 -270.40814 \n",
       "L 167.657412 -265.897543 \n",
       "L 170.936745 -261.211166 \n",
       "L 174.216087 -256.532575 \n",
       "L 177.495429 -251.980736 \n",
       "L 180.774762 -247.652502 \n",
       "L 184.054104 -243.624261 \n",
       "L 187.333446 -239.94943 \n",
       "L 190.612778 -236.657355 \n",
       "L 193.892121 -233.747668 \n",
       "L 197.171463 -231.172022 \n",
       "L 200.450795 -228.49496 \n",
       "L 203.730137 -224.025314 \n",
       "L 207.00948 -219.090534 \n",
       "L 210.288812 -214.10164 \n",
       "L 213.568154 -209.097744 \n",
       "L 216.847496 -204.086235 \n",
       "L 220.126829 -199.061514 \n",
       "L 223.406181 -194.007655 \n",
       "L 226.685504 -188.901006 \n",
       "L 229.964846 -183.710955 \n",
       "L 233.244188 -178.403086 \n",
       "L 236.523511 -172.941656 \n",
       "L 239.802872 -167.292417 \n",
       "L 243.082195 -161.426861 \n",
       "L 246.361537 -155.324255 \n",
       "L 249.640879 -148.97654 \n",
       "L 252.920222 -142.389934 \n",
       "L 256.199564 -135.586842 \n",
       "L 259.478887 -128.5939 \n",
       "L 262.758248 -121.011923 \n",
       "L 266.037571 -110.014025 \n",
       "L 269.316913 -98.741136 \n",
       "L 272.596255 -87.933486 \n",
       "L 275.875578 -77.891434 \n",
       "L 279.15494 -68.899951 \n",
       "L 282.434262 -61.231838 \n",
       "L 285.713605 -55.141745 \n",
       "L 288.992947 -50.856678 \n",
       "L 292.272289 -48.568069 \n",
       "L 295.551631 -48.423375 \n",
       "L 298.830954 -50.519632 \n",
       "L 302.110315 -54.898153 \n",
       "L 305.389638 -61.539569 \n",
       "L 308.66898 -70.363848 \n",
       "L 311.948322 -81.227994 \n",
       "L 315.227645 -93.929308 \n",
       "L 318.507007 -108.209124 \n",
       "L 321.78633 -123.759269 \n",
       "L 325.065672 -140.226188 \n",
       "L 328.345014 -157.221145 \n",
       "L 331.624356 -174.301431 \n",
       "L 334.903698 -190.800032 \n",
       "L 338.183021 -206.038274 \n",
       "L 341.462363 -220.347541 \n",
       "L 344.741705 -233.633504 \n",
       "L 348.021048 -245.574866 \n",
       "L 351.30039 -255.85546 \n",
       "L 354.579713 -264.18706 \n",
       "L 357.859055 -270.283171 \n",
       "L 361.138397 -273.81051 \n",
       "L 364.417739 -274.534369 \n",
       "L 367.697081 -272.612294 \n",
       "L 370.976423 -268.328975 \n",
       "L 374.255766 -261.90318 \n",
       "L 377.535088 -253.582085 \n",
       "L 380.814431 -243.630867 \n",
       "L 384.093773 -232.067965 \n",
       "L 384.093773 -232.249775 \n",
       "L 384.093773 -232.249775 \n",
       "L 380.814431 -243.739317 \n",
       "L 377.535088 -253.658748 \n",
       "L 374.255766 -261.973033 \n",
       "L 370.976423 -268.404074 \n",
       "L 367.697081 -272.705935 \n",
       "L 364.417739 -274.6718 \n",
       "L 361.138397 -273.992045 \n",
       "L 357.859055 -270.415959 \n",
       "L 354.579713 -264.277174 \n",
       "L 351.30039 -255.926448 \n",
       "L 348.021048 -245.638816 \n",
       "L 344.741705 -233.698554 \n",
       "L 341.462363 -220.423966 \n",
       "L 338.183021 -206.150993 \n",
       "L 334.903698 -190.982019 \n",
       "L 331.624356 -174.389744 \n",
       "L 328.345014 -157.266197 \n",
       "L 325.065672 -140.254583 \n",
       "L 321.78633 -123.779434 \n",
       "L 318.507007 -108.224577 \n",
       "L 315.227645 -93.94181 \n",
       "L 311.948322 -81.238547 \n",
       "L 308.66898 -70.373083 \n",
       "L 305.389638 -61.547882 \n",
       "L 302.110315 -54.905858 \n",
       "L 298.830954 -50.52694 \n",
       "L 295.551631 -48.430495 \n",
       "L 292.272289 -48.575209 \n",
       "L 288.992947 -50.863986 \n",
       "L 285.713605 -55.149471 \n",
       "L 282.434262 -61.240277 \n",
       "L 279.15494 -68.90952 \n",
       "L 275.875578 -77.902888 \n",
       "L 272.596255 -87.948248 \n",
       "L 269.316913 -98.762704 \n",
       "L 266.037571 -110.055768 \n",
       "L 262.758248 -121.193282 \n",
       "L 259.478887 -128.635957 \n",
       "L 256.199564 -135.608745 \n",
       "L 252.920222 -142.405042 \n",
       "L 249.640879 -148.988361 \n",
       "L 246.361537 -155.334244 \n",
       "L 243.082195 -161.43575 \n",
       "L 239.802872 -167.300657 \n",
       "L 236.523511 -172.949561 \n",
       "L 233.244188 -178.410928 \n",
       "L 229.964846 -183.718954 \n",
       "L 226.685504 -188.909414 \n",
       "L 223.406181 -194.016779 \n",
       "L 220.126829 -199.071774 \n",
       "L 216.847496 -204.09827 \n",
       "L 213.568154 -209.112647 \n",
       "L 210.288812 -214.121549 \n",
       "L 207.00948 -219.120713 \n",
       "L 203.730137 -224.084909 \n",
       "L 200.450795 -228.677078 \n",
       "L 197.171463 -231.238322 \n",
       "L 193.892121 -233.78538 \n",
       "L 190.612778 -236.685385 \n",
       "L 187.333446 -239.973223 \n",
       "L 184.054104 -243.646305 \n",
       "L 180.774762 -247.674421 \n",
       "L 177.495429 -252.004034 \n",
       "L 174.216087 -256.559253 \n",
       "L 170.936745 -261.244826 \n",
       "L 167.657412 -265.947222 \n",
       "L 164.37807 -270.509875 \n",
       "L 161.098728 -274.075064 \n",
       "L 157.819395 -275.934378 \n",
       "L 154.540053 -277.309531 \n",
       "L 151.260711 -278.307306 \n",
       "L 147.981379 -278.949557 \n",
       "L 144.702037 -279.250581 \n",
       "L 141.422694 -279.224325 \n",
       "L 138.143362 -278.883956 \n",
       "L 134.86402 -278.241573 \n",
       "L 131.584682 -277.305643 \n",
       "L 128.305345 -276.083678 \n",
       "L 125.026003 -274.575562 \n",
       "L 121.746666 -272.762746 \n",
       "L 118.467328 -269.840602 \n",
       "L 115.187986 -264.009854 \n",
       "L 111.908649 -257.538583 \n",
       "L 108.629311 -250.692952 \n",
       "L 105.349969 -243.622766 \n",
       "L 102.070632 -236.477372 \n",
       "L 98.791295 -229.406231 \n",
       "L 95.511955 -222.555192 \n",
       "L 92.232615 -216.065359 \n",
       "L 88.953278 -210.068253 \n",
       "L 85.673938 -204.683583 \n",
       "L 82.394598 -200.016905 \n",
       "L 79.115261 -196.156721 \n",
       "L 75.835921 -193.174169 \n",
       "L 72.556583 -191.121718 \n",
       "L 69.277244 -190.031972 \n",
       "L 65.997905 -189.917704 \n",
       "L 62.718566 -190.767889 \n",
       "L 59.439227 -192.169014 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pc18e2bc6c3)\">\n",
       "     <use xlink:href=\"#m32592da4ce\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"mc8e0914250\" d=\"M 59.439227 -193.227445 \n",
       "L 59.439227 -193.045248 \n",
       "L 62.718566 -197.824713 \n",
       "L 65.997905 -203.13233 \n",
       "L 69.277244 -208.521806 \n",
       "L 72.556583 -213.932269 \n",
       "L 75.835921 -219.310108 \n",
       "L 79.115261 -224.605455 \n",
       "L 82.394598 -229.773629 \n",
       "L 85.673938 -234.774474 \n",
       "L 88.953278 -239.57323 \n",
       "L 92.232615 -244.141658 \n",
       "L 95.511955 -248.457729 \n",
       "L 98.791295 -252.50484 \n",
       "L 102.070632 -256.272564 \n",
       "L 105.349969 -259.754199 \n",
       "L 108.629311 -262.948183 \n",
       "L 111.908649 -265.857592 \n",
       "L 115.187986 -268.492681 \n",
       "L 118.467328 -270.990013 \n",
       "L 121.746666 -275.500269 \n",
       "L 125.026003 -280.121261 \n",
       "L 128.305345 -283.962349 \n",
       "L 131.584682 -286.937331 \n",
       "L 134.86402 -288.998512 \n",
       "L 138.143362 -290.126859 \n",
       "L 141.422694 -290.326032 \n",
       "L 144.702037 -289.625023 \n",
       "L 147.981379 -288.075491 \n",
       "L 151.260711 -285.750218 \n",
       "L 154.540053 -282.741448 \n",
       "L 157.819395 -279.165742 \n",
       "L 161.098728 -275.239131 \n",
       "L 164.37807 -272.303682 \n",
       "L 167.657412 -269.779269 \n",
       "L 170.936745 -266.940156 \n",
       "L 174.216087 -263.761699 \n",
       "L 177.495429 -260.257621 \n",
       "L 180.774762 -256.451172 \n",
       "L 184.054104 -252.371885 \n",
       "L 187.333446 -248.054671 \n",
       "L 190.612778 -243.53722 \n",
       "L 193.892121 -238.861378 \n",
       "L 197.171463 -234.080756 \n",
       "L 200.450795 -229.553856 \n",
       "L 203.730137 -227.261289 \n",
       "L 207.00948 -225.480605 \n",
       "L 210.288812 -223.786025 \n",
       "L 213.568154 -222.040488 \n",
       "L 216.847496 -220.109258 \n",
       "L 220.126829 -217.85466 \n",
       "L 223.406181 -215.140477 \n",
       "L 226.685504 -211.837154 \n",
       "L 229.964846 -207.827696 \n",
       "L 233.244188 -203.013393 \n",
       "L 236.523511 -197.318332 \n",
       "L 239.802872 -190.695019 \n",
       "L 243.082195 -183.128171 \n",
       "L 246.361537 -174.637733 \n",
       "L 249.640879 -165.281134 \n",
       "L 252.920222 -155.154623 \n",
       "L 256.199564 -144.393679 \n",
       "L 259.478887 -133.178646 \n",
       "L 262.758248 -122.075243 \n",
       "L 266.037571 -114.63284 \n",
       "L 269.316913 -107.682311 \n",
       "L 272.596255 -100.997435 \n",
       "L 275.875578 -94.721899 \n",
       "L 279.15494 -89.024111 \n",
       "L 282.434262 -84.081808 \n",
       "L 285.713605 -80.077146 \n",
       "L 288.992947 -77.190937 \n",
       "L 292.272289 -75.592795 \n",
       "L 295.551631 -75.435642 \n",
       "L 298.830954 -76.847525 \n",
       "L 302.110315 -79.924453 \n",
       "L 305.389638 -84.723528 \n",
       "L 308.66898 -91.259052 \n",
       "L 311.948322 -99.497165 \n",
       "L 315.227645 -109.353114 \n",
       "L 318.507007 -120.689294 \n",
       "L 321.78633 -133.320754 \n",
       "L 325.065672 -147.016339 \n",
       "L 328.345014 -161.501532 \n",
       "L 331.624356 -176.484975 \n",
       "L 334.903698 -191.859645 \n",
       "L 338.183021 -207.749167 \n",
       "L 341.462363 -222.870733 \n",
       "L 344.741705 -236.598025 \n",
       "L 348.021048 -248.590383 \n",
       "L 351.30039 -258.571917 \n",
       "L 354.579713 -266.327036 \n",
       "L 357.859055 -271.73543 \n",
       "L 361.138397 -274.872793 \n",
       "L 364.417739 -275.937571 \n",
       "L 367.697081 -274.671679 \n",
       "L 370.976423 -270.89683 \n",
       "L 374.255766 -264.66385 \n",
       "L 377.535088 -256.097521 \n",
       "L 380.814431 -245.409062 \n",
       "L 384.093773 -233.128647 \n",
       "L 384.093773 -233.310456 \n",
       "L 384.093773 -233.310456 \n",
       "L 380.814431 -245.517512 \n",
       "L 377.535088 -256.174184 \n",
       "L 374.255766 -264.733704 \n",
       "L 370.976423 -270.971929 \n",
       "L 367.697081 -274.76532 \n",
       "L 364.417739 -276.075001 \n",
       "L 361.138397 -275.054329 \n",
       "L 357.859055 -271.868218 \n",
       "L 354.579713 -266.417151 \n",
       "L 351.30039 -258.642907 \n",
       "L 348.021048 -248.654332 \n",
       "L 344.741705 -236.663077 \n",
       "L 341.462363 -222.947158 \n",
       "L 338.183021 -207.861885 \n",
       "L 334.903698 -192.041638 \n",
       "L 331.624356 -176.573288 \n",
       "L 328.345014 -161.546584 \n",
       "L 325.065672 -147.044734 \n",
       "L 321.78633 -133.340918 \n",
       "L 318.507007 -120.704747 \n",
       "L 315.227645 -109.365626 \n",
       "L 311.948322 -99.507719 \n",
       "L 308.66898 -91.268286 \n",
       "L 305.389638 -84.731841 \n",
       "L 302.110315 -79.932159 \n",
       "L 298.830954 -76.854833 \n",
       "L 295.551631 -75.442762 \n",
       "L 292.272289 -75.599936 \n",
       "L 288.992947 -77.198245 \n",
       "L 285.713605 -80.084872 \n",
       "L 282.434262 -84.090247 \n",
       "L 279.15494 -89.033681 \n",
       "L 275.875578 -94.733353 \n",
       "L 272.596255 -101.012197 \n",
       "L 269.316913 -107.703879 \n",
       "L 266.037571 -114.674583 \n",
       "L 262.758248 -122.256602 \n",
       "L 259.478887 -133.220703 \n",
       "L 256.199564 -144.415582 \n",
       "L 252.920222 -155.169731 \n",
       "L 249.640879 -165.292955 \n",
       "L 246.361537 -174.647722 \n",
       "L 243.082195 -183.13706 \n",
       "L 239.802872 -190.703259 \n",
       "L 236.523511 -197.326242 \n",
       "L 233.244188 -203.021229 \n",
       "L 229.964846 -207.835695 \n",
       "L 226.685504 -211.845561 \n",
       "L 223.406181 -215.149601 \n",
       "L 220.126829 -217.86492 \n",
       "L 216.847496 -220.121293 \n",
       "L 213.568154 -222.055392 \n",
       "L 210.288812 -223.805934 \n",
       "L 207.00948 -225.510785 \n",
       "L 203.730137 -227.320884 \n",
       "L 200.450795 -229.735974 \n",
       "L 197.171463 -234.147057 \n",
       "L 193.892121 -238.899088 \n",
       "L 190.612778 -243.56525 \n",
       "L 187.333446 -248.078463 \n",
       "L 184.054104 -252.39393 \n",
       "L 180.774762 -256.473091 \n",
       "L 177.495429 -260.28092 \n",
       "L 174.216087 -263.788375 \n",
       "L 170.936745 -266.973817 \n",
       "L 167.657412 -269.828948 \n",
       "L 164.37807 -272.405417 \n",
       "L 161.098728 -275.386211 \n",
       "L 157.819395 -279.224358 \n",
       "L 154.540053 -282.77672 \n",
       "L 151.260711 -285.776038 \n",
       "L 147.981379 -288.096573 \n",
       "L 144.702037 -289.643578 \n",
       "L 141.422694 -290.343375 \n",
       "L 138.143362 -290.143985 \n",
       "L 134.86402 -289.016409 \n",
       "L 131.584682 -286.957311 \n",
       "L 128.305345 -283.98675 \n",
       "L 125.026003 -280.155819 \n",
       "L 121.746666 -275.568988 \n",
       "L 118.467328 -271.138584 \n",
       "L 115.187986 -268.535294 \n",
       "L 111.908649 -265.880708 \n",
       "L 108.629311 -262.963898 \n",
       "L 105.349969 -259.766145 \n",
       "L 102.070632 -256.282301 \n",
       "L 98.791295 -252.513184 \n",
       "L 95.511955 -248.465171 \n",
       "L 92.232615 -244.148527 \n",
       "L 88.953278 -239.579763 \n",
       "L 85.673938 -234.780882 \n",
       "L 82.394598 -229.78011 \n",
       "L 79.115261 -224.612234 \n",
       "L 75.835921 -219.317479 \n",
       "L 72.556583 -213.940719 \n",
       "L 69.277244 -208.532229 \n",
       "L 65.997905 -203.14691 \n",
       "L 62.718566 -197.851935 \n",
       "L 59.439227 -193.227445 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pc18e2bc6c3)\">\n",
       "     <use xlink:href=\"#mc8e0914250\" x=\"0\" y=\"322.539375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_13\">\n",
       "    <defs>\n",
       "     <path id=\"mb7af837a23\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pc18e2bc6c3)\">\n",
       "     <use xlink:href=\"#mb7af837a23\" x=\"361.243318\" y=\"47.983239\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb7af837a23\" x=\"162.151989\" y=\"48.888072\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb7af837a23\" x=\"119.149308\" y=\"51.312278\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb7af837a23\" x=\"262.758248\" y=\"200.902882\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb7af837a23\" x=\"59.439227\" y=\"129.934746\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb7af837a23\" x=\"384.093773\" y=\"89.882762\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb7af837a23\" x=\"334.903698\" y=\"131.15123\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb7af837a23\" x=\"200.450795\" y=\"93.427311\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <path d=\"M 59.439227 129.932244 \n",
       "L 62.718566 128.243077 \n",
       "L 65.997905 126.014355 \n",
       "L 69.277244 123.262486 \n",
       "L 72.556583 120.012381 \n",
       "L 75.835921 116.297236 \n",
       "L 79.115261 112.158287 \n",
       "L 82.394598 107.644108 \n",
       "L 85.673938 102.810346 \n",
       "L 88.953278 97.718633 \n",
       "L 92.232615 92.435866 \n",
       "L 95.511955 87.032916 \n",
       "L 98.791295 81.58384 \n",
       "L 102.070632 76.164407 \n",
       "L 105.349969 70.850892 \n",
       "L 108.629311 65.718807 \n",
       "L 111.908649 60.841287 \n",
       "L 115.187986 56.288108 \n",
       "L 118.467328 52.124067 \n",
       "L 121.746666 48.407868 \n",
       "L 125.026003 45.190963 \n",
       "L 128.305345 42.516361 \n",
       "L 131.584682 40.417888 \n",
       "L 134.86402 38.919332 \n",
       "L 138.143362 38.033967 \n",
       "L 141.422694 37.764197 \n",
       "L 144.702037 38.101573 \n",
       "L 147.981379 39.026851 \n",
       "L 151.260711 40.510613 \n",
       "L 154.540053 42.513886 \n",
       "L 157.819395 44.989315 \n",
       "L 161.098728 47.882278 \n",
       "L 164.37807 51.132597 \n",
       "L 167.657412 54.67613 \n",
       "L 170.936745 58.446884 \n",
       "L 174.216087 62.378899 \n",
       "L 177.495429 66.408547 \n",
       "L 180.774762 70.476579 \n",
       "L 184.054104 74.53028 \n",
       "L 187.333446 78.525428 \n",
       "L 190.612778 82.428073 \n",
       "L 193.892121 86.215996 \n",
       "L 197.171463 89.879836 \n",
       "L 200.450795 93.423908 \n",
       "L 203.730137 96.866276 \n",
       "L 207.00948 100.238716 \n",
       "L 210.288812 103.585588 \n",
       "L 213.568154 106.962807 \n",
       "L 216.847496 110.435611 \n",
       "L 220.126829 114.076158 \n",
       "L 223.406181 117.960747 \n",
       "L 226.685504 122.166091 \n",
       "L 229.964846 126.76605 \n",
       "L 233.244188 131.827217 \n",
       "L 236.523511 137.405428 \n",
       "L 239.802872 143.541537 \n",
       "L 243.082195 150.257415 \n",
       "L 246.361537 157.553386 \n",
       "L 249.640879 165.404628 \n",
       "L 252.920222 173.759543 \n",
       "L 256.199564 182.538163 \n",
       "L 259.478887 191.632073 \n",
       "L 262.758248 200.905113 \n",
       "L 266.037571 210.195071 \n",
       "L 269.316913 219.316862 \n",
       "L 272.596255 228.066534 \n",
       "L 275.875578 236.226981 \n",
       "L 279.15494 243.572559 \n",
       "L 282.434262 249.878332 \n",
       "L 285.713605 254.926066 \n",
       "L 288.992947 258.511914 \n",
       "L 292.272289 260.455373 \n",
       "L 295.551631 260.606307 \n",
       "L 298.830954 258.852142 \n",
       "L 302.110315 255.124219 \n",
       "L 305.389638 249.40367 \n",
       "L 308.66898 241.723308 \n",
       "L 311.948322 232.171519 \n",
       "L 315.227645 220.891908 \n",
       "L 318.507007 208.082439 \n",
       "L 321.78633 193.989281 \n",
       "L 325.065672 178.903914 \n",
       "L 328.345014 163.155511 \n",
       "L 331.624356 147.102016 \n",
       "L 334.903698 131.118543 \n",
       "L 338.183021 115.589295 \n",
       "L 341.462363 100.892025 \n",
       "L 344.741705 87.391085 \n",
       "L 348.021048 75.424776 \n",
       "L 351.30039 65.290192 \n",
       "L 354.579713 57.23727 \n",
       "L 357.859055 51.46368 \n",
       "L 361.138397 48.106956 \n",
       "L 364.417739 47.23469 \n",
       "L 367.697081 48.850568 \n",
       "L 370.976423 52.888923 \n",
       "L 374.255766 59.220933 \n",
       "L 377.535088 67.661241 \n",
       "L 380.814431 77.965185 \n",
       "L 384.093773 89.850164 \n",
       "\" clip-path=\"url(#pc18e2bc6c3)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 59.439227 129.934746 \n",
       "L 62.718566 124.576496 \n",
       "L 65.997905 119.238129 \n",
       "L 69.277244 113.939442 \n",
       "L 72.556583 108.700162 \n",
       "L 75.835921 103.539793 \n",
       "L 79.115261 98.477652 \n",
       "L 82.394598 93.532716 \n",
       "L 85.673938 88.723585 \n",
       "L 88.953278 84.06845 \n",
       "L 92.232615 79.584974 \n",
       "L 95.511955 75.290269 \n",
       "L 98.791295 71.200827 \n",
       "L 102.070632 67.332461 \n",
       "L 105.349969 63.700237 \n",
       "L 108.629311 60.318469 \n",
       "L 111.908649 57.200615 \n",
       "L 115.187986 54.359259 \n",
       "L 118.467328 51.80605 \n",
       "L 121.746666 49.551688 \n",
       "L 125.026003 47.605873 \n",
       "L 128.305345 45.977253 \n",
       "L 131.584682 44.673419 \n",
       "L 134.86402 43.700868 \n",
       "L 138.143362 43.064964 \n",
       "L 141.422694 42.769939 \n",
       "L 144.702037 42.818865 \n",
       "L 147.981379 43.213621 \n",
       "L 151.260711 43.954903 \n",
       "L 154.540053 45.042215 \n",
       "L 157.819395 46.473839 \n",
       "L 161.098728 48.246833 \n",
       "L 164.37807 50.357072 \n",
       "L 167.657412 52.79917 \n",
       "L 170.936745 55.566556 \n",
       "L 174.216087 58.65143 \n",
       "L 177.495429 62.044783 \n",
       "L 180.774762 65.736402 \n",
       "L 184.054104 69.714859 \n",
       "L 187.333446 73.967579 \n",
       "L 190.612778 78.480732 \n",
       "L 193.892121 83.239372 \n",
       "L 197.171463 88.227324 \n",
       "L 200.450795 93.427311 \n",
       "L 203.730137 98.820844 \n",
       "L 207.00948 104.388266 \n",
       "L 210.288812 110.108778 \n",
       "L 213.568154 115.960442 \n",
       "L 216.847496 121.920102 \n",
       "L 220.126829 127.963484 \n",
       "L 223.406181 134.065131 \n",
       "L 226.685504 140.19835 \n",
       "L 229.964846 146.335338 \n",
       "L 233.244188 152.447063 \n",
       "L 236.523511 158.503129 \n",
       "L 239.802872 164.472181 \n",
       "L 243.082195 170.321279 \n",
       "L 246.361537 176.016491 \n",
       "L 249.640879 181.52245 \n",
       "L 252.920222 186.802552 \n",
       "L 256.199564 191.818971 \n",
       "L 259.478887 196.532517 \n",
       "L 262.758248 200.902882 \n",
       "L 266.037571 204.888511 \n",
       "L 269.316913 208.446812 \n",
       "L 272.596255 211.534188 \n",
       "L 275.875578 214.106311 \n",
       "L 279.15494 216.118202 \n",
       "L 282.434262 217.52463 \n",
       "L 285.713605 218.280439 \n",
       "L 288.992947 218.341029 \n",
       "L 292.272289 217.662937 \n",
       "L 295.551631 216.20463 \n",
       "L 298.830954 213.92736 \n",
       "L 302.110315 210.796167 \n",
       "L 305.389638 206.7816 \n",
       "L 308.66898 201.860656 \n",
       "L 311.948322 196.019201 \n",
       "L 315.227645 189.25401 \n",
       "L 318.507007 181.574987 \n",
       "L 321.78633 173.008528 \n",
       "L 325.065672 163.600334 \n",
       "L 328.345014 153.419138 \n",
       "L 331.624356 142.560604 \n",
       "L 334.903698 131.15123 \n",
       "L 338.183021 119.352476 \n",
       "L 341.462363 107.36473 \n",
       "L 344.741705 95.430459 \n",
       "L 348.021048 83.836841 \n",
       "L 351.30039 72.916755 \n",
       "L 354.579713 63.047032 \n",
       "L 357.859055 54.64382 \n",
       "L 361.138397 48.154123 \n",
       "L 364.417739 44.040521 \n",
       "L 367.697081 42.759977 \n",
       "L 370.976423 44.733794 \n",
       "L 374.255766 50.308298 \n",
       "L 377.535088 59.705856 \n",
       "L 380.814431 72.966471 \n",
       "L 384.093773 89.882762 \n",
       "\" clip-path=\"url(#pc18e2bc6c3)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 43.2065 262.316916 \n",
       "L 43.2065 42.747806 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 59.439227 286.212 \n",
       "L 384.093773 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_15\">\n",
       "    <!-- N=4, psi=1.96 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(191.87975 14.1) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2c\" d=\"M 569 0 \n",
       "L 569 641 \n",
       "L 1209 641 \n",
       "L 1209 0 \n",
       "Q 1209 -353 1084 -570 \n",
       "Q 959 -788 688 -906 \n",
       "L 531 -666 \n",
       "Q 709 -588 793 -436 \n",
       "Q 878 -284 888 0 \n",
       "L 569 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-34\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-2c\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"214.013672\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"241.796875\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"297.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"347.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"369.628906\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"428.027344\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"483.642578\"/>\n",
       "     <use xlink:href=\"#ArialMT-39\" x=\"511.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-36\" x=\"567.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_16\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#mb7af837a23\" x=\"59.9265\" y=\"220.007125\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_16\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 223.087125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_17\">\n",
       "     <path d=\"M 51.1265 232.591125 \n",
       "L 59.9265 232.591125 \n",
       "L 68.7265 232.591125 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 235.671125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 51.1265 249.828125 \n",
       "L 68.7265 249.828125 \n",
       "L 68.7265 243.668125 \n",
       "L 51.1265 243.668125 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 249.828125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 51.1265 263.996125 \n",
       "L 68.7265 263.996125 \n",
       "L 68.7265 257.836125 \n",
       "L 51.1265 257.836125 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 263.996125) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_18\">\n",
       "     <path d=\"M 51.1265 273.463 \n",
       "L 59.9265 273.463 \n",
       "L 68.7265 273.463 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 276.543) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <defs>\n",
       "       <path id=\"md191d61e41\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#md191d61e41\" x=\"400.3265\" y=\"241.525394\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_21\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 244.674831) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md191d61e41\" x=\"400.3265\" y=\"192.12451\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 195.273948) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md191d61e41\" x=\"400.3265\" y=\"142.723627\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 145.873065) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md191d61e41\" x=\"400.3265\" y=\"93.322744\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 96.472182) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md191d61e41\" x=\"400.3265\" y=\"43.921861\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 47.071299) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_26\">\n",
       "     <!-- Maximum Upper Interval -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(429.531375 205.43475) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4d\" d=\"M 475 0 \n",
       "L 475 4581 \n",
       "L 1388 4581 \n",
       "L 2472 1338 \n",
       "Q 2622 884 2691 659 \n",
       "Q 2769 909 2934 1394 \n",
       "L 4031 4581 \n",
       "L 4847 4581 \n",
       "L 4847 0 \n",
       "L 4263 0 \n",
       "L 4263 3834 \n",
       "L 2931 0 \n",
       "L 2384 0 \n",
       "L 1059 3900 \n",
       "L 1059 0 \n",
       "L 475 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-78\" d=\"M 47 0 \n",
       "L 1259 1725 \n",
       "L 138 3319 \n",
       "L 841 3319 \n",
       "L 1350 2541 \n",
       "Q 1494 2319 1581 2169 \n",
       "Q 1719 2375 1834 2534 \n",
       "L 2394 3319 \n",
       "L 3066 3319 \n",
       "L 1919 1756 \n",
       "L 3153 0 \n",
       "L 2463 0 \n",
       "L 1781 1031 \n",
       "L 1600 1309 \n",
       "L 728 0 \n",
       "L 47 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-55\" d=\"M 3500 4581 \n",
       "L 4106 4581 \n",
       "L 4106 1934 \n",
       "Q 4106 1244 3950 837 \n",
       "Q 3794 431 3386 176 \n",
       "Q 2978 -78 2316 -78 \n",
       "Q 1672 -78 1262 144 \n",
       "Q 853 366 678 786 \n",
       "Q 503 1206 503 1934 \n",
       "L 503 4581 \n",
       "L 1109 4581 \n",
       "L 1109 1938 \n",
       "Q 1109 1341 1220 1058 \n",
       "Q 1331 775 1601 622 \n",
       "Q 1872 469 2263 469 \n",
       "Q 2931 469 3215 772 \n",
       "Q 3500 1075 3500 1938 \n",
       "L 3500 4581 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4d\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "      <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"188.916016\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"211.132812\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"294.433594\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"350.048828\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"433.349609\"/>\n",
       "      <use xlink:href=\"#ArialMT-55\" x=\"461.132812\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" x=\"533.349609\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" x=\"588.964844\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"644.580078\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"700.195312\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"733.496094\"/>\n",
       "      <use xlink:href=\"#ArialMT-49\" x=\"761.279297\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"789.0625\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.677734\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"872.460938\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"928.076172\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"961.376953\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"1011.376953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6c\" x=\"1066.992188\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_24\">\n",
       "    <path d=\"M 59.439227 141.517051 \n",
       "L 62.718566 136.209921 \n",
       "L 65.997905 130.30838 \n",
       "L 69.277244 124.304829 \n",
       "L 72.556583 118.266933 \n",
       "L 75.835921 112.254537 \n",
       "L 79.115261 106.323551 \n",
       "L 82.394598 100.524321 \n",
       "L 85.673938 94.90238 \n",
       "L 88.953278 89.497427 \n",
       "L 92.232615 84.342093 \n",
       "L 95.511955 79.462275 \n",
       "L 98.791295 74.877934 \n",
       "L 102.070632 70.60227 \n",
       "L 105.349969 66.644385 \n",
       "L 108.629311 63.007706 \n",
       "L 111.908649 59.690482 \n",
       "L 115.187986 56.682983 \n",
       "L 118.467328 53.836108 \n",
       "L 121.746666 48.780159 \n",
       "L 125.026003 43.61336 \n",
       "L 128.305345 39.318571 \n",
       "L 131.584682 35.991583 \n",
       "L 134.86402 33.685516 \n",
       "L 138.143362 32.421647 \n",
       "L 141.422694 32.196 \n",
       "L 144.702037 32.976418 \n",
       "L 147.981379 34.70552 \n",
       "L 151.260711 37.302405 \n",
       "L 154.540053 40.6645 \n",
       "L 157.819395 44.662237 \n",
       "L 161.098728 49.056225 \n",
       "L 164.37807 52.365545 \n",
       "L 167.657412 55.228314 \n",
       "L 170.936745 58.443137 \n",
       "L 174.216087 62.035697 \n",
       "L 177.495429 65.989438 \n",
       "L 180.774762 70.277389 \n",
       "L 184.054104 74.865812 \n",
       "L 187.333446 79.715219 \n",
       "L 190.612778 84.783295 \n",
       "L 193.892121 90.02341 \n",
       "L 197.171463 95.376242 \n",
       "L 200.450795 100.446674 \n",
       "L 203.730137 103.051563 \n",
       "L 207.00948 105.090562 \n",
       "L 210.288812 107.034059 \n",
       "L 213.568154 109.034408 \n",
       "L 216.847496 111.241634 \n",
       "L 220.126829 113.809127 \n",
       "L 223.406181 116.888779 \n",
       "L 226.685504 120.625154 \n",
       "L 229.964846 125.148882 \n",
       "L 233.244188 130.570289 \n",
       "L 236.523511 136.974319 \n",
       "L 239.802872 144.414266 \n",
       "L 243.082195 152.907446 \n",
       "L 246.361537 162.431891 \n",
       "L 249.640879 172.923741 \n",
       "L 252.920222 184.27571 \n",
       "L 256.199564 196.336626 \n",
       "L 259.478887 208.905271 \n",
       "L 262.758248 221.354864 \n",
       "L 266.037571 229.768777 \n",
       "L 269.316913 237.636622 \n",
       "L 272.596255 245.203243 \n",
       "L 275.875578 252.305312 \n",
       "L 279.15494 258.75212 \n",
       "L 282.434262 264.34266 \n",
       "L 285.713605 268.871147 \n",
       "L 288.992947 272.133748 \n",
       "L 292.272289 273.939329 \n",
       "L 295.551631 274.116 \n",
       "L 298.830954 272.519998 \n",
       "L 302.110315 269.043955 \n",
       "L 305.389638 263.624479 \n",
       "L 308.66898 256.246591 \n",
       "L 311.948322 246.94958 \n",
       "L 315.227645 235.830075 \n",
       "L 318.507007 223.044289 \n",
       "L 321.78633 208.801636 \n",
       "L 325.065672 193.363506 \n",
       "L 328.345014 177.039959 \n",
       "L 331.624356 160.160263 \n",
       "L 334.903698 142.850807 \n",
       "L 338.183021 124.983989 \n",
       "L 341.462363 107.982519 \n",
       "L 344.741705 92.545084 \n",
       "L 348.021048 79.054862 \n",
       "L 351.30039 67.822684 \n",
       "L 354.579713 59.091857 \n",
       "L 357.859055 52.999464 \n",
       "L 361.138397 49.46515 \n",
       "L 364.417739 48.271659 \n",
       "L 367.697081 49.703598 \n",
       "L 370.976423 53.956046 \n",
       "L 374.255766 60.97007 \n",
       "L 377.535088 70.603931 \n",
       "L 380.814431 82.619268 \n",
       "L 384.093773 96.425234 \n",
       "\" clip-path=\"url(#pc18e2bc6c3)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_25\">\n",
       "    <path d=\"M 141.422694 43.921861 \n",
       "L 141.422694 43.803418 \n",
       "L 141.422694 43.684975 \n",
       "L 141.422694 43.566532 \n",
       "L 141.422694 43.448089 \n",
       "L 141.422694 43.329646 \n",
       "L 141.422694 43.211203 \n",
       "L 141.422694 43.09276 \n",
       "L 141.422694 42.974317 \n",
       "L 141.422694 42.855874 \n",
       "L 141.422694 42.737431 \n",
       "L 141.422694 42.618988 \n",
       "L 141.422694 42.500545 \n",
       "L 141.422694 42.382102 \n",
       "L 141.422694 42.263659 \n",
       "L 141.422694 42.145216 \n",
       "L 141.422694 42.026773 \n",
       "L 141.422694 41.90833 \n",
       "L 141.422694 41.789887 \n",
       "L 141.422694 41.671444 \n",
       "L 141.422694 41.553001 \n",
       "L 141.422694 41.434557 \n",
       "L 141.422694 41.316114 \n",
       "L 141.422694 41.197671 \n",
       "L 141.422694 41.079228 \n",
       "L 141.422694 40.960785 \n",
       "L 141.422694 40.842342 \n",
       "L 141.422694 40.723899 \n",
       "L 141.422694 40.605456 \n",
       "L 141.422694 40.487013 \n",
       "L 141.422694 40.36857 \n",
       "L 141.422694 40.250127 \n",
       "L 141.422694 40.131684 \n",
       "L 141.422694 40.013241 \n",
       "L 141.422694 39.894798 \n",
       "L 141.422694 39.776355 \n",
       "L 141.422694 39.657912 \n",
       "L 141.422694 39.539469 \n",
       "L 141.422694 39.421026 \n",
       "L 141.422694 39.302583 \n",
       "L 141.422694 39.18414 \n",
       "L 141.422694 39.065697 \n",
       "L 141.422694 38.947254 \n",
       "L 141.422694 38.828811 \n",
       "L 141.422694 38.710368 \n",
       "L 141.422694 38.591925 \n",
       "L 141.422694 38.473481 \n",
       "L 141.422694 38.355038 \n",
       "L 141.422694 38.236595 \n",
       "L 141.422694 38.118152 \n",
       "L 141.422694 37.999709 \n",
       "L 141.422694 37.881266 \n",
       "L 141.422694 37.762823 \n",
       "L 141.422694 37.64438 \n",
       "L 141.422694 37.525937 \n",
       "L 141.422694 37.407493 \n",
       "L 141.422694 37.289051 \n",
       "L 141.422694 37.170608 \n",
       "L 141.422694 37.052165 \n",
       "L 141.422694 36.933721 \n",
       "L 141.422694 36.815279 \n",
       "L 141.422694 36.696836 \n",
       "L 141.422694 36.578393 \n",
       "L 141.422694 36.459949 \n",
       "L 141.422694 36.341507 \n",
       "L 141.422694 36.223064 \n",
       "L 141.422694 36.10462 \n",
       "L 141.422694 35.986177 \n",
       "L 141.422694 35.867734 \n",
       "L 141.422694 35.749292 \n",
       "L 141.422694 35.630848 \n",
       "L 141.422694 35.512405 \n",
       "L 141.422694 35.393962 \n",
       "L 141.422694 35.27552 \n",
       "L 141.422694 35.157076 \n",
       "L 141.422694 35.038633 \n",
       "L 141.422694 34.92019 \n",
       "L 141.422694 34.801747 \n",
       "L 141.422694 34.683304 \n",
       "L 141.422694 34.564861 \n",
       "L 141.422694 34.446418 \n",
       "L 141.422694 34.327975 \n",
       "L 141.422694 34.209532 \n",
       "L 141.422694 34.091089 \n",
       "L 141.422694 33.972646 \n",
       "L 141.422694 33.854202 \n",
       "L 141.422694 33.73576 \n",
       "L 141.422694 33.617316 \n",
       "L 141.422694 33.498874 \n",
       "L 141.422694 33.38043 \n",
       "L 141.422694 33.261988 \n",
       "L 141.422694 33.143544 \n",
       "L 141.422694 33.025102 \n",
       "L 141.422694 32.906658 \n",
       "L 141.422694 32.788216 \n",
       "L 141.422694 32.669772 \n",
       "L 141.422694 32.551329 \n",
       "L 141.422694 32.432886 \n",
       "L 141.422694 32.314443 \n",
       "L 141.422694 32.196 \n",
       "\" clip-path=\"url(#pc18e2bc6c3)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 43.2065 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 400.3265 286.212 \n",
       "L 400.3265 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 43.2065 286.212 \n",
       "L 400.3265 286.212 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 43.2065 20.1 \n",
       "L 400.3265 20.1 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pc18e2bc6c3\">\n",
       "   <rect x=\"43.2065\" y=\"20.1\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "train_x = torch.from_numpy(X).float()\n",
    "train_y = torch.from_numpy(Y).float()\n",
    "covar_module = ScaleKernel(RBFKernel())\n",
    "model = ExactGP(train_x, train_y)\n",
    "\n",
    "# It is not a good idea to train the model when we don't have enough data\n",
    "# So we fix the hyperparameters to something reasonable\n",
    "model.covar_module.base_kernel.lengthscale = 0.15\n",
    "model.covar_module.outputscale = 4.0\n",
    "model.likelihood.noise = 1e-4\n",
    "model.eval()\n",
    "\n",
    "# Run the algorithm\n",
    "X_design = torch.linspace(0, 1, 100)\n",
    "af_all = maximize(\n",
    "    f,\n",
    "    model,\n",
    "    X_design,\n",
    "    mui,\n",
    "    alpha_params=dict(psi=1.96),\n",
    "    max_it=5,\n",
    "    plot=1\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Questions\n",
    "+ Repeat the main algorithm using MUI for a $\\psi$ that exploits. Does the method converge?\n",
    "+ Repeat the main algorithm using MUI for a $\\psi$ that explores. Does the method converge?"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": []
  }
 ],
 "metadata": {
  "celltoolbar": "Tags",
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.11.6"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 4
}
